#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1225
#define LARGE_STATE_COUNT 9
#define SYMBOL_COUNT 169
#define ALIAS_COUNT 0
#define TOKEN_COUNT 81
#define EXTERNAL_TOKEN_COUNT 8
#define FIELD_COUNT 37
#define MAX_ALIAS_SEQUENCE_LENGTH 6
#define PRODUCTION_ID_COUNT 68

enum ts_symbol_identifiers {
  sym_keyword = 1,
  sym_num_literal = 2,
  sym_signed_num_literal = 3,
  sym_ident = 4,
  sym_raw_enum_tag = 5,
  anon_sym_PIPE = 6,
  anon_sym_default = 7,
  anon_sym_force = 8,
  anon_sym_optional = 9,
  anon_sym_priority = 10,
  anon_sym_doc = 11,
  anon_sym_rec = 12,
  anon_sym_not_exported = 13,
  anon_sym_COLON = 14,
  anon_sym_EQ = 15,
  anon_sym_let = 16,
  anon_sym_COMMA = 17,
  anon_sym_in = 18,
  anon_sym_fun = 19,
  anon_sym_EQ_GT = 20,
  anon_sym_match = 21,
  anon_sym_LBRACE = 22,
  anon_sym_RBRACE = 23,
  anon_sym_if = 24,
  anon_sym_then = 25,
  anon_sym_else = 26,
  anon_sym_forall = 27,
  anon_sym_DOT = 28,
  anon_sym_import = 29,
  anon_sym_Array = 30,
  anon_sym_Dyn = 31,
  anon_sym_SEMI = 32,
  anon_sym_LPAREN = 33,
  anon_sym_RPAREN = 34,
  anon_sym_null = 35,
  anon_sym_LBRACK = 36,
  anon_sym_RBRACK = 37,
  anon_sym_DOT_DOT = 38,
  anon_sym_AT = 39,
  anon_sym__ = 40,
  anon_sym_or = 41,
  anon_sym_QMARK = 42,
  anon_sym_true = 43,
  anon_sym_false = 44,
  anon_sym_PERCENT = 45,
  sym_double_quote = 46,
  sym_str_literal = 47,
  sym_mult_str_literal = 48,
  sym_str_esc_char = 49,
  aux_sym_builtin_token1 = 50,
  anon_sym_PLUS_PLUS = 51,
  anon_sym_STAR = 52,
  anon_sym_SLASH = 53,
  anon_sym_PLUS = 54,
  anon_sym_DASH = 55,
  anon_sym_BANG = 56,
  anon_sym_AMP = 57,
  anon_sym_PIPE_GT = 58,
  anon_sym_LT = 59,
  anon_sym_LT_EQ = 60,
  anon_sym_GT = 61,
  anon_sym_GT_EQ = 62,
  anon_sym_EQ_EQ = 63,
  anon_sym_BANG_EQ = 64,
  anon_sym_AMP_AMP = 65,
  anon_sym_PIPE_PIPE = 66,
  anon_sym_DASH_GT = 67,
  anon_sym_Number = 68,
  anon_sym_Bool = 69,
  anon_sym_String = 70,
  anon_sym_LBRACK_PIPE = 71,
  anon_sym_PIPE_RBRACK = 72,
  sym_multstr_start = 73,
  sym_multstr_end = 74,
  sym__str_start = 75,
  sym__str_end = 76,
  sym_interpolation_start = 77,
  sym_interpolation_end = 78,
  sym_quoted_enum_tag_start = 79,
  sym_comment = 80,
  sym_term = 81,
  sym_annot_atom = 82,
  sym_annot = 83,
  sym_types = 84,
  sym_uni_term = 85,
  sym_let_expr = 86,
  sym_let_binding = 87,
  sym_let_in_block = 88,
  sym_fun_expr = 89,
  sym_match_expr = 90,
  sym_ite_expr = 91,
  sym_annotated_infix_expr = 92,
  sym_forall = 93,
  sym_applicative = 94,
  sym_type_array = 95,
  sym_record_operand = 96,
  sym_record_operation_chain = 97,
  sym_row_tail = 98,
  sym_uni_record = 99,
  sym_atom = 100,
  sym_record_field = 101,
  sym_record_last_field = 102,
  sym_field_path = 103,
  sym_field_path_elem = 104,
  sym_last_field_pat = 105,
  sym_last_elem_pat = 106,
  sym_pattern = 107,
  sym_pattern_fun = 108,
  sym_pattern_or_branch = 109,
  sym_constant_pattern = 110,
  sym_record_pattern = 111,
  sym_array_pattern = 112,
  sym_field_pattern = 113,
  sym_enum_variant_pattern = 114,
  sym_enum_pattern_parens = 115,
  sym_enum_pattern = 116,
  sym_or_pattern_unparens = 117,
  sym_or_pattern_parens = 118,
  sym_or_pattern = 119,
  sym_default_annot = 120,
  sym_bool = 121,
  sym_str_chunks = 122,
  sym_str_chunks_single = 123,
  sym_str_chunks_multi = 124,
  sym_chunk_expr = 125,
  sym_static_string = 126,
  sym_quoted_enum_tag = 127,
  sym_enum_tag = 128,
  sym_enum_variant = 129,
  sym_enum = 130,
  sym_chunk_literal_single = 131,
  sym_chunk_literal_multi = 132,
  sym_percent = 133,
  sym_builtin = 134,
  sym_pattern_guard = 135,
  sym_match_branch = 136,
  sym_infix_b_op_2 = 137,
  sym_infix_b_op_3 = 138,
  sym_infix_b_op_4 = 139,
  sym_infix_u_op_5 = 140,
  sym_infix_b_op_6 = 141,
  sym_infix_b_op_7 = 142,
  sym_infix_b_op_8 = 143,
  sym_infix_lazy_b_op_9 = 144,
  sym_infix_lazy_b_op_10 = 145,
  sym_infix_b_op = 146,
  sym_infix_u_op_or_lazy_b_op = 147,
  sym_infix_op = 148,
  sym_curried_op = 149,
  sym_infix_expr = 150,
  sym_type_builtin = 151,
  sym_type_atom = 152,
  aux_sym_annot_repeat1 = 153,
  aux_sym_let_in_block_repeat1 = 154,
  aux_sym_fun_expr_repeat1 = 155,
  aux_sym_match_expr_repeat1 = 156,
  aux_sym_forall_repeat1 = 157,
  aux_sym_uni_record_repeat1 = 158,
  aux_sym_atom_repeat1 = 159,
  aux_sym_field_path_repeat1 = 160,
  aux_sym_record_pattern_repeat1 = 161,
  aux_sym_array_pattern_repeat1 = 162,
  aux_sym_or_pattern_unparens_repeat1 = 163,
  aux_sym_str_chunks_single_repeat1 = 164,
  aux_sym_str_chunks_multi_repeat1 = 165,
  aux_sym_static_string_repeat1 = 166,
  aux_sym_static_string_repeat2 = 167,
  aux_sym_type_atom_repeat1 = 168,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_keyword] = "keyword",
  [sym_num_literal] = "num_literal",
  [sym_signed_num_literal] = "signed_num_literal",
  [sym_ident] = "ident",
  [sym_raw_enum_tag] = "raw_enum_tag",
  [anon_sym_PIPE] = "|",
  [anon_sym_default] = "default",
  [anon_sym_force] = "force",
  [anon_sym_optional] = "optional",
  [anon_sym_priority] = "priority",
  [anon_sym_doc] = "doc",
  [anon_sym_rec] = "rec",
  [anon_sym_not_exported] = "not_exported",
  [anon_sym_COLON] = ":",
  [anon_sym_EQ] = "=",
  [anon_sym_let] = "let",
  [anon_sym_COMMA] = ",",
  [anon_sym_in] = "in",
  [anon_sym_fun] = "fun",
  [anon_sym_EQ_GT] = "=>",
  [anon_sym_match] = "match",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_if] = "if",
  [anon_sym_then] = "then",
  [anon_sym_else] = "else",
  [anon_sym_forall] = "forall",
  [anon_sym_DOT] = ".",
  [anon_sym_import] = "import",
  [anon_sym_Array] = "Array",
  [anon_sym_Dyn] = "Dyn",
  [anon_sym_SEMI] = ";",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_null] = "null",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_AT] = "@",
  [anon_sym__] = "_",
  [anon_sym_or] = "or",
  [anon_sym_QMARK] = "\?",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [anon_sym_PERCENT] = "%",
  [sym_double_quote] = "double_quote",
  [sym_str_literal] = "str_literal",
  [sym_mult_str_literal] = "mult_str_literal",
  [sym_str_esc_char] = "str_esc_char",
  [aux_sym_builtin_token1] = "builtin_token1",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_BANG] = "!",
  [anon_sym_AMP] = "&",
  [anon_sym_PIPE_GT] = "|>",
  [anon_sym_LT] = "<",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_Number] = "Number",
  [anon_sym_Bool] = "Bool",
  [anon_sym_String] = "String",
  [anon_sym_LBRACK_PIPE] = "[|",
  [anon_sym_PIPE_RBRACK] = "|]",
  [sym_multstr_start] = "multstr_start",
  [sym_multstr_end] = "multstr_end",
  [sym__str_start] = "_str_start",
  [sym__str_end] = "_str_end",
  [sym_interpolation_start] = "interpolation_start",
  [sym_interpolation_end] = "interpolation_end",
  [sym_quoted_enum_tag_start] = "quoted_enum_tag_start",
  [sym_comment] = "comment",
  [sym_term] = "term",
  [sym_annot_atom] = "annot_atom",
  [sym_annot] = "annot",
  [sym_types] = "types",
  [sym_uni_term] = "uni_term",
  [sym_let_expr] = "let_expr",
  [sym_let_binding] = "let_binding",
  [sym_let_in_block] = "let_in_block",
  [sym_fun_expr] = "fun_expr",
  [sym_match_expr] = "match_expr",
  [sym_ite_expr] = "ite_expr",
  [sym_annotated_infix_expr] = "annotated_infix_expr",
  [sym_forall] = "forall",
  [sym_applicative] = "applicative",
  [sym_type_array] = "type_array",
  [sym_record_operand] = "record_operand",
  [sym_record_operation_chain] = "record_operation_chain",
  [sym_row_tail] = "row_tail",
  [sym_uni_record] = "uni_record",
  [sym_atom] = "atom",
  [sym_record_field] = "record_field",
  [sym_record_last_field] = "record_last_field",
  [sym_field_path] = "field_path",
  [sym_field_path_elem] = "field_path_elem",
  [sym_last_field_pat] = "last_field_pat",
  [sym_last_elem_pat] = "last_elem_pat",
  [sym_pattern] = "pattern",
  [sym_pattern_fun] = "pattern_fun",
  [sym_pattern_or_branch] = "pattern_or_branch",
  [sym_constant_pattern] = "constant_pattern",
  [sym_record_pattern] = "record_pattern",
  [sym_array_pattern] = "array_pattern",
  [sym_field_pattern] = "field_pattern",
  [sym_enum_variant_pattern] = "enum_variant_pattern",
  [sym_enum_pattern_parens] = "enum_pattern_parens",
  [sym_enum_pattern] = "enum_pattern",
  [sym_or_pattern_unparens] = "or_pattern_unparens",
  [sym_or_pattern_parens] = "or_pattern_parens",
  [sym_or_pattern] = "or_pattern",
  [sym_default_annot] = "default_annot",
  [sym_bool] = "bool",
  [sym_str_chunks] = "str_chunks",
  [sym_str_chunks_single] = "str_chunks_single",
  [sym_str_chunks_multi] = "str_chunks_multi",
  [sym_chunk_expr] = "chunk_expr",
  [sym_static_string] = "static_string",
  [sym_quoted_enum_tag] = "quoted_enum_tag",
  [sym_enum_tag] = "enum_tag",
  [sym_enum_variant] = "enum_variant",
  [sym_enum] = "enum",
  [sym_chunk_literal_single] = "chunk_literal_single",
  [sym_chunk_literal_multi] = "chunk_literal_multi",
  [sym_percent] = "percent",
  [sym_builtin] = "builtin",
  [sym_pattern_guard] = "pattern_guard",
  [sym_match_branch] = "match_branch",
  [sym_infix_b_op_2] = "infix_b_op_2",
  [sym_infix_b_op_3] = "infix_b_op_3",
  [sym_infix_b_op_4] = "infix_b_op_4",
  [sym_infix_u_op_5] = "infix_u_op_5",
  [sym_infix_b_op_6] = "infix_b_op_6",
  [sym_infix_b_op_7] = "infix_b_op_7",
  [sym_infix_b_op_8] = "infix_b_op_8",
  [sym_infix_lazy_b_op_9] = "infix_lazy_b_op_9",
  [sym_infix_lazy_b_op_10] = "infix_lazy_b_op_10",
  [sym_infix_b_op] = "infix_b_op",
  [sym_infix_u_op_or_lazy_b_op] = "infix_u_op_or_lazy_b_op",
  [sym_infix_op] = "infix_op",
  [sym_curried_op] = "curried_op",
  [sym_infix_expr] = "infix_expr",
  [sym_type_builtin] = "type_builtin",
  [sym_type_atom] = "type_atom",
  [aux_sym_annot_repeat1] = "annot_repeat1",
  [aux_sym_let_in_block_repeat1] = "let_in_block_repeat1",
  [aux_sym_fun_expr_repeat1] = "fun_expr_repeat1",
  [aux_sym_match_expr_repeat1] = "match_expr_repeat1",
  [aux_sym_forall_repeat1] = "forall_repeat1",
  [aux_sym_uni_record_repeat1] = "uni_record_repeat1",
  [aux_sym_atom_repeat1] = "atom_repeat1",
  [aux_sym_field_path_repeat1] = "field_path_repeat1",
  [aux_sym_record_pattern_repeat1] = "record_pattern_repeat1",
  [aux_sym_array_pattern_repeat1] = "array_pattern_repeat1",
  [aux_sym_or_pattern_unparens_repeat1] = "or_pattern_unparens_repeat1",
  [aux_sym_str_chunks_single_repeat1] = "str_chunks_single_repeat1",
  [aux_sym_str_chunks_multi_repeat1] = "str_chunks_multi_repeat1",
  [aux_sym_static_string_repeat1] = "static_string_repeat1",
  [aux_sym_static_string_repeat2] = "static_string_repeat2",
  [aux_sym_type_atom_repeat1] = "type_atom_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_keyword] = sym_keyword,
  [sym_num_literal] = sym_num_literal,
  [sym_signed_num_literal] = sym_signed_num_literal,
  [sym_ident] = sym_ident,
  [sym_raw_enum_tag] = sym_raw_enum_tag,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_force] = anon_sym_force,
  [anon_sym_optional] = anon_sym_optional,
  [anon_sym_priority] = anon_sym_priority,
  [anon_sym_doc] = anon_sym_doc,
  [anon_sym_rec] = anon_sym_rec,
  [anon_sym_not_exported] = anon_sym_not_exported,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_let] = anon_sym_let,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_fun] = anon_sym_fun,
  [anon_sym_EQ_GT] = anon_sym_EQ_GT,
  [anon_sym_match] = anon_sym_match,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_then] = anon_sym_then,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_forall] = anon_sym_forall,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_Array] = anon_sym_Array,
  [anon_sym_Dyn] = anon_sym_Dyn,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_null] = anon_sym_null,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym__] = anon_sym__,
  [anon_sym_or] = anon_sym_or,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [sym_double_quote] = sym_double_quote,
  [sym_str_literal] = sym_str_literal,
  [sym_mult_str_literal] = sym_mult_str_literal,
  [sym_str_esc_char] = sym_str_esc_char,
  [aux_sym_builtin_token1] = aux_sym_builtin_token1,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_PIPE_GT] = anon_sym_PIPE_GT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_Number] = anon_sym_Number,
  [anon_sym_Bool] = anon_sym_Bool,
  [anon_sym_String] = anon_sym_String,
  [anon_sym_LBRACK_PIPE] = anon_sym_LBRACK_PIPE,
  [anon_sym_PIPE_RBRACK] = anon_sym_PIPE_RBRACK,
  [sym_multstr_start] = sym_multstr_start,
  [sym_multstr_end] = sym_multstr_end,
  [sym__str_start] = sym__str_start,
  [sym__str_end] = sym__str_end,
  [sym_interpolation_start] = sym_interpolation_start,
  [sym_interpolation_end] = sym_interpolation_end,
  [sym_quoted_enum_tag_start] = sym_quoted_enum_tag_start,
  [sym_comment] = sym_comment,
  [sym_term] = sym_term,
  [sym_annot_atom] = sym_annot_atom,
  [sym_annot] = sym_annot,
  [sym_types] = sym_types,
  [sym_uni_term] = sym_uni_term,
  [sym_let_expr] = sym_let_expr,
  [sym_let_binding] = sym_let_binding,
  [sym_let_in_block] = sym_let_in_block,
  [sym_fun_expr] = sym_fun_expr,
  [sym_match_expr] = sym_match_expr,
  [sym_ite_expr] = sym_ite_expr,
  [sym_annotated_infix_expr] = sym_annotated_infix_expr,
  [sym_forall] = sym_forall,
  [sym_applicative] = sym_applicative,
  [sym_type_array] = sym_type_array,
  [sym_record_operand] = sym_record_operand,
  [sym_record_operation_chain] = sym_record_operation_chain,
  [sym_row_tail] = sym_row_tail,
  [sym_uni_record] = sym_uni_record,
  [sym_atom] = sym_atom,
  [sym_record_field] = sym_record_field,
  [sym_record_last_field] = sym_record_last_field,
  [sym_field_path] = sym_field_path,
  [sym_field_path_elem] = sym_field_path_elem,
  [sym_last_field_pat] = sym_last_field_pat,
  [sym_last_elem_pat] = sym_last_elem_pat,
  [sym_pattern] = sym_pattern,
  [sym_pattern_fun] = sym_pattern_fun,
  [sym_pattern_or_branch] = sym_pattern_or_branch,
  [sym_constant_pattern] = sym_constant_pattern,
  [sym_record_pattern] = sym_record_pattern,
  [sym_array_pattern] = sym_array_pattern,
  [sym_field_pattern] = sym_field_pattern,
  [sym_enum_variant_pattern] = sym_enum_variant_pattern,
  [sym_enum_pattern_parens] = sym_enum_pattern_parens,
  [sym_enum_pattern] = sym_enum_pattern,
  [sym_or_pattern_unparens] = sym_or_pattern_unparens,
  [sym_or_pattern_parens] = sym_or_pattern_parens,
  [sym_or_pattern] = sym_or_pattern,
  [sym_default_annot] = sym_default_annot,
  [sym_bool] = sym_bool,
  [sym_str_chunks] = sym_str_chunks,
  [sym_str_chunks_single] = sym_str_chunks_single,
  [sym_str_chunks_multi] = sym_str_chunks_multi,
  [sym_chunk_expr] = sym_chunk_expr,
  [sym_static_string] = sym_static_string,
  [sym_quoted_enum_tag] = sym_quoted_enum_tag,
  [sym_enum_tag] = sym_enum_tag,
  [sym_enum_variant] = sym_enum_variant,
  [sym_enum] = sym_enum,
  [sym_chunk_literal_single] = sym_chunk_literal_single,
  [sym_chunk_literal_multi] = sym_chunk_literal_multi,
  [sym_percent] = sym_percent,
  [sym_builtin] = sym_builtin,
  [sym_pattern_guard] = sym_pattern_guard,
  [sym_match_branch] = sym_match_branch,
  [sym_infix_b_op_2] = sym_infix_b_op_2,
  [sym_infix_b_op_3] = sym_infix_b_op_3,
  [sym_infix_b_op_4] = sym_infix_b_op_4,
  [sym_infix_u_op_5] = sym_infix_u_op_5,
  [sym_infix_b_op_6] = sym_infix_b_op_6,
  [sym_infix_b_op_7] = sym_infix_b_op_7,
  [sym_infix_b_op_8] = sym_infix_b_op_8,
  [sym_infix_lazy_b_op_9] = sym_infix_lazy_b_op_9,
  [sym_infix_lazy_b_op_10] = sym_infix_lazy_b_op_10,
  [sym_infix_b_op] = sym_infix_b_op,
  [sym_infix_u_op_or_lazy_b_op] = sym_infix_u_op_or_lazy_b_op,
  [sym_infix_op] = sym_infix_op,
  [sym_curried_op] = sym_curried_op,
  [sym_infix_expr] = sym_infix_expr,
  [sym_type_builtin] = sym_type_builtin,
  [sym_type_atom] = sym_type_atom,
  [aux_sym_annot_repeat1] = aux_sym_annot_repeat1,
  [aux_sym_let_in_block_repeat1] = aux_sym_let_in_block_repeat1,
  [aux_sym_fun_expr_repeat1] = aux_sym_fun_expr_repeat1,
  [aux_sym_match_expr_repeat1] = aux_sym_match_expr_repeat1,
  [aux_sym_forall_repeat1] = aux_sym_forall_repeat1,
  [aux_sym_uni_record_repeat1] = aux_sym_uni_record_repeat1,
  [aux_sym_atom_repeat1] = aux_sym_atom_repeat1,
  [aux_sym_field_path_repeat1] = aux_sym_field_path_repeat1,
  [aux_sym_record_pattern_repeat1] = aux_sym_record_pattern_repeat1,
  [aux_sym_array_pattern_repeat1] = aux_sym_array_pattern_repeat1,
  [aux_sym_or_pattern_unparens_repeat1] = aux_sym_or_pattern_unparens_repeat1,
  [aux_sym_str_chunks_single_repeat1] = aux_sym_str_chunks_single_repeat1,
  [aux_sym_str_chunks_multi_repeat1] = aux_sym_str_chunks_multi_repeat1,
  [aux_sym_static_string_repeat1] = aux_sym_static_string_repeat1,
  [aux_sym_static_string_repeat2] = aux_sym_static_string_repeat2,
  [aux_sym_type_atom_repeat1] = aux_sym_type_atom_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_num_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_signed_num_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_ident] = {
    .visible = true,
    .named = true,
  },
  [sym_raw_enum_tag] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_force] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_optional] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_priority] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_doc] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rec] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not_exported] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_let] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fun] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_match] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_then] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_forall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Array] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Dyn] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_null] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [sym_double_quote] = {
    .visible = true,
    .named = true,
  },
  [sym_str_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_mult_str_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_str_esc_char] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_builtin_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Number] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Bool] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_String] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [sym_multstr_start] = {
    .visible = true,
    .named = true,
  },
  [sym_multstr_end] = {
    .visible = true,
    .named = true,
  },
  [sym__str_start] = {
    .visible = false,
    .named = true,
  },
  [sym__str_end] = {
    .visible = false,
    .named = true,
  },
  [sym_interpolation_start] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolation_end] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_enum_tag_start] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_term] = {
    .visible = true,
    .named = true,
  },
  [sym_annot_atom] = {
    .visible = true,
    .named = true,
  },
  [sym_annot] = {
    .visible = true,
    .named = true,
  },
  [sym_types] = {
    .visible = true,
    .named = true,
  },
  [sym_uni_term] = {
    .visible = true,
    .named = true,
  },
  [sym_let_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_let_binding] = {
    .visible = true,
    .named = true,
  },
  [sym_let_in_block] = {
    .visible = true,
    .named = true,
  },
  [sym_fun_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_match_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_ite_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_annotated_infix_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_forall] = {
    .visible = true,
    .named = true,
  },
  [sym_applicative] = {
    .visible = true,
    .named = true,
  },
  [sym_type_array] = {
    .visible = true,
    .named = true,
  },
  [sym_record_operand] = {
    .visible = true,
    .named = true,
  },
  [sym_record_operation_chain] = {
    .visible = true,
    .named = true,
  },
  [sym_row_tail] = {
    .visible = true,
    .named = true,
  },
  [sym_uni_record] = {
    .visible = true,
    .named = true,
  },
  [sym_atom] = {
    .visible = true,
    .named = true,
  },
  [sym_record_field] = {
    .visible = true,
    .named = true,
  },
  [sym_record_last_field] = {
    .visible = true,
    .named = true,
  },
  [sym_field_path] = {
    .visible = true,
    .named = true,
  },
  [sym_field_path_elem] = {
    .visible = true,
    .named = true,
  },
  [sym_last_field_pat] = {
    .visible = true,
    .named = true,
  },
  [sym_last_elem_pat] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern_fun] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern_or_branch] = {
    .visible = true,
    .named = true,
  },
  [sym_constant_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_record_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_array_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_field_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_variant_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_pattern_parens] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_or_pattern_unparens] = {
    .visible = true,
    .named = true,
  },
  [sym_or_pattern_parens] = {
    .visible = true,
    .named = true,
  },
  [sym_or_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_default_annot] = {
    .visible = true,
    .named = true,
  },
  [sym_bool] = {
    .visible = true,
    .named = true,
  },
  [sym_str_chunks] = {
    .visible = true,
    .named = true,
  },
  [sym_str_chunks_single] = {
    .visible = true,
    .named = true,
  },
  [sym_str_chunks_multi] = {
    .visible = true,
    .named = true,
  },
  [sym_chunk_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_static_string] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_enum_tag] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_tag] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_variant] = {
    .visible = true,
    .named = true,
  },
  [sym_enum] = {
    .visible = true,
    .named = true,
  },
  [sym_chunk_literal_single] = {
    .visible = true,
    .named = true,
  },
  [sym_chunk_literal_multi] = {
    .visible = true,
    .named = true,
  },
  [sym_percent] = {
    .visible = true,
    .named = true,
  },
  [sym_builtin] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern_guard] = {
    .visible = true,
    .named = true,
  },
  [sym_match_branch] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_b_op_2] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_b_op_3] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_b_op_4] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_u_op_5] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_b_op_6] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_b_op_7] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_b_op_8] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_lazy_b_op_9] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_lazy_b_op_10] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_b_op] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_u_op_or_lazy_b_op] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_op] = {
    .visible = true,
    .named = true,
  },
  [sym_curried_op] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_type_builtin] = {
    .visible = true,
    .named = true,
  },
  [sym_type_atom] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_annot_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_let_in_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fun_expr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_match_expr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_forall_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_uni_record_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_atom_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_path_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_or_pattern_unparens_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_chunks_single_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_chunks_multi_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_static_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_static_string_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_atom_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_alias = 1,
  field_ann = 2,
  field_anns = 3,
  field_arg = 4,
  field_binding = 5,
  field_bindings = 6,
  field_body = 7,
  field_cases = 8,
  field_chunks = 9,
  field_cond = 10,
  field_default = 11,
  field_doc = 12,
  field_end = 13,
  field_fields = 14,
  field_guard = 15,
  field_id = 16,
  field_ids = 17,
  field_last = 18,
  field_meta = 19,
  field_op = 20,
  field_pat = 21,
  field_path = 22,
  field_pats = 23,
  field_patterns = 24,
  field_priority = 25,
  field_rows = 26,
  field_s = 27,
  field_start = 28,
  field_t = 29,
  field_t1 = 30,
  field_t2 = 31,
  field_t_id = 32,
  field_tag = 33,
  field_tail = 34,
  field_terms = 35,
  field_ty = 36,
  field_types = 37,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alias] = "alias",
  [field_ann] = "ann",
  [field_anns] = "anns",
  [field_arg] = "arg",
  [field_binding] = "binding",
  [field_bindings] = "bindings",
  [field_body] = "body",
  [field_cases] = "cases",
  [field_chunks] = "chunks",
  [field_cond] = "cond",
  [field_default] = "default",
  [field_doc] = "doc",
  [field_end] = "end",
  [field_fields] = "fields",
  [field_guard] = "guard",
  [field_id] = "id",
  [field_ids] = "ids",
  [field_last] = "last",
  [field_meta] = "meta",
  [field_op] = "op",
  [field_pat] = "pat",
  [field_path] = "path",
  [field_pats] = "pats",
  [field_patterns] = "patterns",
  [field_priority] = "priority",
  [field_rows] = "rows",
  [field_s] = "s",
  [field_start] = "start",
  [field_t] = "t",
  [field_t1] = "t1",
  [field_t2] = "t2",
  [field_t_id] = "t_id",
  [field_tag] = "tag",
  [field_tail] = "tail",
  [field_terms] = "terms",
  [field_ty] = "ty",
  [field_types] = "types",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 2},
  [2] = {.index = 2, .length = 1},
  [3] = {.index = 3, .length = 1},
  [4] = {.index = 4, .length = 1},
  [5] = {.index = 5, .length = 2},
  [6] = {.index = 7, .length = 2},
  [7] = {.index = 9, .length = 2},
  [8] = {.index = 11, .length = 2},
  [9] = {.index = 13, .length = 2},
  [10] = {.index = 15, .length = 1},
  [11] = {.index = 16, .length = 3},
  [12] = {.index = 19, .length = 1},
  [13] = {.index = 20, .length = 1},
  [14] = {.index = 21, .length = 1},
  [15] = {.index = 22, .length = 2},
  [16] = {.index = 24, .length = 2},
  [17] = {.index = 26, .length = 1},
  [18] = {.index = 27, .length = 2},
  [19] = {.index = 29, .length = 1},
  [20] = {.index = 30, .length = 1},
  [21] = {.index = 31, .length = 1},
  [22] = {.index = 32, .length = 2},
  [23] = {.index = 34, .length = 2},
  [24] = {.index = 36, .length = 1},
  [25] = {.index = 37, .length = 3},
  [26] = {.index = 40, .length = 3},
  [27] = {.index = 43, .length = 3},
  [28] = {.index = 46, .length = 1},
  [29] = {.index = 47, .length = 2},
  [30] = {.index = 49, .length = 2},
  [31] = {.index = 51, .length = 1},
  [32] = {.index = 52, .length = 2},
  [33] = {.index = 54, .length = 2},
  [34] = {.index = 56, .length = 2},
  [35] = {.index = 58, .length = 1},
  [36] = {.index = 59, .length = 2},
  [37] = {.index = 61, .length = 3},
  [38] = {.index = 64, .length = 2},
  [39] = {.index = 66, .length = 2},
  [40] = {.index = 68, .length = 2},
  [41] = {.index = 70, .length = 2},
  [42] = {.index = 72, .length = 1},
  [43] = {.index = 73, .length = 1},
  [44] = {.index = 74, .length = 2},
  [45] = {.index = 76, .length = 3},
  [46] = {.index = 79, .length = 1},
  [47] = {.index = 80, .length = 3},
  [48] = {.index = 83, .length = 2},
  [49] = {.index = 85, .length = 3},
  [50] = {.index = 88, .length = 3},
  [51] = {.index = 91, .length = 2},
  [52] = {.index = 93, .length = 2},
  [53] = {.index = 95, .length = 1},
  [54] = {.index = 96, .length = 3},
  [55] = {.index = 99, .length = 4},
  [56] = {.index = 103, .length = 3},
  [57] = {.index = 106, .length = 3},
  [58] = {.index = 109, .length = 3},
  [59] = {.index = 112, .length = 3},
  [60] = {.index = 115, .length = 4},
  [61] = {.index = 119, .length = 4},
  [62] = {.index = 123, .length = 3},
  [63] = {.index = 126, .length = 3},
  [64] = {.index = 129, .length = 4},
  [65] = {.index = 133, .length = 3},
  [66] = {.index = 136, .length = 4},
  [67] = {.index = 140, .length = 5},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_end, 1},
    {field_start, 0},
  [2] =
    {field_pat, 0},
  [3] =
    {field_path, 0},
  [4] =
    {field_s, 1},
  [5] =
    {field_op, 0},
    {field_t, 1},
  [7] =
    {field_binding, 0},
    {field_t2, 1},
  [9] =
    {field_t1, 0},
    {field_t2, 1},
  [11] =
    {field_arg, 1},
    {field_tag, 0},
  [13] =
    {field_meta, 1},
    {field_t, 0},
  [15] =
    {field_anns, 0},
  [16] =
    {field_chunks, 1},
    {field_end, 2},
    {field_start, 0},
  [19] =
    {field_chunks, 1},
  [20] =
    {field_bindings, 1},
  [21] =
    {field_id, 0},
  [22] =
    {field_pat, 1},
    {field_tag, 0},
  [24] =
    {field_last, 1},
    {field_patterns, 0},
  [26] =
    {field_last, 1},
  [27] =
    {field_ann, 1},
    {field_path, 0},
  [29] =
    {field_fields, 1},
  [30] =
    {field_terms, 1},
  [31] =
    {field_rows, 1},
  [32] =
    {field_id, 2},
    {field_t, 0},
  [34] =
    {field_t, 0},
    {field_t_id, 2},
  [36] =
    {field_ty, 1},
  [37] =
    {field_op, 1},
    {field_t1, 0},
    {field_t2, 2},
  [40] =
    {field_end, 2},
    {field_start, 0},
    {field_t, 1},
  [43] =
    {field_alias, 0},
    {field_alias, 1},
    {field_pat, 2},
  [46] =
    {field_bindings, 2},
  [47] =
    {field_anns, 1},
    {field_id, 0},
  [49] =
    {field_default, 1},
    {field_id, 0},
  [51] =
    {field_patterns, 1},
  [52] =
    {field_bindings, 1},
    {field_bindings, 2},
  [54] =
    {field_pat, 0},
    {field_t1, 2},
  [56] =
    {field_pats, 1},
    {field_t, 3},
  [58] =
    {field_cases, 2},
  [59] =
    {field_tail, 1},
    {field_tail, 2},
  [61] =
    {field_path, 0},
    {field_t, 1},
    {field_t, 2},
  [64] =
    {field_fields, 1},
    {field_last, 2},
  [66] =
    {field_ids, 1},
    {field_ty, 3},
  [68] =
    {field_terms, 1},
    {field_terms, 2},
  [70] =
    {field_rows, 1},
    {field_rows, 2},
  [72] =
    {field_priority, 2},
  [73] =
    {field_doc, 2},
  [74] =
    {field_bindings, 2},
    {field_bindings, 3},
  [76] =
    {field_id, 0},
    {field_pat, 1},
    {field_pat, 2},
  [79] =
    {field_t, 1},
  [80] =
    {field_anns, 1},
    {field_default, 2},
    {field_id, 0},
  [83] =
    {field_last, 2},
    {field_patterns, 1},
  [85] =
    {field_bindings, 1},
    {field_bindings, 2},
    {field_bindings, 3},
  [88] =
    {field_meta, 1},
    {field_pat, 0},
    {field_t1, 3},
  [91] =
    {field_body, 2},
    {field_pat, 0},
  [93] =
    {field_cases, 2},
    {field_cases, 3},
  [95] =
    {field_types, 3},
  [96] =
    {field_last, 1},
    {field_tail, 2},
    {field_tail, 3},
  [99] =
    {field_ann, 1},
    {field_path, 0},
    {field_t, 2},
    {field_t, 3},
  [103] =
    {field_fields, 1},
    {field_tail, 2},
    {field_tail, 3},
  [106] =
    {field_terms, 1},
    {field_terms, 2},
    {field_terms, 3},
  [109] =
    {field_rows, 1},
    {field_tail, 2},
    {field_tail, 3},
  [112] =
    {field_bindings, 2},
    {field_bindings, 3},
    {field_bindings, 4},
  [115] =
    {field_anns, 1},
    {field_id, 0},
    {field_pat, 2},
    {field_pat, 3},
  [119] =
    {field_default, 1},
    {field_id, 0},
    {field_pat, 2},
    {field_pat, 3},
  [123] =
    {field_body, 3},
    {field_guard, 1},
    {field_pat, 0},
  [126] =
    {field_cases, 2},
    {field_cases, 3},
    {field_cases, 4},
  [129] =
    {field_fields, 1},
    {field_last, 2},
    {field_tail, 3},
    {field_tail, 4},
  [133] =
    {field_cond, 1},
    {field_t1, 3},
    {field_t2, 5},
  [136] =
    {field_rows, 1},
    {field_rows, 2},
    {field_tail, 3},
    {field_tail, 4},
  [140] =
    {field_anns, 1},
    {field_default, 2},
    {field_id, 0},
    {field_pat, 3},
    {field_pat, 4},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 2,
  [5] = 2,
  [6] = 2,
  [7] = 2,
  [8] = 2,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 11,
  [13] = 11,
  [14] = 11,
  [15] = 11,
  [16] = 11,
  [17] = 11,
  [18] = 18,
  [19] = 19,
  [20] = 18,
  [21] = 19,
  [22] = 19,
  [23] = 18,
  [24] = 18,
  [25] = 19,
  [26] = 19,
  [27] = 19,
  [28] = 18,
  [29] = 18,
  [30] = 19,
  [31] = 18,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 35,
  [38] = 38,
  [39] = 38,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 38,
  [44] = 40,
  [45] = 45,
  [46] = 46,
  [47] = 41,
  [48] = 35,
  [49] = 49,
  [50] = 32,
  [51] = 51,
  [52] = 41,
  [53] = 41,
  [54] = 32,
  [55] = 45,
  [56] = 41,
  [57] = 57,
  [58] = 45,
  [59] = 32,
  [60] = 38,
  [61] = 61,
  [62] = 45,
  [63] = 32,
  [64] = 38,
  [65] = 38,
  [66] = 45,
  [67] = 35,
  [68] = 32,
  [69] = 35,
  [70] = 35,
  [71] = 45,
  [72] = 41,
  [73] = 9,
  [74] = 74,
  [75] = 74,
  [76] = 74,
  [77] = 10,
  [78] = 74,
  [79] = 74,
  [80] = 74,
  [81] = 9,
  [82] = 9,
  [83] = 9,
  [84] = 9,
  [85] = 10,
  [86] = 10,
  [87] = 10,
  [88] = 10,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 129,
  [131] = 131,
  [132] = 131,
  [133] = 131,
  [134] = 131,
  [135] = 131,
  [136] = 129,
  [137] = 129,
  [138] = 138,
  [139] = 129,
  [140] = 138,
  [141] = 131,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 138,
  [147] = 147,
  [148] = 138,
  [149] = 131,
  [150] = 150,
  [151] = 151,
  [152] = 138,
  [153] = 138,
  [154] = 154,
  [155] = 129,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 159,
  [170] = 161,
  [171] = 162,
  [172] = 163,
  [173] = 164,
  [174] = 165,
  [175] = 168,
  [176] = 158,
  [177] = 159,
  [178] = 161,
  [179] = 160,
  [180] = 162,
  [181] = 163,
  [182] = 160,
  [183] = 160,
  [184] = 158,
  [185] = 164,
  [186] = 165,
  [187] = 158,
  [188] = 166,
  [189] = 165,
  [190] = 164,
  [191] = 163,
  [192] = 162,
  [193] = 161,
  [194] = 159,
  [195] = 168,
  [196] = 167,
  [197] = 166,
  [198] = 167,
  [199] = 158,
  [200] = 168,
  [201] = 159,
  [202] = 161,
  [203] = 167,
  [204] = 162,
  [205] = 160,
  [206] = 168,
  [207] = 163,
  [208] = 166,
  [209] = 167,
  [210] = 168,
  [211] = 159,
  [212] = 161,
  [213] = 162,
  [214] = 163,
  [215] = 164,
  [216] = 165,
  [217] = 166,
  [218] = 164,
  [219] = 165,
  [220] = 166,
  [221] = 160,
  [222] = 158,
  [223] = 167,
  [224] = 110,
  [225] = 99,
  [226] = 124,
  [227] = 90,
  [228] = 103,
  [229] = 102,
  [230] = 101,
  [231] = 100,
  [232] = 92,
  [233] = 97,
  [234] = 96,
  [235] = 95,
  [236] = 94,
  [237] = 93,
  [238] = 109,
  [239] = 104,
  [240] = 105,
  [241] = 106,
  [242] = 91,
  [243] = 108,
  [244] = 119,
  [245] = 113,
  [246] = 114,
  [247] = 115,
  [248] = 116,
  [249] = 89,
  [250] = 123,
  [251] = 117,
  [252] = 118,
  [253] = 120,
  [254] = 121,
  [255] = 122,
  [256] = 125,
  [257] = 112,
  [258] = 111,
  [259] = 107,
  [260] = 126,
  [261] = 127,
  [262] = 128,
  [263] = 98,
  [264] = 107,
  [265] = 121,
  [266] = 98,
  [267] = 89,
  [268] = 124,
  [269] = 112,
  [270] = 111,
  [271] = 107,
  [272] = 104,
  [273] = 127,
  [274] = 128,
  [275] = 127,
  [276] = 126,
  [277] = 99,
  [278] = 127,
  [279] = 124,
  [280] = 93,
  [281] = 128,
  [282] = 98,
  [283] = 128,
  [284] = 94,
  [285] = 125,
  [286] = 89,
  [287] = 122,
  [288] = 98,
  [289] = 123,
  [290] = 116,
  [291] = 121,
  [292] = 115,
  [293] = 118,
  [294] = 114,
  [295] = 113,
  [296] = 117,
  [297] = 92,
  [298] = 119,
  [299] = 126,
  [300] = 150,
  [301] = 110,
  [302] = 116,
  [303] = 107,
  [304] = 115,
  [305] = 114,
  [306] = 92,
  [307] = 113,
  [308] = 109,
  [309] = 111,
  [310] = 95,
  [311] = 96,
  [312] = 108,
  [313] = 97,
  [314] = 106,
  [315] = 126,
  [316] = 100,
  [317] = 91,
  [318] = 101,
  [319] = 125,
  [320] = 90,
  [321] = 110,
  [322] = 109,
  [323] = 119,
  [324] = 108,
  [325] = 117,
  [326] = 123,
  [327] = 102,
  [328] = 120,
  [329] = 103,
  [330] = 106,
  [331] = 98,
  [332] = 144,
  [333] = 122,
  [334] = 128,
  [335] = 127,
  [336] = 123,
  [337] = 121,
  [338] = 122,
  [339] = 91,
  [340] = 120,
  [341] = 90,
  [342] = 105,
  [343] = 92,
  [344] = 126,
  [345] = 104,
  [346] = 99,
  [347] = 95,
  [348] = 116,
  [349] = 115,
  [350] = 112,
  [351] = 114,
  [352] = 92,
  [353] = 113,
  [354] = 112,
  [355] = 124,
  [356] = 93,
  [357] = 94,
  [358] = 89,
  [359] = 95,
  [360] = 125,
  [361] = 110,
  [362] = 123,
  [363] = 96,
  [364] = 151,
  [365] = 97,
  [366] = 100,
  [367] = 120,
  [368] = 101,
  [369] = 102,
  [370] = 103,
  [371] = 122,
  [372] = 147,
  [373] = 121,
  [374] = 124,
  [375] = 120,
  [376] = 118,
  [377] = 111,
  [378] = 154,
  [379] = 109,
  [380] = 107,
  [381] = 108,
  [382] = 125,
  [383] = 89,
  [384] = 106,
  [385] = 91,
  [386] = 90,
  [387] = 118,
  [388] = 103,
  [389] = 102,
  [390] = 145,
  [391] = 119,
  [392] = 101,
  [393] = 117,
  [394] = 100,
  [395] = 117,
  [396] = 119,
  [397] = 90,
  [398] = 97,
  [399] = 96,
  [400] = 116,
  [401] = 115,
  [402] = 118,
  [403] = 114,
  [404] = 113,
  [405] = 110,
  [406] = 109,
  [407] = 108,
  [408] = 106,
  [409] = 143,
  [410] = 105,
  [411] = 112,
  [412] = 111,
  [413] = 142,
  [414] = 103,
  [415] = 102,
  [416] = 101,
  [417] = 100,
  [418] = 97,
  [419] = 96,
  [420] = 95,
  [421] = 94,
  [422] = 93,
  [423] = 99,
  [424] = 104,
  [425] = 91,
  [426] = 105,
  [427] = 104,
  [428] = 99,
  [429] = 93,
  [430] = 94,
  [431] = 105,
  [432] = 145,
  [433] = 144,
  [434] = 142,
  [435] = 147,
  [436] = 151,
  [437] = 151,
  [438] = 150,
  [439] = 147,
  [440] = 143,
  [441] = 142,
  [442] = 145,
  [443] = 154,
  [444] = 154,
  [445] = 147,
  [446] = 143,
  [447] = 154,
  [448] = 143,
  [449] = 142,
  [450] = 143,
  [451] = 150,
  [452] = 151,
  [453] = 144,
  [454] = 142,
  [455] = 151,
  [456] = 144,
  [457] = 150,
  [458] = 154,
  [459] = 145,
  [460] = 147,
  [461] = 144,
  [462] = 150,
  [463] = 145,
  [464] = 464,
  [465] = 465,
  [466] = 466,
  [467] = 467,
  [468] = 468,
  [469] = 469,
  [470] = 470,
  [471] = 471,
  [472] = 472,
  [473] = 473,
  [474] = 474,
  [475] = 475,
  [476] = 476,
  [477] = 477,
  [478] = 478,
  [479] = 479,
  [480] = 480,
  [481] = 464,
  [482] = 478,
  [483] = 479,
  [484] = 484,
  [485] = 485,
  [486] = 484,
  [487] = 484,
  [488] = 464,
  [489] = 484,
  [490] = 464,
  [491] = 491,
  [492] = 484,
  [493] = 464,
  [494] = 491,
  [495] = 491,
  [496] = 491,
  [497] = 491,
  [498] = 464,
  [499] = 491,
  [500] = 484,
  [501] = 501,
  [502] = 502,
  [503] = 503,
  [504] = 502,
  [505] = 502,
  [506] = 502,
  [507] = 507,
  [508] = 507,
  [509] = 509,
  [510] = 507,
  [511] = 511,
  [512] = 502,
  [513] = 502,
  [514] = 507,
  [515] = 507,
  [516] = 516,
  [517] = 507,
  [518] = 473,
  [519] = 468,
  [520] = 467,
  [521] = 465,
  [522] = 469,
  [523] = 523,
  [524] = 470,
  [525] = 466,
  [526] = 526,
  [527] = 471,
  [528] = 472,
  [529] = 474,
  [530] = 476,
  [531] = 475,
  [532] = 532,
  [533] = 470,
  [534] = 466,
  [535] = 535,
  [536] = 536,
  [537] = 537,
  [538] = 475,
  [539] = 465,
  [540] = 476,
  [541] = 468,
  [542] = 475,
  [543] = 469,
  [544] = 474,
  [545] = 467,
  [546] = 470,
  [547] = 471,
  [548] = 476,
  [549] = 472,
  [550] = 473,
  [551] = 474,
  [552] = 475,
  [553] = 476,
  [554] = 474,
  [555] = 475,
  [556] = 474,
  [557] = 467,
  [558] = 467,
  [559] = 473,
  [560] = 473,
  [561] = 472,
  [562] = 471,
  [563] = 472,
  [564] = 471,
  [565] = 470,
  [566] = 469,
  [567] = 473,
  [568] = 468,
  [569] = 465,
  [570] = 472,
  [571] = 466,
  [572] = 470,
  [573] = 471,
  [574] = 469,
  [575] = 468,
  [576] = 465,
  [577] = 469,
  [578] = 466,
  [579] = 468,
  [580] = 580,
  [581] = 476,
  [582] = 467,
  [583] = 465,
  [584] = 466,
  [585] = 585,
  [586] = 586,
  [587] = 587,
  [588] = 588,
  [589] = 589,
  [590] = 590,
  [591] = 591,
  [592] = 592,
  [593] = 592,
  [594] = 594,
  [595] = 595,
  [596] = 596,
  [597] = 532,
  [598] = 595,
  [599] = 599,
  [600] = 599,
  [601] = 599,
  [602] = 599,
  [603] = 599,
  [604] = 604,
  [605] = 599,
  [606] = 606,
  [607] = 607,
  [608] = 608,
  [609] = 609,
  [610] = 609,
  [611] = 609,
  [612] = 612,
  [613] = 613,
  [614] = 609,
  [615] = 615,
  [616] = 609,
  [617] = 617,
  [618] = 609,
  [619] = 619,
  [620] = 620,
  [621] = 621,
  [622] = 622,
  [623] = 623,
  [624] = 624,
  [625] = 624,
  [626] = 90,
  [627] = 89,
  [628] = 91,
  [629] = 144,
  [630] = 89,
  [631] = 91,
  [632] = 90,
  [633] = 150,
  [634] = 634,
  [635] = 635,
  [636] = 635,
  [637] = 635,
  [638] = 635,
  [639] = 635,
  [640] = 635,
  [641] = 635,
  [642] = 642,
  [643] = 643,
  [644] = 644,
  [645] = 644,
  [646] = 646,
  [647] = 644,
  [648] = 648,
  [649] = 644,
  [650] = 644,
  [651] = 90,
  [652] = 652,
  [653] = 653,
  [654] = 654,
  [655] = 655,
  [656] = 644,
  [657] = 657,
  [658] = 150,
  [659] = 91,
  [660] = 89,
  [661] = 124,
  [662] = 662,
  [663] = 663,
  [664] = 144,
  [665] = 665,
  [666] = 666,
  [667] = 667,
  [668] = 668,
  [669] = 669,
  [670] = 670,
  [671] = 671,
  [672] = 672,
  [673] = 673,
  [674] = 674,
  [675] = 644,
  [676] = 676,
  [677] = 677,
  [678] = 124,
  [679] = 91,
  [680] = 89,
  [681] = 681,
  [682] = 90,
  [683] = 683,
  [684] = 684,
  [685] = 685,
  [686] = 686,
  [687] = 687,
  [688] = 688,
  [689] = 689,
  [690] = 690,
  [691] = 691,
  [692] = 674,
  [693] = 693,
  [694] = 693,
  [695] = 671,
  [696] = 691,
  [697] = 693,
  [698] = 693,
  [699] = 670,
  [700] = 693,
  [701] = 654,
  [702] = 676,
  [703] = 634,
  [704] = 666,
  [705] = 691,
  [706] = 669,
  [707] = 707,
  [708] = 668,
  [709] = 691,
  [710] = 710,
  [711] = 711,
  [712] = 673,
  [713] = 713,
  [714] = 665,
  [715] = 691,
  [716] = 663,
  [717] = 691,
  [718] = 691,
  [719] = 652,
  [720] = 693,
  [721] = 693,
  [722] = 722,
  [723] = 723,
  [724] = 724,
  [725] = 725,
  [726] = 723,
  [727] = 727,
  [728] = 723,
  [729] = 722,
  [730] = 730,
  [731] = 731,
  [732] = 722,
  [733] = 722,
  [734] = 723,
  [735] = 723,
  [736] = 722,
  [737] = 722,
  [738] = 672,
  [739] = 739,
  [740] = 723,
  [741] = 653,
  [742] = 722,
  [743] = 743,
  [744] = 723,
  [745] = 745,
  [746] = 745,
  [747] = 747,
  [748] = 112,
  [749] = 111,
  [750] = 750,
  [751] = 107,
  [752] = 752,
  [753] = 753,
  [754] = 754,
  [755] = 750,
  [756] = 745,
  [757] = 745,
  [758] = 750,
  [759] = 759,
  [760] = 760,
  [761] = 745,
  [762] = 745,
  [763] = 763,
  [764] = 753,
  [765] = 750,
  [766] = 753,
  [767] = 117,
  [768] = 768,
  [769] = 750,
  [770] = 750,
  [771] = 750,
  [772] = 772,
  [773] = 753,
  [774] = 774,
  [775] = 750,
  [776] = 753,
  [777] = 753,
  [778] = 119,
  [779] = 750,
  [780] = 745,
  [781] = 745,
  [782] = 745,
  [783] = 753,
  [784] = 784,
  [785] = 785,
  [786] = 786,
  [787] = 787,
  [788] = 788,
  [789] = 789,
  [790] = 788,
  [791] = 788,
  [792] = 784,
  [793] = 784,
  [794] = 784,
  [795] = 785,
  [796] = 786,
  [797] = 786,
  [798] = 785,
  [799] = 786,
  [800] = 800,
  [801] = 785,
  [802] = 785,
  [803] = 786,
  [804] = 804,
  [805] = 788,
  [806] = 786,
  [807] = 788,
  [808] = 784,
  [809] = 785,
  [810] = 788,
  [811] = 785,
  [812] = 784,
  [813] = 788,
  [814] = 788,
  [815] = 784,
  [816] = 786,
  [817] = 784,
  [818] = 785,
  [819] = 786,
  [820] = 785,
  [821] = 788,
  [822] = 784,
  [823] = 786,
  [824] = 784,
  [825] = 786,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 829,
  [831] = 829,
  [832] = 832,
  [833] = 833,
  [834] = 829,
  [835] = 835,
  [836] = 836,
  [837] = 829,
  [838] = 829,
  [839] = 839,
  [840] = 683,
  [841] = 833,
  [842] = 829,
  [843] = 827,
  [844] = 684,
  [845] = 684,
  [846] = 683,
  [847] = 847,
  [848] = 684,
  [849] = 683,
  [850] = 683,
  [851] = 684,
  [852] = 852,
  [853] = 828,
  [854] = 854,
  [855] = 832,
  [856] = 683,
  [857] = 684,
  [858] = 828,
  [859] = 826,
  [860] = 828,
  [861] = 861,
  [862] = 101,
  [863] = 122,
  [864] = 864,
  [865] = 118,
  [866] = 121,
  [867] = 100,
  [868] = 868,
  [869] = 103,
  [870] = 97,
  [871] = 96,
  [872] = 864,
  [873] = 95,
  [874] = 94,
  [875] = 93,
  [876] = 864,
  [877] = 99,
  [878] = 104,
  [879] = 864,
  [880] = 105,
  [881] = 861,
  [882] = 98,
  [883] = 102,
  [884] = 128,
  [885] = 106,
  [886] = 864,
  [887] = 127,
  [888] = 888,
  [889] = 768,
  [890] = 116,
  [891] = 126,
  [892] = 847,
  [893] = 115,
  [894] = 864,
  [895] = 114,
  [896] = 108,
  [897] = 861,
  [898] = 861,
  [899] = 113,
  [900] = 109,
  [901] = 861,
  [902] = 110,
  [903] = 861,
  [904] = 861,
  [905] = 125,
  [906] = 864,
  [907] = 907,
  [908] = 908,
  [909] = 909,
  [910] = 910,
  [911] = 911,
  [912] = 911,
  [913] = 910,
  [914] = 914,
  [915] = 914,
  [916] = 916,
  [917] = 657,
  [918] = 908,
  [919] = 910,
  [920] = 920,
  [921] = 921,
  [922] = 914,
  [923] = 923,
  [924] = 924,
  [925] = 144,
  [926] = 926,
  [927] = 908,
  [928] = 150,
  [929] = 929,
  [930] = 923,
  [931] = 931,
  [932] = 932,
  [933] = 933,
  [934] = 933,
  [935] = 916,
  [936] = 923,
  [937] = 926,
  [938] = 933,
  [939] = 923,
  [940] = 933,
  [941] = 941,
  [942] = 914,
  [943] = 923,
  [944] = 932,
  [945] = 908,
  [946] = 929,
  [947] = 916,
  [948] = 948,
  [949] = 926,
  [950] = 950,
  [951] = 910,
  [952] = 914,
  [953] = 932,
  [954] = 911,
  [955] = 955,
  [956] = 910,
  [957] = 957,
  [958] = 958,
  [959] = 911,
  [960] = 960,
  [961] = 932,
  [962] = 962,
  [963] = 923,
  [964] = 926,
  [965] = 965,
  [966] = 932,
  [967] = 916,
  [968] = 911,
  [969] = 969,
  [970] = 911,
  [971] = 929,
  [972] = 921,
  [973] = 655,
  [974] = 929,
  [975] = 643,
  [976] = 976,
  [977] = 926,
  [978] = 662,
  [979] = 910,
  [980] = 908,
  [981] = 932,
  [982] = 926,
  [983] = 908,
  [984] = 916,
  [985] = 916,
  [986] = 646,
  [987] = 648,
  [988] = 929,
  [989] = 932,
  [990] = 926,
  [991] = 916,
  [992] = 667,
  [993] = 929,
  [994] = 933,
  [995] = 923,
  [996] = 933,
  [997] = 910,
  [998] = 998,
  [999] = 999,
  [1000] = 929,
  [1001] = 914,
  [1002] = 1002,
  [1003] = 1003,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 1005,
  [1007] = 1005,
  [1008] = 1003,
  [1009] = 1005,
  [1010] = 1010,
  [1011] = 1005,
  [1012] = 1005,
  [1013] = 1013,
  [1014] = 1014,
  [1015] = 1014,
  [1016] = 1016,
  [1017] = 1017,
  [1018] = 1014,
  [1019] = 1019,
  [1020] = 1003,
  [1021] = 1014,
  [1022] = 1014,
  [1023] = 1023,
  [1024] = 1010,
  [1025] = 1025,
  [1026] = 1026,
  [1027] = 1027,
  [1028] = 1014,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 1031,
  [1032] = 1032,
  [1033] = 1010,
  [1034] = 1003,
  [1035] = 1010,
  [1036] = 1003,
  [1037] = 1003,
  [1038] = 1025,
  [1039] = 1010,
  [1040] = 1010,
  [1041] = 1041,
  [1042] = 1042,
  [1043] = 1003,
  [1044] = 1005,
  [1045] = 1010,
  [1046] = 1046,
  [1047] = 1047,
  [1048] = 1048,
  [1049] = 1049,
  [1050] = 1050,
  [1051] = 689,
  [1052] = 1052,
  [1053] = 1053,
  [1054] = 1054,
  [1055] = 1055,
  [1056] = 690,
  [1057] = 688,
  [1058] = 1058,
  [1059] = 1059,
  [1060] = 1060,
  [1061] = 1061,
  [1062] = 1062,
  [1063] = 1062,
  [1064] = 1061,
  [1065] = 1060,
  [1066] = 1066,
  [1067] = 1050,
  [1068] = 1061,
  [1069] = 1059,
  [1070] = 1070,
  [1071] = 1058,
  [1072] = 1072,
  [1073] = 1073,
  [1074] = 1055,
  [1075] = 1075,
  [1076] = 1049,
  [1077] = 1077,
  [1078] = 1049,
  [1079] = 1075,
  [1080] = 1073,
  [1081] = 1077,
  [1082] = 1070,
  [1083] = 1050,
  [1084] = 1048,
  [1085] = 1050,
  [1086] = 1055,
  [1087] = 1055,
  [1088] = 1048,
  [1089] = 1089,
  [1090] = 1058,
  [1091] = 1059,
  [1092] = 1060,
  [1093] = 1061,
  [1094] = 1062,
  [1095] = 1062,
  [1096] = 1061,
  [1097] = 1060,
  [1098] = 1058,
  [1099] = 1099,
  [1100] = 1100,
  [1101] = 1101,
  [1102] = 1058,
  [1103] = 1077,
  [1104] = 1104,
  [1105] = 1055,
  [1106] = 1077,
  [1107] = 1049,
  [1108] = 1075,
  [1109] = 1109,
  [1110] = 1070,
  [1111] = 1048,
  [1112] = 1050,
  [1113] = 1113,
  [1114] = 1114,
  [1115] = 1115,
  [1116] = 1050,
  [1117] = 1048,
  [1118] = 1070,
  [1119] = 1073,
  [1120] = 1075,
  [1121] = 1049,
  [1122] = 1077,
  [1123] = 1123,
  [1124] = 1052,
  [1125] = 1077,
  [1126] = 1070,
  [1127] = 1127,
  [1128] = 1049,
  [1129] = 1073,
  [1130] = 1130,
  [1131] = 1131,
  [1132] = 1132,
  [1133] = 1133,
  [1134] = 1075,
  [1135] = 1135,
  [1136] = 1136,
  [1137] = 1048,
  [1138] = 1066,
  [1139] = 1055,
  [1140] = 1072,
  [1141] = 1077,
  [1142] = 1142,
  [1143] = 1075,
  [1144] = 1127,
  [1145] = 1073,
  [1146] = 1058,
  [1147] = 1130,
  [1148] = 1059,
  [1149] = 1135,
  [1150] = 1150,
  [1151] = 1101,
  [1152] = 1113,
  [1153] = 1115,
  [1154] = 1072,
  [1155] = 1132,
  [1156] = 1142,
  [1157] = 1142,
  [1158] = 1127,
  [1159] = 1070,
  [1160] = 1070,
  [1161] = 1130,
  [1162] = 1162,
  [1163] = 1135,
  [1164] = 1130,
  [1165] = 1060,
  [1166] = 1061,
  [1167] = 1062,
  [1168] = 1072,
  [1169] = 1048,
  [1170] = 1142,
  [1171] = 1162,
  [1172] = 1127,
  [1173] = 685,
  [1174] = 1050,
  [1175] = 1130,
  [1176] = 1135,
  [1177] = 1135,
  [1178] = 1073,
  [1179] = 1060,
  [1180] = 1061,
  [1181] = 1181,
  [1182] = 1072,
  [1183] = 1183,
  [1184] = 1142,
  [1185] = 1185,
  [1186] = 1127,
  [1187] = 686,
  [1188] = 1188,
  [1189] = 1130,
  [1190] = 1062,
  [1191] = 1135,
  [1192] = 1123,
  [1193] = 613,
  [1194] = 615,
  [1195] = 1075,
  [1196] = 1072,
  [1197] = 608,
  [1198] = 1142,
  [1199] = 1127,
  [1200] = 1130,
  [1201] = 619,
  [1202] = 1135,
  [1203] = 607,
  [1204] = 620,
  [1205] = 622,
  [1206] = 1072,
  [1207] = 687,
  [1208] = 1142,
  [1209] = 1055,
  [1210] = 1210,
  [1211] = 1059,
  [1212] = 1210,
  [1213] = 1062,
  [1214] = 1210,
  [1215] = 1058,
  [1216] = 1210,
  [1217] = 1059,
  [1218] = 1210,
  [1219] = 1060,
  [1220] = 621,
  [1221] = 1221,
  [1222] = 1049,
  [1223] = 1210,
  [1224] = 1224,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(96);
      ADVANCE_MAP(
        '!', 232,
        '"', 219,
        '%', 218,
        '&', 233,
        '\'', 21,
        '(', 207,
        ')', 208,
        '*', 228,
        '+', 230,
        ',', 198,
        '-', 231,
        '.', 203,
        '/', 229,
        '0', 99,
        ':', 194,
        ';', 206,
        '<', 235,
        '=', 196,
        '>', 237,
        '?', 217,
        '@', 213,
        'A', 170,
        'B', 152,
        'D', 185,
        'N', 181,
        'S', 178,
        '[', 210,
        '\\', 92,
        ']', 211,
        '_', 214,
        'd', 124,
        'e', 141,
        'f', 114,
        'i', 146,
        'l', 129,
        'm', 118,
        'n', 154,
        'o', 160,
        'p', 163,
        'r', 125,
        't', 136,
        '{', 200,
        '|', 191,
        '}', 201,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(100);
      if (('C' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '!', 17,
        '%', 218,
        '&', 233,
        '\'', 21,
        '(', 207,
        ')', 208,
        '*', 228,
        '+', 230,
        ',', 198,
        '-', 231,
        '.', 203,
        '/', 229,
        '0', 99,
        ':', 194,
        ';', 206,
        '<', 235,
        '=', 196,
        '>', 237,
        '?', 217,
        '@', 213,
        'B', 152,
        'D', 185,
        'N', 181,
        'S', 178,
        '[', 210,
        ']', 211,
        '_', 214,
        'd', 124,
        'e', 141,
        'f', 114,
        'i', 146,
        'l', 129,
        'm', 118,
        'n', 154,
        'o', 161,
        'p', 163,
        'r', 125,
        't', 136,
        '{', 200,
        '|', 191,
        '}', 201,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(100);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 2:
      if (lookahead == '"') ADVANCE(219);
      if (lookahead == '%') ADVANCE(218);
      if (lookahead == '\\') ADVANCE(222);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(223);
      if (lookahead != 0) ADVANCE(224);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '%', 218,
        '\'', 21,
        '(', 207,
        ',', 198,
        '.', 86,
        '0', 99,
        ';', 206,
        '=', 195,
        '?', 217,
        'B', 152,
        'D', 185,
        'N', 181,
        'S', 178,
        '[', 210,
        '_', 214,
        'd', 124,
        'e', 141,
        'f', 114,
        'i', 146,
        'l', 129,
        'm', 118,
        'n', 154,
        'o', 161,
        'p', 163,
        'r', 125,
        't', 136,
        '{', 200,
        '|', 20,
        '}', 201,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(100);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 4:
      if (lookahead == '%') ADVANCE(218);
      if (lookahead == '\\') ADVANCE(92);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(220);
      if (lookahead != 0 &&
          lookahead != '"') ADVANCE(221);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '\'', 21,
        '(', 207,
        ',', 198,
        '-', 16,
        '.', 14,
        '0', 106,
        '=', 18,
        '@', 213,
        '[', 209,
        ']', 211,
        '_', 214,
        'd', 124,
        'e', 141,
        'f', 114,
        'i', 146,
        'l', 129,
        'm', 118,
        'n', 154,
        'o', 161,
        'p', 163,
        'r', 125,
        't', 136,
        '{', 200,
        '}', 201,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(5);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(107);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '\'', 21,
        '(', 207,
        ',', 198,
        '-', 16,
        '.', 88,
        '0', 106,
        ':', 194,
        ';', 206,
        '=', 195,
        '?', 217,
        '[', 209,
        ']', 211,
        '_', 214,
        'd', 124,
        'e', 141,
        'f', 114,
        'i', 146,
        'l', 129,
        'm', 118,
        'n', 154,
        'o', 160,
        'p', 163,
        'r', 125,
        't', 136,
        '{', 200,
        '|', 190,
        '}', 201,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(6);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(107);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '\'', 21,
        '(', 207,
        '-', 16,
        '.', 88,
        '0', 106,
        '=', 18,
        '[', 209,
        '_', 214,
        'd', 124,
        'e', 141,
        'f', 114,
        'i', 146,
        'l', 129,
        'm', 118,
        'n', 154,
        'o', 160,
        'p', 163,
        'r', 125,
        't', 136,
        '{', 200,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(107);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        ')', 208,
        ',', 198,
        '.', 202,
        ':', 194,
        ';', 206,
        '=', 197,
        ']', 211,
        'd', 33,
        'e', 47,
        'f', 25,
        'i', 51,
        'l', 37,
        'm', 27,
        'n', 55,
        'o', 60,
        'p', 64,
        'r', 34,
        't', 43,
        '|', 193,
        '}', 201,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      END_STATE();
    case 9:
      if (lookahead == ')') ADVANCE(208);
      if (lookahead == '_') ADVANCE(23);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(226);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        ',', 198,
        '.', 202,
        ':', 194,
        ';', 206,
        '=', 195,
        '@', 213,
        ']', 211,
        'o', 63,
        '|', 190,
        '}', 201,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        ',', 198,
        '.', 202,
        ':', 194,
        ';', 206,
        '=', 195,
        '_', 22,
        '|', 193,
        '}', 201,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        ',', 198,
        '.', 202,
        ';', 206,
        '=', 18,
        '@', 213,
        'd', 33,
        'e', 47,
        'f', 25,
        'i', 51,
        'l', 37,
        'm', 27,
        'n', 55,
        'o', 60,
        'p', 64,
        'r', 34,
        't', 43,
        '|', 20,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      END_STATE();
    case 13:
      if (lookahead == '.') ADVANCE(212);
      END_STATE();
    case 14:
      if (lookahead == '.') ADVANCE(212);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(108);
      END_STATE();
    case 15:
      if (lookahead == '.') ADVANCE(13);
      if (lookahead == ';') ADVANCE(206);
      if (lookahead == ']') ADVANCE(211);
      if (lookahead == '_') ADVANCE(214);
      if (lookahead == '}') ADVANCE(201);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 16:
      if (lookahead == '.') ADVANCE(88);
      if (lookahead == '0') ADVANCE(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(107);
      END_STATE();
    case 17:
      if (lookahead == '=') ADVANCE(240);
      END_STATE();
    case 18:
      if (lookahead == '>') ADVANCE(199);
      END_STATE();
    case 19:
      if (lookahead == 'D') ADVANCE(185);
      if (lookahead == '_') ADVANCE(22);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 20:
      if (lookahead == ']') ADVANCE(248);
      END_STATE();
    case 21:
      if (lookahead == '_') ADVANCE(21);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(189);
      END_STATE();
    case 22:
      if (lookahead == '_') ADVANCE(22);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 23:
      if (lookahead == '_') ADVANCE(23);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(226);
      END_STATE();
    case 24:
      if (lookahead == '_') ADVANCE(38);
      END_STATE();
    case 25:
      if (lookahead == 'a') ADVANCE(47);
      if (lookahead == 'o') ADVANCE(65);
      if (lookahead == 'u') ADVANCE(52);
      END_STATE();
    case 26:
      if (lookahead == 'a') ADVANCE(50);
      if (lookahead == 'c') ADVANCE(36);
      END_STATE();
    case 27:
      if (lookahead == 'a') ADVANCE(73);
      if (lookahead == 'e') ADVANCE(66);
      END_STATE();
    case 28:
      if (lookahead == 'a') ADVANCE(76);
      END_STATE();
    case 29:
      if (lookahead == 'a') ADVANCE(48);
      END_STATE();
    case 30:
      if (lookahead == 'c') ADVANCE(97);
      END_STATE();
    case 31:
      if (lookahead == 'c') ADVANCE(42);
      END_STATE();
    case 32:
      if (lookahead == 'd') ADVANCE(97);
      END_STATE();
    case 33:
      if (lookahead == 'e') ADVANCE(40);
      if (lookahead == 'o') ADVANCE(30);
      END_STATE();
    case 34:
      if (lookahead == 'e') ADVANCE(30);
      END_STATE();
    case 35:
      if (lookahead == 'e') ADVANCE(52);
      END_STATE();
    case 36:
      if (lookahead == 'e') ADVANCE(97);
      END_STATE();
    case 37:
      if (lookahead == 'e') ADVANCE(70);
      END_STATE();
    case 38:
      if (lookahead == 'e') ADVANCE(78);
      END_STATE();
    case 39:
      if (lookahead == 'e') ADVANCE(32);
      END_STATE();
    case 40:
      if (lookahead == 'f') ADVANCE(28);
      END_STATE();
    case 41:
      if (lookahead == 'g') ADVANCE(36);
      END_STATE();
    case 42:
      if (lookahead == 'h') ADVANCE(97);
      END_STATE();
    case 43:
      if (lookahead == 'h') ADVANCE(35);
      if (lookahead == 'r') ADVANCE(77);
      END_STATE();
    case 44:
      if (lookahead == 'i') ADVANCE(58);
      END_STATE();
    case 45:
      if (lookahead == 'i') ADVANCE(54);
      END_STATE();
    case 46:
      if (lookahead == 'i') ADVANCE(72);
      END_STATE();
    case 47:
      if (lookahead == 'l') ADVANCE(69);
      END_STATE();
    case 48:
      if (lookahead == 'l') ADVANCE(97);
      END_STATE();
    case 49:
      if (lookahead == 'l') ADVANCE(70);
      END_STATE();
    case 50:
      if (lookahead == 'l') ADVANCE(48);
      END_STATE();
    case 51:
      if (lookahead == 'm') ADVANCE(59);
      if (lookahead == 'f' ||
          lookahead == 'n') ADVANCE(97);
      END_STATE();
    case 52:
      if (lookahead == 'n') ADVANCE(97);
      END_STATE();
    case 53:
      if (lookahead == 'n') ADVANCE(29);
      END_STATE();
    case 54:
      if (lookahead == 'o') ADVANCE(53);
      END_STATE();
    case 55:
      if (lookahead == 'o') ADVANCE(71);
      if (lookahead == 'u') ADVANCE(50);
      END_STATE();
    case 56:
      if (lookahead == 'o') ADVANCE(62);
      END_STATE();
    case 57:
      if (lookahead == 'o') ADVANCE(68);
      END_STATE();
    case 58:
      if (lookahead == 'o') ADVANCE(67);
      END_STATE();
    case 59:
      if (lookahead == 'p') ADVANCE(56);
      END_STATE();
    case 60:
      if (lookahead == 'p') ADVANCE(75);
      if (lookahead == 'r') ADVANCE(215);
      END_STATE();
    case 61:
      if (lookahead == 'p') ADVANCE(57);
      END_STATE();
    case 62:
      if (lookahead == 'r') ADVANCE(70);
      END_STATE();
    case 63:
      if (lookahead == 'r') ADVANCE(215);
      END_STATE();
    case 64:
      if (lookahead == 'r') ADVANCE(44);
      END_STATE();
    case 65:
      if (lookahead == 'r') ADVANCE(26);
      END_STATE();
    case 66:
      if (lookahead == 'r') ADVANCE(41);
      END_STATE();
    case 67:
      if (lookahead == 'r') ADVANCE(46);
      END_STATE();
    case 68:
      if (lookahead == 'r') ADVANCE(74);
      END_STATE();
    case 69:
      if (lookahead == 's') ADVANCE(36);
      END_STATE();
    case 70:
      if (lookahead == 't') ADVANCE(97);
      END_STATE();
    case 71:
      if (lookahead == 't') ADVANCE(24);
      END_STATE();
    case 72:
      if (lookahead == 't') ADVANCE(79);
      END_STATE();
    case 73:
      if (lookahead == 't') ADVANCE(31);
      END_STATE();
    case 74:
      if (lookahead == 't') ADVANCE(39);
      END_STATE();
    case 75:
      if (lookahead == 't') ADVANCE(45);
      END_STATE();
    case 76:
      if (lookahead == 'u') ADVANCE(49);
      END_STATE();
    case 77:
      if (lookahead == 'u') ADVANCE(36);
      END_STATE();
    case 78:
      if (lookahead == 'x') ADVANCE(61);
      END_STATE();
    case 79:
      if (lookahead == 'y') ADVANCE(97);
      END_STATE();
    case 80:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(87);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(104);
      END_STATE();
    case 81:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(89);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(111);
      END_STATE();
    case 82:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(102);
      END_STATE();
    case 83:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(109);
      END_STATE();
    case 84:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(103);
      END_STATE();
    case 85:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(110);
      END_STATE();
    case 86:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      END_STATE();
    case 87:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(104);
      END_STATE();
    case 88:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(108);
      END_STATE();
    case 89:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(111);
      END_STATE();
    case 90:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(105);
      END_STATE();
    case 91:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(112);
      END_STATE();
    case 92:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(225);
      END_STATE();
    case 93:
      if (eof) ADVANCE(96);
      ADVANCE_MAP(
        '!', 232,
        '%', 218,
        '&', 233,
        '\'', 21,
        '(', 207,
        ')', 208,
        '*', 228,
        '+', 230,
        ',', 198,
        '-', 231,
        '.', 203,
        '/', 229,
        '0', 99,
        ':', 194,
        ';', 206,
        '<', 235,
        '=', 196,
        '>', 237,
        '?', 217,
        '@', 213,
        'A', 170,
        'B', 152,
        'D', 185,
        'N', 181,
        'S', 178,
        '[', 210,
        ']', 211,
        '_', 214,
        'd', 124,
        'e', 141,
        'f', 114,
        'i', 146,
        'l', 129,
        'm', 118,
        'n', 154,
        'o', 161,
        'p', 163,
        'r', 125,
        't', 136,
        '{', 200,
        '|', 192,
        '}', 201,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(93);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(100);
      if (('C' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 94:
      if (eof) ADVANCE(96);
      ADVANCE_MAP(
        '!', 17,
        '%', 218,
        '&', 233,
        '\'', 21,
        '(', 207,
        ')', 208,
        '*', 228,
        '+', 230,
        ',', 198,
        '-', 231,
        '.', 203,
        '/', 229,
        '0', 99,
        ':', 194,
        ';', 206,
        '<', 235,
        '=', 196,
        '>', 237,
        '?', 217,
        '@', 213,
        'B', 152,
        'D', 185,
        'N', 181,
        'S', 178,
        '[', 210,
        ']', 211,
        '_', 214,
        'd', 124,
        'e', 141,
        'f', 114,
        'i', 146,
        'l', 129,
        'm', 118,
        'n', 154,
        'o', 161,
        'p', 163,
        'r', 125,
        't', 136,
        '{', 200,
        '|', 192,
        '}', 201,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(94);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(100);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 95:
      if (eof) ADVANCE(96);
      ADVANCE_MAP(
        '!', 17,
        '%', 218,
        '&', 233,
        ')', 208,
        '*', 228,
        '+', 230,
        ',', 198,
        '-', 231,
        '/', 229,
        ':', 194,
        ';', 206,
        '<', 235,
        '=', 196,
        '>', 237,
        '?', 217,
        '@', 213,
        ']', 211,
        'd', 33,
        'e', 47,
        'f', 25,
        'i', 51,
        'l', 37,
        'm', 27,
        'n', 55,
        'o', 60,
        'p', 64,
        'r', 34,
        't', 43,
        '|', 192,
        '}', 201,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(95);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(sym_keyword);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(sym_num_literal);
      if (lookahead == '.') ADVANCE(86);
      if (lookahead == 'b') ADVANCE(82);
      if (lookahead == 'o') ADVANCE(84);
      if (lookahead == 'x') ADVANCE(90);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(80);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(100);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(sym_num_literal);
      if (lookahead == '.') ADVANCE(86);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(80);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(100);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(sym_num_literal);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(80);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(sym_num_literal);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(102);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(sym_num_literal);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(103);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(sym_num_literal);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(104);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(sym_num_literal);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(105);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(sym_signed_num_literal);
      if (lookahead == '.') ADVANCE(88);
      if (lookahead == 'b') ADVANCE(83);
      if (lookahead == 'o') ADVANCE(85);
      if (lookahead == 'x') ADVANCE(91);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(81);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(107);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(sym_signed_num_literal);
      if (lookahead == '.') ADVANCE(88);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(81);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(107);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(sym_signed_num_literal);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(81);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(108);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(sym_signed_num_literal);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(109);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(sym_signed_num_literal);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(110);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(sym_signed_num_literal);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(111);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(sym_signed_num_literal);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(112);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '_') ADVANCE(127);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'a') ADVANCE(141);
      if (lookahead == 'o') ADVANCE(165);
      if (lookahead == 'u') ADVANCE(148);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'a') ADVANCE(187);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'a') ADVANCE(145);
      if (lookahead == 'c') ADVANCE(126);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'a') ADVANCE(183);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'a') ADVANCE(176);
      if (lookahead == 'e') ADVANCE(166);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'a') ADVANCE(142);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'b') ADVANCE(131);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'c') ADVANCE(98);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'c') ADVANCE(135);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'd') ADVANCE(98);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'e') ADVANCE(132);
      if (lookahead == 'o') ADVANCE(121);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'e') ADVANCE(121);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'e') ADVANCE(98);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'e') ADVANCE(184);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'e') ADVANCE(123);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'e') ADVANCE(174);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'e') ADVANCE(148);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'e') ADVANCE(167);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'f') ADVANCE(117);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'g') ADVANCE(246);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'g') ADVANCE(126);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'h') ADVANCE(98);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'h') ADVANCE(130);
      if (lookahead == 'r') ADVANCE(182);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'i') ADVANCE(150);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'i') ADVANCE(155);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'i') ADVANCE(177);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'i') ADVANCE(157);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'l') ADVANCE(173);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'l') ADVANCE(98);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'l') ADVANCE(245);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'l') ADVANCE(174);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'l') ADVANCE(142);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'm') ADVANCE(159);
      if (lookahead == 'f' ||
          lookahead == 'n') ADVANCE(98);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'm') ADVANCE(120);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'n') ADVANCE(98);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'n') ADVANCE(205);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'n') ADVANCE(133);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'n') ADVANCE(119);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'o') ADVANCE(153);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'o') ADVANCE(143);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'o') ADVANCE(175);
      if (lookahead == 'u') ADVANCE(145);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'o') ADVANCE(151);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'o') ADVANCE(168);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'o') ADVANCE(171);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'o') ADVANCE(172);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'p') ADVANCE(156);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'p') ADVANCE(180);
      if (lookahead == 'r') ADVANCE(216);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'p') ADVANCE(180);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'p') ADVANCE(158);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'r') ADVANCE(140);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'r') ADVANCE(115);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'r') ADVANCE(116);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'r') ADVANCE(134);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'r') ADVANCE(244);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'r') ADVANCE(174);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'r') ADVANCE(137);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'r') ADVANCE(164);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'r') ADVANCE(139);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'r') ADVANCE(179);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 's') ADVANCE(126);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 't') ADVANCE(98);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 't') ADVANCE(113);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 't') ADVANCE(122);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 't') ADVANCE(186);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 't') ADVANCE(169);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 't') ADVANCE(128);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 't') ADVANCE(138);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'u') ADVANCE(147);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'u') ADVANCE(126);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'u') ADVANCE(144);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'x') ADVANCE(162);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'y') ADVANCE(149);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'y') ADVANCE(98);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == 'y') ADVANCE(204);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(sym_raw_enum_tag);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(189);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '>') ADVANCE(234);
      if (lookahead == ']') ADVANCE(248);
      if (lookahead == '|') ADVANCE(242);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '>') ADVANCE(234);
      if (lookahead == '|') ADVANCE(242);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == ']') ADVANCE(248);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(239);
      if (lookahead == '>') ADVANCE(199);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '>') ADVANCE(199);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(anon_sym_Array);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(anon_sym_Dyn);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '|') ADVANCE(247);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(anon_sym__);
      if (lookahead == '_') ADVANCE(22);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(anon_sym_or);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(anon_sym_or);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(sym_double_quote);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(sym_str_literal);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(220);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '%' &&
          lookahead != '\\') ADVANCE(221);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(sym_str_literal);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '%' &&
          lookahead != '\\') ADVANCE(221);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(sym_mult_str_literal);
      if (lookahead == '\n') ADVANCE(224);
      if (lookahead == '"' ||
          lookahead == '%') ADVANCE(225);
      if (lookahead != 0) ADVANCE(224);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(sym_mult_str_literal);
      if (lookahead == '\\') ADVANCE(222);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(223);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '%') ADVANCE(224);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(sym_mult_str_literal);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '%') ADVANCE(224);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(sym_str_esc_char);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(aux_sym_builtin_token1);
      if (lookahead == '\'' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(226);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(227);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '>') ADVANCE(243);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(240);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(241);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(anon_sym_PIPE_GT);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(236);
      END_STATE();
    case 236:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 237:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(238);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(anon_sym_Number);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(anon_sym_Bool);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(anon_sym_String);
      if (lookahead == '\'' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(188);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(anon_sym_LBRACK_PIPE);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(anon_sym_PIPE_RBRACK);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'd', 1,
        'e', 2,
        'f', 3,
        'i', 4,
        'l', 5,
        'm', 6,
        'n', 7,
        'o', 8,
        'p', 9,
        'r', 10,
        't', 11,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'e') ADVANCE(12);
      if (lookahead == 'o') ADVANCE(13);
      END_STATE();
    case 2:
      if (lookahead == 'l') ADVANCE(14);
      END_STATE();
    case 3:
      if (lookahead == 'a') ADVANCE(15);
      if (lookahead == 'o') ADVANCE(16);
      if (lookahead == 'u') ADVANCE(17);
      END_STATE();
    case 4:
      if (lookahead == 'f') ADVANCE(18);
      if (lookahead == 'm') ADVANCE(19);
      if (lookahead == 'n') ADVANCE(20);
      END_STATE();
    case 5:
      if (lookahead == 'e') ADVANCE(21);
      END_STATE();
    case 6:
      if (lookahead == 'a') ADVANCE(22);
      END_STATE();
    case 7:
      if (lookahead == 'o') ADVANCE(23);
      if (lookahead == 'u') ADVANCE(24);
      END_STATE();
    case 8:
      if (lookahead == 'p') ADVANCE(25);
      END_STATE();
    case 9:
      if (lookahead == 'r') ADVANCE(26);
      END_STATE();
    case 10:
      if (lookahead == 'e') ADVANCE(27);
      END_STATE();
    case 11:
      if (lookahead == 'h') ADVANCE(28);
      if (lookahead == 'r') ADVANCE(29);
      END_STATE();
    case 12:
      if (lookahead == 'f') ADVANCE(30);
      END_STATE();
    case 13:
      if (lookahead == 'c') ADVANCE(31);
      END_STATE();
    case 14:
      if (lookahead == 's') ADVANCE(32);
      END_STATE();
    case 15:
      if (lookahead == 'l') ADVANCE(33);
      END_STATE();
    case 16:
      if (lookahead == 'r') ADVANCE(34);
      END_STATE();
    case 17:
      if (lookahead == 'n') ADVANCE(35);
      END_STATE();
    case 18:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 19:
      if (lookahead == 'p') ADVANCE(36);
      END_STATE();
    case 20:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 21:
      if (lookahead == 't') ADVANCE(37);
      END_STATE();
    case 22:
      if (lookahead == 't') ADVANCE(38);
      END_STATE();
    case 23:
      if (lookahead == 't') ADVANCE(39);
      END_STATE();
    case 24:
      if (lookahead == 'l') ADVANCE(40);
      END_STATE();
    case 25:
      if (lookahead == 't') ADVANCE(41);
      END_STATE();
    case 26:
      if (lookahead == 'i') ADVANCE(42);
      END_STATE();
    case 27:
      if (lookahead == 'c') ADVANCE(43);
      END_STATE();
    case 28:
      if (lookahead == 'e') ADVANCE(44);
      END_STATE();
    case 29:
      if (lookahead == 'u') ADVANCE(45);
      END_STATE();
    case 30:
      if (lookahead == 'a') ADVANCE(46);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(anon_sym_doc);
      END_STATE();
    case 32:
      if (lookahead == 'e') ADVANCE(47);
      END_STATE();
    case 33:
      if (lookahead == 's') ADVANCE(48);
      END_STATE();
    case 34:
      if (lookahead == 'a') ADVANCE(49);
      if (lookahead == 'c') ADVANCE(50);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(anon_sym_fun);
      END_STATE();
    case 36:
      if (lookahead == 'o') ADVANCE(51);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(anon_sym_let);
      END_STATE();
    case 38:
      if (lookahead == 'c') ADVANCE(52);
      END_STATE();
    case 39:
      if (lookahead == '_') ADVANCE(53);
      END_STATE();
    case 40:
      if (lookahead == 'l') ADVANCE(54);
      END_STATE();
    case 41:
      if (lookahead == 'i') ADVANCE(55);
      END_STATE();
    case 42:
      if (lookahead == 'o') ADVANCE(56);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_rec);
      END_STATE();
    case 44:
      if (lookahead == 'n') ADVANCE(57);
      END_STATE();
    case 45:
      if (lookahead == 'e') ADVANCE(58);
      END_STATE();
    case 46:
      if (lookahead == 'u') ADVANCE(59);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 48:
      if (lookahead == 'e') ADVANCE(60);
      END_STATE();
    case 49:
      if (lookahead == 'l') ADVANCE(61);
      END_STATE();
    case 50:
      if (lookahead == 'e') ADVANCE(62);
      END_STATE();
    case 51:
      if (lookahead == 'r') ADVANCE(63);
      END_STATE();
    case 52:
      if (lookahead == 'h') ADVANCE(64);
      END_STATE();
    case 53:
      if (lookahead == 'e') ADVANCE(65);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(anon_sym_null);
      END_STATE();
    case 55:
      if (lookahead == 'o') ADVANCE(66);
      END_STATE();
    case 56:
      if (lookahead == 'r') ADVANCE(67);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_then);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 59:
      if (lookahead == 'l') ADVANCE(68);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 61:
      if (lookahead == 'l') ADVANCE(69);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_force);
      END_STATE();
    case 63:
      if (lookahead == 't') ADVANCE(70);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(anon_sym_match);
      END_STATE();
    case 65:
      if (lookahead == 'x') ADVANCE(71);
      END_STATE();
    case 66:
      if (lookahead == 'n') ADVANCE(72);
      END_STATE();
    case 67:
      if (lookahead == 'i') ADVANCE(73);
      END_STATE();
    case 68:
      if (lookahead == 't') ADVANCE(74);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_forall);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 71:
      if (lookahead == 'p') ADVANCE(75);
      END_STATE();
    case 72:
      if (lookahead == 'a') ADVANCE(76);
      END_STATE();
    case 73:
      if (lookahead == 't') ADVANCE(77);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 75:
      if (lookahead == 'o') ADVANCE(78);
      END_STATE();
    case 76:
      if (lookahead == 'l') ADVANCE(79);
      END_STATE();
    case 77:
      if (lookahead == 'y') ADVANCE(80);
      END_STATE();
    case 78:
      if (lookahead == 'r') ADVANCE(81);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_optional);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_priority);
      END_STATE();
    case 81:
      if (lookahead == 't') ADVANCE(82);
      END_STATE();
    case 82:
      if (lookahead == 'e') ADVANCE(83);
      END_STATE();
    case 83:
      if (lookahead == 'd') ADVANCE(84);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_not_exported);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 93, .external_lex_state = 2},
  [2] = {.lex_state = 93, .external_lex_state = 2},
  [3] = {.lex_state = 93, .external_lex_state = 2},
  [4] = {.lex_state = 93, .external_lex_state = 2},
  [5] = {.lex_state = 93, .external_lex_state = 2},
  [6] = {.lex_state = 93, .external_lex_state = 2},
  [7] = {.lex_state = 93, .external_lex_state = 2},
  [8] = {.lex_state = 93, .external_lex_state = 2},
  [9] = {.lex_state = 94, .external_lex_state = 2},
  [10] = {.lex_state = 94, .external_lex_state = 2},
  [11] = {.lex_state = 93, .external_lex_state = 2},
  [12] = {.lex_state = 93, .external_lex_state = 2},
  [13] = {.lex_state = 93, .external_lex_state = 2},
  [14] = {.lex_state = 93, .external_lex_state = 2},
  [15] = {.lex_state = 93, .external_lex_state = 2},
  [16] = {.lex_state = 93, .external_lex_state = 2},
  [17] = {.lex_state = 93, .external_lex_state = 2},
  [18] = {.lex_state = 93, .external_lex_state = 2},
  [19] = {.lex_state = 93, .external_lex_state = 2},
  [20] = {.lex_state = 93, .external_lex_state = 2},
  [21] = {.lex_state = 93, .external_lex_state = 2},
  [22] = {.lex_state = 93, .external_lex_state = 2},
  [23] = {.lex_state = 93, .external_lex_state = 2},
  [24] = {.lex_state = 93, .external_lex_state = 2},
  [25] = {.lex_state = 93, .external_lex_state = 2},
  [26] = {.lex_state = 93, .external_lex_state = 2},
  [27] = {.lex_state = 93, .external_lex_state = 2},
  [28] = {.lex_state = 93, .external_lex_state = 2},
  [29] = {.lex_state = 93, .external_lex_state = 2},
  [30] = {.lex_state = 93, .external_lex_state = 2},
  [31] = {.lex_state = 93, .external_lex_state = 2},
  [32] = {.lex_state = 93, .external_lex_state = 2},
  [33] = {.lex_state = 93, .external_lex_state = 2},
  [34] = {.lex_state = 93, .external_lex_state = 2},
  [35] = {.lex_state = 93, .external_lex_state = 2},
  [36] = {.lex_state = 93, .external_lex_state = 2},
  [37] = {.lex_state = 93, .external_lex_state = 2},
  [38] = {.lex_state = 93, .external_lex_state = 2},
  [39] = {.lex_state = 93, .external_lex_state = 2},
  [40] = {.lex_state = 93, .external_lex_state = 2},
  [41] = {.lex_state = 93, .external_lex_state = 2},
  [42] = {.lex_state = 93, .external_lex_state = 2},
  [43] = {.lex_state = 93, .external_lex_state = 2},
  [44] = {.lex_state = 93, .external_lex_state = 2},
  [45] = {.lex_state = 93, .external_lex_state = 2},
  [46] = {.lex_state = 93, .external_lex_state = 2},
  [47] = {.lex_state = 93, .external_lex_state = 2},
  [48] = {.lex_state = 93, .external_lex_state = 2},
  [49] = {.lex_state = 93, .external_lex_state = 2},
  [50] = {.lex_state = 93, .external_lex_state = 2},
  [51] = {.lex_state = 93, .external_lex_state = 2},
  [52] = {.lex_state = 93, .external_lex_state = 2},
  [53] = {.lex_state = 93, .external_lex_state = 2},
  [54] = {.lex_state = 93, .external_lex_state = 2},
  [55] = {.lex_state = 93, .external_lex_state = 2},
  [56] = {.lex_state = 93, .external_lex_state = 2},
  [57] = {.lex_state = 93, .external_lex_state = 2},
  [58] = {.lex_state = 93, .external_lex_state = 2},
  [59] = {.lex_state = 93, .external_lex_state = 2},
  [60] = {.lex_state = 93, .external_lex_state = 2},
  [61] = {.lex_state = 93, .external_lex_state = 2},
  [62] = {.lex_state = 93, .external_lex_state = 2},
  [63] = {.lex_state = 93, .external_lex_state = 2},
  [64] = {.lex_state = 93, .external_lex_state = 2},
  [65] = {.lex_state = 93, .external_lex_state = 2},
  [66] = {.lex_state = 93, .external_lex_state = 2},
  [67] = {.lex_state = 93, .external_lex_state = 2},
  [68] = {.lex_state = 93, .external_lex_state = 2},
  [69] = {.lex_state = 93, .external_lex_state = 2},
  [70] = {.lex_state = 93, .external_lex_state = 2},
  [71] = {.lex_state = 93, .external_lex_state = 2},
  [72] = {.lex_state = 93, .external_lex_state = 2},
  [73] = {.lex_state = 94, .external_lex_state = 2},
  [74] = {.lex_state = 93, .external_lex_state = 2},
  [75] = {.lex_state = 93, .external_lex_state = 2},
  [76] = {.lex_state = 93, .external_lex_state = 2},
  [77] = {.lex_state = 94, .external_lex_state = 2},
  [78] = {.lex_state = 93, .external_lex_state = 2},
  [79] = {.lex_state = 93, .external_lex_state = 2},
  [80] = {.lex_state = 93, .external_lex_state = 2},
  [81] = {.lex_state = 94, .external_lex_state = 3},
  [82] = {.lex_state = 94, .external_lex_state = 2},
  [83] = {.lex_state = 94, .external_lex_state = 2},
  [84] = {.lex_state = 94, .external_lex_state = 2},
  [85] = {.lex_state = 94, .external_lex_state = 2},
  [86] = {.lex_state = 94, .external_lex_state = 3},
  [87] = {.lex_state = 94, .external_lex_state = 2},
  [88] = {.lex_state = 94, .external_lex_state = 2},
  [89] = {.lex_state = 1, .external_lex_state = 2},
  [90] = {.lex_state = 1, .external_lex_state = 2},
  [91] = {.lex_state = 1, .external_lex_state = 2},
  [92] = {.lex_state = 94, .external_lex_state = 2},
  [93] = {.lex_state = 94, .external_lex_state = 2},
  [94] = {.lex_state = 94, .external_lex_state = 2},
  [95] = {.lex_state = 94, .external_lex_state = 2},
  [96] = {.lex_state = 94, .external_lex_state = 2},
  [97] = {.lex_state = 94, .external_lex_state = 2},
  [98] = {.lex_state = 94, .external_lex_state = 2},
  [99] = {.lex_state = 94, .external_lex_state = 2},
  [100] = {.lex_state = 94, .external_lex_state = 2},
  [101] = {.lex_state = 94, .external_lex_state = 2},
  [102] = {.lex_state = 94, .external_lex_state = 2},
  [103] = {.lex_state = 94, .external_lex_state = 2},
  [104] = {.lex_state = 94, .external_lex_state = 2},
  [105] = {.lex_state = 94, .external_lex_state = 2},
  [106] = {.lex_state = 94, .external_lex_state = 2},
  [107] = {.lex_state = 94, .external_lex_state = 2},
  [108] = {.lex_state = 94, .external_lex_state = 2},
  [109] = {.lex_state = 94, .external_lex_state = 2},
  [110] = {.lex_state = 94, .external_lex_state = 2},
  [111] = {.lex_state = 94, .external_lex_state = 2},
  [112] = {.lex_state = 94, .external_lex_state = 2},
  [113] = {.lex_state = 94, .external_lex_state = 2},
  [114] = {.lex_state = 94, .external_lex_state = 2},
  [115] = {.lex_state = 94, .external_lex_state = 2},
  [116] = {.lex_state = 94, .external_lex_state = 2},
  [117] = {.lex_state = 94, .external_lex_state = 2},
  [118] = {.lex_state = 94, .external_lex_state = 2},
  [119] = {.lex_state = 94, .external_lex_state = 2},
  [120] = {.lex_state = 94, .external_lex_state = 2},
  [121] = {.lex_state = 94, .external_lex_state = 2},
  [122] = {.lex_state = 94, .external_lex_state = 2},
  [123] = {.lex_state = 94, .external_lex_state = 2},
  [124] = {.lex_state = 94, .external_lex_state = 2},
  [125] = {.lex_state = 94, .external_lex_state = 2},
  [126] = {.lex_state = 94, .external_lex_state = 2},
  [127] = {.lex_state = 94, .external_lex_state = 2},
  [128] = {.lex_state = 94, .external_lex_state = 2},
  [129] = {.lex_state = 93, .external_lex_state = 2},
  [130] = {.lex_state = 93, .external_lex_state = 2},
  [131] = {.lex_state = 93, .external_lex_state = 2},
  [132] = {.lex_state = 93, .external_lex_state = 2},
  [133] = {.lex_state = 93, .external_lex_state = 2},
  [134] = {.lex_state = 93, .external_lex_state = 2},
  [135] = {.lex_state = 93, .external_lex_state = 2},
  [136] = {.lex_state = 93, .external_lex_state = 2},
  [137] = {.lex_state = 93, .external_lex_state = 2},
  [138] = {.lex_state = 93, .external_lex_state = 2},
  [139] = {.lex_state = 93, .external_lex_state = 2},
  [140] = {.lex_state = 93, .external_lex_state = 2},
  [141] = {.lex_state = 93, .external_lex_state = 2},
  [142] = {.lex_state = 94, .external_lex_state = 2},
  [143] = {.lex_state = 94, .external_lex_state = 2},
  [144] = {.lex_state = 94, .external_lex_state = 2},
  [145] = {.lex_state = 94, .external_lex_state = 2},
  [146] = {.lex_state = 93, .external_lex_state = 2},
  [147] = {.lex_state = 94, .external_lex_state = 2},
  [148] = {.lex_state = 93, .external_lex_state = 2},
  [149] = {.lex_state = 93, .external_lex_state = 2},
  [150] = {.lex_state = 94, .external_lex_state = 2},
  [151] = {.lex_state = 94, .external_lex_state = 2},
  [152] = {.lex_state = 93, .external_lex_state = 2},
  [153] = {.lex_state = 93, .external_lex_state = 2},
  [154] = {.lex_state = 94, .external_lex_state = 2},
  [155] = {.lex_state = 93, .external_lex_state = 2},
  [156] = {.lex_state = 93, .external_lex_state = 2},
  [157] = {.lex_state = 93, .external_lex_state = 2},
  [158] = {.lex_state = 93, .external_lex_state = 2},
  [159] = {.lex_state = 93, .external_lex_state = 2},
  [160] = {.lex_state = 93, .external_lex_state = 2},
  [161] = {.lex_state = 93, .external_lex_state = 2},
  [162] = {.lex_state = 93, .external_lex_state = 2},
  [163] = {.lex_state = 93, .external_lex_state = 2},
  [164] = {.lex_state = 93, .external_lex_state = 2},
  [165] = {.lex_state = 93, .external_lex_state = 2},
  [166] = {.lex_state = 93, .external_lex_state = 2},
  [167] = {.lex_state = 93, .external_lex_state = 2},
  [168] = {.lex_state = 93, .external_lex_state = 2},
  [169] = {.lex_state = 93, .external_lex_state = 2},
  [170] = {.lex_state = 93, .external_lex_state = 2},
  [171] = {.lex_state = 93, .external_lex_state = 2},
  [172] = {.lex_state = 93, .external_lex_state = 2},
  [173] = {.lex_state = 93, .external_lex_state = 2},
  [174] = {.lex_state = 93, .external_lex_state = 2},
  [175] = {.lex_state = 93, .external_lex_state = 2},
  [176] = {.lex_state = 93, .external_lex_state = 2},
  [177] = {.lex_state = 93, .external_lex_state = 2},
  [178] = {.lex_state = 93, .external_lex_state = 2},
  [179] = {.lex_state = 93, .external_lex_state = 2},
  [180] = {.lex_state = 93, .external_lex_state = 2},
  [181] = {.lex_state = 93, .external_lex_state = 2},
  [182] = {.lex_state = 93, .external_lex_state = 2},
  [183] = {.lex_state = 93, .external_lex_state = 2},
  [184] = {.lex_state = 93, .external_lex_state = 2},
  [185] = {.lex_state = 93, .external_lex_state = 2},
  [186] = {.lex_state = 93, .external_lex_state = 2},
  [187] = {.lex_state = 93, .external_lex_state = 2},
  [188] = {.lex_state = 93, .external_lex_state = 2},
  [189] = {.lex_state = 93, .external_lex_state = 2},
  [190] = {.lex_state = 93, .external_lex_state = 2},
  [191] = {.lex_state = 93, .external_lex_state = 2},
  [192] = {.lex_state = 93, .external_lex_state = 2},
  [193] = {.lex_state = 93, .external_lex_state = 2},
  [194] = {.lex_state = 93, .external_lex_state = 2},
  [195] = {.lex_state = 93, .external_lex_state = 2},
  [196] = {.lex_state = 93, .external_lex_state = 2},
  [197] = {.lex_state = 93, .external_lex_state = 2},
  [198] = {.lex_state = 93, .external_lex_state = 2},
  [199] = {.lex_state = 93, .external_lex_state = 2},
  [200] = {.lex_state = 93, .external_lex_state = 2},
  [201] = {.lex_state = 93, .external_lex_state = 2},
  [202] = {.lex_state = 93, .external_lex_state = 2},
  [203] = {.lex_state = 93, .external_lex_state = 2},
  [204] = {.lex_state = 93, .external_lex_state = 2},
  [205] = {.lex_state = 93, .external_lex_state = 2},
  [206] = {.lex_state = 93, .external_lex_state = 2},
  [207] = {.lex_state = 93, .external_lex_state = 2},
  [208] = {.lex_state = 93, .external_lex_state = 2},
  [209] = {.lex_state = 93, .external_lex_state = 2},
  [210] = {.lex_state = 93, .external_lex_state = 2},
  [211] = {.lex_state = 93, .external_lex_state = 2},
  [212] = {.lex_state = 93, .external_lex_state = 2},
  [213] = {.lex_state = 93, .external_lex_state = 2},
  [214] = {.lex_state = 93, .external_lex_state = 2},
  [215] = {.lex_state = 93, .external_lex_state = 2},
  [216] = {.lex_state = 93, .external_lex_state = 2},
  [217] = {.lex_state = 93, .external_lex_state = 2},
  [218] = {.lex_state = 93, .external_lex_state = 2},
  [219] = {.lex_state = 93, .external_lex_state = 2},
  [220] = {.lex_state = 93, .external_lex_state = 2},
  [221] = {.lex_state = 93, .external_lex_state = 2},
  [222] = {.lex_state = 93, .external_lex_state = 2},
  [223] = {.lex_state = 93, .external_lex_state = 2},
  [224] = {.lex_state = 94, .external_lex_state = 2},
  [225] = {.lex_state = 94, .external_lex_state = 2},
  [226] = {.lex_state = 94, .external_lex_state = 2},
  [227] = {.lex_state = 94, .external_lex_state = 2},
  [228] = {.lex_state = 94, .external_lex_state = 2},
  [229] = {.lex_state = 94, .external_lex_state = 2},
  [230] = {.lex_state = 94, .external_lex_state = 2},
  [231] = {.lex_state = 94, .external_lex_state = 2},
  [232] = {.lex_state = 94, .external_lex_state = 2},
  [233] = {.lex_state = 94, .external_lex_state = 2},
  [234] = {.lex_state = 94, .external_lex_state = 2},
  [235] = {.lex_state = 94, .external_lex_state = 2},
  [236] = {.lex_state = 94, .external_lex_state = 2},
  [237] = {.lex_state = 94, .external_lex_state = 2},
  [238] = {.lex_state = 94, .external_lex_state = 2},
  [239] = {.lex_state = 94, .external_lex_state = 2},
  [240] = {.lex_state = 94, .external_lex_state = 2},
  [241] = {.lex_state = 94, .external_lex_state = 2},
  [242] = {.lex_state = 94, .external_lex_state = 2},
  [243] = {.lex_state = 94, .external_lex_state = 2},
  [244] = {.lex_state = 94, .external_lex_state = 2},
  [245] = {.lex_state = 94, .external_lex_state = 2},
  [246] = {.lex_state = 94, .external_lex_state = 2},
  [247] = {.lex_state = 94, .external_lex_state = 2},
  [248] = {.lex_state = 94, .external_lex_state = 2},
  [249] = {.lex_state = 94, .external_lex_state = 2},
  [250] = {.lex_state = 94, .external_lex_state = 2},
  [251] = {.lex_state = 94, .external_lex_state = 2},
  [252] = {.lex_state = 94, .external_lex_state = 2},
  [253] = {.lex_state = 94, .external_lex_state = 2},
  [254] = {.lex_state = 94, .external_lex_state = 2},
  [255] = {.lex_state = 94, .external_lex_state = 2},
  [256] = {.lex_state = 94, .external_lex_state = 2},
  [257] = {.lex_state = 94, .external_lex_state = 2},
  [258] = {.lex_state = 94, .external_lex_state = 2},
  [259] = {.lex_state = 94, .external_lex_state = 2},
  [260] = {.lex_state = 94, .external_lex_state = 2},
  [261] = {.lex_state = 94, .external_lex_state = 2},
  [262] = {.lex_state = 94, .external_lex_state = 2},
  [263] = {.lex_state = 94, .external_lex_state = 2},
  [264] = {.lex_state = 94, .external_lex_state = 3},
  [265] = {.lex_state = 94, .external_lex_state = 2},
  [266] = {.lex_state = 94, .external_lex_state = 2},
  [267] = {.lex_state = 94, .external_lex_state = 2},
  [268] = {.lex_state = 94, .external_lex_state = 2},
  [269] = {.lex_state = 94, .external_lex_state = 2},
  [270] = {.lex_state = 94, .external_lex_state = 2},
  [271] = {.lex_state = 94, .external_lex_state = 2},
  [272] = {.lex_state = 94, .external_lex_state = 2},
  [273] = {.lex_state = 94, .external_lex_state = 3},
  [274] = {.lex_state = 94, .external_lex_state = 2},
  [275] = {.lex_state = 94, .external_lex_state = 2},
  [276] = {.lex_state = 94, .external_lex_state = 2},
  [277] = {.lex_state = 94, .external_lex_state = 2},
  [278] = {.lex_state = 94, .external_lex_state = 2},
  [279] = {.lex_state = 94, .external_lex_state = 2},
  [280] = {.lex_state = 94, .external_lex_state = 2},
  [281] = {.lex_state = 94, .external_lex_state = 2},
  [282] = {.lex_state = 94, .external_lex_state = 2},
  [283] = {.lex_state = 94, .external_lex_state = 3},
  [284] = {.lex_state = 94, .external_lex_state = 2},
  [285] = {.lex_state = 94, .external_lex_state = 2},
  [286] = {.lex_state = 94, .external_lex_state = 2},
  [287] = {.lex_state = 94, .external_lex_state = 2},
  [288] = {.lex_state = 94, .external_lex_state = 3},
  [289] = {.lex_state = 94, .external_lex_state = 2},
  [290] = {.lex_state = 94, .external_lex_state = 2},
  [291] = {.lex_state = 94, .external_lex_state = 2},
  [292] = {.lex_state = 94, .external_lex_state = 2},
  [293] = {.lex_state = 94, .external_lex_state = 2},
  [294] = {.lex_state = 94, .external_lex_state = 2},
  [295] = {.lex_state = 94, .external_lex_state = 2},
  [296] = {.lex_state = 94, .external_lex_state = 2},
  [297] = {.lex_state = 94, .external_lex_state = 2},
  [298] = {.lex_state = 94, .external_lex_state = 2},
  [299] = {.lex_state = 94, .external_lex_state = 2},
  [300] = {.lex_state = 94, .external_lex_state = 2},
  [301] = {.lex_state = 94, .external_lex_state = 2},
  [302] = {.lex_state = 94, .external_lex_state = 2},
  [303] = {.lex_state = 94, .external_lex_state = 2},
  [304] = {.lex_state = 94, .external_lex_state = 2},
  [305] = {.lex_state = 94, .external_lex_state = 2},
  [306] = {.lex_state = 94, .external_lex_state = 3},
  [307] = {.lex_state = 94, .external_lex_state = 2},
  [308] = {.lex_state = 94, .external_lex_state = 2},
  [309] = {.lex_state = 94, .external_lex_state = 2},
  [310] = {.lex_state = 94, .external_lex_state = 2},
  [311] = {.lex_state = 94, .external_lex_state = 2},
  [312] = {.lex_state = 94, .external_lex_state = 2},
  [313] = {.lex_state = 94, .external_lex_state = 2},
  [314] = {.lex_state = 94, .external_lex_state = 2},
  [315] = {.lex_state = 94, .external_lex_state = 3},
  [316] = {.lex_state = 94, .external_lex_state = 2},
  [317] = {.lex_state = 94, .external_lex_state = 2},
  [318] = {.lex_state = 94, .external_lex_state = 2},
  [319] = {.lex_state = 94, .external_lex_state = 3},
  [320] = {.lex_state = 94, .external_lex_state = 3},
  [321] = {.lex_state = 94, .external_lex_state = 2},
  [322] = {.lex_state = 94, .external_lex_state = 2},
  [323] = {.lex_state = 94, .external_lex_state = 2},
  [324] = {.lex_state = 94, .external_lex_state = 2},
  [325] = {.lex_state = 94, .external_lex_state = 2},
  [326] = {.lex_state = 94, .external_lex_state = 3},
  [327] = {.lex_state = 94, .external_lex_state = 2},
  [328] = {.lex_state = 94, .external_lex_state = 2},
  [329] = {.lex_state = 94, .external_lex_state = 2},
  [330] = {.lex_state = 94, .external_lex_state = 2},
  [331] = {.lex_state = 94, .external_lex_state = 2},
  [332] = {.lex_state = 94, .external_lex_state = 2},
  [333] = {.lex_state = 94, .external_lex_state = 3},
  [334] = {.lex_state = 94, .external_lex_state = 2},
  [335] = {.lex_state = 94, .external_lex_state = 2},
  [336] = {.lex_state = 94, .external_lex_state = 2},
  [337] = {.lex_state = 94, .external_lex_state = 3},
  [338] = {.lex_state = 94, .external_lex_state = 2},
  [339] = {.lex_state = 94, .external_lex_state = 3},
  [340] = {.lex_state = 94, .external_lex_state = 3},
  [341] = {.lex_state = 94, .external_lex_state = 2},
  [342] = {.lex_state = 94, .external_lex_state = 2},
  [343] = {.lex_state = 94, .external_lex_state = 2},
  [344] = {.lex_state = 94, .external_lex_state = 2},
  [345] = {.lex_state = 94, .external_lex_state = 2},
  [346] = {.lex_state = 94, .external_lex_state = 2},
  [347] = {.lex_state = 94, .external_lex_state = 2},
  [348] = {.lex_state = 94, .external_lex_state = 3},
  [349] = {.lex_state = 94, .external_lex_state = 3},
  [350] = {.lex_state = 94, .external_lex_state = 2},
  [351] = {.lex_state = 94, .external_lex_state = 3},
  [352] = {.lex_state = 94, .external_lex_state = 2},
  [353] = {.lex_state = 94, .external_lex_state = 3},
  [354] = {.lex_state = 94, .external_lex_state = 2},
  [355] = {.lex_state = 94, .external_lex_state = 3},
  [356] = {.lex_state = 94, .external_lex_state = 2},
  [357] = {.lex_state = 94, .external_lex_state = 2},
  [358] = {.lex_state = 94, .external_lex_state = 3},
  [359] = {.lex_state = 94, .external_lex_state = 2},
  [360] = {.lex_state = 94, .external_lex_state = 2},
  [361] = {.lex_state = 94, .external_lex_state = 3},
  [362] = {.lex_state = 94, .external_lex_state = 2},
  [363] = {.lex_state = 94, .external_lex_state = 2},
  [364] = {.lex_state = 94, .external_lex_state = 2},
  [365] = {.lex_state = 94, .external_lex_state = 2},
  [366] = {.lex_state = 94, .external_lex_state = 2},
  [367] = {.lex_state = 94, .external_lex_state = 2},
  [368] = {.lex_state = 94, .external_lex_state = 2},
  [369] = {.lex_state = 94, .external_lex_state = 2},
  [370] = {.lex_state = 94, .external_lex_state = 2},
  [371] = {.lex_state = 94, .external_lex_state = 2},
  [372] = {.lex_state = 94, .external_lex_state = 2},
  [373] = {.lex_state = 94, .external_lex_state = 2},
  [374] = {.lex_state = 94, .external_lex_state = 2},
  [375] = {.lex_state = 94, .external_lex_state = 2},
  [376] = {.lex_state = 94, .external_lex_state = 2},
  [377] = {.lex_state = 94, .external_lex_state = 2},
  [378] = {.lex_state = 94, .external_lex_state = 2},
  [379] = {.lex_state = 94, .external_lex_state = 3},
  [380] = {.lex_state = 94, .external_lex_state = 2},
  [381] = {.lex_state = 94, .external_lex_state = 3},
  [382] = {.lex_state = 94, .external_lex_state = 2},
  [383] = {.lex_state = 94, .external_lex_state = 2},
  [384] = {.lex_state = 94, .external_lex_state = 3},
  [385] = {.lex_state = 94, .external_lex_state = 2},
  [386] = {.lex_state = 94, .external_lex_state = 2},
  [387] = {.lex_state = 94, .external_lex_state = 2},
  [388] = {.lex_state = 94, .external_lex_state = 2},
  [389] = {.lex_state = 94, .external_lex_state = 2},
  [390] = {.lex_state = 94, .external_lex_state = 2},
  [391] = {.lex_state = 94, .external_lex_state = 3},
  [392] = {.lex_state = 94, .external_lex_state = 2},
  [393] = {.lex_state = 94, .external_lex_state = 3},
  [394] = {.lex_state = 94, .external_lex_state = 2},
  [395] = {.lex_state = 94, .external_lex_state = 2},
  [396] = {.lex_state = 94, .external_lex_state = 2},
  [397] = {.lex_state = 94, .external_lex_state = 2},
  [398] = {.lex_state = 94, .external_lex_state = 2},
  [399] = {.lex_state = 94, .external_lex_state = 2},
  [400] = {.lex_state = 94, .external_lex_state = 2},
  [401] = {.lex_state = 94, .external_lex_state = 2},
  [402] = {.lex_state = 94, .external_lex_state = 3},
  [403] = {.lex_state = 94, .external_lex_state = 2},
  [404] = {.lex_state = 94, .external_lex_state = 2},
  [405] = {.lex_state = 94, .external_lex_state = 2},
  [406] = {.lex_state = 94, .external_lex_state = 2},
  [407] = {.lex_state = 94, .external_lex_state = 2},
  [408] = {.lex_state = 94, .external_lex_state = 2},
  [409] = {.lex_state = 94, .external_lex_state = 2},
  [410] = {.lex_state = 94, .external_lex_state = 2},
  [411] = {.lex_state = 94, .external_lex_state = 3},
  [412] = {.lex_state = 94, .external_lex_state = 3},
  [413] = {.lex_state = 94, .external_lex_state = 2},
  [414] = {.lex_state = 94, .external_lex_state = 3},
  [415] = {.lex_state = 94, .external_lex_state = 3},
  [416] = {.lex_state = 94, .external_lex_state = 3},
  [417] = {.lex_state = 94, .external_lex_state = 3},
  [418] = {.lex_state = 94, .external_lex_state = 3},
  [419] = {.lex_state = 94, .external_lex_state = 3},
  [420] = {.lex_state = 94, .external_lex_state = 3},
  [421] = {.lex_state = 94, .external_lex_state = 3},
  [422] = {.lex_state = 94, .external_lex_state = 3},
  [423] = {.lex_state = 94, .external_lex_state = 3},
  [424] = {.lex_state = 94, .external_lex_state = 3},
  [425] = {.lex_state = 94, .external_lex_state = 2},
  [426] = {.lex_state = 94, .external_lex_state = 2},
  [427] = {.lex_state = 94, .external_lex_state = 2},
  [428] = {.lex_state = 94, .external_lex_state = 2},
  [429] = {.lex_state = 94, .external_lex_state = 2},
  [430] = {.lex_state = 94, .external_lex_state = 2},
  [431] = {.lex_state = 94, .external_lex_state = 3},
  [432] = {.lex_state = 94, .external_lex_state = 2},
  [433] = {.lex_state = 94, .external_lex_state = 2},
  [434] = {.lex_state = 94, .external_lex_state = 2},
  [435] = {.lex_state = 94, .external_lex_state = 3},
  [436] = {.lex_state = 94, .external_lex_state = 2},
  [437] = {.lex_state = 94, .external_lex_state = 3},
  [438] = {.lex_state = 94, .external_lex_state = 2},
  [439] = {.lex_state = 94, .external_lex_state = 2},
  [440] = {.lex_state = 94, .external_lex_state = 2},
  [441] = {.lex_state = 94, .external_lex_state = 2},
  [442] = {.lex_state = 94, .external_lex_state = 3},
  [443] = {.lex_state = 94, .external_lex_state = 2},
  [444] = {.lex_state = 94, .external_lex_state = 3},
  [445] = {.lex_state = 94, .external_lex_state = 2},
  [446] = {.lex_state = 94, .external_lex_state = 2},
  [447] = {.lex_state = 94, .external_lex_state = 2},
  [448] = {.lex_state = 94, .external_lex_state = 3},
  [449] = {.lex_state = 94, .external_lex_state = 2},
  [450] = {.lex_state = 94, .external_lex_state = 2},
  [451] = {.lex_state = 94, .external_lex_state = 2},
  [452] = {.lex_state = 94, .external_lex_state = 2},
  [453] = {.lex_state = 94, .external_lex_state = 2},
  [454] = {.lex_state = 94, .external_lex_state = 3},
  [455] = {.lex_state = 94, .external_lex_state = 2},
  [456] = {.lex_state = 94, .external_lex_state = 3},
  [457] = {.lex_state = 94, .external_lex_state = 2},
  [458] = {.lex_state = 94, .external_lex_state = 2},
  [459] = {.lex_state = 94, .external_lex_state = 2},
  [460] = {.lex_state = 94, .external_lex_state = 2},
  [461] = {.lex_state = 94, .external_lex_state = 2},
  [462] = {.lex_state = 94, .external_lex_state = 3},
  [463] = {.lex_state = 94, .external_lex_state = 2},
  [464] = {.lex_state = 93, .external_lex_state = 4},
  [465] = {.lex_state = 93, .external_lex_state = 4},
  [466] = {.lex_state = 93, .external_lex_state = 4},
  [467] = {.lex_state = 93, .external_lex_state = 4},
  [468] = {.lex_state = 93, .external_lex_state = 4},
  [469] = {.lex_state = 93, .external_lex_state = 4},
  [470] = {.lex_state = 93, .external_lex_state = 4},
  [471] = {.lex_state = 93, .external_lex_state = 4},
  [472] = {.lex_state = 93, .external_lex_state = 4},
  [473] = {.lex_state = 93, .external_lex_state = 4},
  [474] = {.lex_state = 93, .external_lex_state = 4},
  [475] = {.lex_state = 93, .external_lex_state = 4},
  [476] = {.lex_state = 93, .external_lex_state = 4},
  [477] = {.lex_state = 3, .external_lex_state = 2},
  [478] = {.lex_state = 5, .external_lex_state = 2},
  [479] = {.lex_state = 5, .external_lex_state = 2},
  [480] = {.lex_state = 5, .external_lex_state = 2},
  [481] = {.lex_state = 95, .external_lex_state = 4},
  [482] = {.lex_state = 5, .external_lex_state = 2},
  [483] = {.lex_state = 5, .external_lex_state = 2},
  [484] = {.lex_state = 94, .external_lex_state = 2},
  [485] = {.lex_state = 5, .external_lex_state = 2},
  [486] = {.lex_state = 94, .external_lex_state = 2},
  [487] = {.lex_state = 94, .external_lex_state = 2},
  [488] = {.lex_state = 93, .external_lex_state = 4},
  [489] = {.lex_state = 94, .external_lex_state = 2},
  [490] = {.lex_state = 93, .external_lex_state = 5},
  [491] = {.lex_state = 5, .external_lex_state = 2},
  [492] = {.lex_state = 94, .external_lex_state = 2},
  [493] = {.lex_state = 95, .external_lex_state = 4},
  [494] = {.lex_state = 5, .external_lex_state = 2},
  [495] = {.lex_state = 5, .external_lex_state = 2},
  [496] = {.lex_state = 5, .external_lex_state = 2},
  [497] = {.lex_state = 5, .external_lex_state = 2},
  [498] = {.lex_state = 95, .external_lex_state = 4},
  [499] = {.lex_state = 5, .external_lex_state = 2},
  [500] = {.lex_state = 94, .external_lex_state = 2},
  [501] = {.lex_state = 5, .external_lex_state = 2},
  [502] = {.lex_state = 5, .external_lex_state = 2},
  [503] = {.lex_state = 5, .external_lex_state = 2},
  [504] = {.lex_state = 5, .external_lex_state = 2},
  [505] = {.lex_state = 5, .external_lex_state = 2},
  [506] = {.lex_state = 5, .external_lex_state = 2},
  [507] = {.lex_state = 5, .external_lex_state = 2},
  [508] = {.lex_state = 5, .external_lex_state = 2},
  [509] = {.lex_state = 5, .external_lex_state = 2},
  [510] = {.lex_state = 5, .external_lex_state = 2},
  [511] = {.lex_state = 5, .external_lex_state = 2},
  [512] = {.lex_state = 5, .external_lex_state = 2},
  [513] = {.lex_state = 5, .external_lex_state = 2},
  [514] = {.lex_state = 5, .external_lex_state = 2},
  [515] = {.lex_state = 5, .external_lex_state = 2},
  [516] = {.lex_state = 5, .external_lex_state = 2},
  [517] = {.lex_state = 5, .external_lex_state = 2},
  [518] = {.lex_state = 95, .external_lex_state = 4},
  [519] = {.lex_state = 95, .external_lex_state = 4},
  [520] = {.lex_state = 95, .external_lex_state = 4},
  [521] = {.lex_state = 95, .external_lex_state = 4},
  [522] = {.lex_state = 95, .external_lex_state = 4},
  [523] = {.lex_state = 5, .external_lex_state = 2},
  [524] = {.lex_state = 95, .external_lex_state = 4},
  [525] = {.lex_state = 95, .external_lex_state = 4},
  [526] = {.lex_state = 5, .external_lex_state = 2},
  [527] = {.lex_state = 95, .external_lex_state = 4},
  [528] = {.lex_state = 95, .external_lex_state = 4},
  [529] = {.lex_state = 95, .external_lex_state = 4},
  [530] = {.lex_state = 95, .external_lex_state = 4},
  [531] = {.lex_state = 95, .external_lex_state = 4},
  [532] = {.lex_state = 6, .external_lex_state = 2},
  [533] = {.lex_state = 95, .external_lex_state = 4},
  [534] = {.lex_state = 95, .external_lex_state = 4},
  [535] = {.lex_state = 5, .external_lex_state = 2},
  [536] = {.lex_state = 5, .external_lex_state = 2},
  [537] = {.lex_state = 5, .external_lex_state = 2},
  [538] = {.lex_state = 93, .external_lex_state = 4},
  [539] = {.lex_state = 95, .external_lex_state = 4},
  [540] = {.lex_state = 95, .external_lex_state = 4},
  [541] = {.lex_state = 95, .external_lex_state = 4},
  [542] = {.lex_state = 93, .external_lex_state = 5},
  [543] = {.lex_state = 95, .external_lex_state = 4},
  [544] = {.lex_state = 93, .external_lex_state = 5},
  [545] = {.lex_state = 95, .external_lex_state = 4},
  [546] = {.lex_state = 95, .external_lex_state = 4},
  [547] = {.lex_state = 95, .external_lex_state = 4},
  [548] = {.lex_state = 95, .external_lex_state = 4},
  [549] = {.lex_state = 95, .external_lex_state = 4},
  [550] = {.lex_state = 95, .external_lex_state = 4},
  [551] = {.lex_state = 95, .external_lex_state = 4},
  [552] = {.lex_state = 95, .external_lex_state = 4},
  [553] = {.lex_state = 93, .external_lex_state = 4},
  [554] = {.lex_state = 93, .external_lex_state = 4},
  [555] = {.lex_state = 95, .external_lex_state = 4},
  [556] = {.lex_state = 95, .external_lex_state = 4},
  [557] = {.lex_state = 93, .external_lex_state = 4},
  [558] = {.lex_state = 95, .external_lex_state = 4},
  [559] = {.lex_state = 93, .external_lex_state = 5},
  [560] = {.lex_state = 93, .external_lex_state = 4},
  [561] = {.lex_state = 93, .external_lex_state = 4},
  [562] = {.lex_state = 93, .external_lex_state = 4},
  [563] = {.lex_state = 93, .external_lex_state = 5},
  [564] = {.lex_state = 93, .external_lex_state = 5},
  [565] = {.lex_state = 93, .external_lex_state = 4},
  [566] = {.lex_state = 93, .external_lex_state = 4},
  [567] = {.lex_state = 95, .external_lex_state = 4},
  [568] = {.lex_state = 93, .external_lex_state = 4},
  [569] = {.lex_state = 93, .external_lex_state = 4},
  [570] = {.lex_state = 95, .external_lex_state = 4},
  [571] = {.lex_state = 93, .external_lex_state = 4},
  [572] = {.lex_state = 93, .external_lex_state = 5},
  [573] = {.lex_state = 95, .external_lex_state = 4},
  [574] = {.lex_state = 95, .external_lex_state = 4},
  [575] = {.lex_state = 95, .external_lex_state = 4},
  [576] = {.lex_state = 95, .external_lex_state = 4},
  [577] = {.lex_state = 93, .external_lex_state = 5},
  [578] = {.lex_state = 95, .external_lex_state = 4},
  [579] = {.lex_state = 93, .external_lex_state = 5},
  [580] = {.lex_state = 5, .external_lex_state = 2},
  [581] = {.lex_state = 93, .external_lex_state = 5},
  [582] = {.lex_state = 93, .external_lex_state = 5},
  [583] = {.lex_state = 93, .external_lex_state = 5},
  [584] = {.lex_state = 93, .external_lex_state = 5},
  [585] = {.lex_state = 93, .external_lex_state = 2},
  [586] = {.lex_state = 93, .external_lex_state = 2},
  [587] = {.lex_state = 93, .external_lex_state = 2},
  [588] = {.lex_state = 93, .external_lex_state = 2},
  [589] = {.lex_state = 93, .external_lex_state = 2},
  [590] = {.lex_state = 93, .external_lex_state = 2},
  [591] = {.lex_state = 93, .external_lex_state = 2},
  [592] = {.lex_state = 5, .external_lex_state = 2},
  [593] = {.lex_state = 5, .external_lex_state = 2},
  [594] = {.lex_state = 93, .external_lex_state = 2},
  [595] = {.lex_state = 5, .external_lex_state = 2},
  [596] = {.lex_state = 5, .external_lex_state = 2},
  [597] = {.lex_state = 7, .external_lex_state = 2},
  [598] = {.lex_state = 5, .external_lex_state = 2},
  [599] = {.lex_state = 5, .external_lex_state = 2},
  [600] = {.lex_state = 5, .external_lex_state = 2},
  [601] = {.lex_state = 5, .external_lex_state = 2},
  [602] = {.lex_state = 5, .external_lex_state = 2},
  [603] = {.lex_state = 5, .external_lex_state = 2},
  [604] = {.lex_state = 5, .external_lex_state = 2},
  [605] = {.lex_state = 5, .external_lex_state = 2},
  [606] = {.lex_state = 93, .external_lex_state = 2},
  [607] = {.lex_state = 93, .external_lex_state = 2},
  [608] = {.lex_state = 93, .external_lex_state = 2},
  [609] = {.lex_state = 5, .external_lex_state = 2},
  [610] = {.lex_state = 5, .external_lex_state = 2},
  [611] = {.lex_state = 5, .external_lex_state = 2},
  [612] = {.lex_state = 6, .external_lex_state = 2},
  [613] = {.lex_state = 93, .external_lex_state = 2},
  [614] = {.lex_state = 5, .external_lex_state = 2},
  [615] = {.lex_state = 93, .external_lex_state = 2},
  [616] = {.lex_state = 5, .external_lex_state = 2},
  [617] = {.lex_state = 5, .external_lex_state = 2},
  [618] = {.lex_state = 5, .external_lex_state = 2},
  [619] = {.lex_state = 93, .external_lex_state = 2},
  [620] = {.lex_state = 93, .external_lex_state = 2},
  [621] = {.lex_state = 93, .external_lex_state = 2},
  [622] = {.lex_state = 93, .external_lex_state = 2},
  [623] = {.lex_state = 5, .external_lex_state = 2},
  [624] = {.lex_state = 5, .external_lex_state = 2},
  [625] = {.lex_state = 5, .external_lex_state = 2},
  [626] = {.lex_state = 6, .external_lex_state = 2},
  [627] = {.lex_state = 6, .external_lex_state = 2},
  [628] = {.lex_state = 6, .external_lex_state = 2},
  [629] = {.lex_state = 95, .external_lex_state = 4},
  [630] = {.lex_state = 7, .external_lex_state = 2},
  [631] = {.lex_state = 7, .external_lex_state = 2},
  [632] = {.lex_state = 7, .external_lex_state = 2},
  [633] = {.lex_state = 95, .external_lex_state = 4},
  [634] = {.lex_state = 5, .external_lex_state = 2},
  [635] = {.lex_state = 15, .external_lex_state = 6},
  [636] = {.lex_state = 15, .external_lex_state = 6},
  [637] = {.lex_state = 15, .external_lex_state = 6},
  [638] = {.lex_state = 15, .external_lex_state = 6},
  [639] = {.lex_state = 15, .external_lex_state = 6},
  [640] = {.lex_state = 15, .external_lex_state = 6},
  [641] = {.lex_state = 15, .external_lex_state = 6},
  [642] = {.lex_state = 5, .external_lex_state = 2},
  [643] = {.lex_state = 95, .external_lex_state = 4},
  [644] = {.lex_state = 15, .external_lex_state = 6},
  [645] = {.lex_state = 15, .external_lex_state = 6},
  [646] = {.lex_state = 95, .external_lex_state = 4},
  [647] = {.lex_state = 15, .external_lex_state = 6},
  [648] = {.lex_state = 95, .external_lex_state = 4},
  [649] = {.lex_state = 15, .external_lex_state = 6},
  [650] = {.lex_state = 15, .external_lex_state = 6},
  [651] = {.lex_state = 5, .external_lex_state = 2},
  [652] = {.lex_state = 5, .external_lex_state = 2},
  [653] = {.lex_state = 5, .external_lex_state = 2},
  [654] = {.lex_state = 5, .external_lex_state = 2},
  [655] = {.lex_state = 95, .external_lex_state = 4},
  [656] = {.lex_state = 15, .external_lex_state = 6},
  [657] = {.lex_state = 95, .external_lex_state = 4},
  [658] = {.lex_state = 5, .external_lex_state = 2},
  [659] = {.lex_state = 5, .external_lex_state = 2},
  [660] = {.lex_state = 5, .external_lex_state = 2},
  [661] = {.lex_state = 5, .external_lex_state = 2},
  [662] = {.lex_state = 95, .external_lex_state = 4},
  [663] = {.lex_state = 5, .external_lex_state = 2},
  [664] = {.lex_state = 5, .external_lex_state = 2},
  [665] = {.lex_state = 5, .external_lex_state = 2},
  [666] = {.lex_state = 5, .external_lex_state = 2},
  [667] = {.lex_state = 95, .external_lex_state = 4},
  [668] = {.lex_state = 5, .external_lex_state = 2},
  [669] = {.lex_state = 5, .external_lex_state = 2},
  [670] = {.lex_state = 5, .external_lex_state = 2},
  [671] = {.lex_state = 5, .external_lex_state = 2},
  [672] = {.lex_state = 5, .external_lex_state = 2},
  [673] = {.lex_state = 5, .external_lex_state = 2},
  [674] = {.lex_state = 5, .external_lex_state = 2},
  [675] = {.lex_state = 15, .external_lex_state = 6},
  [676] = {.lex_state = 5, .external_lex_state = 2},
  [677] = {.lex_state = 5, .external_lex_state = 2},
  [678] = {.lex_state = 8, .external_lex_state = 4},
  [679] = {.lex_state = 8, .external_lex_state = 4},
  [680] = {.lex_state = 8, .external_lex_state = 4},
  [681] = {.lex_state = 15, .external_lex_state = 6},
  [682] = {.lex_state = 8, .external_lex_state = 4},
  [683] = {.lex_state = 93, .external_lex_state = 4},
  [684] = {.lex_state = 93, .external_lex_state = 4},
  [685] = {.lex_state = 95, .external_lex_state = 4},
  [686] = {.lex_state = 95, .external_lex_state = 4},
  [687] = {.lex_state = 95, .external_lex_state = 4},
  [688] = {.lex_state = 95, .external_lex_state = 4},
  [689] = {.lex_state = 95, .external_lex_state = 4},
  [690] = {.lex_state = 95, .external_lex_state = 4},
  [691] = {.lex_state = 2, .external_lex_state = 7},
  [692] = {.lex_state = 95, .external_lex_state = 4},
  [693] = {.lex_state = 2, .external_lex_state = 7},
  [694] = {.lex_state = 2, .external_lex_state = 7},
  [695] = {.lex_state = 95, .external_lex_state = 4},
  [696] = {.lex_state = 2, .external_lex_state = 7},
  [697] = {.lex_state = 2, .external_lex_state = 7},
  [698] = {.lex_state = 2, .external_lex_state = 7},
  [699] = {.lex_state = 95, .external_lex_state = 4},
  [700] = {.lex_state = 2, .external_lex_state = 7},
  [701] = {.lex_state = 95, .external_lex_state = 4},
  [702] = {.lex_state = 95, .external_lex_state = 4},
  [703] = {.lex_state = 95, .external_lex_state = 4},
  [704] = {.lex_state = 95, .external_lex_state = 4},
  [705] = {.lex_state = 2, .external_lex_state = 7},
  [706] = {.lex_state = 95, .external_lex_state = 4},
  [707] = {.lex_state = 2, .external_lex_state = 7},
  [708] = {.lex_state = 95, .external_lex_state = 4},
  [709] = {.lex_state = 2, .external_lex_state = 7},
  [710] = {.lex_state = 95, .external_lex_state = 4},
  [711] = {.lex_state = 95, .external_lex_state = 4},
  [712] = {.lex_state = 95, .external_lex_state = 4},
  [713] = {.lex_state = 6, .external_lex_state = 4},
  [714] = {.lex_state = 95, .external_lex_state = 4},
  [715] = {.lex_state = 2, .external_lex_state = 7},
  [716] = {.lex_state = 95, .external_lex_state = 4},
  [717] = {.lex_state = 2, .external_lex_state = 7},
  [718] = {.lex_state = 2, .external_lex_state = 7},
  [719] = {.lex_state = 95, .external_lex_state = 4},
  [720] = {.lex_state = 2, .external_lex_state = 7},
  [721] = {.lex_state = 2, .external_lex_state = 7},
  [722] = {.lex_state = 4, .external_lex_state = 8},
  [723] = {.lex_state = 4, .external_lex_state = 8},
  [724] = {.lex_state = 95, .external_lex_state = 4},
  [725] = {.lex_state = 95, .external_lex_state = 4},
  [726] = {.lex_state = 4, .external_lex_state = 8},
  [727] = {.lex_state = 95, .external_lex_state = 4},
  [728] = {.lex_state = 4, .external_lex_state = 8},
  [729] = {.lex_state = 4, .external_lex_state = 8},
  [730] = {.lex_state = 4, .external_lex_state = 8},
  [731] = {.lex_state = 6, .external_lex_state = 4},
  [732] = {.lex_state = 4, .external_lex_state = 8},
  [733] = {.lex_state = 4, .external_lex_state = 8},
  [734] = {.lex_state = 4, .external_lex_state = 8},
  [735] = {.lex_state = 4, .external_lex_state = 8},
  [736] = {.lex_state = 4, .external_lex_state = 8},
  [737] = {.lex_state = 4, .external_lex_state = 8},
  [738] = {.lex_state = 95, .external_lex_state = 4},
  [739] = {.lex_state = 95, .external_lex_state = 4},
  [740] = {.lex_state = 4, .external_lex_state = 8},
  [741] = {.lex_state = 95, .external_lex_state = 4},
  [742] = {.lex_state = 4, .external_lex_state = 8},
  [743] = {.lex_state = 95, .external_lex_state = 4},
  [744] = {.lex_state = 4, .external_lex_state = 8},
  [745] = {.lex_state = 2, .external_lex_state = 9},
  [746] = {.lex_state = 2, .external_lex_state = 9},
  [747] = {.lex_state = 10, .external_lex_state = 4},
  [748] = {.lex_state = 11, .external_lex_state = 4},
  [749] = {.lex_state = 11, .external_lex_state = 4},
  [750] = {.lex_state = 2, .external_lex_state = 9},
  [751] = {.lex_state = 11, .external_lex_state = 4},
  [752] = {.lex_state = 95, .external_lex_state = 4},
  [753] = {.lex_state = 3, .external_lex_state = 10},
  [754] = {.lex_state = 95, .external_lex_state = 4},
  [755] = {.lex_state = 2, .external_lex_state = 9},
  [756] = {.lex_state = 2, .external_lex_state = 9},
  [757] = {.lex_state = 2, .external_lex_state = 9},
  [758] = {.lex_state = 2, .external_lex_state = 9},
  [759] = {.lex_state = 95, .external_lex_state = 4},
  [760] = {.lex_state = 2, .external_lex_state = 9},
  [761] = {.lex_state = 2, .external_lex_state = 9},
  [762] = {.lex_state = 2, .external_lex_state = 9},
  [763] = {.lex_state = 95, .external_lex_state = 4},
  [764] = {.lex_state = 3, .external_lex_state = 10},
  [765] = {.lex_state = 2, .external_lex_state = 9},
  [766] = {.lex_state = 3, .external_lex_state = 10},
  [767] = {.lex_state = 11, .external_lex_state = 4},
  [768] = {.lex_state = 10, .external_lex_state = 4},
  [769] = {.lex_state = 2, .external_lex_state = 9},
  [770] = {.lex_state = 2, .external_lex_state = 9},
  [771] = {.lex_state = 2, .external_lex_state = 9},
  [772] = {.lex_state = 10, .external_lex_state = 4},
  [773] = {.lex_state = 3, .external_lex_state = 10},
  [774] = {.lex_state = 10, .external_lex_state = 4},
  [775] = {.lex_state = 2, .external_lex_state = 9},
  [776] = {.lex_state = 3, .external_lex_state = 10},
  [777] = {.lex_state = 3, .external_lex_state = 10},
  [778] = {.lex_state = 11, .external_lex_state = 4},
  [779] = {.lex_state = 2, .external_lex_state = 9},
  [780] = {.lex_state = 2, .external_lex_state = 9},
  [781] = {.lex_state = 2, .external_lex_state = 9},
  [782] = {.lex_state = 2, .external_lex_state = 9},
  [783] = {.lex_state = 3, .external_lex_state = 10},
  [784] = {.lex_state = 4, .external_lex_state = 11},
  [785] = {.lex_state = 4, .external_lex_state = 11},
  [786] = {.lex_state = 4, .external_lex_state = 11},
  [787] = {.lex_state = 10, .external_lex_state = 4},
  [788] = {.lex_state = 4, .external_lex_state = 11},
  [789] = {.lex_state = 4, .external_lex_state = 11},
  [790] = {.lex_state = 4, .external_lex_state = 11},
  [791] = {.lex_state = 4, .external_lex_state = 11},
  [792] = {.lex_state = 4, .external_lex_state = 11},
  [793] = {.lex_state = 4, .external_lex_state = 11},
  [794] = {.lex_state = 4, .external_lex_state = 11},
  [795] = {.lex_state = 4, .external_lex_state = 11},
  [796] = {.lex_state = 4, .external_lex_state = 11},
  [797] = {.lex_state = 4, .external_lex_state = 11},
  [798] = {.lex_state = 4, .external_lex_state = 11},
  [799] = {.lex_state = 4, .external_lex_state = 11},
  [800] = {.lex_state = 15, .external_lex_state = 6},
  [801] = {.lex_state = 4, .external_lex_state = 11},
  [802] = {.lex_state = 4, .external_lex_state = 11},
  [803] = {.lex_state = 4, .external_lex_state = 11},
  [804] = {.lex_state = 10, .external_lex_state = 4},
  [805] = {.lex_state = 4, .external_lex_state = 11},
  [806] = {.lex_state = 4, .external_lex_state = 11},
  [807] = {.lex_state = 4, .external_lex_state = 11},
  [808] = {.lex_state = 4, .external_lex_state = 11},
  [809] = {.lex_state = 4, .external_lex_state = 11},
  [810] = {.lex_state = 4, .external_lex_state = 11},
  [811] = {.lex_state = 4, .external_lex_state = 11},
  [812] = {.lex_state = 4, .external_lex_state = 11},
  [813] = {.lex_state = 4, .external_lex_state = 11},
  [814] = {.lex_state = 4, .external_lex_state = 11},
  [815] = {.lex_state = 4, .external_lex_state = 11},
  [816] = {.lex_state = 4, .external_lex_state = 11},
  [817] = {.lex_state = 4, .external_lex_state = 11},
  [818] = {.lex_state = 4, .external_lex_state = 11},
  [819] = {.lex_state = 4, .external_lex_state = 11},
  [820] = {.lex_state = 4, .external_lex_state = 11},
  [821] = {.lex_state = 4, .external_lex_state = 11},
  [822] = {.lex_state = 4, .external_lex_state = 11},
  [823] = {.lex_state = 4, .external_lex_state = 11},
  [824] = {.lex_state = 4, .external_lex_state = 11},
  [825] = {.lex_state = 4, .external_lex_state = 11},
  [826] = {.lex_state = 2, .external_lex_state = 7},
  [827] = {.lex_state = 15, .external_lex_state = 4},
  [828] = {.lex_state = 2, .external_lex_state = 7},
  [829] = {.lex_state = 15, .external_lex_state = 6},
  [830] = {.lex_state = 15, .external_lex_state = 6},
  [831] = {.lex_state = 15, .external_lex_state = 6},
  [832] = {.lex_state = 2, .external_lex_state = 7},
  [833] = {.lex_state = 15, .external_lex_state = 4},
  [834] = {.lex_state = 15, .external_lex_state = 6},
  [835] = {.lex_state = 6, .external_lex_state = 4},
  [836] = {.lex_state = 0, .external_lex_state = 10},
  [837] = {.lex_state = 15, .external_lex_state = 6},
  [838] = {.lex_state = 15, .external_lex_state = 6},
  [839] = {.lex_state = 15, .external_lex_state = 6},
  [840] = {.lex_state = 95, .external_lex_state = 4},
  [841] = {.lex_state = 15, .external_lex_state = 4},
  [842] = {.lex_state = 15, .external_lex_state = 6},
  [843] = {.lex_state = 15, .external_lex_state = 4},
  [844] = {.lex_state = 95, .external_lex_state = 4},
  [845] = {.lex_state = 95, .external_lex_state = 4},
  [846] = {.lex_state = 93, .external_lex_state = 4},
  [847] = {.lex_state = 4, .external_lex_state = 8},
  [848] = {.lex_state = 93, .external_lex_state = 4},
  [849] = {.lex_state = 95, .external_lex_state = 4},
  [850] = {.lex_state = 93, .external_lex_state = 5},
  [851] = {.lex_state = 93, .external_lex_state = 5},
  [852] = {.lex_state = 3, .external_lex_state = 4},
  [853] = {.lex_state = 4, .external_lex_state = 8},
  [854] = {.lex_state = 15, .external_lex_state = 4},
  [855] = {.lex_state = 2, .external_lex_state = 9},
  [856] = {.lex_state = 95, .external_lex_state = 4},
  [857] = {.lex_state = 95, .external_lex_state = 4},
  [858] = {.lex_state = 2, .external_lex_state = 9},
  [859] = {.lex_state = 4, .external_lex_state = 8},
  [860] = {.lex_state = 4, .external_lex_state = 11},
  [861] = {.lex_state = 3, .external_lex_state = 4},
  [862] = {.lex_state = 12, .external_lex_state = 4},
  [863] = {.lex_state = 12, .external_lex_state = 4},
  [864] = {.lex_state = 3, .external_lex_state = 4},
  [865] = {.lex_state = 12, .external_lex_state = 4},
  [866] = {.lex_state = 12, .external_lex_state = 4},
  [867] = {.lex_state = 12, .external_lex_state = 4},
  [868] = {.lex_state = 3, .external_lex_state = 4},
  [869] = {.lex_state = 12, .external_lex_state = 4},
  [870] = {.lex_state = 12, .external_lex_state = 4},
  [871] = {.lex_state = 12, .external_lex_state = 4},
  [872] = {.lex_state = 3, .external_lex_state = 4},
  [873] = {.lex_state = 12, .external_lex_state = 4},
  [874] = {.lex_state = 12, .external_lex_state = 4},
  [875] = {.lex_state = 12, .external_lex_state = 4},
  [876] = {.lex_state = 3, .external_lex_state = 4},
  [877] = {.lex_state = 12, .external_lex_state = 4},
  [878] = {.lex_state = 12, .external_lex_state = 4},
  [879] = {.lex_state = 3, .external_lex_state = 4},
  [880] = {.lex_state = 12, .external_lex_state = 4},
  [881] = {.lex_state = 3, .external_lex_state = 4},
  [882] = {.lex_state = 12, .external_lex_state = 4},
  [883] = {.lex_state = 12, .external_lex_state = 4},
  [884] = {.lex_state = 12, .external_lex_state = 4},
  [885] = {.lex_state = 12, .external_lex_state = 4},
  [886] = {.lex_state = 3, .external_lex_state = 4},
  [887] = {.lex_state = 12, .external_lex_state = 4},
  [888] = {.lex_state = 3, .external_lex_state = 4},
  [889] = {.lex_state = 12, .external_lex_state = 4},
  [890] = {.lex_state = 12, .external_lex_state = 4},
  [891] = {.lex_state = 12, .external_lex_state = 4},
  [892] = {.lex_state = 4, .external_lex_state = 11},
  [893] = {.lex_state = 12, .external_lex_state = 4},
  [894] = {.lex_state = 3, .external_lex_state = 4},
  [895] = {.lex_state = 12, .external_lex_state = 4},
  [896] = {.lex_state = 12, .external_lex_state = 4},
  [897] = {.lex_state = 3, .external_lex_state = 4},
  [898] = {.lex_state = 3, .external_lex_state = 4},
  [899] = {.lex_state = 12, .external_lex_state = 4},
  [900] = {.lex_state = 12, .external_lex_state = 4},
  [901] = {.lex_state = 3, .external_lex_state = 4},
  [902] = {.lex_state = 12, .external_lex_state = 4},
  [903] = {.lex_state = 3, .external_lex_state = 4},
  [904] = {.lex_state = 3, .external_lex_state = 4},
  [905] = {.lex_state = 12, .external_lex_state = 4},
  [906] = {.lex_state = 3, .external_lex_state = 4},
  [907] = {.lex_state = 12, .external_lex_state = 4},
  [908] = {.lex_state = 0, .external_lex_state = 6},
  [909] = {.lex_state = 11, .external_lex_state = 4},
  [910] = {.lex_state = 0, .external_lex_state = 4},
  [911] = {.lex_state = 0, .external_lex_state = 4},
  [912] = {.lex_state = 0, .external_lex_state = 4},
  [913] = {.lex_state = 0, .external_lex_state = 4},
  [914] = {.lex_state = 0, .external_lex_state = 4},
  [915] = {.lex_state = 0, .external_lex_state = 4},
  [916] = {.lex_state = 19, .external_lex_state = 4},
  [917] = {.lex_state = 93, .external_lex_state = 5},
  [918] = {.lex_state = 0, .external_lex_state = 6},
  [919] = {.lex_state = 0, .external_lex_state = 4},
  [920] = {.lex_state = 0, .external_lex_state = 4},
  [921] = {.lex_state = 0, .external_lex_state = 6},
  [922] = {.lex_state = 0, .external_lex_state = 4},
  [923] = {.lex_state = 0, .external_lex_state = 4},
  [924] = {.lex_state = 0, .external_lex_state = 4},
  [925] = {.lex_state = 93, .external_lex_state = 5},
  [926] = {.lex_state = 19, .external_lex_state = 4},
  [927] = {.lex_state = 0, .external_lex_state = 6},
  [928] = {.lex_state = 93, .external_lex_state = 5},
  [929] = {.lex_state = 19, .external_lex_state = 4},
  [930] = {.lex_state = 0, .external_lex_state = 4},
  [931] = {.lex_state = 3, .external_lex_state = 4},
  [932] = {.lex_state = 19, .external_lex_state = 4},
  [933] = {.lex_state = 11, .external_lex_state = 4},
  [934] = {.lex_state = 11, .external_lex_state = 4},
  [935] = {.lex_state = 19, .external_lex_state = 4},
  [936] = {.lex_state = 0, .external_lex_state = 4},
  [937] = {.lex_state = 19, .external_lex_state = 4},
  [938] = {.lex_state = 11, .external_lex_state = 4},
  [939] = {.lex_state = 0, .external_lex_state = 4},
  [940] = {.lex_state = 11, .external_lex_state = 4},
  [941] = {.lex_state = 0, .external_lex_state = 4},
  [942] = {.lex_state = 0, .external_lex_state = 4},
  [943] = {.lex_state = 0, .external_lex_state = 4},
  [944] = {.lex_state = 19, .external_lex_state = 4},
  [945] = {.lex_state = 0, .external_lex_state = 6},
  [946] = {.lex_state = 19, .external_lex_state = 4},
  [947] = {.lex_state = 19, .external_lex_state = 4},
  [948] = {.lex_state = 95, .external_lex_state = 4},
  [949] = {.lex_state = 19, .external_lex_state = 4},
  [950] = {.lex_state = 95, .external_lex_state = 4},
  [951] = {.lex_state = 0, .external_lex_state = 4},
  [952] = {.lex_state = 0, .external_lex_state = 4},
  [953] = {.lex_state = 19, .external_lex_state = 4},
  [954] = {.lex_state = 0, .external_lex_state = 4},
  [955] = {.lex_state = 3, .external_lex_state = 4},
  [956] = {.lex_state = 0, .external_lex_state = 4},
  [957] = {.lex_state = 0, .external_lex_state = 4},
  [958] = {.lex_state = 95, .external_lex_state = 4},
  [959] = {.lex_state = 0, .external_lex_state = 4},
  [960] = {.lex_state = 3, .external_lex_state = 4},
  [961] = {.lex_state = 19, .external_lex_state = 4},
  [962] = {.lex_state = 15, .external_lex_state = 4},
  [963] = {.lex_state = 0, .external_lex_state = 4},
  [964] = {.lex_state = 19, .external_lex_state = 4},
  [965] = {.lex_state = 95, .external_lex_state = 4},
  [966] = {.lex_state = 19, .external_lex_state = 4},
  [967] = {.lex_state = 19, .external_lex_state = 4},
  [968] = {.lex_state = 0, .external_lex_state = 4},
  [969] = {.lex_state = 3, .external_lex_state = 4},
  [970] = {.lex_state = 0, .external_lex_state = 4},
  [971] = {.lex_state = 19, .external_lex_state = 4},
  [972] = {.lex_state = 0, .external_lex_state = 6},
  [973] = {.lex_state = 93, .external_lex_state = 5},
  [974] = {.lex_state = 19, .external_lex_state = 4},
  [975] = {.lex_state = 93, .external_lex_state = 5},
  [976] = {.lex_state = 95, .external_lex_state = 4},
  [977] = {.lex_state = 19, .external_lex_state = 4},
  [978] = {.lex_state = 93, .external_lex_state = 5},
  [979] = {.lex_state = 0, .external_lex_state = 4},
  [980] = {.lex_state = 0, .external_lex_state = 6},
  [981] = {.lex_state = 19, .external_lex_state = 4},
  [982] = {.lex_state = 19, .external_lex_state = 4},
  [983] = {.lex_state = 0, .external_lex_state = 6},
  [984] = {.lex_state = 19, .external_lex_state = 4},
  [985] = {.lex_state = 19, .external_lex_state = 4},
  [986] = {.lex_state = 93, .external_lex_state = 5},
  [987] = {.lex_state = 93, .external_lex_state = 5},
  [988] = {.lex_state = 19, .external_lex_state = 4},
  [989] = {.lex_state = 19, .external_lex_state = 4},
  [990] = {.lex_state = 19, .external_lex_state = 4},
  [991] = {.lex_state = 19, .external_lex_state = 4},
  [992] = {.lex_state = 93, .external_lex_state = 5},
  [993] = {.lex_state = 19, .external_lex_state = 4},
  [994] = {.lex_state = 11, .external_lex_state = 4},
  [995] = {.lex_state = 0, .external_lex_state = 4},
  [996] = {.lex_state = 11, .external_lex_state = 4},
  [997] = {.lex_state = 0, .external_lex_state = 4},
  [998] = {.lex_state = 3, .external_lex_state = 4},
  [999] = {.lex_state = 0, .external_lex_state = 4},
  [1000] = {.lex_state = 19, .external_lex_state = 4},
  [1001] = {.lex_state = 0, .external_lex_state = 4},
  [1002] = {.lex_state = 0, .external_lex_state = 4},
  [1003] = {.lex_state = 0, .external_lex_state = 4},
  [1004] = {.lex_state = 0, .external_lex_state = 4},
  [1005] = {.lex_state = 93, .external_lex_state = 4},
  [1006] = {.lex_state = 93, .external_lex_state = 4},
  [1007] = {.lex_state = 93, .external_lex_state = 4},
  [1008] = {.lex_state = 0, .external_lex_state = 4},
  [1009] = {.lex_state = 93, .external_lex_state = 4},
  [1010] = {.lex_state = 0, .external_lex_state = 4},
  [1011] = {.lex_state = 93, .external_lex_state = 4},
  [1012] = {.lex_state = 93, .external_lex_state = 4},
  [1013] = {.lex_state = 9, .external_lex_state = 4},
  [1014] = {.lex_state = 15, .external_lex_state = 4},
  [1015] = {.lex_state = 15, .external_lex_state = 4},
  [1016] = {.lex_state = 95, .external_lex_state = 4},
  [1017] = {.lex_state = 0, .external_lex_state = 4},
  [1018] = {.lex_state = 15, .external_lex_state = 4},
  [1019] = {.lex_state = 95, .external_lex_state = 4},
  [1020] = {.lex_state = 0, .external_lex_state = 4},
  [1021] = {.lex_state = 15, .external_lex_state = 4},
  [1022] = {.lex_state = 15, .external_lex_state = 4},
  [1023] = {.lex_state = 0, .external_lex_state = 4},
  [1024] = {.lex_state = 0, .external_lex_state = 4},
  [1025] = {.lex_state = 95, .external_lex_state = 4},
  [1026] = {.lex_state = 15, .external_lex_state = 4},
  [1027] = {.lex_state = 95, .external_lex_state = 4},
  [1028] = {.lex_state = 15, .external_lex_state = 4},
  [1029] = {.lex_state = 0, .external_lex_state = 4},
  [1030] = {.lex_state = 0, .external_lex_state = 4},
  [1031] = {.lex_state = 15, .external_lex_state = 4},
  [1032] = {.lex_state = 0, .external_lex_state = 4},
  [1033] = {.lex_state = 0, .external_lex_state = 4},
  [1034] = {.lex_state = 0, .external_lex_state = 4},
  [1035] = {.lex_state = 0, .external_lex_state = 4},
  [1036] = {.lex_state = 0, .external_lex_state = 4},
  [1037] = {.lex_state = 0, .external_lex_state = 4},
  [1038] = {.lex_state = 95, .external_lex_state = 4},
  [1039] = {.lex_state = 0, .external_lex_state = 4},
  [1040] = {.lex_state = 0, .external_lex_state = 4},
  [1041] = {.lex_state = 0, .external_lex_state = 4},
  [1042] = {.lex_state = 0, .external_lex_state = 4},
  [1043] = {.lex_state = 0, .external_lex_state = 4},
  [1044] = {.lex_state = 93, .external_lex_state = 4},
  [1045] = {.lex_state = 0, .external_lex_state = 4},
  [1046] = {.lex_state = 0, .external_lex_state = 4},
  [1047] = {.lex_state = 0, .external_lex_state = 4},
  [1048] = {.lex_state = 0, .external_lex_state = 4},
  [1049] = {.lex_state = 0, .external_lex_state = 4},
  [1050] = {.lex_state = 3, .external_lex_state = 4},
  [1051] = {.lex_state = 0, .external_lex_state = 5},
  [1052] = {.lex_state = 0, .external_lex_state = 4},
  [1053] = {.lex_state = 0, .external_lex_state = 4},
  [1054] = {.lex_state = 0, .external_lex_state = 4},
  [1055] = {.lex_state = 3, .external_lex_state = 4},
  [1056] = {.lex_state = 0, .external_lex_state = 5},
  [1057] = {.lex_state = 0, .external_lex_state = 5},
  [1058] = {.lex_state = 0, .external_lex_state = 4},
  [1059] = {.lex_state = 0, .external_lex_state = 4},
  [1060] = {.lex_state = 0, .external_lex_state = 4},
  [1061] = {.lex_state = 0, .external_lex_state = 4},
  [1062] = {.lex_state = 0, .external_lex_state = 4},
  [1063] = {.lex_state = 0, .external_lex_state = 4},
  [1064] = {.lex_state = 0, .external_lex_state = 4},
  [1065] = {.lex_state = 0, .external_lex_state = 4},
  [1066] = {.lex_state = 5, .external_lex_state = 4},
  [1067] = {.lex_state = 3, .external_lex_state = 4},
  [1068] = {.lex_state = 0, .external_lex_state = 4},
  [1069] = {.lex_state = 0, .external_lex_state = 4},
  [1070] = {.lex_state = 3, .external_lex_state = 4},
  [1071] = {.lex_state = 0, .external_lex_state = 4},
  [1072] = {.lex_state = 15, .external_lex_state = 4},
  [1073] = {.lex_state = 95, .external_lex_state = 4},
  [1074] = {.lex_state = 3, .external_lex_state = 4},
  [1075] = {.lex_state = 0, .external_lex_state = 4},
  [1076] = {.lex_state = 0, .external_lex_state = 4},
  [1077] = {.lex_state = 0, .external_lex_state = 4},
  [1078] = {.lex_state = 0, .external_lex_state = 4},
  [1079] = {.lex_state = 0, .external_lex_state = 4},
  [1080] = {.lex_state = 95, .external_lex_state = 4},
  [1081] = {.lex_state = 0, .external_lex_state = 4},
  [1082] = {.lex_state = 3, .external_lex_state = 4},
  [1083] = {.lex_state = 3, .external_lex_state = 4},
  [1084] = {.lex_state = 0, .external_lex_state = 4},
  [1085] = {.lex_state = 3, .external_lex_state = 4},
  [1086] = {.lex_state = 3, .external_lex_state = 4},
  [1087] = {.lex_state = 3, .external_lex_state = 4},
  [1088] = {.lex_state = 0, .external_lex_state = 4},
  [1089] = {.lex_state = 95, .external_lex_state = 4},
  [1090] = {.lex_state = 0, .external_lex_state = 4},
  [1091] = {.lex_state = 0, .external_lex_state = 4},
  [1092] = {.lex_state = 0, .external_lex_state = 4},
  [1093] = {.lex_state = 0, .external_lex_state = 4},
  [1094] = {.lex_state = 0, .external_lex_state = 4},
  [1095] = {.lex_state = 0, .external_lex_state = 4},
  [1096] = {.lex_state = 0, .external_lex_state = 4},
  [1097] = {.lex_state = 0, .external_lex_state = 4},
  [1098] = {.lex_state = 0, .external_lex_state = 4},
  [1099] = {.lex_state = 0, .external_lex_state = 4},
  [1100] = {.lex_state = 95, .external_lex_state = 4},
  [1101] = {.lex_state = 0, .external_lex_state = 4},
  [1102] = {.lex_state = 0, .external_lex_state = 4},
  [1103] = {.lex_state = 0, .external_lex_state = 4},
  [1104] = {.lex_state = 3, .external_lex_state = 4},
  [1105] = {.lex_state = 3, .external_lex_state = 4},
  [1106] = {.lex_state = 0, .external_lex_state = 4},
  [1107] = {.lex_state = 0, .external_lex_state = 4},
  [1108] = {.lex_state = 0, .external_lex_state = 4},
  [1109] = {.lex_state = 5, .external_lex_state = 4},
  [1110] = {.lex_state = 3, .external_lex_state = 4},
  [1111] = {.lex_state = 0, .external_lex_state = 4},
  [1112] = {.lex_state = 3, .external_lex_state = 4},
  [1113] = {.lex_state = 0, .external_lex_state = 4},
  [1114] = {.lex_state = 0, .external_lex_state = 4},
  [1115] = {.lex_state = 0, .external_lex_state = 4},
  [1116] = {.lex_state = 3, .external_lex_state = 4},
  [1117] = {.lex_state = 0, .external_lex_state = 4},
  [1118] = {.lex_state = 3, .external_lex_state = 4},
  [1119] = {.lex_state = 95, .external_lex_state = 4},
  [1120] = {.lex_state = 0, .external_lex_state = 4},
  [1121] = {.lex_state = 0, .external_lex_state = 4},
  [1122] = {.lex_state = 0, .external_lex_state = 4},
  [1123] = {.lex_state = 0, .external_lex_state = 4},
  [1124] = {.lex_state = 0, .external_lex_state = 4},
  [1125] = {.lex_state = 0, .external_lex_state = 4},
  [1126] = {.lex_state = 3, .external_lex_state = 4},
  [1127] = {.lex_state = 0, .external_lex_state = 4},
  [1128] = {.lex_state = 0, .external_lex_state = 4},
  [1129] = {.lex_state = 95, .external_lex_state = 4},
  [1130] = {.lex_state = 9, .external_lex_state = 4},
  [1131] = {.lex_state = 0, .external_lex_state = 4},
  [1132] = {.lex_state = 0, .external_lex_state = 4},
  [1133] = {.lex_state = 0, .external_lex_state = 4},
  [1134] = {.lex_state = 0, .external_lex_state = 4},
  [1135] = {.lex_state = 15, .external_lex_state = 4},
  [1136] = {.lex_state = 95, .external_lex_state = 4},
  [1137] = {.lex_state = 0, .external_lex_state = 4},
  [1138] = {.lex_state = 5, .external_lex_state = 4},
  [1139] = {.lex_state = 3, .external_lex_state = 4},
  [1140] = {.lex_state = 15, .external_lex_state = 4},
  [1141] = {.lex_state = 0, .external_lex_state = 4},
  [1142] = {.lex_state = 15, .external_lex_state = 4},
  [1143] = {.lex_state = 0, .external_lex_state = 4},
  [1144] = {.lex_state = 0, .external_lex_state = 4},
  [1145] = {.lex_state = 95, .external_lex_state = 4},
  [1146] = {.lex_state = 0, .external_lex_state = 4},
  [1147] = {.lex_state = 9, .external_lex_state = 4},
  [1148] = {.lex_state = 0, .external_lex_state = 4},
  [1149] = {.lex_state = 15, .external_lex_state = 4},
  [1150] = {.lex_state = 0, .external_lex_state = 4},
  [1151] = {.lex_state = 0, .external_lex_state = 4},
  [1152] = {.lex_state = 0, .external_lex_state = 4},
  [1153] = {.lex_state = 0, .external_lex_state = 4},
  [1154] = {.lex_state = 15, .external_lex_state = 4},
  [1155] = {.lex_state = 0, .external_lex_state = 4},
  [1156] = {.lex_state = 15, .external_lex_state = 4},
  [1157] = {.lex_state = 15, .external_lex_state = 4},
  [1158] = {.lex_state = 0, .external_lex_state = 4},
  [1159] = {.lex_state = 3, .external_lex_state = 4},
  [1160] = {.lex_state = 3, .external_lex_state = 4},
  [1161] = {.lex_state = 9, .external_lex_state = 4},
  [1162] = {.lex_state = 0, .external_lex_state = 5},
  [1163] = {.lex_state = 15, .external_lex_state = 4},
  [1164] = {.lex_state = 9, .external_lex_state = 4},
  [1165] = {.lex_state = 0, .external_lex_state = 4},
  [1166] = {.lex_state = 0, .external_lex_state = 4},
  [1167] = {.lex_state = 0, .external_lex_state = 4},
  [1168] = {.lex_state = 15, .external_lex_state = 4},
  [1169] = {.lex_state = 0, .external_lex_state = 4},
  [1170] = {.lex_state = 15, .external_lex_state = 4},
  [1171] = {.lex_state = 0, .external_lex_state = 5},
  [1172] = {.lex_state = 0, .external_lex_state = 4},
  [1173] = {.lex_state = 0, .external_lex_state = 5},
  [1174] = {.lex_state = 3, .external_lex_state = 4},
  [1175] = {.lex_state = 9, .external_lex_state = 4},
  [1176] = {.lex_state = 15, .external_lex_state = 4},
  [1177] = {.lex_state = 15, .external_lex_state = 4},
  [1178] = {.lex_state = 95, .external_lex_state = 4},
  [1179] = {.lex_state = 0, .external_lex_state = 4},
  [1180] = {.lex_state = 0, .external_lex_state = 4},
  [1181] = {.lex_state = 0, .external_lex_state = 4},
  [1182] = {.lex_state = 15, .external_lex_state = 4},
  [1183] = {.lex_state = 0, .external_lex_state = 4},
  [1184] = {.lex_state = 15, .external_lex_state = 4},
  [1185] = {.lex_state = 0, .external_lex_state = 4},
  [1186] = {.lex_state = 0, .external_lex_state = 4},
  [1187] = {.lex_state = 0, .external_lex_state = 5},
  [1188] = {.lex_state = 0, .external_lex_state = 4},
  [1189] = {.lex_state = 9, .external_lex_state = 4},
  [1190] = {.lex_state = 0, .external_lex_state = 4},
  [1191] = {.lex_state = 15, .external_lex_state = 4},
  [1192] = {.lex_state = 0, .external_lex_state = 4},
  [1193] = {.lex_state = 0, .external_lex_state = 4},
  [1194] = {.lex_state = 0, .external_lex_state = 4},
  [1195] = {.lex_state = 0, .external_lex_state = 4},
  [1196] = {.lex_state = 15, .external_lex_state = 4},
  [1197] = {.lex_state = 0, .external_lex_state = 4},
  [1198] = {.lex_state = 15, .external_lex_state = 4},
  [1199] = {.lex_state = 0, .external_lex_state = 4},
  [1200] = {.lex_state = 9, .external_lex_state = 4},
  [1201] = {.lex_state = 0, .external_lex_state = 4},
  [1202] = {.lex_state = 15, .external_lex_state = 4},
  [1203] = {.lex_state = 0, .external_lex_state = 4},
  [1204] = {.lex_state = 0, .external_lex_state = 4},
  [1205] = {.lex_state = 0, .external_lex_state = 4},
  [1206] = {.lex_state = 15, .external_lex_state = 4},
  [1207] = {.lex_state = 0, .external_lex_state = 5},
  [1208] = {.lex_state = 15, .external_lex_state = 4},
  [1209] = {.lex_state = 3, .external_lex_state = 4},
  [1210] = {.lex_state = 95, .external_lex_state = 4},
  [1211] = {.lex_state = 0, .external_lex_state = 4},
  [1212] = {.lex_state = 95, .external_lex_state = 4},
  [1213] = {.lex_state = 0, .external_lex_state = 4},
  [1214] = {.lex_state = 95, .external_lex_state = 4},
  [1215] = {.lex_state = 0, .external_lex_state = 4},
  [1216] = {.lex_state = 95, .external_lex_state = 4},
  [1217] = {.lex_state = 0, .external_lex_state = 4},
  [1218] = {.lex_state = 95, .external_lex_state = 4},
  [1219] = {.lex_state = 0, .external_lex_state = 4},
  [1220] = {.lex_state = 0, .external_lex_state = 4},
  [1221] = {.lex_state = 0, .external_lex_state = 4},
  [1222] = {.lex_state = 0, .external_lex_state = 4},
  [1223] = {.lex_state = 95, .external_lex_state = 4},
  [1224] = {.lex_state = 5, .external_lex_state = 4},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_keyword] = ACTIONS(1),
    [sym_num_literal] = ACTIONS(1),
    [sym_ident] = ACTIONS(1),
    [sym_raw_enum_tag] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [anon_sym_force] = ACTIONS(1),
    [anon_sym_optional] = ACTIONS(1),
    [anon_sym_priority] = ACTIONS(1),
    [anon_sym_doc] = ACTIONS(1),
    [anon_sym_rec] = ACTIONS(1),
    [anon_sym_not_exported] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_let] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_fun] = ACTIONS(1),
    [anon_sym_EQ_GT] = ACTIONS(1),
    [anon_sym_match] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_then] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_forall] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_Array] = ACTIONS(1),
    [anon_sym_Dyn] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_null] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym__] = ACTIONS(1),
    [anon_sym_or] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [sym_double_quote] = ACTIONS(1),
    [sym_str_esc_char] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_PIPE_GT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_Number] = ACTIONS(1),
    [anon_sym_Bool] = ACTIONS(1),
    [anon_sym_String] = ACTIONS(1),
    [anon_sym_LBRACK_PIPE] = ACTIONS(1),
    [anon_sym_PIPE_RBRACK] = ACTIONS(1),
    [sym_multstr_start] = ACTIONS(1),
    [sym_multstr_end] = ACTIONS(1),
    [sym__str_start] = ACTIONS(1),
    [sym__str_end] = ACTIONS(1),
    [sym_interpolation_start] = ACTIONS(1),
    [sym_interpolation_end] = ACTIONS(1),
    [sym_quoted_enum_tag_start] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
  },
  [1] = {
    [sym_term] = STATE(1150),
    [sym_uni_term] = STATE(688),
    [sym_let_expr] = STATE(690),
    [sym_let_in_block] = STATE(39),
    [sym_fun_expr] = STATE(690),
    [sym_match_expr] = STATE(441),
    [sym_ite_expr] = STATE(690),
    [sym_annotated_infix_expr] = STATE(690),
    [sym_forall] = STATE(690),
    [sym_applicative] = STATE(88),
    [sym_type_array] = STATE(441),
    [sym_record_operand] = STATE(297),
    [sym_record_operation_chain] = STATE(299),
    [sym_uni_record] = STATE(266),
    [sym_atom] = STATE(299),
    [sym_bool] = STATE(266),
    [sym_str_chunks] = STATE(266),
    [sym_str_chunks_single] = STATE(303),
    [sym_str_chunks_multi] = STATE(303),
    [sym_quoted_enum_tag] = STATE(267),
    [sym_enum_tag] = STATE(84),
    [sym_enum_variant] = STATE(441),
    [sym_builtin] = STATE(266),
    [sym_infix_u_op_5] = STATE(184),
    [sym_infix_expr] = STATE(488),
    [sym_type_builtin] = STATE(275),
    [sym_type_atom] = STATE(266),
    [sym_num_literal] = ACTIONS(5),
    [sym_ident] = ACTIONS(7),
    [sym_raw_enum_tag] = ACTIONS(9),
    [anon_sym_let] = ACTIONS(11),
    [anon_sym_fun] = ACTIONS(13),
    [anon_sym_match] = ACTIONS(15),
    [anon_sym_LBRACE] = ACTIONS(17),
    [anon_sym_if] = ACTIONS(19),
    [anon_sym_forall] = ACTIONS(21),
    [anon_sym_import] = ACTIONS(23),
    [anon_sym_Array] = ACTIONS(25),
    [anon_sym_Dyn] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(29),
    [anon_sym_null] = ACTIONS(7),
    [anon_sym_LBRACK] = ACTIONS(31),
    [anon_sym__] = ACTIONS(33),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(37),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(41),
    [anon_sym_Number] = ACTIONS(27),
    [anon_sym_Bool] = ACTIONS(27),
    [anon_sym_String] = ACTIONS(27),
    [anon_sym_LBRACK_PIPE] = ACTIONS(43),
    [sym_multstr_start] = ACTIONS(45),
    [sym__str_start] = ACTIONS(47),
    [sym_quoted_enum_tag_start] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
  },
  [2] = {
    [sym_uni_term] = STATE(1095),
    [sym_let_expr] = STATE(690),
    [sym_let_in_block] = STATE(60),
    [sym_fun_expr] = STATE(690),
    [sym_match_expr] = STATE(142),
    [sym_ite_expr] = STATE(690),
    [sym_annotated_infix_expr] = STATE(690),
    [sym_forall] = STATE(690),
    [sym_applicative] = STATE(10),
    [sym_type_array] = STATE(142),
    [sym_record_operand] = STATE(92),
    [sym_record_operation_chain] = STATE(126),
    [sym_uni_record] = STATE(98),
    [sym_atom] = STATE(126),
    [sym_bool] = STATE(98),
    [sym_str_chunks] = STATE(98),
    [sym_str_chunks_single] = STATE(107),
    [sym_str_chunks_multi] = STATE(107),
    [sym_quoted_enum_tag] = STATE(89),
    [sym_enum_tag] = STATE(9),
    [sym_enum_variant] = STATE(142),
    [sym_builtin] = STATE(98),
    [sym_infix_b_op_2] = STATE(1188),
    [sym_infix_b_op_3] = STATE(1188),
    [sym_infix_b_op_4] = STATE(1188),
    [sym_infix_u_op_5] = STATE(157),
    [sym_infix_b_op_6] = STATE(1188),
    [sym_infix_b_op_7] = STATE(1188),
    [sym_infix_b_op_8] = STATE(1188),
    [sym_infix_lazy_b_op_9] = STATE(1185),
    [sym_infix_lazy_b_op_10] = STATE(1185),
    [sym_infix_b_op] = STATE(1183),
    [sym_infix_u_op_or_lazy_b_op] = STATE(1183),
    [sym_infix_op] = STATE(1221),
    [sym_curried_op] = STATE(1095),
    [sym_infix_expr] = STATE(464),
    [sym_type_builtin] = STATE(127),
    [sym_type_atom] = STATE(98),
    [sym_num_literal] = ACTIONS(51),
    [sym_ident] = ACTIONS(53),
    [sym_raw_enum_tag] = ACTIONS(55),
    [anon_sym_let] = ACTIONS(11),
    [anon_sym_fun] = ACTIONS(57),
    [anon_sym_match] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(63),
    [anon_sym_forall] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(67),
    [anon_sym_import] = ACTIONS(69),
    [anon_sym_Array] = ACTIONS(71),
    [anon_sym_Dyn] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_null] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(79),
    [anon_sym__] = ACTIONS(81),
    [anon_sym_true] = ACTIONS(83),
    [anon_sym_false] = ACTIONS(83),
    [anon_sym_PERCENT] = ACTIONS(85),
    [anon_sym_PLUS_PLUS] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(87),
    [anon_sym_PLUS] = ACTIONS(89),
    [anon_sym_DASH] = ACTIONS(91),
    [anon_sym_BANG] = ACTIONS(93),
    [anon_sym_AMP] = ACTIONS(95),
    [anon_sym_PIPE_GT] = ACTIONS(97),
    [anon_sym_LT] = ACTIONS(99),
    [anon_sym_LT_EQ] = ACTIONS(101),
    [anon_sym_GT] = ACTIONS(99),
    [anon_sym_GT_EQ] = ACTIONS(101),
    [anon_sym_EQ_EQ] = ACTIONS(103),
    [anon_sym_BANG_EQ] = ACTIONS(103),
    [anon_sym_AMP_AMP] = ACTIONS(105),
    [anon_sym_PIPE_PIPE] = ACTIONS(107),
    [anon_sym_Number] = ACTIONS(73),
    [anon_sym_Bool] = ACTIONS(73),
    [anon_sym_String] = ACTIONS(73),
    [anon_sym_LBRACK_PIPE] = ACTIONS(109),
    [sym_multstr_start] = ACTIONS(111),
    [sym__str_start] = ACTIONS(113),
    [sym_quoted_enum_tag_start] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
  },
  [3] = {
    [sym_uni_term] = STATE(1167),
    [sym_let_expr] = STATE(690),
    [sym_let_in_block] = STATE(60),
    [sym_fun_expr] = STATE(690),
    [sym_match_expr] = STATE(142),
    [sym_ite_expr] = STATE(690),
    [sym_annotated_infix_expr] = STATE(690),
    [sym_forall] = STATE(690),
    [sym_applicative] = STATE(10),
    [sym_type_array] = STATE(142),
    [sym_record_operand] = STATE(92),
    [sym_record_operation_chain] = STATE(126),
    [sym_uni_record] = STATE(98),
    [sym_atom] = STATE(126),
    [sym_bool] = STATE(98),
    [sym_str_chunks] = STATE(98),
    [sym_str_chunks_single] = STATE(107),
    [sym_str_chunks_multi] = STATE(107),
    [sym_quoted_enum_tag] = STATE(89),
    [sym_enum_tag] = STATE(9),
    [sym_enum_variant] = STATE(142),
    [sym_builtin] = STATE(98),
    [sym_infix_b_op_2] = STATE(1188),
    [sym_infix_b_op_3] = STATE(1188),
    [sym_infix_b_op_4] = STATE(1188),
    [sym_infix_u_op_5] = STATE(157),
    [sym_infix_b_op_6] = STATE(1188),
    [sym_infix_b_op_7] = STATE(1188),
    [sym_infix_b_op_8] = STATE(1188),
    [sym_infix_lazy_b_op_9] = STATE(1185),
    [sym_infix_lazy_b_op_10] = STATE(1185),
    [sym_infix_b_op] = STATE(1183),
    [sym_infix_u_op_or_lazy_b_op] = STATE(1183),
    [sym_infix_op] = STATE(1221),
    [sym_curried_op] = STATE(1167),
    [sym_infix_expr] = STATE(464),
    [sym_type_builtin] = STATE(127),
    [sym_type_atom] = STATE(98),
    [sym_num_literal] = ACTIONS(51),
    [sym_ident] = ACTIONS(53),
    [sym_raw_enum_tag] = ACTIONS(55),
    [anon_sym_let] = ACTIONS(11),
    [anon_sym_fun] = ACTIONS(57),
    [anon_sym_match] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(63),
    [anon_sym_forall] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(67),
    [anon_sym_import] = ACTIONS(69),
    [anon_sym_Array] = ACTIONS(71),
    [anon_sym_Dyn] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_null] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(79),
    [anon_sym__] = ACTIONS(81),
    [anon_sym_true] = ACTIONS(83),
    [anon_sym_false] = ACTIONS(83),
    [anon_sym_PERCENT] = ACTIONS(85),
    [anon_sym_PLUS_PLUS] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(87),
    [anon_sym_PLUS] = ACTIONS(89),
    [anon_sym_DASH] = ACTIONS(91),
    [anon_sym_BANG] = ACTIONS(93),
    [anon_sym_AMP] = ACTIONS(95),
    [anon_sym_PIPE_GT] = ACTIONS(97),
    [anon_sym_LT] = ACTIONS(99),
    [anon_sym_LT_EQ] = ACTIONS(101),
    [anon_sym_GT] = ACTIONS(99),
    [anon_sym_GT_EQ] = ACTIONS(101),
    [anon_sym_EQ_EQ] = ACTIONS(103),
    [anon_sym_BANG_EQ] = ACTIONS(103),
    [anon_sym_AMP_AMP] = ACTIONS(105),
    [anon_sym_PIPE_PIPE] = ACTIONS(107),
    [anon_sym_Number] = ACTIONS(73),
    [anon_sym_Bool] = ACTIONS(73),
    [anon_sym_String] = ACTIONS(73),
    [anon_sym_LBRACK_PIPE] = ACTIONS(109),
    [sym_multstr_start] = ACTIONS(111),
    [sym__str_start] = ACTIONS(113),
    [sym_quoted_enum_tag_start] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
  },
  [4] = {
    [sym_uni_term] = STATE(1063),
    [sym_let_expr] = STATE(690),
    [sym_let_in_block] = STATE(60),
    [sym_fun_expr] = STATE(690),
    [sym_match_expr] = STATE(142),
    [sym_ite_expr] = STATE(690),
    [sym_annotated_infix_expr] = STATE(690),
    [sym_forall] = STATE(690),
    [sym_applicative] = STATE(10),
    [sym_type_array] = STATE(142),
    [sym_record_operand] = STATE(92),
    [sym_record_operation_chain] = STATE(126),
    [sym_uni_record] = STATE(98),
    [sym_atom] = STATE(126),
    [sym_bool] = STATE(98),
    [sym_str_chunks] = STATE(98),
    [sym_str_chunks_single] = STATE(107),
    [sym_str_chunks_multi] = STATE(107),
    [sym_quoted_enum_tag] = STATE(89),
    [sym_enum_tag] = STATE(9),
    [sym_enum_variant] = STATE(142),
    [sym_builtin] = STATE(98),
    [sym_infix_b_op_2] = STATE(1188),
    [sym_infix_b_op_3] = STATE(1188),
    [sym_infix_b_op_4] = STATE(1188),
    [sym_infix_u_op_5] = STATE(157),
    [sym_infix_b_op_6] = STATE(1188),
    [sym_infix_b_op_7] = STATE(1188),
    [sym_infix_b_op_8] = STATE(1188),
    [sym_infix_lazy_b_op_9] = STATE(1185),
    [sym_infix_lazy_b_op_10] = STATE(1185),
    [sym_infix_b_op] = STATE(1183),
    [sym_infix_u_op_or_lazy_b_op] = STATE(1183),
    [sym_infix_op] = STATE(1221),
    [sym_curried_op] = STATE(1063),
    [sym_infix_expr] = STATE(464),
    [sym_type_builtin] = STATE(127),
    [sym_type_atom] = STATE(98),
    [sym_num_literal] = ACTIONS(51),
    [sym_ident] = ACTIONS(53),
    [sym_raw_enum_tag] = ACTIONS(55),
    [anon_sym_let] = ACTIONS(11),
    [anon_sym_fun] = ACTIONS(57),
    [anon_sym_match] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(63),
    [anon_sym_forall] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(67),
    [anon_sym_import] = ACTIONS(69),
    [anon_sym_Array] = ACTIONS(71),
    [anon_sym_Dyn] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_null] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(79),
    [anon_sym__] = ACTIONS(81),
    [anon_sym_true] = ACTIONS(83),
    [anon_sym_false] = ACTIONS(83),
    [anon_sym_PERCENT] = ACTIONS(85),
    [anon_sym_PLUS_PLUS] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(87),
    [anon_sym_PLUS] = ACTIONS(89),
    [anon_sym_DASH] = ACTIONS(91),
    [anon_sym_BANG] = ACTIONS(93),
    [anon_sym_AMP] = ACTIONS(95),
    [anon_sym_PIPE_GT] = ACTIONS(97),
    [anon_sym_LT] = ACTIONS(99),
    [anon_sym_LT_EQ] = ACTIONS(101),
    [anon_sym_GT] = ACTIONS(99),
    [anon_sym_GT_EQ] = ACTIONS(101),
    [anon_sym_EQ_EQ] = ACTIONS(103),
    [anon_sym_BANG_EQ] = ACTIONS(103),
    [anon_sym_AMP_AMP] = ACTIONS(105),
    [anon_sym_PIPE_PIPE] = ACTIONS(107),
    [anon_sym_Number] = ACTIONS(73),
    [anon_sym_Bool] = ACTIONS(73),
    [anon_sym_String] = ACTIONS(73),
    [anon_sym_LBRACK_PIPE] = ACTIONS(109),
    [sym_multstr_start] = ACTIONS(111),
    [sym__str_start] = ACTIONS(113),
    [sym_quoted_enum_tag_start] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
  },
  [5] = {
    [sym_uni_term] = STATE(1062),
    [sym_let_expr] = STATE(690),
    [sym_let_in_block] = STATE(60),
    [sym_fun_expr] = STATE(690),
    [sym_match_expr] = STATE(142),
    [sym_ite_expr] = STATE(690),
    [sym_annotated_infix_expr] = STATE(690),
    [sym_forall] = STATE(690),
    [sym_applicative] = STATE(10),
    [sym_type_array] = STATE(142),
    [sym_record_operand] = STATE(92),
    [sym_record_operation_chain] = STATE(126),
    [sym_uni_record] = STATE(98),
    [sym_atom] = STATE(126),
    [sym_bool] = STATE(98),
    [sym_str_chunks] = STATE(98),
    [sym_str_chunks_single] = STATE(107),
    [sym_str_chunks_multi] = STATE(107),
    [sym_quoted_enum_tag] = STATE(89),
    [sym_enum_tag] = STATE(9),
    [sym_enum_variant] = STATE(142),
    [sym_builtin] = STATE(98),
    [sym_infix_b_op_2] = STATE(1188),
    [sym_infix_b_op_3] = STATE(1188),
    [sym_infix_b_op_4] = STATE(1188),
    [sym_infix_u_op_5] = STATE(157),
    [sym_infix_b_op_6] = STATE(1188),
    [sym_infix_b_op_7] = STATE(1188),
    [sym_infix_b_op_8] = STATE(1188),
    [sym_infix_lazy_b_op_9] = STATE(1185),
    [sym_infix_lazy_b_op_10] = STATE(1185),
    [sym_infix_b_op] = STATE(1183),
    [sym_infix_u_op_or_lazy_b_op] = STATE(1183),
    [sym_infix_op] = STATE(1221),
    [sym_curried_op] = STATE(1062),
    [sym_infix_expr] = STATE(464),
    [sym_type_builtin] = STATE(127),
    [sym_type_atom] = STATE(98),
    [sym_num_literal] = ACTIONS(51),
    [sym_ident] = ACTIONS(53),
    [sym_raw_enum_tag] = ACTIONS(55),
    [anon_sym_let] = ACTIONS(11),
    [anon_sym_fun] = ACTIONS(57),
    [anon_sym_match] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(63),
    [anon_sym_forall] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(67),
    [anon_sym_import] = ACTIONS(69),
    [anon_sym_Array] = ACTIONS(71),
    [anon_sym_Dyn] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_null] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(79),
    [anon_sym__] = ACTIONS(81),
    [anon_sym_true] = ACTIONS(83),
    [anon_sym_false] = ACTIONS(83),
    [anon_sym_PERCENT] = ACTIONS(85),
    [anon_sym_PLUS_PLUS] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(87),
    [anon_sym_PLUS] = ACTIONS(89),
    [anon_sym_DASH] = ACTIONS(91),
    [anon_sym_BANG] = ACTIONS(93),
    [anon_sym_AMP] = ACTIONS(95),
    [anon_sym_PIPE_GT] = ACTIONS(97),
    [anon_sym_LT] = ACTIONS(99),
    [anon_sym_LT_EQ] = ACTIONS(101),
    [anon_sym_GT] = ACTIONS(99),
    [anon_sym_GT_EQ] = ACTIONS(101),
    [anon_sym_EQ_EQ] = ACTIONS(103),
    [anon_sym_BANG_EQ] = ACTIONS(103),
    [anon_sym_AMP_AMP] = ACTIONS(105),
    [anon_sym_PIPE_PIPE] = ACTIONS(107),
    [anon_sym_Number] = ACTIONS(73),
    [anon_sym_Bool] = ACTIONS(73),
    [anon_sym_String] = ACTIONS(73),
    [anon_sym_LBRACK_PIPE] = ACTIONS(109),
    [sym_multstr_start] = ACTIONS(111),
    [sym__str_start] = ACTIONS(113),
    [sym_quoted_enum_tag_start] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
  },
  [6] = {
    [sym_uni_term] = STATE(1094),
    [sym_let_expr] = STATE(690),
    [sym_let_in_block] = STATE(60),
    [sym_fun_expr] = STATE(690),
    [sym_match_expr] = STATE(142),
    [sym_ite_expr] = STATE(690),
    [sym_annotated_infix_expr] = STATE(690),
    [sym_forall] = STATE(690),
    [sym_applicative] = STATE(10),
    [sym_type_array] = STATE(142),
    [sym_record_operand] = STATE(92),
    [sym_record_operation_chain] = STATE(126),
    [sym_uni_record] = STATE(98),
    [sym_atom] = STATE(126),
    [sym_bool] = STATE(98),
    [sym_str_chunks] = STATE(98),
    [sym_str_chunks_single] = STATE(107),
    [sym_str_chunks_multi] = STATE(107),
    [sym_quoted_enum_tag] = STATE(89),
    [sym_enum_tag] = STATE(9),
    [sym_enum_variant] = STATE(142),
    [sym_builtin] = STATE(98),
    [sym_infix_b_op_2] = STATE(1188),
    [sym_infix_b_op_3] = STATE(1188),
    [sym_infix_b_op_4] = STATE(1188),
    [sym_infix_u_op_5] = STATE(157),
    [sym_infix_b_op_6] = STATE(1188),
    [sym_infix_b_op_7] = STATE(1188),
    [sym_infix_b_op_8] = STATE(1188),
    [sym_infix_lazy_b_op_9] = STATE(1185),
    [sym_infix_lazy_b_op_10] = STATE(1185),
    [sym_infix_b_op] = STATE(1183),
    [sym_infix_u_op_or_lazy_b_op] = STATE(1183),
    [sym_infix_op] = STATE(1221),
    [sym_curried_op] = STATE(1094),
    [sym_infix_expr] = STATE(464),
    [sym_type_builtin] = STATE(127),
    [sym_type_atom] = STATE(98),
    [sym_num_literal] = ACTIONS(51),
    [sym_ident] = ACTIONS(53),
    [sym_raw_enum_tag] = ACTIONS(55),
    [anon_sym_let] = ACTIONS(11),
    [anon_sym_fun] = ACTIONS(57),
    [anon_sym_match] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(63),
    [anon_sym_forall] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(67),
    [anon_sym_import] = ACTIONS(69),
    [anon_sym_Array] = ACTIONS(71),
    [anon_sym_Dyn] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_null] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(79),
    [anon_sym__] = ACTIONS(81),
    [anon_sym_true] = ACTIONS(83),
    [anon_sym_false] = ACTIONS(83),
    [anon_sym_PERCENT] = ACTIONS(85),
    [anon_sym_PLUS_PLUS] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(87),
    [anon_sym_PLUS] = ACTIONS(89),
    [anon_sym_DASH] = ACTIONS(91),
    [anon_sym_BANG] = ACTIONS(93),
    [anon_sym_AMP] = ACTIONS(95),
    [anon_sym_PIPE_GT] = ACTIONS(97),
    [anon_sym_LT] = ACTIONS(99),
    [anon_sym_LT_EQ] = ACTIONS(101),
    [anon_sym_GT] = ACTIONS(99),
    [anon_sym_GT_EQ] = ACTIONS(101),
    [anon_sym_EQ_EQ] = ACTIONS(103),
    [anon_sym_BANG_EQ] = ACTIONS(103),
    [anon_sym_AMP_AMP] = ACTIONS(105),
    [anon_sym_PIPE_PIPE] = ACTIONS(107),
    [anon_sym_Number] = ACTIONS(73),
    [anon_sym_Bool] = ACTIONS(73),
    [anon_sym_String] = ACTIONS(73),
    [anon_sym_LBRACK_PIPE] = ACTIONS(109),
    [sym_multstr_start] = ACTIONS(111),
    [sym__str_start] = ACTIONS(113),
    [sym_quoted_enum_tag_start] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
  },
  [7] = {
    [sym_uni_term] = STATE(1213),
    [sym_let_expr] = STATE(690),
    [sym_let_in_block] = STATE(60),
    [sym_fun_expr] = STATE(690),
    [sym_match_expr] = STATE(142),
    [sym_ite_expr] = STATE(690),
    [sym_annotated_infix_expr] = STATE(690),
    [sym_forall] = STATE(690),
    [sym_applicative] = STATE(10),
    [sym_type_array] = STATE(142),
    [sym_record_operand] = STATE(92),
    [sym_record_operation_chain] = STATE(126),
    [sym_uni_record] = STATE(98),
    [sym_atom] = STATE(126),
    [sym_bool] = STATE(98),
    [sym_str_chunks] = STATE(98),
    [sym_str_chunks_single] = STATE(107),
    [sym_str_chunks_multi] = STATE(107),
    [sym_quoted_enum_tag] = STATE(89),
    [sym_enum_tag] = STATE(9),
    [sym_enum_variant] = STATE(142),
    [sym_builtin] = STATE(98),
    [sym_infix_b_op_2] = STATE(1188),
    [sym_infix_b_op_3] = STATE(1188),
    [sym_infix_b_op_4] = STATE(1188),
    [sym_infix_u_op_5] = STATE(157),
    [sym_infix_b_op_6] = STATE(1188),
    [sym_infix_b_op_7] = STATE(1188),
    [sym_infix_b_op_8] = STATE(1188),
    [sym_infix_lazy_b_op_9] = STATE(1185),
    [sym_infix_lazy_b_op_10] = STATE(1185),
    [sym_infix_b_op] = STATE(1183),
    [sym_infix_u_op_or_lazy_b_op] = STATE(1183),
    [sym_infix_op] = STATE(1221),
    [sym_curried_op] = STATE(1213),
    [sym_infix_expr] = STATE(464),
    [sym_type_builtin] = STATE(127),
    [sym_type_atom] = STATE(98),
    [sym_num_literal] = ACTIONS(51),
    [sym_ident] = ACTIONS(53),
    [sym_raw_enum_tag] = ACTIONS(55),
    [anon_sym_let] = ACTIONS(11),
    [anon_sym_fun] = ACTIONS(57),
    [anon_sym_match] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(63),
    [anon_sym_forall] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(67),
    [anon_sym_import] = ACTIONS(69),
    [anon_sym_Array] = ACTIONS(71),
    [anon_sym_Dyn] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_null] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(79),
    [anon_sym__] = ACTIONS(81),
    [anon_sym_true] = ACTIONS(83),
    [anon_sym_false] = ACTIONS(83),
    [anon_sym_PERCENT] = ACTIONS(85),
    [anon_sym_PLUS_PLUS] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(87),
    [anon_sym_PLUS] = ACTIONS(89),
    [anon_sym_DASH] = ACTIONS(91),
    [anon_sym_BANG] = ACTIONS(93),
    [anon_sym_AMP] = ACTIONS(95),
    [anon_sym_PIPE_GT] = ACTIONS(97),
    [anon_sym_LT] = ACTIONS(99),
    [anon_sym_LT_EQ] = ACTIONS(101),
    [anon_sym_GT] = ACTIONS(99),
    [anon_sym_GT_EQ] = ACTIONS(101),
    [anon_sym_EQ_EQ] = ACTIONS(103),
    [anon_sym_BANG_EQ] = ACTIONS(103),
    [anon_sym_AMP_AMP] = ACTIONS(105),
    [anon_sym_PIPE_PIPE] = ACTIONS(107),
    [anon_sym_Number] = ACTIONS(73),
    [anon_sym_Bool] = ACTIONS(73),
    [anon_sym_String] = ACTIONS(73),
    [anon_sym_LBRACK_PIPE] = ACTIONS(109),
    [sym_multstr_start] = ACTIONS(111),
    [sym__str_start] = ACTIONS(113),
    [sym_quoted_enum_tag_start] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
  },
  [8] = {
    [sym_uni_term] = STATE(1190),
    [sym_let_expr] = STATE(690),
    [sym_let_in_block] = STATE(60),
    [sym_fun_expr] = STATE(690),
    [sym_match_expr] = STATE(142),
    [sym_ite_expr] = STATE(690),
    [sym_annotated_infix_expr] = STATE(690),
    [sym_forall] = STATE(690),
    [sym_applicative] = STATE(10),
    [sym_type_array] = STATE(142),
    [sym_record_operand] = STATE(92),
    [sym_record_operation_chain] = STATE(126),
    [sym_uni_record] = STATE(98),
    [sym_atom] = STATE(126),
    [sym_bool] = STATE(98),
    [sym_str_chunks] = STATE(98),
    [sym_str_chunks_single] = STATE(107),
    [sym_str_chunks_multi] = STATE(107),
    [sym_quoted_enum_tag] = STATE(89),
    [sym_enum_tag] = STATE(9),
    [sym_enum_variant] = STATE(142),
    [sym_builtin] = STATE(98),
    [sym_infix_b_op_2] = STATE(1188),
    [sym_infix_b_op_3] = STATE(1188),
    [sym_infix_b_op_4] = STATE(1188),
    [sym_infix_u_op_5] = STATE(157),
    [sym_infix_b_op_6] = STATE(1188),
    [sym_infix_b_op_7] = STATE(1188),
    [sym_infix_b_op_8] = STATE(1188),
    [sym_infix_lazy_b_op_9] = STATE(1185),
    [sym_infix_lazy_b_op_10] = STATE(1185),
    [sym_infix_b_op] = STATE(1183),
    [sym_infix_u_op_or_lazy_b_op] = STATE(1183),
    [sym_infix_op] = STATE(1221),
    [sym_curried_op] = STATE(1190),
    [sym_infix_expr] = STATE(464),
    [sym_type_builtin] = STATE(127),
    [sym_type_atom] = STATE(98),
    [sym_num_literal] = ACTIONS(51),
    [sym_ident] = ACTIONS(53),
    [sym_raw_enum_tag] = ACTIONS(55),
    [anon_sym_let] = ACTIONS(11),
    [anon_sym_fun] = ACTIONS(57),
    [anon_sym_match] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(63),
    [anon_sym_forall] = ACTIONS(65),
    [anon_sym_DOT] = ACTIONS(67),
    [anon_sym_import] = ACTIONS(69),
    [anon_sym_Array] = ACTIONS(71),
    [anon_sym_Dyn] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_null] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_AT] = ACTIONS(79),
    [anon_sym__] = ACTIONS(81),
    [anon_sym_true] = ACTIONS(83),
    [anon_sym_false] = ACTIONS(83),
    [anon_sym_PERCENT] = ACTIONS(85),
    [anon_sym_PLUS_PLUS] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(87),
    [anon_sym_PLUS] = ACTIONS(89),
    [anon_sym_DASH] = ACTIONS(91),
    [anon_sym_BANG] = ACTIONS(93),
    [anon_sym_AMP] = ACTIONS(95),
    [anon_sym_PIPE_GT] = ACTIONS(97),
    [anon_sym_LT] = ACTIONS(99),
    [anon_sym_LT_EQ] = ACTIONS(101),
    [anon_sym_GT] = ACTIONS(99),
    [anon_sym_GT_EQ] = ACTIONS(101),
    [anon_sym_EQ_EQ] = ACTIONS(103),
    [anon_sym_BANG_EQ] = ACTIONS(103),
    [anon_sym_AMP_AMP] = ACTIONS(105),
    [anon_sym_PIPE_PIPE] = ACTIONS(107),
    [anon_sym_Number] = ACTIONS(73),
    [anon_sym_Bool] = ACTIONS(73),
    [anon_sym_String] = ACTIONS(73),
    [anon_sym_LBRACK_PIPE] = ACTIONS(109),
    [sym_multstr_start] = ACTIONS(111),
    [sym__str_start] = ACTIONS(113),
    [sym_quoted_enum_tag_start] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(118), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
    ACTIONS(117), 8,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(119), 20,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [108] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(120), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
    ACTIONS(123), 7,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(125), 21,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [213] = 41,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(127), 1,
      anon_sym_COMMA,
    ACTIONS(129), 1,
      anon_sym_RBRACK,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(936), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [354] = 41,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(133), 1,
      anon_sym_COMMA,
    ACTIONS(135), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(939), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [495] = 41,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(137), 1,
      anon_sym_COMMA,
    ACTIONS(139), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(930), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [636] = 41,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(141), 1,
      anon_sym_COMMA,
    ACTIONS(143), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(943), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [777] = 41,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(145), 1,
      anon_sym_COMMA,
    ACTIONS(147), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(995), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [918] = 41,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_COMMA,
    ACTIONS(151), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(923), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [1059] = 41,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(153), 1,
      anon_sym_COMMA,
    ACTIONS(155), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(963), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [1200] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(157), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [1338] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(159), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [1476] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(161), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [1614] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(163), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [1752] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(165), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [1890] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(167), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [2028] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(169), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [2166] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(171), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [2304] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(173), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [2442] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(175), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [2580] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(177), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [2718] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(179), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [2856] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(181), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [2994] = 40,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(183), 1,
      anon_sym_RBRACK,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [3132] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(191), 1,
      anon_sym_fun,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(197), 1,
      anon_sym_if,
    ACTIONS(199), 1,
      anon_sym_forall,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(38), 1,
      sym_let_in_block,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(498), 1,
      sym_infix_expr,
    STATE(687), 1,
      sym_term,
    STATE(688), 1,
      sym_uni_term,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [3267] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(998), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [3402] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1109), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [3537] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(233), 1,
      anon_sym_fun,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(239), 1,
      anon_sym_if,
    ACTIONS(241), 1,
      anon_sym_forall,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(65), 1,
      sym_let_in_block,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(493), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1073), 1,
      sym_term,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [3672] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1029), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [3807] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(233), 1,
      anon_sym_fun,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(239), 1,
      anon_sym_if,
    ACTIONS(241), 1,
      anon_sym_forall,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(65), 1,
      sym_let_in_block,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(493), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1119), 1,
      sym_term,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [3942] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(191), 1,
      anon_sym_fun,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(197), 1,
      anon_sym_if,
    ACTIONS(199), 1,
      anon_sym_forall,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(38), 1,
      sym_let_in_block,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(498), 1,
      sym_infix_expr,
    STATE(685), 1,
      sym_term,
    STATE(688), 1,
      sym_uni_term,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [4077] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(13), 1,
      anon_sym_fun,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 1,
      anon_sym_if,
    ACTIONS(21), 1,
      anon_sym_forall,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(39), 1,
      sym_let_in_block,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(488), 1,
      sym_infix_expr,
    STATE(685), 1,
      sym_term,
    STATE(688), 1,
      sym_uni_term,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [4212] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(275), 1,
      anon_sym_fun,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(281), 1,
      anon_sym_if,
    ACTIONS(283), 1,
      anon_sym_forall,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(43), 1,
      sym_let_in_block,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(490), 1,
      sym_infix_expr,
    STATE(1057), 1,
      sym_uni_term,
    STATE(1162), 1,
      sym_term,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(1056), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [4347] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(689), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [4482] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(999), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [4617] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(275), 1,
      anon_sym_fun,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(281), 1,
      anon_sym_if,
    ACTIONS(283), 1,
      anon_sym_forall,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(43), 1,
      sym_let_in_block,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(490), 1,
      sym_infix_expr,
    STATE(1057), 1,
      sym_uni_term,
    STATE(1173), 1,
      sym_term,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(1056), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [4752] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(275), 1,
      anon_sym_fun,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(281), 1,
      anon_sym_if,
    ACTIONS(283), 1,
      anon_sym_forall,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(43), 1,
      sym_let_in_block,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(490), 1,
      sym_infix_expr,
    STATE(1057), 1,
      sym_uni_term,
    STATE(1171), 1,
      sym_term,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(1056), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [4887] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(191), 1,
      anon_sym_fun,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(197), 1,
      anon_sym_if,
    ACTIONS(199), 1,
      anon_sym_forall,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(38), 1,
      sym_let_in_block,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(498), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1218), 1,
      sym_term,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [5022] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1047), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [5157] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(13), 1,
      anon_sym_fun,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 1,
      anon_sym_if,
    ACTIONS(21), 1,
      anon_sym_forall,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(39), 1,
      sym_let_in_block,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(488), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(689), 1,
      sym_term,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [5292] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(233), 1,
      anon_sym_fun,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(239), 1,
      anon_sym_if,
    ACTIONS(241), 1,
      anon_sym_forall,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(65), 1,
      sym_let_in_block,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(493), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1080), 1,
      sym_term,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [5427] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(317), 1,
      anon_sym_fun,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(323), 1,
      anon_sym_if,
    ACTIONS(325), 1,
      anon_sym_forall,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(64), 1,
      sym_let_in_block,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(481), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1027), 1,
      sym_term,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [5562] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(13), 1,
      anon_sym_fun,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 1,
      anon_sym_if,
    ACTIONS(21), 1,
      anon_sym_forall,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(39), 1,
      sym_let_in_block,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(488), 1,
      sym_infix_expr,
    STATE(687), 1,
      sym_term,
    STATE(688), 1,
      sym_uni_term,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [5697] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(920), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [5832] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(233), 1,
      anon_sym_fun,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(239), 1,
      anon_sym_if,
    ACTIONS(241), 1,
      anon_sym_forall,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(65), 1,
      sym_let_in_block,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(493), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(689), 1,
      sym_term,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [5967] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(317), 1,
      anon_sym_fun,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(323), 1,
      anon_sym_if,
    ACTIONS(325), 1,
      anon_sym_forall,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(64), 1,
      sym_let_in_block,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(481), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(689), 1,
      sym_term,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [6102] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(233), 1,
      anon_sym_fun,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(239), 1,
      anon_sym_if,
    ACTIONS(241), 1,
      anon_sym_forall,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(65), 1,
      sym_let_in_block,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(493), 1,
      sym_infix_expr,
    STATE(687), 1,
      sym_term,
    STATE(688), 1,
      sym_uni_term,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [6237] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(191), 1,
      anon_sym_fun,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(197), 1,
      anon_sym_if,
    ACTIONS(199), 1,
      anon_sym_forall,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(38), 1,
      sym_let_in_block,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(498), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1223), 1,
      sym_term,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [6372] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(191), 1,
      anon_sym_fun,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(197), 1,
      anon_sym_if,
    ACTIONS(199), 1,
      anon_sym_forall,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(38), 1,
      sym_let_in_block,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(498), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(689), 1,
      sym_term,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [6507] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(317), 1,
      anon_sym_fun,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(323), 1,
      anon_sym_if,
    ACTIONS(325), 1,
      anon_sym_forall,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(64), 1,
      sym_let_in_block,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(481), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1019), 1,
      sym_term,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [6642] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(191), 1,
      anon_sym_fun,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(197), 1,
      anon_sym_if,
    ACTIONS(199), 1,
      anon_sym_forall,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(38), 1,
      sym_let_in_block,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(498), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1210), 1,
      sym_term,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [6777] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(687), 1,
      sym_term,
    STATE(688), 1,
      sym_uni_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [6912] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(685), 1,
      sym_term,
    STATE(688), 1,
      sym_uni_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [7047] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(57), 1,
      anon_sym_fun,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_if,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(60), 1,
      sym_let_in_block,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(464), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1017), 1,
      sym_term,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [7182] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(191), 1,
      anon_sym_fun,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(197), 1,
      anon_sym_if,
    ACTIONS(199), 1,
      anon_sym_forall,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(38), 1,
      sym_let_in_block,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(498), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1212), 1,
      sym_term,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [7317] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(317), 1,
      anon_sym_fun,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(323), 1,
      anon_sym_if,
    ACTIONS(325), 1,
      anon_sym_forall,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(64), 1,
      sym_let_in_block,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(481), 1,
      sym_infix_expr,
    STATE(687), 1,
      sym_term,
    STATE(688), 1,
      sym_uni_term,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [7452] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(317), 1,
      anon_sym_fun,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(323), 1,
      anon_sym_if,
    ACTIONS(325), 1,
      anon_sym_forall,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(64), 1,
      sym_let_in_block,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(481), 1,
      sym_infix_expr,
    STATE(685), 1,
      sym_term,
    STATE(688), 1,
      sym_uni_term,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [7587] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(233), 1,
      anon_sym_fun,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(239), 1,
      anon_sym_if,
    ACTIONS(241), 1,
      anon_sym_forall,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(65), 1,
      sym_let_in_block,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(493), 1,
      sym_infix_expr,
    STATE(685), 1,
      sym_term,
    STATE(688), 1,
      sym_uni_term,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [7722] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(191), 1,
      anon_sym_fun,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(197), 1,
      anon_sym_if,
    ACTIONS(199), 1,
      anon_sym_forall,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(38), 1,
      sym_let_in_block,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(498), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1214), 1,
      sym_term,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [7857] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(233), 1,
      anon_sym_fun,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(239), 1,
      anon_sym_if,
    ACTIONS(241), 1,
      anon_sym_forall,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(65), 1,
      sym_let_in_block,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(493), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1129), 1,
      sym_term,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [7992] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(275), 1,
      anon_sym_fun,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(281), 1,
      anon_sym_if,
    ACTIONS(283), 1,
      anon_sym_forall,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(43), 1,
      sym_let_in_block,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(490), 1,
      sym_infix_expr,
    STATE(1057), 1,
      sym_uni_term,
    STATE(1207), 1,
      sym_term,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(1056), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [8127] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(233), 1,
      anon_sym_fun,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(239), 1,
      anon_sym_if,
    ACTIONS(241), 1,
      anon_sym_forall,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(65), 1,
      sym_let_in_block,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(493), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1145), 1,
      sym_term,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [8262] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(233), 1,
      anon_sym_fun,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(239), 1,
      anon_sym_if,
    ACTIONS(241), 1,
      anon_sym_forall,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(65), 1,
      sym_let_in_block,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(493), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1178), 1,
      sym_term,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [8397] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(191), 1,
      anon_sym_fun,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(197), 1,
      anon_sym_if,
    ACTIONS(199), 1,
      anon_sym_forall,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(38), 1,
      sym_let_in_block,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(498), 1,
      sym_infix_expr,
    STATE(688), 1,
      sym_uni_term,
    STATE(1216), 1,
      sym_term,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(690), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [8532] = 39,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_let,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(275), 1,
      anon_sym_fun,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(281), 1,
      anon_sym_if,
    ACTIONS(283), 1,
      anon_sym_forall,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(43), 1,
      sym_let_in_block,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(490), 1,
      sym_infix_expr,
    STATE(1051), 1,
      sym_term,
    STATE(1057), 1,
      sym_uni_term,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
    STATE(1056), 5,
      sym_let_expr,
      sym_fun_expr,
      sym_ite_expr,
      sym_annotated_infix_expr,
      sym_forall,
  [8667] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(252), 1,
      sym_record_operand,
    STATE(261), 1,
      sym_type_builtin,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
    ACTIONS(117), 8,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(119), 14,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [8769] = 38,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(325), 1,
      anon_sym_forall,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(355), 1,
      anon_sym_priority,
    ACTIONS(357), 1,
      anon_sym_doc,
    ACTIONS(359), 1,
      anon_sym_rec,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(530), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(648), 1,
      sym_types,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(353), 4,
      anon_sym_default,
      anon_sym_force,
      anon_sym_optional,
      anon_sym_not_exported,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [8900] = 38,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_forall,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(355), 1,
      anon_sym_priority,
    ACTIONS(357), 1,
      anon_sym_doc,
    ACTIONS(359), 1,
      anon_sym_rec,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(553), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(648), 1,
      sym_types,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(353), 4,
      anon_sym_default,
      anon_sym_force,
      anon_sym_optional,
      anon_sym_not_exported,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [9031] = 38,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_forall,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(355), 1,
      anon_sym_priority,
    ACTIONS(357), 1,
      anon_sym_doc,
    ACTIONS(359), 1,
      anon_sym_rec,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(540), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(648), 1,
      sym_types,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(353), 4,
      anon_sym_default,
      anon_sym_force,
      anon_sym_optional,
      anon_sym_not_exported,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [9162] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(253), 1,
      sym_record_operand,
    STATE(261), 1,
      sym_type_builtin,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
    ACTIONS(123), 7,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(125), 15,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [9261] = 38,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(283), 1,
      anon_sym_forall,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(363), 1,
      anon_sym_priority,
    ACTIONS(365), 1,
      anon_sym_doc,
    ACTIONS(367), 1,
      anon_sym_rec,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(581), 1,
      sym_infix_expr,
    STATE(986), 1,
      sym_forall,
    STATE(987), 1,
      sym_types,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(361), 4,
      anon_sym_default,
      anon_sym_force,
      anon_sym_optional,
      anon_sym_not_exported,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [9392] = 38,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(355), 1,
      anon_sym_priority,
    ACTIONS(357), 1,
      anon_sym_doc,
    ACTIONS(359), 1,
      anon_sym_rec,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(476), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(648), 1,
      sym_types,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(353), 4,
      anon_sym_default,
      anon_sym_force,
      anon_sym_optional,
      anon_sym_not_exported,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [9523] = 38,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(241), 1,
      anon_sym_forall,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(355), 1,
      anon_sym_priority,
    ACTIONS(357), 1,
      anon_sym_doc,
    ACTIONS(359), 1,
      anon_sym_rec,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(548), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(648), 1,
      sym_types,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(353), 4,
      anon_sym_default,
      anon_sym_force,
      anon_sym_optional,
      anon_sym_not_exported,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [9654] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(273), 1,
      sym_type_builtin,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(402), 1,
      sym_record_operand,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
    ACTIONS(117), 7,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(119), 14,
      sym_interpolation_end,
      anon_sym_COLON,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [9755] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(278), 1,
      sym_type_builtin,
    STATE(293), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
    ACTIONS(117), 8,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(119), 13,
      anon_sym_COLON,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [9856] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(376), 1,
      sym_record_operand,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
    ACTIONS(117), 8,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(119), 13,
      anon_sym_COLON,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [9957] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(387), 1,
      sym_record_operand,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
    ACTIONS(117), 7,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(119), 14,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [10058] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(278), 1,
      sym_type_builtin,
    STATE(328), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
    ACTIONS(123), 7,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(125), 14,
      anon_sym_COLON,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [10156] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(273), 1,
      sym_type_builtin,
    STATE(340), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(123), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    STATE(288), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
    ACTIONS(125), 15,
      sym_interpolation_end,
      anon_sym_COLON,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [10254] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(375), 1,
      sym_record_operand,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
    ACTIONS(123), 7,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(125), 14,
      anon_sym_COLON,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [10352] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(367), 1,
      sym_record_operand,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(123), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    STATE(266), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
    ACTIONS(125), 15,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [10450] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(369), 30,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
  [10506] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(373), 30,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
  [10562] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(379), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(377), 30,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
      anon_sym_PIPE_RBRACK,
  [10618] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(385), 1,
      anon_sym_DOT,
    ACTIONS(383), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(381), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [10675] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(389), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(387), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [10730] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(393), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(391), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [10785] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(397), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(395), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [10840] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(401), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(399), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [10895] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(403), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [10950] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(119), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11005] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(407), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11060] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(413), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(411), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11115] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(417), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(415), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11170] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(421), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(419), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11225] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(425), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(423), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11280] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(427), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11335] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(431), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11390] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(435), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11445] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(439), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11500] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(443), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11555] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(447), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11610] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(451), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11665] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(457), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(455), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11720] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(461), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(459), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11775] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(465), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(463), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11830] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(467), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11885] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(471), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(475), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [11995] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(481), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(479), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [12050] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(385), 1,
      anon_sym_DOT,
    ACTIONS(485), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(483), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [12107] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(487), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [12162] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(385), 1,
      anon_sym_DOT,
    ACTIONS(493), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(491), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [12219] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(495), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [12274] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(501), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(499), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [12329] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(385), 1,
      anon_sym_DOT,
    ACTIONS(505), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(503), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [12386] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(507), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [12441] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(511), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [12496] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(517), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(515), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [12551] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(521), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(519), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [12606] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(525), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(523), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [12661] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(283), 1,
      anon_sym_forall,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(581), 1,
      sym_infix_expr,
    STATE(986), 1,
      sym_forall,
    STATE(987), 1,
      sym_types,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [12777] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_forall,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(540), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(648), 1,
      sym_types,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [12893] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(476), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(1077), 1,
      sym_types,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [13009] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(476), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(1141), 1,
      sym_types,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [13125] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(476), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(1125), 1,
      sym_types,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [13241] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(476), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(1081), 1,
      sym_types,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [13357] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(476), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(1122), 1,
      sym_types,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [13473] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(241), 1,
      anon_sym_forall,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(548), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(648), 1,
      sym_types,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [13589] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(325), 1,
      anon_sym_forall,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(530), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(648), 1,
      sym_types,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [13705] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(241), 1,
      anon_sym_forall,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(548), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(662), 1,
      sym_types,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [13821] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(476), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(648), 1,
      sym_types,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [13937] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_forall,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(540), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(662), 1,
      sym_types,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [14053] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(476), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(1106), 1,
      sym_types,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [14169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(383), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(381), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [14223] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(529), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(527), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [14277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(531), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [14331] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(537), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(535), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [14385] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(476), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(662), 1,
      sym_types,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [14501] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(541), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(539), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [14555] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_forall,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(553), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(662), 1,
      sym_types,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [14671] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(65), 1,
      anon_sym_forall,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(476), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(1103), 1,
      sym_types,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [14787] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(545), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(543), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [14841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(549), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(547), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [14895] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(283), 1,
      anon_sym_forall,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(581), 1,
      sym_infix_expr,
    STATE(978), 1,
      sym_types,
    STATE(986), 1,
      sym_forall,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [15011] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(325), 1,
      anon_sym_forall,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(530), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(662), 1,
      sym_types,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [15127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(553), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(551), 29,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [15181] = 34,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_forall,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(553), 1,
      sym_infix_expr,
    STATE(646), 1,
      sym_forall,
    STATE(648), 1,
      sym_types,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [15297] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(555), 1,
      anon_sym_RPAREN,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(475), 1,
      sym_infix_expr,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [15407] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    ACTIONS(557), 1,
      anon_sym_RPAREN,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(474), 1,
      sym_infix_expr,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [15517] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(551), 1,
      sym_infix_expr,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [15624] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(543), 1,
      sym_infix_expr,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [15731] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(531), 1,
      sym_infix_expr,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [15838] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(565), 1,
      sym_infix_expr,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [15945] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(562), 1,
      sym_infix_expr,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [16052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(561), 1,
      sym_infix_expr,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [16159] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(560), 1,
      sym_infix_expr,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [16266] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(557), 1,
      sym_infix_expr,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [16373] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(584), 1,
      sym_infix_expr,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [16480] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(583), 1,
      sym_infix_expr,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [16587] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(579), 1,
      sym_infix_expr,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [16694] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(577), 1,
      sym_infix_expr,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [16801] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(572), 1,
      sym_infix_expr,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [16908] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(564), 1,
      sym_infix_expr,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [17015] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(563), 1,
      sym_infix_expr,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [17122] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(559), 1,
      sym_infix_expr,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [17229] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(582), 1,
      sym_infix_expr,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [17336] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(519), 1,
      sym_infix_expr,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [17443] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(544), 1,
      sym_infix_expr,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [17550] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(522), 1,
      sym_infix_expr,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [17657] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(524), 1,
      sym_infix_expr,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [17764] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(538), 1,
      sym_infix_expr,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [17871] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(527), 1,
      sym_infix_expr,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [17978] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(528), 1,
      sym_infix_expr,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [18085] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(277), 1,
      anon_sym_match,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(285), 1,
      anon_sym_import,
    ACTIONS(287), 1,
      anon_sym_Array,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(301), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(81), 1,
      sym_enum_tag,
    STATE(86), 1,
      sym_applicative,
    STATE(176), 1,
      sym_infix_u_op_5,
    STATE(273), 1,
      sym_type_builtin,
    STATE(306), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    STATE(542), 1,
      sym_infix_expr,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(454), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [18192] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(555), 1,
      sym_infix_expr,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [18299] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(554), 1,
      sym_infix_expr,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [18406] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(518), 1,
      sym_infix_expr,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [18513] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(520), 1,
      sym_infix_expr,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [18620] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(556), 1,
      sym_infix_expr,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [18727] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(534), 1,
      sym_infix_expr,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [18834] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(558), 1,
      sym_infix_expr,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [18941] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(567), 1,
      sym_infix_expr,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [19048] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(570), 1,
      sym_infix_expr,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [19155] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(573), 1,
      sym_infix_expr,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [19262] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(533), 1,
      sym_infix_expr,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [19369] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(574), 1,
      sym_infix_expr,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [19476] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(575), 1,
      sym_infix_expr,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [19583] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(576), 1,
      sym_infix_expr,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [19690] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(193), 1,
      anon_sym_match,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(201), 1,
      anon_sym_import,
    ACTIONS(203), 1,
      anon_sym_Array,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(83), 1,
      sym_enum_tag,
    STATE(87), 1,
      sym_applicative,
    STATE(187), 1,
      sym_infix_u_op_5,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(343), 1,
      sym_record_operand,
    STATE(578), 1,
      sym_infix_expr,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(434), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [19797] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(539), 1,
      sym_infix_expr,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [19904] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(529), 1,
      sym_infix_expr,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [20011] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(541), 1,
      sym_infix_expr,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [20118] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(566), 1,
      sym_infix_expr,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [20225] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(546), 1,
      sym_infix_expr,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [20332] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(521), 1,
      sym_infix_expr,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [20439] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(547), 1,
      sym_infix_expr,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [20546] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(475), 1,
      sym_infix_expr,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [20653] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(568), 1,
      sym_infix_expr,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [20760] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(549), 1,
      sym_infix_expr,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [20867] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(466), 1,
      sym_infix_expr,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [20974] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(465), 1,
      sym_infix_expr,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [21081] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(468), 1,
      sym_infix_expr,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [21188] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(469), 1,
      sym_infix_expr,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [21295] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(470), 1,
      sym_infix_expr,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [21402] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(471), 1,
      sym_infix_expr,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [21509] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(472), 1,
      sym_infix_expr,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [21616] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(473), 1,
      sym_infix_expr,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [21723] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(467), 1,
      sym_infix_expr,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [21830] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(571), 1,
      sym_infix_expr,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [21937] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(550), 1,
      sym_infix_expr,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [22044] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(545), 1,
      sym_infix_expr,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [22151] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(319), 1,
      anon_sym_match,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      anon_sym_import,
    ACTIONS(329), 1,
      anon_sym_Array,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(343), 1,
      anon_sym_DASH,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(73), 1,
      sym_enum_tag,
    STATE(77), 1,
      sym_applicative,
    STATE(199), 1,
      sym_infix_u_op_5,
    STATE(232), 1,
      sym_record_operand,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(261), 1,
      sym_type_builtin,
    STATE(525), 1,
      sym_infix_expr,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(413), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [22258] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(235), 1,
      anon_sym_match,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(243), 1,
      anon_sym_import,
    ACTIONS(245), 1,
      anon_sym_Array,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(259), 1,
      anon_sym_DASH,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(82), 1,
      sym_enum_tag,
    STATE(85), 1,
      sym_applicative,
    STATE(158), 1,
      sym_infix_u_op_5,
    STATE(278), 1,
      sym_type_builtin,
    STATE(352), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    STATE(552), 1,
      sym_infix_expr,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(449), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [22365] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(59), 1,
      anon_sym_match,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_import,
    ACTIONS(71), 1,
      anon_sym_Array,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    ACTIONS(131), 1,
      anon_sym_DASH,
    STATE(9), 1,
      sym_enum_tag,
    STATE(10), 1,
      sym_applicative,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(92), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    STATE(222), 1,
      sym_infix_u_op_5,
    STATE(474), 1,
      sym_infix_expr,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(142), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [22472] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(15), 1,
      anon_sym_match,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(23), 1,
      anon_sym_import,
    ACTIONS(25), 1,
      anon_sym_Array,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(39), 1,
      anon_sym_DASH,
    ACTIONS(41), 1,
      anon_sym_BANG,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(84), 1,
      sym_enum_tag,
    STATE(88), 1,
      sym_applicative,
    STATE(184), 1,
      sym_infix_u_op_5,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(297), 1,
      sym_record_operand,
    STATE(569), 1,
      sym_infix_expr,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(441), 3,
      sym_match_expr,
      sym_type_array,
      sym_enum_variant,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 5,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_builtin,
      sym_type_atom,
  [22579] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(451), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [22628] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(407), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [22677] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(507), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [22726] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(373), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [22775] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(425), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(423), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [22824] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(421), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(419), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [22873] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(417), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(415), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [22922] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(413), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(411), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [22971] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(559), 1,
      anon_sym_DOT,
    ACTIONS(383), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(381), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23022] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(403), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23071] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(401), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(399), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23120] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(397), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(395), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(393), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(391), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23218] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(389), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(387), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(447), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23316] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(427), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23365] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(431), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23414] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(435), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23463] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(379), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(377), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23512] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(443), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23561] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(487), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23610] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(465), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(463), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23659] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(467), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23708] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(471), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23757] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(475), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(369), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23855] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(559), 1,
      anon_sym_DOT,
    ACTIONS(505), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(503), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(481), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(479), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [23955] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(559), 1,
      anon_sym_DOT,
    ACTIONS(485), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(483), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24006] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(559), 1,
      anon_sym_DOT,
    ACTIONS(493), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(491), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24057] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(495), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24106] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(501), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(499), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24155] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(511), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24204] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(461), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(459), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24253] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(457), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(455), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24302] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(439), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24351] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(517), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(515), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24400] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(521), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(519), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24449] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(525), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(523), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24498] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(119), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24547] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(439), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24595] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(495), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24643] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(119), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24691] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(369), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24739] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(507), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24787] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(461), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(459), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24835] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(457), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(455), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24883] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(439), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24931] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(427), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [24979] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(521), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(519), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25027] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(525), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(523), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25075] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(521), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(519), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25123] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(517), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(515), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(407), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25219] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(521), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(519), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(507), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25315] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(389), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(387), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25363] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(525), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(523), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25411] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(119), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25459] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(525), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(523), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25507] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(393), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(391), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25555] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(511), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25603] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(369), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25651] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(501), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(499), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25699] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(119), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25747] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(561), 1,
      anon_sym_DOT,
    ACTIONS(505), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(503), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25797] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(475), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25845] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(495), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25893] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(471), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25941] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(563), 1,
      anon_sym_DOT,
    ACTIONS(485), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(483), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [25991] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(467), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26039] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(465), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(463), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26087] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(481), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(479), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26135] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(561), 1,
      anon_sym_DOT,
    ACTIONS(383), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(381), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26185] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(487), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26233] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(517), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(515), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26281] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(545), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(543), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26329] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(451), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26377] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(475), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26425] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(439), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26473] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(471), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26521] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(467), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26569] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(565), 1,
      anon_sym_DOT,
    ACTIONS(383), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(381), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26619] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(465), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(463), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26667] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(447), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26715] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(457), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(455), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26763] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(397), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(395), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26811] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(401), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(399), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26859] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(443), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26907] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(403), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [26955] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(435), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27003] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(517), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(515), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27051] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(413), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(411), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27099] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(379), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(377), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27147] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(417), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(415), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27195] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(511), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27243] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(373), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27291] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(451), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27339] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(447), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27387] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(487), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27435] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(443), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27483] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(481), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(479), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27531] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(565), 1,
      anon_sym_DOT,
    ACTIONS(505), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(503), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27581] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(421), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(419), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27629] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(563), 1,
      anon_sym_DOT,
    ACTIONS(493), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(491), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27679] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(425), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(423), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(435), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27775] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(119), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27823] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(531), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27871] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(501), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(499), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27919] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(525), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(523), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [27967] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(521), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(519), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28015] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(563), 1,
      anon_sym_DOT,
    ACTIONS(505), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(503), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28065] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(495), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28113] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(501), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(499), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28161] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(379), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(377), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28209] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(565), 1,
      anon_sym_DOT,
    ACTIONS(493), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(491), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28259] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(373), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28307] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(431), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28355] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(567), 1,
      anon_sym_DOT,
    ACTIONS(383), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(381), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28405] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(517), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(515), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28453] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(427), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28501] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(407), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28549] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(397), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(395), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28597] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(475), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28645] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(471), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28693] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(461), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(459), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28741] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(467), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28789] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(563), 1,
      anon_sym_DOT,
    ACTIONS(383), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(381), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28839] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(465), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(463), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(461), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(459), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28935] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(507), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [28983] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(389), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(387), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29031] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(393), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(391), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29079] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(369), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(397), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(395), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29175] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(511), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29223] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(451), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29271] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(567), 1,
      anon_sym_DOT,
    ACTIONS(505), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(503), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29321] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(401), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(399), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29369] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(549), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(547), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29417] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(403), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29465] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(413), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(411), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29513] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(561), 1,
      anon_sym_DOT,
    ACTIONS(493), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(491), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(417), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(415), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29611] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(421), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(419), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29659] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(425), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(423), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29707] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(501), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(499), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29755] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(541), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(539), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29803] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(495), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29851] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(507), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29899] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(567), 1,
      anon_sym_DOT,
    ACTIONS(493), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(491), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29949] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(567), 1,
      anon_sym_DOT,
    ACTIONS(485), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(483), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [29999] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(457), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(455), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30047] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(553), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(551), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30095] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(447), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30143] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(439), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30191] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(443), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30239] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(511), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30287] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(369), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30335] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(435), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30383] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(379), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(377), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30431] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(373), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30479] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(561), 1,
      anon_sym_DOT,
    ACTIONS(485), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(483), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30529] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(425), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(423), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30577] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(421), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(419), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30625] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(537), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(535), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30673] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(487), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30721] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(417), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(415), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30769] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(481), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(479), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30817] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(413), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(411), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30865] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(481), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(479), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30913] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(487), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [30961] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(373), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31009] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(403), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31057] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(401), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(399), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31105] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(475), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31153] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(471), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31201] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(565), 1,
      anon_sym_DOT,
    ACTIONS(485), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(483), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31251] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(467), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31299] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(465), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(463), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31347] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(451), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31395] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(447), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31443] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(443), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31491] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(435), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31539] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(529), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(527), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31587] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(431), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31635] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(461), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(459), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31683] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(457), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(455), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31731] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(383), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(381), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31779] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(425), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(423), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31827] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(421), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(419), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31875] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(417), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(415), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31923] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(413), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(411), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [31971] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(403), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32019] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(401), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(399), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32067] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(397), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(395), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32115] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(393), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(391), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32163] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(389), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(387), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(407), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32259] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(427), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32307] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(379), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(377), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32355] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(431), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32403] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(427), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32451] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(407), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(389), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(387), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32547] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(393), 18,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(391), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32595] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(431), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32643] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(537), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(535), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32690] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(531), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32737] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(383), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(381), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32784] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(541), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(539), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32831] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(549), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(547), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32878] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(549), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(547), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32925] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(545), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(543), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [32972] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(541), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(539), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33019] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(529), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(527), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33066] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(383), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(381), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33113] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(537), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(535), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33160] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(553), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(551), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33207] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(553), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(551), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33254] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(541), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(539), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(529), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(527), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33348] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(553), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(551), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33395] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(529), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(527), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33442] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(383), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(381), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33489] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(529), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(527), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33536] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(545), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(543), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33583] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(549), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(547), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33630] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(531), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33677] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(383), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(381), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33724] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(549), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(547), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33771] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(531), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33818] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(545), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(543), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33865] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(553), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_then,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(551), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33912] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(537), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(535), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [33959] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(541), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(539), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [34006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(531), 23,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      ts_builtin_sym_end,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [34053] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(545), 16,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(543), 23,
      sym_multstr_start,
      sym__str_start,
      sym_interpolation_end,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [34100] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(537), 17,
      sym_ident,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    ACTIONS(535), 22,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_LBRACK_PIPE,
  [34147] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(569), 1,
      anon_sym_PIPE,
    ACTIONS(571), 1,
      anon_sym_COLON,
    ACTIONS(573), 1,
      anon_sym_EQ,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(597), 1,
      anon_sym_DASH_GT,
    STATE(208), 1,
      sym_infix_lazy_b_op_10,
    STATE(209), 1,
      sym_infix_lazy_b_op_9,
    STATE(210), 1,
      sym_infix_b_op_8,
    STATE(211), 1,
      sym_infix_b_op_7,
    STATE(212), 1,
      sym_infix_b_op_6,
    STATE(213), 1,
      sym_infix_b_op_4,
    STATE(214), 1,
      sym_infix_b_op_3,
    STATE(215), 1,
      sym_infix_b_op_2,
    STATE(686), 1,
      sym_annot,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(684), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(575), 6,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [34239] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    STATE(208), 1,
      sym_infix_lazy_b_op_10,
    STATE(209), 1,
      sym_infix_lazy_b_op_9,
    STATE(210), 1,
      sym_infix_b_op_8,
    STATE(211), 1,
      sym_infix_b_op_7,
    STATE(212), 1,
      sym_infix_b_op_6,
    STATE(213), 1,
      sym_infix_b_op_4,
    STATE(214), 1,
      sym_infix_b_op_3,
    STATE(215), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(599), 2,
      anon_sym_PIPE,
      anon_sym_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 11,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [34315] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    STATE(208), 1,
      sym_infix_lazy_b_op_10,
    STATE(209), 1,
      sym_infix_lazy_b_op_9,
    STATE(210), 1,
      sym_infix_b_op_8,
    STATE(211), 1,
      sym_infix_b_op_7,
    STATE(212), 1,
      sym_infix_b_op_6,
    STATE(213), 1,
      sym_infix_b_op_4,
    STATE(214), 1,
      sym_infix_b_op_3,
    STATE(215), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(599), 2,
      anon_sym_PIPE,
      anon_sym_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 10,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [34393] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(597), 1,
      anon_sym_DASH_GT,
    STATE(208), 1,
      sym_infix_lazy_b_op_10,
    STATE(209), 1,
      sym_infix_lazy_b_op_9,
    STATE(210), 1,
      sym_infix_b_op_8,
    STATE(211), 1,
      sym_infix_b_op_7,
    STATE(212), 1,
      sym_infix_b_op_6,
    STATE(213), 1,
      sym_infix_b_op_4,
    STATE(214), 1,
      sym_infix_b_op_3,
    STATE(215), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(599), 2,
      anon_sym_PIPE,
      anon_sym_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 8,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [34475] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    STATE(208), 1,
      sym_infix_lazy_b_op_10,
    STATE(209), 1,
      sym_infix_lazy_b_op_9,
    STATE(210), 1,
      sym_infix_b_op_8,
    STATE(211), 1,
      sym_infix_b_op_7,
    STATE(212), 1,
      sym_infix_b_op_6,
    STATE(213), 1,
      sym_infix_b_op_4,
    STATE(214), 1,
      sym_infix_b_op_3,
    STATE(215), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(599), 2,
      anon_sym_PIPE,
      anon_sym_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [34549] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    STATE(208), 1,
      sym_infix_lazy_b_op_10,
    STATE(209), 1,
      sym_infix_lazy_b_op_9,
    STATE(210), 1,
      sym_infix_b_op_8,
    STATE(211), 1,
      sym_infix_b_op_7,
    STATE(212), 1,
      sym_infix_b_op_6,
    STATE(213), 1,
      sym_infix_b_op_4,
    STATE(214), 1,
      sym_infix_b_op_3,
    STATE(215), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 4,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 15,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [34619] = 14,
    ACTIONS(3), 1,
      sym_comment,
    STATE(208), 1,
      sym_infix_lazy_b_op_10,
    STATE(209), 1,
      sym_infix_lazy_b_op_9,
    STATE(210), 1,
      sym_infix_b_op_8,
    STATE(211), 1,
      sym_infix_b_op_7,
    STATE(212), 1,
      sym_infix_b_op_6,
    STATE(213), 1,
      sym_infix_b_op_4,
    STATE(214), 1,
      sym_infix_b_op_3,
    STATE(215), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 5,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 16,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [34685] = 13,
    ACTIONS(3), 1,
      sym_comment,
    STATE(208), 1,
      sym_infix_lazy_b_op_10,
    STATE(209), 1,
      sym_infix_lazy_b_op_9,
    STATE(210), 1,
      sym_infix_b_op_8,
    STATE(211), 1,
      sym_infix_b_op_7,
    STATE(212), 1,
      sym_infix_b_op_6,
    STATE(213), 1,
      sym_infix_b_op_4,
    STATE(214), 1,
      sym_infix_b_op_3,
    STATE(215), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 7,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 16,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [34749] = 12,
    ACTIONS(3), 1,
      sym_comment,
    STATE(208), 1,
      sym_infix_lazy_b_op_10,
    STATE(209), 1,
      sym_infix_lazy_b_op_9,
    STATE(210), 1,
      sym_infix_b_op_8,
    STATE(211), 1,
      sym_infix_b_op_7,
    STATE(212), 1,
      sym_infix_b_op_6,
    STATE(213), 1,
      sym_infix_b_op_4,
    STATE(214), 1,
      sym_infix_b_op_3,
    STATE(215), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(599), 7,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 19,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [34811] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(208), 1,
      sym_infix_lazy_b_op_10,
    STATE(209), 1,
      sym_infix_lazy_b_op_9,
    STATE(210), 1,
      sym_infix_b_op_8,
    STATE(211), 1,
      sym_infix_b_op_7,
    STATE(212), 1,
      sym_infix_b_op_6,
    STATE(213), 1,
      sym_infix_b_op_4,
    STATE(214), 1,
      sym_infix_b_op_3,
    STATE(215), 1,
      sym_infix_b_op_2,
    ACTIONS(599), 7,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 21,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [34871] = 14,
    ACTIONS(3), 1,
      sym_comment,
    STATE(208), 1,
      sym_infix_lazy_b_op_10,
    STATE(209), 1,
      sym_infix_lazy_b_op_9,
    STATE(210), 1,
      sym_infix_b_op_8,
    STATE(211), 1,
      sym_infix_b_op_7,
    STATE(212), 1,
      sym_infix_b_op_6,
    STATE(213), 1,
      sym_infix_b_op_4,
    STATE(214), 1,
      sym_infix_b_op_3,
    STATE(215), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(603), 5,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(605), 16,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [34937] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(208), 1,
      sym_infix_lazy_b_op_10,
    STATE(209), 1,
      sym_infix_lazy_b_op_9,
    STATE(210), 1,
      sym_infix_b_op_8,
    STATE(211), 1,
      sym_infix_b_op_7,
    STATE(212), 1,
      sym_infix_b_op_6,
    STATE(213), 1,
      sym_infix_b_op_4,
    STATE(214), 1,
      sym_infix_b_op_3,
    STATE(215), 1,
      sym_infix_b_op_2,
    ACTIONS(603), 7,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(605), 21,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [34997] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(597), 1,
      anon_sym_DASH_GT,
    STATE(208), 1,
      sym_infix_lazy_b_op_10,
    STATE(209), 1,
      sym_infix_lazy_b_op_9,
    STATE(210), 1,
      sym_infix_b_op_8,
    STATE(211), 1,
      sym_infix_b_op_7,
    STATE(212), 1,
      sym_infix_b_op_6,
    STATE(213), 1,
      sym_infix_b_op_4,
    STATE(214), 1,
      sym_infix_b_op_3,
    STATE(215), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(607), 2,
      anon_sym_PIPE,
      anon_sym_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(609), 8,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [35079] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(611), 1,
      sym_num_literal,
    ACTIONS(615), 1,
      sym_raw_enum_tag,
    ACTIONS(619), 1,
      anon_sym_LBRACE,
    ACTIONS(623), 1,
      anon_sym_LPAREN,
    ACTIONS(625), 1,
      anon_sym_LBRACK,
    ACTIONS(627), 1,
      anon_sym__,
    ACTIONS(631), 1,
      anon_sym_PERCENT,
    ACTIONS(633), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(639), 1,
      sym_quoted_enum_tag_start,
    STATE(680), 1,
      sym_quoted_enum_tag,
    STATE(865), 1,
      sym_record_operand,
    STATE(887), 1,
      sym_type_builtin,
    ACTIONS(613), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(891), 2,
      sym_record_operation_chain,
      sym_atom,
    ACTIONS(617), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
    ACTIONS(621), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(882), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
  [35160] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(655), 1,
      anon_sym_RBRACK,
    ACTIONS(657), 1,
      anon_sym_DOT_DOT,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    STATE(501), 1,
      aux_sym_array_pattern_repeat1,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(1002), 1,
      sym_pattern,
    STATE(1100), 1,
      sym_pattern_or_branch,
    STATE(1192), 1,
      sym_last_elem_pat,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [35253] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(657), 1,
      anon_sym_DOT_DOT,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(667), 1,
      anon_sym_RBRACK,
    STATE(482), 1,
      aux_sym_array_pattern_repeat1,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(1002), 1,
      sym_pattern,
    STATE(1100), 1,
      sym_pattern_or_branch,
    STATE(1152), 1,
      sym_last_elem_pat,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [35346] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(669), 1,
      anon_sym_rec,
    ACTIONS(671), 1,
      anon_sym_COMMA,
    ACTIONS(673), 1,
      anon_sym_in,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(835), 1,
      sym_pattern,
    STATE(950), 1,
      sym_let_binding,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [35439] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(675), 1,
      anon_sym_PIPE,
    ACTIONS(677), 1,
      anon_sym_COLON,
    ACTIONS(679), 1,
      anon_sym_DASH_GT,
    STATE(175), 1,
      sym_infix_b_op_8,
    STATE(177), 1,
      sym_infix_b_op_7,
    STATE(178), 1,
      sym_infix_b_op_6,
    STATE(180), 1,
      sym_infix_b_op_4,
    STATE(181), 1,
      sym_infix_b_op_3,
    STATE(185), 1,
      sym_infix_b_op_2,
    STATE(203), 1,
      sym_infix_lazy_b_op_9,
    STATE(220), 1,
      sym_infix_lazy_b_op_10,
    STATE(686), 1,
      sym_annot,
    ACTIONS(575), 2,
      anon_sym_COMMA,
      anon_sym_in,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(844), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
  [35524] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(657), 1,
      anon_sym_DOT_DOT,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(681), 1,
      anon_sym_RBRACK,
    STATE(501), 1,
      aux_sym_array_pattern_repeat1,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(1002), 1,
      sym_pattern,
    STATE(1100), 1,
      sym_pattern_or_branch,
    STATE(1123), 1,
      sym_last_elem_pat,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [35617] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(657), 1,
      anon_sym_DOT_DOT,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(683), 1,
      anon_sym_RBRACK,
    STATE(478), 1,
      aux_sym_array_pattern_repeat1,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(1002), 1,
      sym_pattern,
    STATE(1100), 1,
      sym_pattern_or_branch,
    STATE(1113), 1,
      sym_last_elem_pat,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [35710] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      sym_num_literal,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LPAREN,
    ACTIONS(77), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      anon_sym__,
    ACTIONS(109), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(121), 1,
      anon_sym_PERCENT,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(123), 1,
      sym_record_operand,
    STATE(127), 1,
      sym_type_builtin,
    ACTIONS(53), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(83), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(126), 2,
      sym_record_operation_chain,
      sym_atom,
    ACTIONS(73), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(98), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
  [35786] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(685), 1,
      anon_sym_COMMA,
    ACTIONS(687), 1,
      anon_sym_in,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(835), 1,
      sym_pattern,
    STATE(965), 1,
      sym_let_binding,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [35876] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_num_literal,
    ACTIONS(9), 1,
      sym_raw_enum_tag,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_LBRACK,
    ACTIONS(33), 1,
      anon_sym__,
    ACTIONS(37), 1,
      anon_sym_PERCENT,
    ACTIONS(43), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(49), 1,
      sym_quoted_enum_tag_start,
    STATE(267), 1,
      sym_quoted_enum_tag,
    STATE(275), 1,
      sym_type_builtin,
    STATE(289), 1,
      sym_record_operand,
    ACTIONS(7), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(35), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(299), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    ACTIONS(27), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(266), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
  [35952] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(311), 1,
      sym_num_literal,
    ACTIONS(315), 1,
      sym_raw_enum_tag,
    ACTIONS(321), 1,
      anon_sym_LBRACE,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(335), 1,
      anon_sym_LBRACK,
    ACTIONS(337), 1,
      anon_sym__,
    ACTIONS(341), 1,
      anon_sym_PERCENT,
    ACTIONS(345), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(351), 1,
      sym_quoted_enum_tag_start,
    STATE(249), 1,
      sym_quoted_enum_tag,
    STATE(250), 1,
      sym_record_operand,
    STATE(261), 1,
      sym_type_builtin,
    ACTIONS(313), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(339), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(260), 2,
      sym_record_operation_chain,
      sym_atom,
    ACTIONS(331), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(263), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
  [36028] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      ts_builtin_sym_end,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(689), 1,
      anon_sym_PIPE,
    ACTIONS(691), 1,
      anon_sym_COLON,
    ACTIONS(693), 1,
      anon_sym_DASH_GT,
    STATE(161), 1,
      sym_infix_b_op_6,
    STATE(162), 1,
      sym_infix_b_op_4,
    STATE(163), 1,
      sym_infix_b_op_3,
    STATE(164), 1,
      sym_infix_b_op_2,
    STATE(201), 1,
      sym_infix_b_op_7,
    STATE(206), 1,
      sym_infix_b_op_8,
    STATE(217), 1,
      sym_infix_lazy_b_op_10,
    STATE(223), 1,
      sym_infix_lazy_b_op_9,
    STATE(686), 1,
      sym_annot,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(848), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
  [36112] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(269), 1,
      sym_num_literal,
    ACTIONS(273), 1,
      sym_raw_enum_tag,
    ACTIONS(279), 1,
      anon_sym_LBRACE,
    ACTIONS(291), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_LBRACK,
    ACTIONS(295), 1,
      anon_sym__,
    ACTIONS(299), 1,
      anon_sym_PERCENT,
    ACTIONS(303), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(309), 1,
      sym_quoted_enum_tag_start,
    STATE(273), 1,
      sym_type_builtin,
    STATE(326), 1,
      sym_record_operand,
    STATE(358), 1,
      sym_quoted_enum_tag,
    ACTIONS(271), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(297), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(315), 2,
      sym_record_operation_chain,
      sym_atom,
    ACTIONS(289), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(288), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
  [36188] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      sym_interpolation_end,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(695), 1,
      anon_sym_PIPE,
    ACTIONS(697), 1,
      anon_sym_COLON,
    ACTIONS(699), 1,
      anon_sym_DASH_GT,
    STATE(166), 1,
      sym_infix_lazy_b_op_10,
    STATE(167), 1,
      sym_infix_lazy_b_op_9,
    STATE(168), 1,
      sym_infix_b_op_8,
    STATE(169), 1,
      sym_infix_b_op_7,
    STATE(170), 1,
      sym_infix_b_op_6,
    STATE(171), 1,
      sym_infix_b_op_4,
    STATE(172), 1,
      sym_infix_b_op_3,
    STATE(173), 1,
      sym_infix_b_op_2,
    STATE(1187), 1,
      sym_annot,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(851), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
  [36272] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(705), 1,
      anon_sym_COMMA,
    ACTIONS(707), 1,
      anon_sym_RBRACE,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(922), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [36362] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(185), 1,
      sym_num_literal,
    ACTIONS(189), 1,
      sym_raw_enum_tag,
    ACTIONS(195), 1,
      anon_sym_LBRACE,
    ACTIONS(207), 1,
      anon_sym_LPAREN,
    ACTIONS(209), 1,
      anon_sym_LBRACK,
    ACTIONS(211), 1,
      anon_sym__,
    ACTIONS(215), 1,
      anon_sym_PERCENT,
    ACTIONS(219), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(225), 1,
      sym_quoted_enum_tag_start,
    STATE(286), 1,
      sym_quoted_enum_tag,
    STATE(335), 1,
      sym_type_builtin,
    STATE(362), 1,
      sym_record_operand,
    ACTIONS(187), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(344), 2,
      sym_record_operation_chain,
      sym_atom,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    ACTIONS(205), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(331), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
  [36438] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_else,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(713), 1,
      anon_sym_COLON,
    ACTIONS(715), 1,
      anon_sym_DASH_GT,
    STATE(159), 1,
      sym_infix_b_op_7,
    STATE(188), 1,
      sym_infix_lazy_b_op_10,
    STATE(198), 1,
      sym_infix_lazy_b_op_9,
    STATE(200), 1,
      sym_infix_b_op_8,
    STATE(202), 1,
      sym_infix_b_op_6,
    STATE(204), 1,
      sym_infix_b_op_4,
    STATE(207), 1,
      sym_infix_b_op_3,
    STATE(218), 1,
      sym_infix_b_op_2,
    STATE(686), 1,
      sym_annot,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(857), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
  [36522] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(717), 1,
      anon_sym_COMMA,
    ACTIONS(719), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(915), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [36612] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(721), 1,
      anon_sym_COMMA,
    ACTIONS(723), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(952), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [36702] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(725), 1,
      anon_sym_COMMA,
    ACTIONS(727), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(914), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [36792] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(731), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1001), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [36882] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_then,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(733), 1,
      anon_sym_PIPE,
    ACTIONS(735), 1,
      anon_sym_COLON,
    ACTIONS(737), 1,
      anon_sym_DASH_GT,
    STATE(190), 1,
      sym_infix_b_op_2,
    STATE(191), 1,
      sym_infix_b_op_3,
    STATE(192), 1,
      sym_infix_b_op_4,
    STATE(193), 1,
      sym_infix_b_op_6,
    STATE(194), 1,
      sym_infix_b_op_7,
    STATE(195), 1,
      sym_infix_b_op_8,
    STATE(196), 1,
      sym_infix_lazy_b_op_9,
    STATE(197), 1,
      sym_infix_lazy_b_op_10,
    STATE(686), 1,
      sym_annot,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(845), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
  [36966] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(739), 1,
      anon_sym_COMMA,
    ACTIONS(741), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(942), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [37056] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(227), 1,
      sym_num_literal,
    ACTIONS(231), 1,
      sym_raw_enum_tag,
    ACTIONS(237), 1,
      anon_sym_LBRACE,
    ACTIONS(249), 1,
      anon_sym_LPAREN,
    ACTIONS(251), 1,
      anon_sym_LBRACK,
    ACTIONS(253), 1,
      anon_sym__,
    ACTIONS(257), 1,
      anon_sym_PERCENT,
    ACTIONS(261), 1,
      anon_sym_LBRACK_PIPE,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(267), 1,
      sym_quoted_enum_tag_start,
    STATE(278), 1,
      sym_type_builtin,
    STATE(336), 1,
      sym_record_operand,
    STATE(383), 1,
      sym_quoted_enum_tag,
    ACTIONS(229), 2,
      sym_ident,
      anon_sym_null,
    ACTIONS(255), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    STATE(276), 2,
      sym_record_operation_chain,
      sym_atom,
    ACTIONS(247), 4,
      anon_sym_Dyn,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
    STATE(282), 6,
      sym_uni_record,
      sym_bool,
      sym_str_chunks,
      sym_enum_tag,
      sym_builtin,
      sym_type_atom,
  [37132] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(743), 1,
      sym_signed_num_literal,
    ACTIONS(746), 1,
      sym_ident,
    ACTIONS(749), 1,
      sym_raw_enum_tag,
    ACTIONS(752), 1,
      anon_sym_LBRACE,
    ACTIONS(755), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_null,
    ACTIONS(761), 1,
      anon_sym_LBRACK,
    ACTIONS(766), 1,
      anon_sym__,
    ACTIONS(772), 1,
      sym_multstr_start,
    ACTIONS(775), 1,
      sym__str_start,
    ACTIONS(778), 1,
      sym_quoted_enum_tag_start,
    STATE(501), 1,
      aux_sym_array_pattern_repeat1,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(1100), 1,
      sym_pattern_or_branch,
    STATE(1131), 1,
      sym_pattern,
    ACTIONS(764), 2,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
    ACTIONS(769), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [37220] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(781), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1042), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [37307] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(783), 1,
      anon_sym_in,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(835), 1,
      sym_pattern,
    STATE(1016), 1,
      sym_let_binding,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [37394] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(785), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1042), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [37481] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(787), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1042), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [37568] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(789), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1042), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [37655] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(791), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1042), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [37742] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(793), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1042), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [37829] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(795), 1,
      anon_sym_in,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(835), 1,
      sym_pattern,
    STATE(1016), 1,
      sym_let_binding,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [37916] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(797), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1042), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [38003] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(799), 1,
      anon_sym_in,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(835), 1,
      sym_pattern,
    STATE(1016), 1,
      sym_let_binding,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [38090] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(801), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1042), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [38177] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(803), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1042), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [38264] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(805), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1042), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [38351] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(807), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1042), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [38438] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(809), 1,
      anon_sym_in,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(835), 1,
      sym_pattern,
    STATE(1016), 1,
      sym_let_binding,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [38525] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(811), 1,
      anon_sym_RBRACE,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1042), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [38612] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(175), 1,
      sym_infix_b_op_8,
    STATE(177), 1,
      sym_infix_b_op_7,
    STATE(178), 1,
      sym_infix_b_op_6,
    STATE(180), 1,
      sym_infix_b_op_4,
    STATE(181), 1,
      sym_infix_b_op_3,
    STATE(185), 1,
      sym_infix_b_op_2,
    STATE(203), 1,
      sym_infix_lazy_b_op_9,
    STATE(220), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 16,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [38666] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(175), 1,
      sym_infix_b_op_8,
    STATE(177), 1,
      sym_infix_b_op_7,
    STATE(178), 1,
      sym_infix_b_op_6,
    STATE(180), 1,
      sym_infix_b_op_4,
    STATE(181), 1,
      sym_infix_b_op_3,
    STATE(185), 1,
      sym_infix_b_op_2,
    STATE(203), 1,
      sym_infix_lazy_b_op_9,
    STATE(220), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 8,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [38734] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    ACTIONS(679), 1,
      anon_sym_DASH_GT,
    STATE(175), 1,
      sym_infix_b_op_8,
    STATE(177), 1,
      sym_infix_b_op_7,
    STATE(178), 1,
      sym_infix_b_op_6,
    STATE(180), 1,
      sym_infix_b_op_4,
    STATE(181), 1,
      sym_infix_b_op_3,
    STATE(185), 1,
      sym_infix_b_op_2,
    STATE(203), 1,
      sym_infix_lazy_b_op_9,
    STATE(220), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 3,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
  [38810] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(175), 1,
      sym_infix_b_op_8,
    STATE(177), 1,
      sym_infix_b_op_7,
    STATE(178), 1,
      sym_infix_b_op_6,
    STATE(180), 1,
      sym_infix_b_op_4,
    STATE(181), 1,
      sym_infix_b_op_3,
    STATE(185), 1,
      sym_infix_b_op_2,
    STATE(203), 1,
      sym_infix_lazy_b_op_9,
    STATE(220), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [38880] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    STATE(175), 1,
      sym_infix_b_op_8,
    STATE(177), 1,
      sym_infix_b_op_7,
    STATE(178), 1,
      sym_infix_b_op_6,
    STATE(180), 1,
      sym_infix_b_op_4,
    STATE(181), 1,
      sym_infix_b_op_3,
    STATE(185), 1,
      sym_infix_b_op_2,
    STATE(203), 1,
      sym_infix_lazy_b_op_9,
    STATE(220), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 10,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [38944] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(701), 1,
      sym_ident,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(907), 1,
      sym_pattern,
    STATE(1042), 1,
      sym_match_branch,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [39028] = 14,
    ACTIONS(3), 1,
      sym_comment,
    STATE(175), 1,
      sym_infix_b_op_8,
    STATE(177), 1,
      sym_infix_b_op_7,
    STATE(178), 1,
      sym_infix_b_op_6,
    STATE(180), 1,
      sym_infix_b_op_4,
    STATE(181), 1,
      sym_infix_b_op_3,
    STATE(185), 1,
      sym_infix_b_op_2,
    STATE(203), 1,
      sym_infix_lazy_b_op_9,
    STATE(220), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 11,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [39088] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(175), 1,
      sym_infix_b_op_8,
    STATE(177), 1,
      sym_infix_b_op_7,
    STATE(178), 1,
      sym_infix_b_op_6,
    STATE(180), 1,
      sym_infix_b_op_4,
    STATE(181), 1,
      sym_infix_b_op_3,
    STATE(185), 1,
      sym_infix_b_op_2,
    STATE(203), 1,
      sym_infix_lazy_b_op_9,
    STATE(220), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [39160] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(835), 1,
      sym_pattern,
    STATE(1016), 1,
      sym_let_binding,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [39244] = 13,
    ACTIONS(3), 1,
      sym_comment,
    STATE(175), 1,
      sym_infix_b_op_8,
    STATE(177), 1,
      sym_infix_b_op_7,
    STATE(178), 1,
      sym_infix_b_op_6,
    STATE(180), 1,
      sym_infix_b_op_4,
    STATE(181), 1,
      sym_infix_b_op_3,
    STATE(185), 1,
      sym_infix_b_op_2,
    STATE(203), 1,
      sym_infix_lazy_b_op_9,
    STATE(220), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 11,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [39302] = 12,
    ACTIONS(3), 1,
      sym_comment,
    STATE(175), 1,
      sym_infix_b_op_8,
    STATE(177), 1,
      sym_infix_b_op_7,
    STATE(178), 1,
      sym_infix_b_op_6,
    STATE(180), 1,
      sym_infix_b_op_4,
    STATE(181), 1,
      sym_infix_b_op_3,
    STATE(185), 1,
      sym_infix_b_op_2,
    STATE(203), 1,
      sym_infix_lazy_b_op_9,
    STATE(220), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 14,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [39358] = 14,
    ACTIONS(3), 1,
      sym_comment,
    STATE(175), 1,
      sym_infix_b_op_8,
    STATE(177), 1,
      sym_infix_b_op_7,
    STATE(178), 1,
      sym_infix_b_op_6,
    STATE(180), 1,
      sym_infix_b_op_4,
    STATE(181), 1,
      sym_infix_b_op_3,
    STATE(185), 1,
      sym_infix_b_op_2,
    STATE(203), 1,
      sym_infix_lazy_b_op_9,
    STATE(220), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(603), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(605), 11,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [39418] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(607), 1,
      anon_sym_PIPE,
    ACTIONS(679), 1,
      anon_sym_DASH_GT,
    STATE(175), 1,
      sym_infix_b_op_8,
    STATE(177), 1,
      sym_infix_b_op_7,
    STATE(178), 1,
      sym_infix_b_op_6,
    STATE(180), 1,
      sym_infix_b_op_4,
    STATE(181), 1,
      sym_infix_b_op_3,
    STATE(185), 1,
      sym_infix_b_op_2,
    STATE(203), 1,
      sym_infix_lazy_b_op_9,
    STATE(220), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(609), 3,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
  [39494] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(175), 1,
      sym_infix_b_op_8,
    STATE(177), 1,
      sym_infix_b_op_7,
    STATE(178), 1,
      sym_infix_b_op_6,
    STATE(180), 1,
      sym_infix_b_op_4,
    STATE(181), 1,
      sym_infix_b_op_3,
    STATE(185), 1,
      sym_infix_b_op_2,
    STATE(203), 1,
      sym_infix_lazy_b_op_9,
    STATE(220), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(603), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(605), 16,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [39548] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      sym_raw_enum_tag,
    ACTIONS(639), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(813), 1,
      sym_ident,
    ACTIONS(817), 1,
      anon_sym_LPAREN,
    ACTIONS(819), 1,
      anon_sym__,
    ACTIONS(821), 1,
      anon_sym_or,
    STATE(680), 1,
      sym_quoted_enum_tag,
    STATE(714), 1,
      sym_enum_tag,
    STATE(727), 1,
      sym_pattern_fun,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(741), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
    ACTIONS(815), 6,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [39620] = 14,
    ACTIONS(3), 1,
      sym_comment,
    STATE(190), 1,
      sym_infix_b_op_2,
    STATE(191), 1,
      sym_infix_b_op_3,
    STATE(192), 1,
      sym_infix_b_op_4,
    STATE(193), 1,
      sym_infix_b_op_6,
    STATE(194), 1,
      sym_infix_b_op_7,
    STATE(195), 1,
      sym_infix_b_op_8,
    STATE(196), 1,
      sym_infix_lazy_b_op_9,
    STATE(197), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 10,
      anon_sym_COLON,
      anon_sym_then,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [39679] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(159), 1,
      sym_infix_b_op_7,
    STATE(188), 1,
      sym_infix_lazy_b_op_10,
    STATE(198), 1,
      sym_infix_lazy_b_op_9,
    STATE(200), 1,
      sym_infix_b_op_8,
    STATE(202), 1,
      sym_infix_b_op_6,
    STATE(204), 1,
      sym_infix_b_op_4,
    STATE(207), 1,
      sym_infix_b_op_3,
    STATE(218), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 4,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [39750] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(1041), 1,
      sym_pattern,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [39831] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(1032), 1,
      sym_pattern,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [39912] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(1046), 1,
      sym_pattern,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [39993] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(161), 1,
      sym_infix_b_op_6,
    STATE(162), 1,
      sym_infix_b_op_4,
    STATE(163), 1,
      sym_infix_b_op_3,
    STATE(164), 1,
      sym_infix_b_op_2,
    STATE(201), 1,
      sym_infix_b_op_7,
    STATE(206), 1,
      sym_infix_b_op_8,
    STATE(217), 1,
      sym_infix_lazy_b_op_10,
    STATE(223), 1,
      sym_infix_lazy_b_op_9,
    ACTIONS(603), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(605), 15,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [40046] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(159), 1,
      sym_infix_b_op_7,
    STATE(188), 1,
      sym_infix_lazy_b_op_10,
    STATE(198), 1,
      sym_infix_lazy_b_op_9,
    STATE(200), 1,
      sym_infix_b_op_8,
    STATE(202), 1,
      sym_infix_b_op_6,
    STATE(204), 1,
      sym_infix_b_op_4,
    STATE(207), 1,
      sym_infix_b_op_3,
    STATE(218), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 5,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [40115] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(607), 1,
      anon_sym_PIPE,
    ACTIONS(737), 1,
      anon_sym_DASH_GT,
    STATE(190), 1,
      sym_infix_b_op_2,
    STATE(191), 1,
      sym_infix_b_op_3,
    STATE(192), 1,
      sym_infix_b_op_4,
    STATE(193), 1,
      sym_infix_b_op_6,
    STATE(194), 1,
      sym_infix_b_op_7,
    STATE(195), 1,
      sym_infix_b_op_8,
    STATE(196), 1,
      sym_infix_lazy_b_op_9,
    STATE(197), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(609), 2,
      anon_sym_COLON,
      anon_sym_then,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
  [40190] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(159), 1,
      sym_infix_b_op_7,
    STATE(188), 1,
      sym_infix_lazy_b_op_10,
    STATE(198), 1,
      sym_infix_lazy_b_op_9,
    STATE(200), 1,
      sym_infix_b_op_8,
    STATE(202), 1,
      sym_infix_b_op_6,
    STATE(204), 1,
      sym_infix_b_op_4,
    STATE(207), 1,
      sym_infix_b_op_3,
    STATE(218), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 7,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [40257] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(166), 1,
      sym_infix_lazy_b_op_10,
    STATE(167), 1,
      sym_infix_lazy_b_op_9,
    STATE(168), 1,
      sym_infix_b_op_8,
    STATE(169), 1,
      sym_infix_b_op_7,
    STATE(170), 1,
      sym_infix_b_op_6,
    STATE(171), 1,
      sym_infix_b_op_4,
    STATE(172), 1,
      sym_infix_b_op_3,
    STATE(173), 1,
      sym_infix_b_op_2,
    ACTIONS(603), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(605), 15,
      sym_interpolation_end,
      anon_sym_COLON,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [40310] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    STATE(159), 1,
      sym_infix_b_op_7,
    STATE(188), 1,
      sym_infix_lazy_b_op_10,
    STATE(198), 1,
      sym_infix_lazy_b_op_9,
    STATE(200), 1,
      sym_infix_b_op_8,
    STATE(202), 1,
      sym_infix_b_op_6,
    STATE(204), 1,
      sym_infix_b_op_4,
    STATE(207), 1,
      sym_infix_b_op_3,
    STATE(218), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 9,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [40373] = 14,
    ACTIONS(3), 1,
      sym_comment,
    STATE(166), 1,
      sym_infix_lazy_b_op_10,
    STATE(167), 1,
      sym_infix_lazy_b_op_9,
    STATE(168), 1,
      sym_infix_b_op_8,
    STATE(169), 1,
      sym_infix_b_op_7,
    STATE(170), 1,
      sym_infix_b_op_6,
    STATE(171), 1,
      sym_infix_b_op_4,
    STATE(172), 1,
      sym_infix_b_op_3,
    STATE(173), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(603), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(605), 10,
      sym_interpolation_end,
      anon_sym_COLON,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [40432] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    ACTIONS(715), 1,
      anon_sym_DASH_GT,
    STATE(159), 1,
      sym_infix_b_op_7,
    STATE(188), 1,
      sym_infix_lazy_b_op_10,
    STATE(198), 1,
      sym_infix_lazy_b_op_9,
    STATE(200), 1,
      sym_infix_b_op_8,
    STATE(202), 1,
      sym_infix_b_op_6,
    STATE(204), 1,
      sym_infix_b_op_4,
    STATE(207), 1,
      sym_infix_b_op_3,
    STATE(218), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(601), 2,
      anon_sym_COLON,
      anon_sym_else,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
  [40507] = 14,
    ACTIONS(3), 1,
      sym_comment,
    STATE(159), 1,
      sym_infix_b_op_7,
    STATE(188), 1,
      sym_infix_lazy_b_op_10,
    STATE(198), 1,
      sym_infix_lazy_b_op_9,
    STATE(200), 1,
      sym_infix_b_op_8,
    STATE(202), 1,
      sym_infix_b_op_6,
    STATE(204), 1,
      sym_infix_b_op_4,
    STATE(207), 1,
      sym_infix_b_op_3,
    STATE(218), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 10,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [40566] = 13,
    ACTIONS(3), 1,
      sym_comment,
    STATE(159), 1,
      sym_infix_b_op_7,
    STATE(188), 1,
      sym_infix_lazy_b_op_10,
    STATE(198), 1,
      sym_infix_lazy_b_op_9,
    STATE(200), 1,
      sym_infix_b_op_8,
    STATE(202), 1,
      sym_infix_b_op_6,
    STATE(204), 1,
      sym_infix_b_op_4,
    STATE(207), 1,
      sym_infix_b_op_3,
    STATE(218), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 10,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [40623] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(607), 1,
      anon_sym_PIPE,
    ACTIONS(715), 1,
      anon_sym_DASH_GT,
    STATE(159), 1,
      sym_infix_b_op_7,
    STATE(188), 1,
      sym_infix_lazy_b_op_10,
    STATE(198), 1,
      sym_infix_lazy_b_op_9,
    STATE(200), 1,
      sym_infix_b_op_8,
    STATE(202), 1,
      sym_infix_b_op_6,
    STATE(204), 1,
      sym_infix_b_op_4,
    STATE(207), 1,
      sym_infix_b_op_3,
    STATE(218), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(609), 2,
      anon_sym_COLON,
      anon_sym_else,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
  [40698] = 12,
    ACTIONS(3), 1,
      sym_comment,
    STATE(159), 1,
      sym_infix_b_op_7,
    STATE(188), 1,
      sym_infix_lazy_b_op_10,
    STATE(198), 1,
      sym_infix_lazy_b_op_9,
    STATE(200), 1,
      sym_infix_b_op_8,
    STATE(202), 1,
      sym_infix_b_op_6,
    STATE(204), 1,
      sym_infix_b_op_4,
    STATE(207), 1,
      sym_infix_b_op_3,
    STATE(218), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 13,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [40753] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(159), 1,
      sym_infix_b_op_7,
    STATE(188), 1,
      sym_infix_lazy_b_op_10,
    STATE(198), 1,
      sym_infix_lazy_b_op_9,
    STATE(200), 1,
      sym_infix_b_op_8,
    STATE(202), 1,
      sym_infix_b_op_6,
    STATE(204), 1,
      sym_infix_b_op_4,
    STATE(207), 1,
      sym_infix_b_op_3,
    STATE(218), 1,
      sym_infix_b_op_2,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 15,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [40806] = 14,
    ACTIONS(3), 1,
      sym_comment,
    STATE(159), 1,
      sym_infix_b_op_7,
    STATE(188), 1,
      sym_infix_lazy_b_op_10,
    STATE(198), 1,
      sym_infix_lazy_b_op_9,
    STATE(200), 1,
      sym_infix_b_op_8,
    STATE(202), 1,
      sym_infix_b_op_6,
    STATE(204), 1,
      sym_infix_b_op_4,
    STATE(207), 1,
      sym_infix_b_op_3,
    STATE(218), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(603), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(605), 10,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [40865] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(159), 1,
      sym_infix_b_op_7,
    STATE(188), 1,
      sym_infix_lazy_b_op_10,
    STATE(198), 1,
      sym_infix_lazy_b_op_9,
    STATE(200), 1,
      sym_infix_b_op_8,
    STATE(202), 1,
      sym_infix_b_op_6,
    STATE(204), 1,
      sym_infix_b_op_4,
    STATE(207), 1,
      sym_infix_b_op_3,
    STATE(218), 1,
      sym_infix_b_op_2,
    ACTIONS(603), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(605), 15,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [40918] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(607), 1,
      anon_sym_PIPE,
    ACTIONS(693), 1,
      anon_sym_DASH_GT,
    STATE(161), 1,
      sym_infix_b_op_6,
    STATE(162), 1,
      sym_infix_b_op_4,
    STATE(163), 1,
      sym_infix_b_op_3,
    STATE(164), 1,
      sym_infix_b_op_2,
    STATE(201), 1,
      sym_infix_b_op_7,
    STATE(206), 1,
      sym_infix_b_op_8,
    STATE(217), 1,
      sym_infix_lazy_b_op_10,
    STATE(223), 1,
      sym_infix_lazy_b_op_9,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(609), 2,
      ts_builtin_sym_end,
      anon_sym_COLON,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
  [40993] = 14,
    ACTIONS(3), 1,
      sym_comment,
    STATE(161), 1,
      sym_infix_b_op_6,
    STATE(162), 1,
      sym_infix_b_op_4,
    STATE(163), 1,
      sym_infix_b_op_3,
    STATE(164), 1,
      sym_infix_b_op_2,
    STATE(201), 1,
      sym_infix_b_op_7,
    STATE(206), 1,
      sym_infix_b_op_8,
    STATE(217), 1,
      sym_infix_lazy_b_op_10,
    STATE(223), 1,
      sym_infix_lazy_b_op_9,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(603), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(605), 10,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41052] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(190), 1,
      sym_infix_b_op_2,
    STATE(191), 1,
      sym_infix_b_op_3,
    STATE(192), 1,
      sym_infix_b_op_4,
    STATE(193), 1,
      sym_infix_b_op_6,
    STATE(194), 1,
      sym_infix_b_op_7,
    STATE(195), 1,
      sym_infix_b_op_8,
    STATE(196), 1,
      sym_infix_lazy_b_op_9,
    STATE(197), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(603), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(605), 15,
      anon_sym_COLON,
      anon_sym_then,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41105] = 14,
    ACTIONS(3), 1,
      sym_comment,
    STATE(190), 1,
      sym_infix_b_op_2,
    STATE(191), 1,
      sym_infix_b_op_3,
    STATE(192), 1,
      sym_infix_b_op_4,
    STATE(193), 1,
      sym_infix_b_op_6,
    STATE(194), 1,
      sym_infix_b_op_7,
    STATE(195), 1,
      sym_infix_b_op_8,
    STATE(196), 1,
      sym_infix_lazy_b_op_9,
    STATE(197), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(603), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(605), 10,
      anon_sym_COLON,
      anon_sym_then,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41164] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    ACTIONS(693), 1,
      anon_sym_DASH_GT,
    STATE(161), 1,
      sym_infix_b_op_6,
    STATE(162), 1,
      sym_infix_b_op_4,
    STATE(163), 1,
      sym_infix_b_op_3,
    STATE(164), 1,
      sym_infix_b_op_2,
    STATE(201), 1,
      sym_infix_b_op_7,
    STATE(206), 1,
      sym_infix_b_op_8,
    STATE(217), 1,
      sym_infix_lazy_b_op_10,
    STATE(223), 1,
      sym_infix_lazy_b_op_9,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(601), 2,
      ts_builtin_sym_end,
      anon_sym_COLON,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
  [41239] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    ACTIONS(737), 1,
      anon_sym_DASH_GT,
    STATE(190), 1,
      sym_infix_b_op_2,
    STATE(191), 1,
      sym_infix_b_op_3,
    STATE(192), 1,
      sym_infix_b_op_4,
    STATE(193), 1,
      sym_infix_b_op_6,
    STATE(194), 1,
      sym_infix_b_op_7,
    STATE(195), 1,
      sym_infix_b_op_8,
    STATE(196), 1,
      sym_infix_lazy_b_op_9,
    STATE(197), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(601), 2,
      anon_sym_COLON,
      anon_sym_then,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
  [41314] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(166), 1,
      sym_infix_lazy_b_op_10,
    STATE(167), 1,
      sym_infix_lazy_b_op_9,
    STATE(168), 1,
      sym_infix_b_op_8,
    STATE(169), 1,
      sym_infix_b_op_7,
    STATE(170), 1,
      sym_infix_b_op_6,
    STATE(171), 1,
      sym_infix_b_op_4,
    STATE(172), 1,
      sym_infix_b_op_3,
    STATE(173), 1,
      sym_infix_b_op_2,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 15,
      sym_interpolation_end,
      anon_sym_COLON,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41367] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(161), 1,
      sym_infix_b_op_6,
    STATE(162), 1,
      sym_infix_b_op_4,
    STATE(163), 1,
      sym_infix_b_op_3,
    STATE(164), 1,
      sym_infix_b_op_2,
    STATE(201), 1,
      sym_infix_b_op_7,
    STATE(206), 1,
      sym_infix_b_op_8,
    STATE(217), 1,
      sym_infix_lazy_b_op_10,
    STATE(223), 1,
      sym_infix_lazy_b_op_9,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 15,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41420] = 12,
    ACTIONS(3), 1,
      sym_comment,
    STATE(161), 1,
      sym_infix_b_op_6,
    STATE(162), 1,
      sym_infix_b_op_4,
    STATE(163), 1,
      sym_infix_b_op_3,
    STATE(164), 1,
      sym_infix_b_op_2,
    STATE(201), 1,
      sym_infix_b_op_7,
    STATE(206), 1,
      sym_infix_b_op_8,
    STATE(217), 1,
      sym_infix_lazy_b_op_10,
    STATE(223), 1,
      sym_infix_lazy_b_op_9,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 13,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41475] = 13,
    ACTIONS(3), 1,
      sym_comment,
    STATE(161), 1,
      sym_infix_b_op_6,
    STATE(162), 1,
      sym_infix_b_op_4,
    STATE(163), 1,
      sym_infix_b_op_3,
    STATE(164), 1,
      sym_infix_b_op_2,
    STATE(201), 1,
      sym_infix_b_op_7,
    STATE(206), 1,
      sym_infix_b_op_8,
    STATE(217), 1,
      sym_infix_lazy_b_op_10,
    STATE(223), 1,
      sym_infix_lazy_b_op_9,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 10,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41532] = 12,
    ACTIONS(3), 1,
      sym_comment,
    STATE(166), 1,
      sym_infix_lazy_b_op_10,
    STATE(167), 1,
      sym_infix_lazy_b_op_9,
    STATE(168), 1,
      sym_infix_b_op_8,
    STATE(169), 1,
      sym_infix_b_op_7,
    STATE(170), 1,
      sym_infix_b_op_6,
    STATE(171), 1,
      sym_infix_b_op_4,
    STATE(172), 1,
      sym_infix_b_op_3,
    STATE(173), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 13,
      sym_interpolation_end,
      anon_sym_COLON,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41587] = 13,
    ACTIONS(3), 1,
      sym_comment,
    STATE(166), 1,
      sym_infix_lazy_b_op_10,
    STATE(167), 1,
      sym_infix_lazy_b_op_9,
    STATE(168), 1,
      sym_infix_b_op_8,
    STATE(169), 1,
      sym_infix_b_op_7,
    STATE(170), 1,
      sym_infix_b_op_6,
    STATE(171), 1,
      sym_infix_b_op_4,
    STATE(172), 1,
      sym_infix_b_op_3,
    STATE(173), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 10,
      sym_interpolation_end,
      anon_sym_COLON,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41644] = 14,
    ACTIONS(3), 1,
      sym_comment,
    STATE(161), 1,
      sym_infix_b_op_6,
    STATE(162), 1,
      sym_infix_b_op_4,
    STATE(163), 1,
      sym_infix_b_op_3,
    STATE(164), 1,
      sym_infix_b_op_2,
    STATE(201), 1,
      sym_infix_b_op_7,
    STATE(206), 1,
      sym_infix_b_op_8,
    STATE(217), 1,
      sym_infix_lazy_b_op_10,
    STATE(223), 1,
      sym_infix_lazy_b_op_9,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 10,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41703] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    STATE(161), 1,
      sym_infix_b_op_6,
    STATE(162), 1,
      sym_infix_b_op_4,
    STATE(163), 1,
      sym_infix_b_op_3,
    STATE(164), 1,
      sym_infix_b_op_2,
    STATE(201), 1,
      sym_infix_b_op_7,
    STATE(206), 1,
      sym_infix_b_op_8,
    STATE(217), 1,
      sym_infix_lazy_b_op_10,
    STATE(223), 1,
      sym_infix_lazy_b_op_9,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 9,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41766] = 11,
    ACTIONS(3), 1,
      sym_comment,
    STATE(190), 1,
      sym_infix_b_op_2,
    STATE(191), 1,
      sym_infix_b_op_3,
    STATE(192), 1,
      sym_infix_b_op_4,
    STATE(193), 1,
      sym_infix_b_op_6,
    STATE(194), 1,
      sym_infix_b_op_7,
    STATE(195), 1,
      sym_infix_b_op_8,
    STATE(196), 1,
      sym_infix_lazy_b_op_9,
    STATE(197), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 15,
      anon_sym_COLON,
      anon_sym_then,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_PLUS_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41819] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(161), 1,
      sym_infix_b_op_6,
    STATE(162), 1,
      sym_infix_b_op_4,
    STATE(163), 1,
      sym_infix_b_op_3,
    STATE(164), 1,
      sym_infix_b_op_2,
    STATE(201), 1,
      sym_infix_b_op_7,
    STATE(206), 1,
      sym_infix_b_op_8,
    STATE(217), 1,
      sym_infix_lazy_b_op_10,
    STATE(223), 1,
      sym_infix_lazy_b_op_9,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 7,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41886] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(161), 1,
      sym_infix_b_op_6,
    STATE(162), 1,
      sym_infix_b_op_4,
    STATE(163), 1,
      sym_infix_b_op_3,
    STATE(164), 1,
      sym_infix_b_op_2,
    STATE(201), 1,
      sym_infix_b_op_7,
    STATE(206), 1,
      sym_infix_b_op_8,
    STATE(217), 1,
      sym_infix_lazy_b_op_10,
    STATE(223), 1,
      sym_infix_lazy_b_op_9,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 5,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [41955] = 12,
    ACTIONS(3), 1,
      sym_comment,
    STATE(190), 1,
      sym_infix_b_op_2,
    STATE(191), 1,
      sym_infix_b_op_3,
    STATE(192), 1,
      sym_infix_b_op_4,
    STATE(193), 1,
      sym_infix_b_op_6,
    STATE(194), 1,
      sym_infix_b_op_7,
    STATE(195), 1,
      sym_infix_b_op_8,
    STATE(196), 1,
      sym_infix_lazy_b_op_9,
    STATE(197), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 13,
      anon_sym_COLON,
      anon_sym_then,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [42010] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(161), 1,
      sym_infix_b_op_6,
    STATE(162), 1,
      sym_infix_b_op_4,
    STATE(163), 1,
      sym_infix_b_op_3,
    STATE(164), 1,
      sym_infix_b_op_2,
    STATE(201), 1,
      sym_infix_b_op_7,
    STATE(206), 1,
      sym_infix_b_op_8,
    STATE(217), 1,
      sym_infix_lazy_b_op_10,
    STATE(223), 1,
      sym_infix_lazy_b_op_9,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 4,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [42081] = 14,
    ACTIONS(3), 1,
      sym_comment,
    STATE(166), 1,
      sym_infix_lazy_b_op_10,
    STATE(167), 1,
      sym_infix_lazy_b_op_9,
    STATE(168), 1,
      sym_infix_b_op_8,
    STATE(169), 1,
      sym_infix_b_op_7,
    STATE(170), 1,
      sym_infix_b_op_6,
    STATE(171), 1,
      sym_infix_b_op_4,
    STATE(172), 1,
      sym_infix_b_op_3,
    STATE(173), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 10,
      sym_interpolation_end,
      anon_sym_COLON,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [42140] = 13,
    ACTIONS(3), 1,
      sym_comment,
    STATE(190), 1,
      sym_infix_b_op_2,
    STATE(191), 1,
      sym_infix_b_op_3,
    STATE(192), 1,
      sym_infix_b_op_4,
    STATE(193), 1,
      sym_infix_b_op_6,
    STATE(194), 1,
      sym_infix_b_op_7,
    STATE(195), 1,
      sym_infix_b_op_8,
    STATE(196), 1,
      sym_infix_lazy_b_op_9,
    STATE(197), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 6,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 10,
      anon_sym_COLON,
      anon_sym_then,
      anon_sym_PIPE_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [42197] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    STATE(190), 1,
      sym_infix_b_op_2,
    STATE(191), 1,
      sym_infix_b_op_3,
    STATE(192), 1,
      sym_infix_b_op_4,
    STATE(193), 1,
      sym_infix_b_op_6,
    STATE(194), 1,
      sym_infix_b_op_7,
    STATE(195), 1,
      sym_infix_b_op_8,
    STATE(196), 1,
      sym_infix_lazy_b_op_9,
    STATE(197), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 9,
      anon_sym_COLON,
      anon_sym_then,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [42260] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(190), 1,
      sym_infix_b_op_2,
    STATE(191), 1,
      sym_infix_b_op_3,
    STATE(192), 1,
      sym_infix_b_op_4,
    STATE(193), 1,
      sym_infix_b_op_6,
    STATE(194), 1,
      sym_infix_b_op_7,
    STATE(195), 1,
      sym_infix_b_op_8,
    STATE(196), 1,
      sym_infix_lazy_b_op_9,
    STATE(197), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 7,
      anon_sym_COLON,
      anon_sym_then,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [42327] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(190), 1,
      sym_infix_b_op_2,
    STATE(191), 1,
      sym_infix_b_op_3,
    STATE(192), 1,
      sym_infix_b_op_4,
    STATE(193), 1,
      sym_infix_b_op_6,
    STATE(194), 1,
      sym_infix_b_op_7,
    STATE(195), 1,
      sym_infix_b_op_8,
    STATE(196), 1,
      sym_infix_lazy_b_op_9,
    STATE(197), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 5,
      anon_sym_COLON,
      anon_sym_then,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [42396] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    STATE(166), 1,
      sym_infix_lazy_b_op_10,
    STATE(167), 1,
      sym_infix_lazy_b_op_9,
    STATE(168), 1,
      sym_infix_b_op_8,
    STATE(169), 1,
      sym_infix_b_op_7,
    STATE(170), 1,
      sym_infix_b_op_6,
    STATE(171), 1,
      sym_infix_b_op_4,
    STATE(172), 1,
      sym_infix_b_op_3,
    STATE(173), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(599), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 9,
      sym_interpolation_end,
      anon_sym_COLON,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [42459] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(190), 1,
      sym_infix_b_op_2,
    STATE(191), 1,
      sym_infix_b_op_3,
    STATE(192), 1,
      sym_infix_b_op_4,
    STATE(193), 1,
      sym_infix_b_op_6,
    STATE(194), 1,
      sym_infix_b_op_7,
    STATE(195), 1,
      sym_infix_b_op_8,
    STATE(196), 1,
      sym_infix_lazy_b_op_9,
    STATE(197), 1,
      sym_infix_lazy_b_op_10,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 4,
      anon_sym_COLON,
      anon_sym_then,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [42530] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(166), 1,
      sym_infix_lazy_b_op_10,
    STATE(167), 1,
      sym_infix_lazy_b_op_9,
    STATE(168), 1,
      sym_infix_b_op_8,
    STATE(169), 1,
      sym_infix_b_op_7,
    STATE(170), 1,
      sym_infix_b_op_6,
    STATE(171), 1,
      sym_infix_b_op_4,
    STATE(172), 1,
      sym_infix_b_op_3,
    STATE(173), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 7,
      sym_interpolation_end,
      anon_sym_COLON,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [42597] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(643), 1,
      sym_ident,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(659), 1,
      anon_sym__,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(1023), 1,
      sym_pattern,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(752), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(725), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [42678] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(607), 1,
      anon_sym_PIPE,
    ACTIONS(699), 1,
      anon_sym_DASH_GT,
    STATE(166), 1,
      sym_infix_lazy_b_op_10,
    STATE(167), 1,
      sym_infix_lazy_b_op_9,
    STATE(168), 1,
      sym_infix_b_op_8,
    STATE(169), 1,
      sym_infix_b_op_7,
    STATE(170), 1,
      sym_infix_b_op_6,
    STATE(171), 1,
      sym_infix_b_op_4,
    STATE(172), 1,
      sym_infix_b_op_3,
    STATE(173), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(609), 2,
      sym_interpolation_end,
      anon_sym_COLON,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
  [42753] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(595), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    ACTIONS(699), 1,
      anon_sym_DASH_GT,
    STATE(166), 1,
      sym_infix_lazy_b_op_10,
    STATE(167), 1,
      sym_infix_lazy_b_op_9,
    STATE(168), 1,
      sym_infix_b_op_8,
    STATE(169), 1,
      sym_infix_b_op_7,
    STATE(170), 1,
      sym_infix_b_op_6,
    STATE(171), 1,
      sym_infix_b_op_4,
    STATE(172), 1,
      sym_infix_b_op_3,
    STATE(173), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(601), 2,
      sym_interpolation_end,
      anon_sym_COLON,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
  [42828] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(166), 1,
      sym_infix_lazy_b_op_10,
    STATE(167), 1,
      sym_infix_lazy_b_op_9,
    STATE(168), 1,
      sym_infix_b_op_8,
    STATE(169), 1,
      sym_infix_b_op_7,
    STATE(170), 1,
      sym_infix_b_op_6,
    STATE(171), 1,
      sym_infix_b_op_4,
    STATE(172), 1,
      sym_infix_b_op_3,
    STATE(173), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 5,
      sym_interpolation_end,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [42897] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 1,
      anon_sym_AMP,
    ACTIONS(585), 1,
      anon_sym_PIPE_GT,
    ACTIONS(593), 1,
      anon_sym_AMP_AMP,
    ACTIONS(599), 1,
      anon_sym_PIPE,
    STATE(166), 1,
      sym_infix_lazy_b_op_10,
    STATE(167), 1,
      sym_infix_lazy_b_op_9,
    STATE(168), 1,
      sym_infix_b_op_8,
    STATE(169), 1,
      sym_infix_b_op_7,
    STATE(170), 1,
      sym_infix_b_op_6,
    STATE(171), 1,
      sym_infix_b_op_4,
    STATE(172), 1,
      sym_infix_b_op_3,
    STATE(173), 1,
      sym_infix_b_op_2,
    ACTIONS(577), 2,
      anon_sym_AT,
      anon_sym_PLUS_PLUS,
    ACTIONS(581), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 2,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(591), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(579), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(601), 4,
      sym_interpolation_end,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
  [42968] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(823), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(825), 17,
      sym_ident,
      anon_sym_let,
      anon_sym_fun,
      anon_sym_match,
      anon_sym_if,
      anon_sym_forall,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [43004] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(827), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(829), 17,
      sym_ident,
      anon_sym_let,
      anon_sym_fun,
      anon_sym_match,
      anon_sym_if,
      anon_sym_forall,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [43040] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(831), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(833), 17,
      sym_ident,
      anon_sym_let,
      anon_sym_fun,
      anon_sym_match,
      anon_sym_if,
      anon_sym_forall,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [43076] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(835), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(837), 17,
      sym_ident,
      anon_sym_let,
      anon_sym_fun,
      anon_sym_match,
      anon_sym_if,
      anon_sym_forall,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [43112] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(839), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(841), 17,
      sym_ident,
      anon_sym_let,
      anon_sym_fun,
      anon_sym_match,
      anon_sym_if,
      anon_sym_forall,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [43148] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(843), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(845), 17,
      sym_ident,
      anon_sym_let,
      anon_sym_fun,
      anon_sym_match,
      anon_sym_if,
      anon_sym_forall,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [43184] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(847), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(849), 17,
      sym_ident,
      anon_sym_let,
      anon_sym_fun,
      anon_sym_match,
      anon_sym_if,
      anon_sym_forall,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [43220] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(703), 1,
      sym_raw_enum_tag,
    ACTIONS(709), 1,
      sym_quoted_enum_tag_start,
    STATE(597), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(630), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(851), 2,
      sym_ident,
      anon_sym__,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(759), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(739), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [43296] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(649), 1,
      anon_sym_LPAREN,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    STATE(532), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(711), 1,
      sym_enum_pattern_parens,
    STATE(724), 1,
      sym_or_pattern_parens,
    STATE(754), 1,
      sym_or_pattern_unparens,
    STATE(763), 1,
      sym_enum_variant_pattern,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(851), 2,
      sym_ident,
      anon_sym__,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(759), 2,
      sym_enum_pattern,
      sym_or_pattern,
    STATE(739), 3,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
  [43372] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(853), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(855), 17,
      sym_ident,
      anon_sym_let,
      anon_sym_fun,
      anon_sym_match,
      anon_sym_if,
      anon_sym_forall,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [43408] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(817), 1,
      anon_sym_LPAREN,
    STATE(612), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(1100), 1,
      sym_pattern_or_branch,
    STATE(1115), 1,
      sym_or_pattern_unparens,
    STATE(1151), 1,
      sym_enum_variant_pattern,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(857), 2,
      sym_ident,
      anon_sym__,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(711), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [43476] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(817), 1,
      anon_sym_LPAREN,
    STATE(612), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(1053), 1,
      sym_enum_variant_pattern,
    STATE(1100), 1,
      sym_pattern_or_branch,
    STATE(1115), 1,
      sym_or_pattern_unparens,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(857), 2,
      sym_ident,
      anon_sym__,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(711), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [43544] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      sym_raw_enum_tag,
    ACTIONS(639), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(813), 1,
      sym_ident,
    ACTIONS(815), 1,
      anon_sym_EQ_GT,
    ACTIONS(817), 1,
      anon_sym_LPAREN,
    ACTIONS(819), 1,
      anon_sym__,
    ACTIONS(821), 1,
      anon_sym_or,
    ACTIONS(859), 1,
      anon_sym_if,
    STATE(680), 1,
      sym_quoted_enum_tag,
    STATE(714), 1,
      sym_enum_tag,
    STATE(727), 1,
      sym_pattern_fun,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(741), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [43614] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(645), 1,
      sym_raw_enum_tag,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(665), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(817), 1,
      anon_sym_LPAREN,
    STATE(612), 1,
      sym_enum_tag,
    STATE(617), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(627), 1,
      sym_quoted_enum_tag,
    STATE(1100), 1,
      sym_pattern_or_branch,
    STATE(1101), 1,
      sym_enum_variant_pattern,
    STATE(1153), 1,
      sym_or_pattern_unparens,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(857), 2,
      sym_ident,
      anon_sym__,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(711), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [43682] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      sym_signed_num_literal,
    ACTIONS(863), 1,
      sym_ident,
    ACTIONS(865), 1,
      sym_raw_enum_tag,
    ACTIONS(867), 1,
      anon_sym_EQ_GT,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_LPAREN,
    ACTIONS(873), 1,
      anon_sym_null,
    ACTIONS(875), 1,
      anon_sym_LBRACK,
    ACTIONS(877), 1,
      anon_sym__,
    ACTIONS(881), 1,
      sym_multstr_start,
    ACTIONS(883), 1,
      sym__str_start,
    ACTIONS(885), 1,
      sym_quoted_enum_tag_start,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(879), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(604), 2,
      sym_pattern_fun,
      aux_sym_fun_expr_repeat1,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(653), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [43747] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      sym_signed_num_literal,
    ACTIONS(863), 1,
      sym_ident,
    ACTIONS(865), 1,
      sym_raw_enum_tag,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_LPAREN,
    ACTIONS(873), 1,
      anon_sym_null,
    ACTIONS(875), 1,
      anon_sym_LBRACK,
    ACTIONS(877), 1,
      anon_sym__,
    ACTIONS(881), 1,
      sym_multstr_start,
    ACTIONS(883), 1,
      sym__str_start,
    ACTIONS(885), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(887), 1,
      anon_sym_EQ_GT,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(879), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(604), 2,
      sym_pattern_fun,
      aux_sym_fun_expr_repeat1,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(653), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [43812] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      sym_signed_num_literal,
    ACTIONS(863), 1,
      sym_ident,
    ACTIONS(865), 1,
      sym_raw_enum_tag,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_LPAREN,
    ACTIONS(873), 1,
      anon_sym_null,
    ACTIONS(875), 1,
      anon_sym_LBRACK,
    ACTIONS(877), 1,
      anon_sym__,
    ACTIONS(881), 1,
      sym_multstr_start,
    ACTIONS(883), 1,
      sym__str_start,
    ACTIONS(885), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(889), 1,
      anon_sym_EQ_GT,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(879), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(604), 2,
      sym_pattern_fun,
      aux_sym_fun_expr_repeat1,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(653), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [43877] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      sym_signed_num_literal,
    ACTIONS(863), 1,
      sym_ident,
    ACTIONS(865), 1,
      sym_raw_enum_tag,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_LPAREN,
    ACTIONS(873), 1,
      anon_sym_null,
    ACTIONS(875), 1,
      anon_sym_LBRACK,
    ACTIONS(877), 1,
      anon_sym__,
    ACTIONS(881), 1,
      sym_multstr_start,
    ACTIONS(883), 1,
      sym__str_start,
    ACTIONS(885), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(891), 1,
      anon_sym_EQ_GT,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(879), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(604), 2,
      sym_pattern_fun,
      aux_sym_fun_expr_repeat1,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(653), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [43942] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      sym_signed_num_literal,
    ACTIONS(863), 1,
      sym_ident,
    ACTIONS(865), 1,
      sym_raw_enum_tag,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_LPAREN,
    ACTIONS(873), 1,
      anon_sym_null,
    ACTIONS(875), 1,
      anon_sym_LBRACK,
    ACTIONS(877), 1,
      anon_sym__,
    ACTIONS(881), 1,
      sym_multstr_start,
    ACTIONS(883), 1,
      sym__str_start,
    ACTIONS(885), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(893), 1,
      anon_sym_EQ_GT,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(879), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(604), 2,
      sym_pattern_fun,
      aux_sym_fun_expr_repeat1,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(653), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [44007] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 1,
      sym_signed_num_literal,
    ACTIONS(898), 1,
      sym_ident,
    ACTIONS(901), 1,
      sym_raw_enum_tag,
    ACTIONS(904), 1,
      anon_sym_EQ_GT,
    ACTIONS(906), 1,
      anon_sym_LBRACE,
    ACTIONS(909), 1,
      anon_sym_LPAREN,
    ACTIONS(912), 1,
      anon_sym_null,
    ACTIONS(915), 1,
      anon_sym_LBRACK,
    ACTIONS(918), 1,
      anon_sym__,
    ACTIONS(924), 1,
      sym_multstr_start,
    ACTIONS(927), 1,
      sym__str_start,
    ACTIONS(930), 1,
      sym_quoted_enum_tag_start,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(921), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(604), 2,
      sym_pattern_fun,
      aux_sym_fun_expr_repeat1,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(653), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [44072] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      sym_signed_num_literal,
    ACTIONS(863), 1,
      sym_ident,
    ACTIONS(865), 1,
      sym_raw_enum_tag,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_LPAREN,
    ACTIONS(873), 1,
      anon_sym_null,
    ACTIONS(875), 1,
      anon_sym_LBRACK,
    ACTIONS(877), 1,
      anon_sym__,
    ACTIONS(881), 1,
      sym_multstr_start,
    ACTIONS(883), 1,
      sym__str_start,
    ACTIONS(885), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(933), 1,
      anon_sym_EQ_GT,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(879), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(604), 2,
      sym_pattern_fun,
      aux_sym_fun_expr_repeat1,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(653), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [44137] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 12,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(937), 13,
      sym_ident,
      anon_sym_match,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [44170] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(939), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(941), 13,
      sym_ident,
      anon_sym_match,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [44202] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(943), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(945), 13,
      sym_ident,
      anon_sym_match,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [44234] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      sym_signed_num_literal,
    ACTIONS(863), 1,
      sym_ident,
    ACTIONS(865), 1,
      sym_raw_enum_tag,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_LPAREN,
    ACTIONS(873), 1,
      anon_sym_null,
    ACTIONS(875), 1,
      anon_sym_LBRACK,
    ACTIONS(877), 1,
      anon_sym__,
    ACTIONS(881), 1,
      sym_multstr_start,
    ACTIONS(883), 1,
      sym__str_start,
    ACTIONS(885), 1,
      sym_quoted_enum_tag_start,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(879), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(601), 2,
      sym_pattern_fun,
      aux_sym_fun_expr_repeat1,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(653), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [44296] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      sym_signed_num_literal,
    ACTIONS(863), 1,
      sym_ident,
    ACTIONS(865), 1,
      sym_raw_enum_tag,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_LPAREN,
    ACTIONS(873), 1,
      anon_sym_null,
    ACTIONS(875), 1,
      anon_sym_LBRACK,
    ACTIONS(877), 1,
      anon_sym__,
    ACTIONS(881), 1,
      sym_multstr_start,
    ACTIONS(883), 1,
      sym__str_start,
    ACTIONS(885), 1,
      sym_quoted_enum_tag_start,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(879), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(603), 2,
      sym_pattern_fun,
      aux_sym_fun_expr_repeat1,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(653), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [44358] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      sym_signed_num_literal,
    ACTIONS(863), 1,
      sym_ident,
    ACTIONS(865), 1,
      sym_raw_enum_tag,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_LPAREN,
    ACTIONS(873), 1,
      anon_sym_null,
    ACTIONS(875), 1,
      anon_sym_LBRACK,
    ACTIONS(877), 1,
      anon_sym__,
    ACTIONS(881), 1,
      sym_multstr_start,
    ACTIONS(883), 1,
      sym__str_start,
    ACTIONS(885), 1,
      sym_quoted_enum_tag_start,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(879), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(599), 2,
      sym_pattern_fun,
      aux_sym_fun_expr_repeat1,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(653), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [44420] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      sym_raw_enum_tag,
    ACTIONS(639), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(813), 1,
      sym_ident,
    ACTIONS(817), 1,
      anon_sym_LPAREN,
    ACTIONS(819), 1,
      anon_sym__,
    ACTIONS(821), 1,
      anon_sym_or,
    STATE(680), 1,
      sym_quoted_enum_tag,
    STATE(714), 1,
      sym_enum_tag,
    STATE(727), 1,
      sym_pattern_fun,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(741), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [44484] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(947), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(949), 13,
      sym_ident,
      anon_sym_match,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [44516] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      sym_signed_num_literal,
    ACTIONS(863), 1,
      sym_ident,
    ACTIONS(865), 1,
      sym_raw_enum_tag,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_LPAREN,
    ACTIONS(873), 1,
      anon_sym_null,
    ACTIONS(875), 1,
      anon_sym_LBRACK,
    ACTIONS(877), 1,
      anon_sym__,
    ACTIONS(881), 1,
      sym_multstr_start,
    ACTIONS(883), 1,
      sym__str_start,
    ACTIONS(885), 1,
      sym_quoted_enum_tag_start,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(879), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(600), 2,
      sym_pattern_fun,
      aux_sym_fun_expr_repeat1,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(653), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [44578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(951), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(953), 13,
      sym_ident,
      anon_sym_match,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [44610] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      sym_signed_num_literal,
    ACTIONS(863), 1,
      sym_ident,
    ACTIONS(865), 1,
      sym_raw_enum_tag,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_LPAREN,
    ACTIONS(873), 1,
      anon_sym_null,
    ACTIONS(875), 1,
      anon_sym_LBRACK,
    ACTIONS(877), 1,
      anon_sym__,
    ACTIONS(881), 1,
      sym_multstr_start,
    ACTIONS(883), 1,
      sym__str_start,
    ACTIONS(885), 1,
      sym_quoted_enum_tag_start,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(879), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(602), 2,
      sym_pattern_fun,
      aux_sym_fun_expr_repeat1,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(653), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [44672] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      sym_raw_enum_tag,
    ACTIONS(639), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(817), 1,
      anon_sym_LPAREN,
    STATE(623), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(680), 1,
      sym_quoted_enum_tag,
    STATE(710), 1,
      sym_pattern_or_branch,
    STATE(714), 1,
      sym_enum_tag,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(857), 2,
      sym_ident,
      anon_sym__,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(711), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [44734] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      sym_signed_num_literal,
    ACTIONS(863), 1,
      sym_ident,
    ACTIONS(865), 1,
      sym_raw_enum_tag,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_LPAREN,
    ACTIONS(873), 1,
      anon_sym_null,
    ACTIONS(875), 1,
      anon_sym_LBRACK,
    ACTIONS(877), 1,
      anon_sym__,
    ACTIONS(881), 1,
      sym_multstr_start,
    ACTIONS(883), 1,
      sym__str_start,
    ACTIONS(885), 1,
      sym_quoted_enum_tag_start,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(879), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(605), 2,
      sym_pattern_fun,
      aux_sym_fun_expr_repeat1,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(653), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [44796] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(955), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(957), 13,
      sym_ident,
      anon_sym_match,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [44828] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(555), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(959), 13,
      sym_ident,
      anon_sym_match,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [44860] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(961), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(963), 13,
      sym_ident,
      anon_sym_match,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [44892] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(965), 11,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_LBRACK_PIPE,
    ACTIONS(967), 13,
      sym_ident,
      anon_sym_match,
      anon_sym_import,
      anon_sym_Array,
      anon_sym_Dyn,
      anon_sym_null,
      anon_sym_LBRACK,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
      anon_sym_Number,
      anon_sym_Bool,
      anon_sym_String,
  [44924] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_signed_num_literal,
    ACTIONS(975), 1,
      sym_raw_enum_tag,
    ACTIONS(978), 1,
      anon_sym_LBRACE,
    ACTIONS(981), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_null,
    ACTIONS(987), 1,
      anon_sym_LBRACK,
    ACTIONS(993), 1,
      sym_multstr_start,
    ACTIONS(996), 1,
      sym__str_start,
    ACTIONS(999), 1,
      sym_quoted_enum_tag_start,
    STATE(623), 1,
      aux_sym_or_pattern_unparens_repeat1,
    STATE(680), 1,
      sym_quoted_enum_tag,
    STATE(714), 1,
      sym_enum_tag,
    STATE(1100), 1,
      sym_pattern_or_branch,
    ACTIONS(972), 2,
      sym_ident,
      anon_sym__,
    ACTIONS(990), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(711), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [44986] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      sym_raw_enum_tag,
    ACTIONS(639), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(641), 1,
      sym_signed_num_literal,
    ACTIONS(647), 1,
      anon_sym_LBRACE,
    ACTIONS(651), 1,
      anon_sym_null,
    ACTIONS(653), 1,
      anon_sym_LBRACK,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    ACTIONS(817), 1,
      anon_sym_LPAREN,
    STATE(680), 1,
      sym_quoted_enum_tag,
    STATE(714), 1,
      sym_enum_tag,
    ACTIONS(629), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1002), 2,
      sym_ident,
      anon_sym__,
    STATE(706), 2,
      sym_bool,
      sym_static_string,
    STATE(738), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [45042] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      sym_signed_num_literal,
    ACTIONS(865), 1,
      sym_raw_enum_tag,
    ACTIONS(869), 1,
      anon_sym_LBRACE,
    ACTIONS(871), 1,
      anon_sym_LPAREN,
    ACTIONS(873), 1,
      anon_sym_null,
    ACTIONS(875), 1,
      anon_sym_LBRACK,
    ACTIONS(881), 1,
      sym_multstr_start,
    ACTIONS(883), 1,
      sym__str_start,
    ACTIONS(885), 1,
      sym_quoted_enum_tag_start,
    STATE(660), 1,
      sym_quoted_enum_tag,
    STATE(665), 1,
      sym_enum_tag,
    ACTIONS(879), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1004), 2,
      sym_ident,
      anon_sym__,
    STATE(669), 2,
      sym_bool,
      sym_static_string,
    STATE(672), 5,
      sym_constant_pattern,
      sym_record_pattern,
      sym_array_pattern,
      sym_enum_pattern_parens,
      sym_or_pattern_parens,
  [45098] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 6,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_or,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(373), 14,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [45126] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 6,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_or,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(369), 14,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [45154] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(379), 6,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_or,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(377), 14,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [45182] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      anon_sym_EQ,
    ACTIONS(531), 15,
      ts_builtin_sym_end,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
      anon_sym_QMARK,
  [45206] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 7,
      sym_ident,
      anon_sym_if,
      anon_sym_null,
      anon_sym__,
      anon_sym_or,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(369), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [45230] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(379), 7,
      sym_ident,
      anon_sym_if,
      anon_sym_null,
      anon_sym__,
      anon_sym_or,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(377), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [45254] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 7,
      sym_ident,
      anon_sym_if,
      anon_sym_null,
      anon_sym__,
      anon_sym_or,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(373), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [45278] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(545), 1,
      anon_sym_EQ,
    ACTIONS(543), 15,
      ts_builtin_sym_end,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
      anon_sym_QMARK,
  [45302] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1010), 1,
      anon_sym_AT,
    ACTIONS(1008), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1006), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [45327] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1014), 1,
      anon_sym_RBRACE,
    ACTIONS(1016), 1,
      anon_sym_SEMI,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1020), 1,
      anon_sym__,
    STATE(650), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1003), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [45374] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1022), 1,
      anon_sym_RBRACE,
    ACTIONS(1024), 1,
      anon_sym_SEMI,
    ACTIONS(1026), 1,
      anon_sym__,
    STATE(649), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1043), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [45421] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1028), 1,
      anon_sym_RBRACE,
    ACTIONS(1030), 1,
      anon_sym_SEMI,
    ACTIONS(1032), 1,
      anon_sym__,
    STATE(645), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1008), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [45468] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1034), 1,
      anon_sym_RBRACE,
    ACTIONS(1036), 1,
      anon_sym_SEMI,
    ACTIONS(1038), 1,
      anon_sym__,
    STATE(656), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1034), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [45515] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1040), 1,
      anon_sym_RBRACE,
    ACTIONS(1042), 1,
      anon_sym_SEMI,
    ACTIONS(1044), 1,
      anon_sym__,
    STATE(644), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1036), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [45562] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1046), 1,
      anon_sym_RBRACE,
    ACTIONS(1048), 1,
      anon_sym_SEMI,
    ACTIONS(1050), 1,
      anon_sym__,
    STATE(675), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1020), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [45609] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1052), 1,
      anon_sym_RBRACE,
    ACTIONS(1054), 1,
      anon_sym_SEMI,
    ACTIONS(1056), 1,
      anon_sym__,
    STATE(647), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1037), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [45656] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1058), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(764), 10,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT,
  [45679] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1062), 1,
      anon_sym_EQ,
    ACTIONS(1060), 13,
      ts_builtin_sym_end,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [45701] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1064), 1,
      anon_sym_RBRACE,
    ACTIONS(1066), 1,
      anon_sym_SEMI,
    STATE(681), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1040), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [45745] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1068), 1,
      anon_sym_RBRACE,
    ACTIONS(1070), 1,
      anon_sym_SEMI,
    STATE(681), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1010), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [45789] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_EQ,
    ACTIONS(609), 13,
      ts_builtin_sym_end,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [45811] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1072), 1,
      anon_sym_RBRACE,
    ACTIONS(1074), 1,
      anon_sym_SEMI,
    STATE(681), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1035), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [45855] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1078), 1,
      anon_sym_EQ,
    ACTIONS(1076), 13,
      ts_builtin_sym_end,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [45877] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1080), 1,
      anon_sym_RBRACE,
    ACTIONS(1082), 1,
      anon_sym_SEMI,
    STATE(681), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1045), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [45921] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1084), 1,
      anon_sym_RBRACE,
    ACTIONS(1086), 1,
      anon_sym_SEMI,
    STATE(681), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1033), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [45965] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(373), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [45987] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1090), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1088), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46009] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1006), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46031] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1094), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1092), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46053] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1098), 1,
      anon_sym_EQ,
    ACTIONS(1096), 13,
      ts_builtin_sym_end,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [46075] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1100), 1,
      anon_sym_RBRACE,
    ACTIONS(1102), 1,
      anon_sym_SEMI,
    STATE(681), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1039), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [46119] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1106), 1,
      anon_sym_EQ,
    ACTIONS(1104), 13,
      ts_builtin_sym_end,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [46141] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(545), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(543), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46163] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(379), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(377), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46185] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(369), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46207] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(507), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46229] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1110), 1,
      anon_sym_EQ,
    ACTIONS(1108), 13,
      ts_builtin_sym_end,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [46251] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1112), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46273] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(531), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46295] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(821), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1116), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1120), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1118), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46339] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1124), 1,
      anon_sym_EQ,
    ACTIONS(1122), 13,
      ts_builtin_sym_end,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [46361] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1128), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1126), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46383] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1132), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1130), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46405] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1136), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1134), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46427] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1140), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1138), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46449] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1144), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1142), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46471] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1148), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1146), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46493] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1152), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1150), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46515] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1154), 1,
      anon_sym_RBRACE,
    ACTIONS(1156), 1,
      anon_sym_SEMI,
    STATE(681), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(941), 1,
      sym_record_field,
    STATE(1024), 1,
      sym_record_last_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [46559] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1160), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1158), 9,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_EQ_GT,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46581] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1164), 5,
      sym_ident,
      anon_sym_null,
      anon_sym__,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1162), 8,
      sym_multstr_start,
      sym__str_start,
      sym_quoted_enum_tag_start,
      sym_signed_num_literal,
      sym_raw_enum_tag,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [46602] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 2,
      anon_sym_PIPE,
      anon_sym_EQ,
    ACTIONS(507), 11,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
      anon_sym_PIPE_RBRACK,
  [46623] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(379), 2,
      anon_sym_PIPE,
      anon_sym_EQ,
    ACTIONS(377), 11,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
      anon_sym_PIPE_RBRACK,
  [46644] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(371), 2,
      anon_sym_PIPE,
      anon_sym_EQ,
    ACTIONS(369), 11,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
      anon_sym_PIPE_RBRACK,
  [46665] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1166), 1,
      sym_ident,
    ACTIONS(1171), 1,
      sym_multstr_start,
    ACTIONS(1174), 1,
      sym__str_start,
    STATE(681), 1,
      aux_sym_uni_record_repeat1,
    STATE(731), 1,
      sym_field_path,
    STATE(772), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(1181), 1,
      sym_record_field,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
    ACTIONS(1169), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_DOT_DOT,
  [46702] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(375), 2,
      anon_sym_PIPE,
      anon_sym_EQ,
    ACTIONS(373), 11,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
      anon_sym_PIPE_RBRACK,
  [46723] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1177), 1,
      anon_sym_PIPE,
    ACTIONS(1180), 1,
      anon_sym_COLON,
    ACTIONS(1183), 1,
      anon_sym_EQ,
    STATE(683), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
    ACTIONS(1185), 7,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [46749] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(571), 1,
      anon_sym_COLON,
    ACTIONS(1187), 1,
      anon_sym_PIPE,
    ACTIONS(1189), 1,
      anon_sym_EQ,
    STATE(683), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
    ACTIONS(1191), 7,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [46775] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1195), 1,
      anon_sym_EQ,
    ACTIONS(1193), 10,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [46794] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1199), 1,
      anon_sym_EQ,
    ACTIONS(1197), 10,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [46813] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1203), 1,
      anon_sym_EQ,
    ACTIONS(1201), 10,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [46832] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1207), 1,
      anon_sym_EQ,
    ACTIONS(1205), 10,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [46851] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1211), 1,
      anon_sym_EQ,
    ACTIONS(1209), 10,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [46870] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(573), 1,
      anon_sym_EQ,
    ACTIONS(575), 10,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_then,
      anon_sym_else,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [46889] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1217), 1,
      sym_multstr_end,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(707), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [46915] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1152), 1,
      anon_sym_EQ,
    ACTIONS(1150), 9,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
  [46933] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    ACTIONS(1221), 1,
      sym_multstr_end,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(718), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [46959] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    ACTIONS(1223), 1,
      sym_multstr_end,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(696), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [46985] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1140), 1,
      anon_sym_EQ,
    ACTIONS(1138), 9,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
  [47003] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    ACTIONS(1225), 1,
      sym_multstr_end,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(707), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [47029] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    ACTIONS(1227), 1,
      sym_multstr_end,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(691), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [47055] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    ACTIONS(1229), 1,
      sym_multstr_end,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(715), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [47081] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1136), 1,
      anon_sym_EQ,
    ACTIONS(1134), 9,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
  [47099] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    ACTIONS(1231), 1,
      sym_multstr_end,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(705), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [47125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1094), 1,
      anon_sym_EQ,
    ACTIONS(1092), 9,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
  [47143] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1160), 1,
      anon_sym_EQ,
    ACTIONS(1158), 9,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
  [47161] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 1,
      anon_sym_EQ,
    ACTIONS(1233), 1,
      anon_sym_AT,
    ACTIONS(1006), 8,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [47181] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1120), 1,
      anon_sym_EQ,
    ACTIONS(1118), 9,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
  [47199] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    ACTIONS(1235), 1,
      sym_multstr_end,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(707), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [47225] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1132), 1,
      anon_sym_EQ,
    ACTIONS(1130), 9,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
  [47243] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1237), 1,
      anon_sym_PERCENT,
    ACTIONS(1243), 1,
      sym_multstr_end,
    ACTIONS(1245), 1,
      sym_interpolation_start,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1240), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(707), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [47269] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1128), 1,
      anon_sym_EQ,
    ACTIONS(1126), 9,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
  [47287] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    ACTIONS(1248), 1,
      sym_multstr_end,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(707), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [47313] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1252), 1,
      anon_sym_EQ,
    ACTIONS(1254), 1,
      anon_sym_or,
    ACTIONS(1250), 8,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [47333] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 1,
      anon_sym_EQ,
    ACTIONS(1256), 9,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
  [47351] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1148), 1,
      anon_sym_EQ,
    ACTIONS(1146), 9,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
  [47369] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(571), 1,
      anon_sym_COLON,
    ACTIONS(1187), 1,
      anon_sym_PIPE,
    ACTIONS(1260), 1,
      anon_sym_EQ,
    ACTIONS(1264), 1,
      anon_sym_QMARK,
    STATE(852), 1,
      sym_annot,
    STATE(960), 1,
      sym_default_annot,
    ACTIONS(1262), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(684), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
  [47399] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(821), 1,
      anon_sym_EQ,
    ACTIONS(1116), 9,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
  [47417] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    ACTIONS(1266), 1,
      sym_multstr_end,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(707), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [47443] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_EQ,
    ACTIONS(1112), 9,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
  [47461] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    ACTIONS(1268), 1,
      sym_multstr_end,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(707), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [47487] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    ACTIONS(1270), 1,
      sym_multstr_end,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(707), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [47513] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1090), 1,
      anon_sym_EQ,
    ACTIONS(1088), 9,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_or,
  [47531] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    ACTIONS(1272), 1,
      sym_multstr_end,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(717), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [47557] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1213), 1,
      anon_sym_PERCENT,
    ACTIONS(1219), 1,
      sym_interpolation_start,
    ACTIONS(1274), 1,
      sym_multstr_end,
    STATE(832), 1,
      sym_percent,
    ACTIONS(1215), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
    STATE(709), 3,
      sym_chunk_expr,
      sym_chunk_literal_multi,
      aux_sym_str_chunks_multi_repeat1,
  [47583] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1282), 1,
      sym__str_end,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    STATE(847), 1,
      sym_percent,
    STATE(730), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [47610] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    ACTIONS(1286), 1,
      sym__str_end,
    STATE(847), 1,
      sym_percent,
    STATE(737), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [47637] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 1,
      anon_sym_or,
    ACTIONS(1290), 1,
      anon_sym_EQ,
    ACTIONS(1288), 7,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RBRACK,
  [47656] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 1,
      anon_sym_or,
    ACTIONS(1294), 1,
      anon_sym_EQ,
    ACTIONS(1292), 7,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RBRACK,
  [47675] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    ACTIONS(1296), 1,
      sym__str_end,
    STATE(847), 1,
      sym_percent,
    STATE(722), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [47702] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1300), 1,
      anon_sym_EQ,
    ACTIONS(1298), 8,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [47719] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    ACTIONS(1302), 1,
      sym__str_end,
    STATE(847), 1,
      sym_percent,
    STATE(729), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [47746] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    ACTIONS(1304), 1,
      sym__str_end,
    STATE(847), 1,
      sym_percent,
    STATE(730), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [47773] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 1,
      anon_sym_PERCENT,
    ACTIONS(1309), 1,
      sym_str_literal,
    ACTIONS(1312), 1,
      sym_str_esc_char,
    ACTIONS(1315), 1,
      sym__str_end,
    ACTIONS(1317), 1,
      sym_interpolation_start,
    STATE(847), 1,
      sym_percent,
    STATE(730), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [47800] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(571), 1,
      anon_sym_COLON,
    ACTIONS(1187), 1,
      anon_sym_PIPE,
    ACTIONS(1320), 1,
      anon_sym_EQ,
    STATE(888), 1,
      sym_annot,
    STATE(684), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
    ACTIONS(1322), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [47825] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    ACTIONS(1324), 1,
      sym__str_end,
    STATE(847), 1,
      sym_percent,
    STATE(730), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [47852] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    ACTIONS(1326), 1,
      sym__str_end,
    STATE(847), 1,
      sym_percent,
    STATE(730), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [47879] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    ACTIONS(1328), 1,
      sym__str_end,
    STATE(847), 1,
      sym_percent,
    STATE(732), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [47906] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    ACTIONS(1330), 1,
      sym__str_end,
    STATE(847), 1,
      sym_percent,
    STATE(733), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [47933] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    ACTIONS(1332), 1,
      sym__str_end,
    STATE(847), 1,
      sym_percent,
    STATE(730), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [47960] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    ACTIONS(1334), 1,
      sym__str_end,
    STATE(847), 1,
      sym_percent,
    STATE(730), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [47987] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1144), 1,
      anon_sym_EQ,
    ACTIONS(1142), 8,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [48004] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 1,
      anon_sym_or,
    ACTIONS(1338), 1,
      anon_sym_EQ,
    ACTIONS(1336), 7,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RBRACK,
  [48023] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    ACTIONS(1340), 1,
      sym__str_end,
    STATE(847), 1,
      sym_percent,
    STATE(736), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [48050] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 1,
      anon_sym_EQ,
    ACTIONS(1006), 8,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [48067] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    ACTIONS(1342), 1,
      sym__str_end,
    STATE(847), 1,
      sym_percent,
    STATE(730), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [48094] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1150), 1,
      anon_sym_or,
    ACTIONS(1346), 1,
      anon_sym_EQ,
    ACTIONS(1344), 7,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RBRACK,
  [48113] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      anon_sym_PERCENT,
    ACTIONS(1278), 1,
      sym_str_literal,
    ACTIONS(1280), 1,
      sym_str_esc_char,
    ACTIONS(1284), 1,
      sym_interpolation_start,
    ACTIONS(1348), 1,
      sym__str_end,
    STATE(847), 1,
      sym_percent,
    STATE(742), 3,
      sym_chunk_expr,
      sym_chunk_literal_single,
      aux_sym_str_chunks_single_repeat1,
  [48140] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1354), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(775), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48162] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1356), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(765), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48184] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1360), 1,
      anon_sym_DOT,
    STATE(774), 1,
      aux_sym_field_path_repeat1,
    ACTIONS(1358), 6,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [48202] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(461), 1,
      anon_sym_PIPE,
    ACTIONS(459), 7,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [48218] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(457), 1,
      anon_sym_PIPE,
    ACTIONS(455), 7,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [48234] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1362), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(760), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48256] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 1,
      anon_sym_PIPE,
    ACTIONS(439), 7,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [48272] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 1,
      anon_sym_EQ,
    ACTIONS(1292), 7,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RBRACK,
  [48288] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(1364), 1,
      anon_sym_SEMI,
    ACTIONS(1366), 1,
      anon_sym_PIPE_RBRACK,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(477), 1,
      sym_enum_tag,
    STATE(894), 1,
      sym_enum,
    STATE(955), 1,
      sym_enum_variant,
  [48316] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 1,
      anon_sym_EQ,
    ACTIONS(1288), 7,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RBRACK,
  [48332] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1368), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(760), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48354] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1370), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(758), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48376] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1372), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(769), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48398] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1374), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(760), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48420] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1338), 1,
      anon_sym_EQ,
    ACTIONS(1336), 7,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RBRACK,
  [48436] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1376), 1,
      anon_sym_PERCENT,
    ACTIONS(1382), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(760), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1379), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48458] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1384), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(750), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48480] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1386), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(755), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48502] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(859), 1,
      anon_sym_EQ,
    ACTIONS(815), 7,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RBRACK,
  [48518] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(1388), 1,
      anon_sym_SEMI,
    ACTIONS(1390), 1,
      anon_sym_PIPE_RBRACK,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(477), 1,
      sym_enum_tag,
    STATE(864), 1,
      sym_enum,
    STATE(955), 1,
      sym_enum_variant,
  [48546] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1392), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(760), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48568] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(1394), 1,
      anon_sym_SEMI,
    ACTIONS(1396), 1,
      anon_sym_PIPE_RBRACK,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(477), 1,
      sym_enum_tag,
    STATE(879), 1,
      sym_enum,
    STATE(955), 1,
      sym_enum_variant,
  [48596] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(481), 1,
      anon_sym_PIPE,
    ACTIONS(479), 7,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [48612] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 1,
      anon_sym_or,
    ACTIONS(1398), 1,
      anon_sym_AT,
    ACTIONS(1292), 6,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [48630] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1400), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(760), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48652] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1402), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(760), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48674] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1404), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(760), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48696] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1360), 1,
      anon_sym_DOT,
    STATE(747), 1,
      aux_sym_field_path_repeat1,
    ACTIONS(1406), 6,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [48714] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(1408), 1,
      anon_sym_SEMI,
    ACTIONS(1410), 1,
      anon_sym_PIPE_RBRACK,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(477), 1,
      sym_enum_tag,
    STATE(886), 1,
      sym_enum,
    STATE(955), 1,
      sym_enum_variant,
  [48742] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1414), 1,
      anon_sym_DOT,
    STATE(774), 1,
      aux_sym_field_path_repeat1,
    ACTIONS(1412), 6,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [48760] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1417), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(760), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48782] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(1419), 1,
      anon_sym_SEMI,
    ACTIONS(1421), 1,
      anon_sym_PIPE_RBRACK,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(477), 1,
      sym_enum_tag,
    STATE(876), 1,
      sym_enum,
    STATE(955), 1,
      sym_enum_variant,
  [48810] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(1423), 1,
      anon_sym_SEMI,
    ACTIONS(1425), 1,
      anon_sym_PIPE_RBRACK,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(477), 1,
      sym_enum_tag,
    STATE(872), 1,
      sym_enum,
    STATE(955), 1,
      sym_enum_variant,
  [48838] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_PIPE,
    ACTIONS(487), 7,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [48854] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1427), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(760), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48876] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1429), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(779), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48898] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1431), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(771), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48920] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_PERCENT,
    ACTIONS(1433), 1,
      sym_multstr_end,
    STATE(855), 1,
      sym_percent,
    STATE(770), 2,
      sym_chunk_literal_multi,
      aux_sym_static_string_repeat2,
    ACTIONS(1352), 3,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [48942] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    ACTIONS(1435), 1,
      anon_sym_SEMI,
    ACTIONS(1437), 1,
      anon_sym_PIPE_RBRACK,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(477), 1,
      sym_enum_tag,
    STATE(906), 1,
      sym_enum,
    STATE(955), 1,
      sym_enum_variant,
  [48970] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1445), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [48993] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1404), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49016] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1447), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(794), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49039] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1412), 7,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
  [49052] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1433), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(801), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49075] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1449), 1,
      anon_sym_PERCENT,
    ACTIONS(1452), 1,
      sym_str_literal,
    ACTIONS(1455), 1,
      sym_str_esc_char,
    ACTIONS(1458), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49098] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1431), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(785), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49121] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1429), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(795), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49144] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1460), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49167] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1462), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49190] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1464), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49213] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1427), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49236] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1466), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(784), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49259] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1468), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(792), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49282] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1417), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49305] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1470), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(793), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49328] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1012), 1,
      sym_ident,
    STATE(787), 1,
      sym_field_path_elem,
    STATE(804), 1,
      sym_str_chunks,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [49351] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1402), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49374] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1400), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49397] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1472), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(808), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49420] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1474), 7,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
  [49433] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1356), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(811), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49456] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1476), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(822), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49479] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1354), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(798), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49502] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1478), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49525] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1374), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49548] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1386), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(820), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49571] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1392), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49594] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1480), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49617] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1370), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(809), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49640] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1372), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(802), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49663] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1482), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49686] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1484), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(815), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49709] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1486), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49732] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1362), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49755] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1488), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(812), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49778] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1368), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49801] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1384), 1,
      sym__str_end,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    STATE(892), 1,
      sym_percent,
    STATE(818), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49824] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1490), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49847] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1492), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(817), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49870] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1494), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(789), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49893] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 1,
      anon_sym_PERCENT,
    ACTIONS(1441), 1,
      sym_str_literal,
    ACTIONS(1443), 1,
      sym_str_esc_char,
    ACTIONS(1496), 1,
      sym__str_end,
    STATE(892), 1,
      sym_percent,
    STATE(824), 2,
      sym_chunk_literal_single,
      aux_sym_static_string_repeat1,
  [49916] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1500), 2,
      sym_multstr_end,
      sym_interpolation_start,
    ACTIONS(1498), 4,
      anon_sym_PERCENT,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [49930] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1502), 1,
      sym_ident,
    ACTIONS(1504), 1,
      anon_sym_RBRACE,
    ACTIONS(1506), 1,
      anon_sym_DOT_DOT,
    STATE(854), 1,
      aux_sym_record_pattern_repeat1,
    STATE(1030), 1,
      sym_field_pattern,
    STATE(1052), 1,
      sym_last_field_pat,
  [49952] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1510), 2,
      sym_multstr_end,
      sym_interpolation_start,
    ACTIONS(1508), 4,
      anon_sym_PERCENT,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [49966] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      sym_multstr_start,
    ACTIONS(47), 1,
      sym__str_start,
    ACTIONS(1512), 1,
      sym_ident,
    STATE(314), 1,
      sym_str_chunks,
    STATE(303), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [49986] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(635), 1,
      sym_multstr_start,
    ACTIONS(637), 1,
      sym__str_start,
    ACTIONS(1514), 1,
      sym_ident,
    STATE(885), 1,
      sym_str_chunks,
    STATE(751), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [50006] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(305), 1,
      sym_multstr_start,
    ACTIONS(307), 1,
      sym__str_start,
    ACTIONS(1516), 1,
      sym_ident,
    STATE(384), 1,
      sym_str_chunks,
    STATE(264), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [50026] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1520), 2,
      sym_multstr_end,
      sym_interpolation_start,
    ACTIONS(1518), 4,
      anon_sym_PERCENT,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [50040] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1502), 1,
      sym_ident,
    ACTIONS(1506), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1522), 1,
      anon_sym_RBRACE,
    STATE(827), 1,
      aux_sym_record_pattern_repeat1,
    STATE(1030), 1,
      sym_field_pattern,
    STATE(1132), 1,
      sym_last_field_pat,
  [50062] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(347), 1,
      sym_multstr_start,
    ACTIONS(349), 1,
      sym__str_start,
    ACTIONS(1524), 1,
      sym_ident,
    STATE(241), 1,
      sym_str_chunks,
    STATE(259), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [50082] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(571), 1,
      anon_sym_COLON,
    ACTIONS(1187), 1,
      anon_sym_PIPE,
    ACTIONS(1526), 1,
      anon_sym_EQ,
    STATE(1104), 1,
      sym_annot,
    STATE(684), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
  [50102] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      sym_raw_enum_tag,
    ACTIONS(115), 1,
      sym_quoted_enum_tag_start,
    STATE(89), 1,
      sym_quoted_enum_tag,
    STATE(477), 1,
      sym_enum_tag,
    STATE(931), 1,
      sym_enum,
    STATE(955), 1,
      sym_enum_variant,
  [50124] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(263), 1,
      sym_multstr_start,
    ACTIONS(265), 1,
      sym__str_start,
    ACTIONS(1528), 1,
      sym_ident,
    STATE(330), 1,
      sym_str_chunks,
    STATE(271), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [50144] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(221), 1,
      sym_multstr_start,
    ACTIONS(223), 1,
      sym__str_start,
    ACTIONS(1530), 1,
      sym_ident,
    STATE(408), 1,
      sym_str_chunks,
    STATE(380), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [50164] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1169), 6,
      sym_multstr_start,
      sym__str_start,
      sym_ident,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_DOT_DOT,
  [50176] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1532), 1,
      anon_sym_PIPE,
    ACTIONS(1535), 1,
      anon_sym_COLON,
    ACTIONS(1185), 2,
      anon_sym_COMMA,
      anon_sym_in,
    STATE(840), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
  [50194] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1502), 1,
      sym_ident,
    ACTIONS(1506), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1538), 1,
      anon_sym_RBRACE,
    STATE(843), 1,
      aux_sym_record_pattern_repeat1,
    STATE(1030), 1,
      sym_field_pattern,
    STATE(1155), 1,
      sym_last_field_pat,
  [50216] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(111), 1,
      sym_multstr_start,
    ACTIONS(113), 1,
      sym__str_start,
    ACTIONS(1540), 1,
      sym_ident,
    STATE(106), 1,
      sym_str_chunks,
    STATE(107), 2,
      sym_str_chunks_single,
      sym_str_chunks_multi,
  [50236] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1502), 1,
      sym_ident,
    ACTIONS(1506), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1542), 1,
      anon_sym_RBRACE,
    STATE(854), 1,
      aux_sym_record_pattern_repeat1,
    STATE(1030), 1,
      sym_field_pattern,
    STATE(1124), 1,
      sym_last_field_pat,
  [50258] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(677), 1,
      anon_sym_COLON,
    ACTIONS(1544), 1,
      anon_sym_PIPE,
    ACTIONS(1191), 2,
      anon_sym_COMMA,
      anon_sym_in,
    STATE(840), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
  [50276] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(735), 1,
      anon_sym_COLON,
    ACTIONS(1191), 1,
      anon_sym_then,
    ACTIONS(1546), 1,
      anon_sym_PIPE,
    STATE(849), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
  [50293] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1185), 1,
      ts_builtin_sym_end,
    ACTIONS(1548), 1,
      anon_sym_PIPE,
    ACTIONS(1551), 1,
      anon_sym_COLON,
    STATE(846), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
  [50310] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1554), 2,
      anon_sym_PERCENT,
      sym_str_esc_char,
    ACTIONS(1556), 3,
      sym__str_end,
      sym_interpolation_start,
      sym_str_literal,
  [50323] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(691), 1,
      anon_sym_COLON,
    ACTIONS(1191), 1,
      ts_builtin_sym_end,
    ACTIONS(1558), 1,
      anon_sym_PIPE,
    STATE(846), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
  [50340] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1185), 1,
      anon_sym_then,
    ACTIONS(1560), 1,
      anon_sym_PIPE,
    ACTIONS(1563), 1,
      anon_sym_COLON,
    STATE(849), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
  [50357] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1185), 1,
      sym_interpolation_end,
    ACTIONS(1566), 1,
      anon_sym_PIPE,
    ACTIONS(1569), 1,
      anon_sym_COLON,
    STATE(850), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
  [50374] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(697), 1,
      anon_sym_COLON,
    ACTIONS(1191), 1,
      sym_interpolation_end,
    ACTIONS(1572), 1,
      anon_sym_PIPE,
    STATE(850), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
  [50391] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1264), 1,
      anon_sym_QMARK,
    ACTIONS(1574), 1,
      anon_sym_EQ,
    STATE(969), 1,
      sym_default_annot,
    ACTIONS(1576), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [50408] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1508), 2,
      anon_sym_PERCENT,
      sym_str_esc_char,
    ACTIONS(1510), 3,
      sym__str_end,
      sym_interpolation_start,
      sym_str_literal,
  [50421] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1578), 1,
      sym_ident,
    STATE(854), 1,
      aux_sym_record_pattern_repeat1,
    STATE(1133), 1,
      sym_field_pattern,
    ACTIONS(1581), 2,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT,
  [50438] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1520), 1,
      sym_multstr_end,
    ACTIONS(1518), 4,
      anon_sym_PERCENT,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [50451] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1185), 1,
      anon_sym_else,
    ACTIONS(1583), 1,
      anon_sym_PIPE,
    ACTIONS(1586), 1,
      anon_sym_COLON,
    STATE(856), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
  [50468] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(713), 1,
      anon_sym_COLON,
    ACTIONS(1191), 1,
      anon_sym_else,
    ACTIONS(1589), 1,
      anon_sym_PIPE,
    STATE(856), 2,
      sym_annot_atom,
      aux_sym_annot_repeat1,
  [50485] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1510), 1,
      sym_multstr_end,
    ACTIONS(1508), 4,
      anon_sym_PERCENT,
      sym_double_quote,
      sym_mult_str_literal,
      sym_str_esc_char,
  [50498] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1498), 2,
      anon_sym_PERCENT,
      sym_str_esc_char,
    ACTIONS(1500), 3,
      sym__str_end,
      sym_interpolation_start,
      sym_str_literal,
  [50511] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1508), 2,
      anon_sym_PERCENT,
      sym_str_esc_char,
    ACTIONS(1510), 2,
      sym__str_end,
      sym_str_literal,
  [50523] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1593), 1,
      anon_sym_SEMI,
    ACTIONS(1595), 1,
      anon_sym_PIPE_RBRACK,
    STATE(868), 1,
      aux_sym_type_atom_repeat1,
  [50539] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50549] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50559] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1597), 1,
      anon_sym_SEMI,
    ACTIONS(1599), 1,
      anon_sym_PIPE_RBRACK,
    STATE(861), 1,
      aux_sym_type_atom_repeat1,
  [50575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1601), 1,
      anon_sym_DOT,
    ACTIONS(483), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50587] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(495), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50597] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(411), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50607] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1603), 1,
      anon_sym_COMMA,
    STATE(868), 1,
      aux_sym_type_atom_repeat1,
    ACTIONS(1606), 2,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50621] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(423), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50631] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50641] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(399), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50651] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1608), 1,
      anon_sym_SEMI,
    ACTIONS(1610), 1,
      anon_sym_PIPE_RBRACK,
    STATE(897), 1,
      aux_sym_type_atom_repeat1,
  [50667] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50677] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(391), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50687] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(387), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50697] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1612), 1,
      anon_sym_SEMI,
    ACTIONS(1614), 1,
      anon_sym_PIPE_RBRACK,
    STATE(881), 1,
      aux_sym_type_atom_repeat1,
  [50713] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50723] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50733] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1616), 1,
      anon_sym_SEMI,
    ACTIONS(1618), 1,
      anon_sym_PIPE_RBRACK,
    STATE(901), 1,
      aux_sym_type_atom_repeat1,
  [50749] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50759] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1620), 1,
      anon_sym_SEMI,
    ACTIONS(1622), 1,
      anon_sym_PIPE_RBRACK,
    STATE(868), 1,
      aux_sym_type_atom_repeat1,
  [50775] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(119), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50785] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(419), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50795] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(523), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50805] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50815] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1624), 1,
      anon_sym_SEMI,
    ACTIONS(1626), 1,
      anon_sym_PIPE_RBRACK,
    STATE(898), 1,
      aux_sym_type_atom_repeat1,
  [50831] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(519), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1628), 1,
      anon_sym_EQ,
    ACTIONS(1630), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [50853] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 1,
      anon_sym_or,
    ACTIONS(1632), 1,
      anon_sym_AT,
    ACTIONS(1292), 2,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50867] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(475), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50877] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(515), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1554), 2,
      anon_sym_PERCENT,
      sym_str_esc_char,
    ACTIONS(1556), 2,
      sym__str_end,
      sym_str_literal,
  [50899] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50909] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1634), 1,
      anon_sym_SEMI,
    ACTIONS(1636), 1,
      anon_sym_PIPE_RBRACK,
    STATE(904), 1,
      aux_sym_type_atom_repeat1,
  [50925] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(467), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50935] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50945] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1638), 1,
      anon_sym_SEMI,
    ACTIONS(1640), 1,
      anon_sym_PIPE_RBRACK,
    STATE(868), 1,
      aux_sym_type_atom_repeat1,
  [50961] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1642), 1,
      anon_sym_SEMI,
    ACTIONS(1644), 1,
      anon_sym_PIPE_RBRACK,
    STATE(868), 1,
      aux_sym_type_atom_repeat1,
  [50977] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(463), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50987] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [50997] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1646), 1,
      anon_sym_SEMI,
    ACTIONS(1648), 1,
      anon_sym_PIPE_RBRACK,
    STATE(868), 1,
      aux_sym_type_atom_repeat1,
  [51013] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [51023] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1650), 1,
      anon_sym_SEMI,
    ACTIONS(1652), 1,
      anon_sym_PIPE_RBRACK,
    STATE(868), 1,
      aux_sym_type_atom_repeat1,
  [51039] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1654), 1,
      anon_sym_SEMI,
    ACTIONS(1656), 1,
      anon_sym_PIPE_RBRACK,
    STATE(868), 1,
      aux_sym_type_atom_repeat1,
  [51055] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(511), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [51065] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 1,
      anon_sym_COMMA,
    ACTIONS(1658), 1,
      anon_sym_SEMI,
    ACTIONS(1660), 1,
      anon_sym_PIPE_RBRACK,
    STATE(903), 1,
      aux_sym_type_atom_repeat1,
  [51081] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1662), 1,
      anon_sym_EQ_GT,
    ACTIONS(1664), 1,
      anon_sym_if,
    STATE(1224), 1,
      sym_pattern_guard,
  [51094] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1666), 1,
      sym_multstr_start,
    ACTIONS(1668), 1,
      sym__str_start,
    STATE(446), 1,
      sym_static_string,
  [51107] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1670), 1,
      sym_ident,
    ACTIONS(1673), 1,
      anon_sym_DOT,
    STATE(909), 1,
      aux_sym_forall_repeat1,
  [51120] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(161), 1,
      anon_sym_RBRACK,
    ACTIONS(1675), 1,
      anon_sym_COMMA,
    STATE(957), 1,
      aux_sym_atom_repeat1,
  [51133] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(791), 1,
      anon_sym_RBRACE,
    ACTIONS(1677), 1,
      anon_sym_COMMA,
    STATE(924), 1,
      aux_sym_match_expr_repeat1,
  [51146] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(811), 1,
      anon_sym_RBRACE,
    ACTIONS(1679), 1,
      anon_sym_COMMA,
    STATE(924), 1,
      aux_sym_match_expr_repeat1,
  [51159] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(177), 1,
      anon_sym_RBRACK,
    ACTIONS(1681), 1,
      anon_sym_COMMA,
    STATE(957), 1,
      aux_sym_atom_repeat1,
  [51172] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1683), 1,
      anon_sym_COMMA,
    ACTIONS(1685), 1,
      anon_sym_RBRACE,
    STATE(912), 1,
      aux_sym_match_expr_repeat1,
  [51185] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1687), 1,
      anon_sym_COMMA,
    ACTIONS(1689), 1,
      anon_sym_RBRACE,
    STATE(959), 1,
      aux_sym_match_expr_repeat1,
  [51198] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1195), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51209] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1104), 3,
      sym_interpolation_end,
      anon_sym_PIPE,
      anon_sym_COLON,
  [51218] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1693), 1,
      sym_multstr_start,
    ACTIONS(1695), 1,
      sym__str_start,
    STATE(450), 1,
      sym_static_string,
  [51231] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(169), 1,
      anon_sym_RBRACK,
    ACTIONS(1697), 1,
      anon_sym_COMMA,
    STATE(957), 1,
      aux_sym_atom_repeat1,
  [51244] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1699), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [51253] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(661), 1,
      sym_multstr_start,
    ACTIONS(663), 1,
      sym__str_start,
    STATE(655), 1,
      sym_static_string,
  [51266] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1701), 1,
      anon_sym_COMMA,
    ACTIONS(1703), 1,
      anon_sym_RBRACE,
    STATE(911), 1,
      aux_sym_match_expr_repeat1,
  [51279] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1705), 1,
      anon_sym_COMMA,
    ACTIONS(1707), 1,
      anon_sym_RBRACK,
    STATE(913), 1,
      aux_sym_atom_repeat1,
  [51292] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1709), 1,
      anon_sym_COMMA,
    ACTIONS(1712), 1,
      anon_sym_RBRACE,
    STATE(924), 1,
      aux_sym_match_expr_repeat1,
  [51305] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(531), 3,
      sym_interpolation_end,
      anon_sym_PIPE,
      anon_sym_COLON,
  [51314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1222), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51325] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1714), 1,
      sym_multstr_start,
    ACTIONS(1716), 1,
      sym__str_start,
    STATE(448), 1,
      sym_static_string,
  [51338] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(543), 3,
      sym_interpolation_end,
      anon_sym_PIPE,
      anon_sym_COLON,
  [51347] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1169), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51358] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1718), 1,
      anon_sym_COMMA,
    ACTIONS(1720), 1,
      anon_sym_RBRACK,
    STATE(919), 1,
      aux_sym_atom_repeat1,
  [51371] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1606), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [51380] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1098), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51391] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1722), 1,
      sym_ident,
    ACTIONS(1724), 1,
      anon_sym_DOT,
    STATE(909), 1,
      aux_sym_forall_repeat1,
  [51404] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1722), 1,
      sym_ident,
    ACTIONS(1726), 1,
      anon_sym_DOT,
    STATE(909), 1,
      aux_sym_forall_repeat1,
  [51417] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1143), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51428] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1728), 1,
      anon_sym_COMMA,
    ACTIONS(1730), 1,
      anon_sym_RBRACK,
    STATE(951), 1,
      aux_sym_atom_repeat1,
  [51441] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1128), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51452] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1722), 1,
      sym_ident,
    ACTIONS(1732), 1,
      anon_sym_DOT,
    STATE(909), 1,
      aux_sym_forall_repeat1,
  [51465] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1734), 1,
      anon_sym_COMMA,
    ACTIONS(1736), 1,
      anon_sym_RBRACK,
    STATE(997), 1,
      aux_sym_atom_repeat1,
  [51478] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1722), 1,
      sym_ident,
    ACTIONS(1738), 1,
      anon_sym_DOT,
    STATE(909), 1,
      aux_sym_forall_repeat1,
  [51491] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1740), 1,
      anon_sym_COMMA,
    ACTIONS(1742), 2,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [51502] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1744), 1,
      anon_sym_COMMA,
    ACTIONS(1746), 1,
      anon_sym_RBRACE,
    STATE(954), 1,
      aux_sym_match_expr_repeat1,
  [51515] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1748), 1,
      anon_sym_COMMA,
    ACTIONS(1750), 1,
      anon_sym_RBRACK,
    STATE(956), 1,
      aux_sym_atom_repeat1,
  [51528] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1090), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51539] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1752), 1,
      sym_multstr_start,
    ACTIONS(1754), 1,
      sym__str_start,
    STATE(143), 1,
      sym_static_string,
  [51552] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1048), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1075), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51574] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1756), 1,
      anon_sym_COMMA,
    ACTIONS(1758), 1,
      anon_sym_in,
    STATE(976), 1,
      aux_sym_let_in_block_repeat1,
  [51587] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1076), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51598] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1760), 1,
      anon_sym_COMMA,
    ACTIONS(1762), 1,
      anon_sym_in,
    STATE(958), 1,
      aux_sym_let_in_block_repeat1,
  [51611] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(167), 1,
      anon_sym_RBRACK,
    ACTIONS(1764), 1,
      anon_sym_COMMA,
    STATE(957), 1,
      aux_sym_atom_repeat1,
  [51624] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1766), 1,
      anon_sym_COMMA,
    ACTIONS(1768), 1,
      anon_sym_RBRACE,
    STATE(968), 1,
      aux_sym_match_expr_repeat1,
  [51637] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1058), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51648] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(797), 1,
      anon_sym_RBRACE,
    ACTIONS(1770), 1,
      anon_sym_COMMA,
    STATE(924), 1,
      aux_sym_match_expr_repeat1,
  [51661] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(617), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_PIPE_RBRACK,
  [51670] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(179), 1,
      anon_sym_RBRACK,
    ACTIONS(1772), 1,
      anon_sym_COMMA,
    STATE(957), 1,
      aux_sym_atom_repeat1,
  [51683] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1774), 1,
      anon_sym_COMMA,
    ACTIONS(1777), 1,
      anon_sym_RBRACK,
    STATE(957), 1,
      aux_sym_atom_repeat1,
  [51696] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1779), 1,
      anon_sym_COMMA,
    ACTIONS(1781), 1,
      anon_sym_in,
    STATE(976), 1,
      aux_sym_let_in_block_repeat1,
  [51709] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(807), 1,
      anon_sym_RBRACE,
    ACTIONS(1783), 1,
      anon_sym_COMMA,
    STATE(924), 1,
      aux_sym_match_expr_repeat1,
  [51722] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1785), 1,
      anon_sym_EQ,
    ACTIONS(1787), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [51733] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1215), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51744] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1581), 3,
      sym_ident,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT,
  [51753] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1789), 1,
      anon_sym_COMMA,
    ACTIONS(1791), 1,
      anon_sym_RBRACK,
    STATE(910), 1,
      aux_sym_atom_repeat1,
  [51766] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1049), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51777] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1793), 1,
      anon_sym_COMMA,
    ACTIONS(1795), 1,
      anon_sym_in,
    STATE(948), 1,
      aux_sym_let_in_block_repeat1,
  [51790] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1146), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51801] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1134), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51812] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_RBRACE,
    ACTIONS(1797), 1,
      anon_sym_COMMA,
    STATE(924), 1,
      aux_sym_match_expr_repeat1,
  [51825] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1799), 1,
      anon_sym_EQ,
    ACTIONS(1801), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [51836] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(805), 1,
      anon_sym_RBRACE,
    ACTIONS(1803), 1,
      anon_sym_COMMA,
    STATE(924), 1,
      aux_sym_match_expr_repeat1,
  [51849] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1137), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51860] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1805), 1,
      sym_multstr_start,
    ACTIONS(1807), 1,
      sym__str_start,
    STATE(973), 1,
      sym_static_string,
  [51873] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1096), 3,
      sym_interpolation_end,
      anon_sym_PIPE,
      anon_sym_COLON,
  [51882] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1088), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51893] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1060), 3,
      sym_interpolation_end,
      anon_sym_PIPE,
      anon_sym_COLON,
  [51902] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1809), 1,
      anon_sym_COMMA,
    ACTIONS(1812), 1,
      anon_sym_in,
    STATE(976), 1,
      aux_sym_let_in_block_repeat1,
  [51915] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1121), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51926] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1108), 3,
      sym_interpolation_end,
      anon_sym_PIPE,
      anon_sym_COLON,
  [51935] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(183), 1,
      anon_sym_RBRACK,
    ACTIONS(1814), 1,
      anon_sym_COMMA,
    STATE(957), 1,
      aux_sym_atom_repeat1,
  [51948] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1816), 1,
      sym_multstr_start,
    ACTIONS(1818), 1,
      sym__str_start,
    STATE(440), 1,
      sym_static_string,
  [51961] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1071), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51972] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1078), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [51983] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1820), 1,
      sym_multstr_start,
    ACTIONS(1822), 1,
      sym__str_start,
    STATE(409), 1,
      sym_static_string,
  [51996] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1120), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [52007] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1079), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [52018] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 3,
      sym_interpolation_end,
      anon_sym_PIPE,
      anon_sym_COLON,
  [52027] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1076), 3,
      sym_interpolation_end,
      anon_sym_PIPE,
      anon_sym_COLON,
  [52036] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1084), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [52047] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1102), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [52058] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1107), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [52069] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1108), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [52080] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1122), 3,
      sym_interpolation_end,
      anon_sym_PIPE,
      anon_sym_COLON,
  [52089] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1111), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [52100] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1722), 1,
      sym_ident,
    ACTIONS(1824), 1,
      anon_sym_DOT,
    STATE(909), 1,
      aux_sym_forall_repeat1,
  [52113] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1826), 1,
      anon_sym_COMMA,
    ACTIONS(1828), 1,
      anon_sym_RBRACK,
    STATE(979), 1,
      aux_sym_atom_repeat1,
  [52126] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1722), 1,
      sym_ident,
    ACTIONS(1830), 1,
      anon_sym_DOT,
    STATE(909), 1,
      aux_sym_forall_repeat1,
  [52139] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(157), 1,
      anon_sym_RBRACK,
    ACTIONS(1832), 1,
      anon_sym_COMMA,
    STATE(957), 1,
      aux_sym_atom_repeat1,
  [52152] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1834), 3,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [52161] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1836), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [52170] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1117), 1,
      sym_row_tail,
    ACTIONS(1691), 2,
      sym_ident,
      anon_sym_Dyn,
  [52181] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1838), 1,
      anon_sym_COMMA,
    ACTIONS(1840), 1,
      anon_sym_RBRACE,
    STATE(970), 1,
      aux_sym_match_expr_repeat1,
  [52194] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1842), 1,
      anon_sym_COMMA,
    ACTIONS(1844), 1,
      anon_sym_RBRACK,
  [52204] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1846), 1,
      anon_sym_RBRACE,
    ACTIONS(1848), 1,
      anon_sym_SEMI,
  [52214] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1742), 2,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [52222] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1850), 2,
      anon_sym_PIPE,
      anon_sym_COLON,
  [52230] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1852), 2,
      anon_sym_PIPE,
      anon_sym_COLON,
  [52238] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1854), 2,
      anon_sym_PIPE,
      anon_sym_COLON,
  [52246] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1856), 1,
      anon_sym_RBRACE,
    ACTIONS(1858), 1,
      anon_sym_SEMI,
  [52256] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1860), 2,
      anon_sym_PIPE,
      anon_sym_COLON,
  [52264] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1862), 1,
      anon_sym_RBRACE,
    ACTIONS(1864), 1,
      anon_sym_SEMI,
  [52274] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1866), 2,
      anon_sym_PIPE,
      anon_sym_COLON,
  [52282] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1868), 2,
      anon_sym_PIPE,
      anon_sym_COLON,
  [52290] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(965), 1,
      anon_sym_RPAREN,
    ACTIONS(1870), 1,
      aux_sym_builtin_token1,
  [52300] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1872), 1,
      sym_ident,
    STATE(996), 1,
      aux_sym_forall_repeat1,
  [52310] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1874), 1,
      sym_ident,
    STATE(938), 1,
      aux_sym_forall_repeat1,
  [52320] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1812), 2,
      anon_sym_COMMA,
      anon_sym_in,
  [52328] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1777), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [52336] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1876), 1,
      sym_ident,
    STATE(994), 1,
      aux_sym_forall_repeat1,
  [52346] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1878), 2,
      anon_sym_COMMA,
      anon_sym_in,
  [52354] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1880), 1,
      anon_sym_RBRACE,
    ACTIONS(1882), 1,
      anon_sym_SEMI,
  [52364] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1884), 1,
      sym_ident,
    STATE(940), 1,
      aux_sym_forall_repeat1,
  [52374] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1886), 1,
      sym_ident,
    STATE(934), 1,
      aux_sym_forall_repeat1,
  [52384] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1888), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [52392] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1890), 1,
      anon_sym_RBRACE,
    ACTIONS(1892), 1,
      anon_sym_SEMI,
  [52402] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1894), 2,
      anon_sym_default,
      anon_sym_force,
  [52410] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1896), 1,
      sym_ident,
    ACTIONS(1898), 1,
      anon_sym_RBRACE,
  [52420] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1900), 2,
      anon_sym_COMMA,
      anon_sym_in,
  [52428] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1902), 1,
      sym_ident,
    STATE(933), 1,
      aux_sym_forall_repeat1,
  [52438] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1904), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [52446] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1898), 1,
      anon_sym_RBRACE,
    ACTIONS(1906), 1,
      anon_sym_COMMA,
  [52456] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1844), 1,
      anon_sym_RBRACK,
    ACTIONS(1908), 1,
      sym_ident,
  [52466] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1910), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [52474] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1912), 1,
      anon_sym_RBRACE,
    ACTIONS(1914), 1,
      anon_sym_SEMI,
  [52484] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1916), 1,
      anon_sym_RBRACE,
    ACTIONS(1918), 1,
      anon_sym_SEMI,
  [52494] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1920), 1,
      anon_sym_RBRACE,
    ACTIONS(1922), 1,
      anon_sym_SEMI,
  [52504] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1924), 1,
      anon_sym_RBRACE,
    ACTIONS(1926), 1,
      anon_sym_SEMI,
  [52514] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1928), 1,
      anon_sym_RBRACE,
    ACTIONS(1930), 1,
      anon_sym_SEMI,
  [52524] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 2,
      anon_sym_default,
      anon_sym_force,
  [52532] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1934), 1,
      anon_sym_RBRACE,
    ACTIONS(1936), 1,
      anon_sym_SEMI,
  [52542] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1938), 1,
      anon_sym_RBRACE,
    ACTIONS(1940), 1,
      anon_sym_SEMI,
  [52552] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1942), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [52560] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [52568] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1944), 1,
      anon_sym_RBRACE,
    ACTIONS(1946), 1,
      anon_sym_SEMI,
  [52578] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1948), 2,
      anon_sym_PIPE,
      anon_sym_COLON,
  [52586] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1950), 1,
      anon_sym_RBRACE,
    ACTIONS(1952), 1,
      anon_sym_SEMI,
  [52596] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1954), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [52604] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1956), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [52612] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1958), 1,
      anon_sym_RBRACE,
  [52619] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1960), 1,
      anon_sym_RBRACE,
  [52626] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1962), 1,
      anon_sym_PIPE_RBRACK,
  [52633] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1209), 1,
      sym_interpolation_end,
  [52640] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1964), 1,
      anon_sym_RBRACE,
  [52647] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1966), 1,
      anon_sym_RPAREN,
  [52654] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1968), 1,
      anon_sym_RBRACE,
  [52661] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1970), 1,
      anon_sym_PIPE_RBRACK,
  [52668] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      sym_interpolation_end,
  [52675] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1205), 1,
      sym_interpolation_end,
  [52682] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1972), 1,
      anon_sym_RBRACE,
  [52689] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1768), 1,
      anon_sym_RBRACE,
  [52696] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1974), 1,
      anon_sym_PERCENT,
  [52703] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1750), 1,
      anon_sym_RBRACK,
  [52710] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1976), 1,
      anon_sym_RPAREN,
  [52717] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1978), 1,
      anon_sym_RPAREN,
  [52724] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1707), 1,
      anon_sym_RBRACK,
  [52731] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      anon_sym_PERCENT,
  [52738] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1982), 1,
      sym_signed_num_literal,
  [52745] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1984), 1,
      anon_sym_PIPE_RBRACK,
  [52752] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1828), 1,
      anon_sym_RBRACK,
  [52759] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1685), 1,
      anon_sym_RBRACE,
  [52766] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1986), 1,
      anon_sym_PIPE_RBRACK,
  [52773] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1988), 1,
      anon_sym_RBRACE,
  [52780] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1990), 1,
      sym_ident,
  [52787] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1992), 1,
      anon_sym_else,
  [52794] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1994), 1,
      anon_sym_PIPE_RBRACK,
  [52801] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1996), 1,
      anon_sym_RBRACE,
  [52808] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1998), 1,
      anon_sym_RBRACE,
  [52815] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2000), 1,
      anon_sym_RBRACE,
  [52822] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2002), 1,
      anon_sym_RBRACE,
  [52829] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2004), 1,
      anon_sym_RBRACE,
  [52836] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2006), 1,
      anon_sym_else,
  [52843] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2008), 1,
      anon_sym_RBRACE,
  [52850] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2010), 1,
      anon_sym_PIPE_RBRACK,
  [52857] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2012), 1,
      anon_sym_PIPE_RBRACK,
  [52864] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2014), 1,
      anon_sym_RBRACE,
  [52871] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2016), 1,
      anon_sym_PIPE_RBRACK,
  [52878] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2018), 1,
      anon_sym_PIPE_RBRACK,
  [52885] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2020), 1,
      anon_sym_PIPE_RBRACK,
  [52892] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2022), 1,
      anon_sym_RBRACE,
  [52899] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1762), 1,
      anon_sym_in,
  [52906] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2024), 1,
      anon_sym_RBRACE,
  [52913] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1703), 1,
      anon_sym_RBRACE,
  [52920] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2026), 1,
      anon_sym_PERCENT,
  [52927] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1720), 1,
      anon_sym_RBRACK,
  [52934] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2028), 1,
      anon_sym_RPAREN,
  [52941] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2030), 1,
      anon_sym_RPAREN,
  [52948] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1730), 1,
      anon_sym_RBRACK,
  [52955] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2032), 1,
      anon_sym_PERCENT,
  [52962] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2034), 1,
      anon_sym_RBRACE,
  [52969] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2036), 1,
      anon_sym_RBRACE,
  [52976] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 1,
      anon_sym_or,
  [52983] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2038), 1,
      anon_sym_RPAREN,
  [52990] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2040), 1,
      anon_sym_RBRACE,
  [52997] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2042), 1,
      anon_sym_RBRACE,
  [53004] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2044), 1,
      anon_sym_EQ,
  [53011] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2046), 1,
      anon_sym_PIPE_RBRACK,
  [53018] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2048), 1,
      anon_sym_RBRACE,
  [53025] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2050), 1,
      anon_sym_RBRACE,
  [53032] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2052), 1,
      anon_sym_RBRACE,
  [53039] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2054), 1,
      anon_sym_EQ_GT,
  [53046] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2056), 1,
      anon_sym_PIPE_RBRACK,
  [53053] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2058), 1,
      anon_sym_RBRACE,
  [53060] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2060), 1,
      anon_sym_PIPE_RBRACK,
  [53067] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2062), 1,
      anon_sym_RBRACK,
  [53074] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2064), 1,
      anon_sym_RBRACK,
  [53081] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2066), 1,
      anon_sym_RPAREN,
  [53088] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2068), 1,
      anon_sym_PIPE_RBRACK,
  [53095] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2070), 1,
      anon_sym_RBRACE,
  [53102] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2072), 1,
      anon_sym_PIPE_RBRACK,
  [53109] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2074), 1,
      anon_sym_else,
  [53116] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2076), 1,
      anon_sym_RBRACE,
  [53123] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_RBRACE,
  [53130] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2080), 1,
      anon_sym_RBRACE,
  [53137] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2082), 1,
      anon_sym_RBRACK,
  [53144] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2084), 1,
      anon_sym_RBRACE,
  [53151] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2086), 1,
      anon_sym_RBRACE,
  [53158] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2088), 1,
      anon_sym_PIPE_RBRACK,
  [53165] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2090), 1,
      anon_sym_LBRACE,
  [53172] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2092), 1,
      anon_sym_RBRACE,
  [53179] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2094), 1,
      anon_sym_else,
  [53186] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2096), 1,
      aux_sym_builtin_token1,
  [53193] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1842), 1,
      anon_sym_COMMA,
  [53200] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2098), 1,
      anon_sym_RBRACE,
  [53207] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1906), 1,
      anon_sym_COMMA,
  [53214] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2100), 1,
      anon_sym_RBRACE,
  [53221] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2102), 1,
      sym_ident,
  [53228] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1795), 1,
      anon_sym_in,
  [53235] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2104), 1,
      anon_sym_RBRACE,
  [53242] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2106), 1,
      sym_signed_num_literal,
  [53249] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2108), 1,
      anon_sym_PIPE_RBRACK,
  [53256] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2110), 1,
      sym_ident,
  [53263] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2112), 1,
      anon_sym_RBRACE,
  [53270] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2114), 1,
      sym_ident,
  [53277] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2116), 1,
      anon_sym_RBRACE,
  [53284] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2118), 1,
      anon_sym_LBRACE,
  [53291] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2120), 1,
      anon_sym_else,
  [53298] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2122), 1,
      anon_sym_RBRACE,
  [53305] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1870), 1,
      aux_sym_builtin_token1,
  [53312] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1689), 1,
      anon_sym_RBRACE,
  [53319] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2124), 1,
      sym_ident,
  [53326] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2126), 1,
      ts_builtin_sym_end,
  [53333] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2128), 1,
      anon_sym_RPAREN,
  [53340] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2130), 1,
      anon_sym_RBRACK,
  [53347] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2132), 1,
      anon_sym_RPAREN,
  [53354] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2134), 1,
      sym_ident,
  [53361] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2136), 1,
      anon_sym_RBRACE,
  [53368] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2138), 1,
      sym_ident,
  [53375] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2140), 1,
      sym_ident,
  [53382] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2142), 1,
      anon_sym_LBRACE,
  [53389] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2144), 1,
      anon_sym_PIPE_RBRACK,
  [53396] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2146), 1,
      anon_sym_PIPE_RBRACK,
  [53403] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      aux_sym_builtin_token1,
  [53410] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2150), 1,
      sym_interpolation_end,
  [53417] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2152), 1,
      sym_ident,
  [53424] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2154), 1,
      aux_sym_builtin_token1,
  [53431] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2156), 1,
      anon_sym_PERCENT,
  [53438] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1736), 1,
      anon_sym_RBRACK,
  [53445] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 1,
      anon_sym_RPAREN,
  [53452] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2160), 1,
      sym_ident,
  [53459] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2162), 1,
      anon_sym_RBRACE,
  [53466] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2164), 1,
      sym_ident,
  [53473] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2166), 1,
      sym_interpolation_end,
  [53480] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2168), 1,
      anon_sym_LBRACE,
  [53487] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1193), 1,
      sym_interpolation_end,
  [53494] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2170), 1,
      anon_sym_PIPE_RBRACK,
  [53501] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2172), 1,
      aux_sym_builtin_token1,
  [53508] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2174), 1,
      sym_ident,
  [53515] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2176), 1,
      sym_ident,
  [53522] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2178), 1,
      anon_sym_else,
  [53529] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2180), 1,
      anon_sym_PERCENT,
  [53536] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1791), 1,
      anon_sym_RBRACK,
  [53543] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1740), 1,
      anon_sym_COMMA,
  [53550] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2182), 1,
      sym_ident,
  [53557] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2184), 1,
      anon_sym_RPAREN,
  [53564] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2186), 1,
      sym_ident,
  [53571] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(557), 1,
      anon_sym_RPAREN,
  [53578] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2188), 1,
      anon_sym_LBRACE,
  [53585] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 1,
      sym_interpolation_end,
  [53592] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2190), 1,
      anon_sym_RPAREN,
  [53599] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2192), 1,
      aux_sym_builtin_token1,
  [53606] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2194), 1,
      anon_sym_RPAREN,
  [53613] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2196), 1,
      sym_ident,
  [53620] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2198), 1,
      anon_sym_RBRACK,
  [53627] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(947), 1,
      anon_sym_RPAREN,
  [53634] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(951), 1,
      anon_sym_RPAREN,
  [53641] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2200), 1,
      anon_sym_RBRACE,
  [53648] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2202), 1,
      sym_ident,
  [53655] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(943), 1,
      anon_sym_RPAREN,
  [53662] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2204), 1,
      sym_ident,
  [53669] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2206), 1,
      anon_sym_LBRACE,
  [53676] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2208), 1,
      aux_sym_builtin_token1,
  [53683] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(955), 1,
      anon_sym_RPAREN,
  [53690] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2210), 1,
      sym_ident,
  [53697] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(939), 1,
      anon_sym_RPAREN,
  [53704] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(555), 1,
      anon_sym_RPAREN,
  [53711] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(965), 1,
      anon_sym_RPAREN,
  [53718] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2212), 1,
      sym_ident,
  [53725] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1201), 1,
      sym_interpolation_end,
  [53732] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2214), 1,
      sym_ident,
  [53739] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2216), 1,
      anon_sym_PIPE_RBRACK,
  [53746] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2218), 1,
      anon_sym_then,
  [53753] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1746), 1,
      anon_sym_RBRACE,
  [53760] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2220), 1,
      anon_sym_then,
  [53767] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2222), 1,
      anon_sym_RPAREN,
  [53774] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2224), 1,
      anon_sym_then,
  [53781] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2226), 1,
      anon_sym_RBRACE,
  [53788] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2228), 1,
      anon_sym_then,
  [53795] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1840), 1,
      anon_sym_RBRACE,
  [53802] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2230), 1,
      anon_sym_then,
  [53809] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2232), 1,
      anon_sym_PERCENT,
  [53816] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(961), 1,
      anon_sym_RPAREN,
  [53823] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2234), 1,
      anon_sym_RPAREN,
  [53830] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2236), 1,
      anon_sym_RBRACE,
  [53837] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2238), 1,
      anon_sym_then,
  [53844] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2240), 1,
      anon_sym_EQ_GT,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(9)] = 0,
  [SMALL_STATE(10)] = 108,
  [SMALL_STATE(11)] = 213,
  [SMALL_STATE(12)] = 354,
  [SMALL_STATE(13)] = 495,
  [SMALL_STATE(14)] = 636,
  [SMALL_STATE(15)] = 777,
  [SMALL_STATE(16)] = 918,
  [SMALL_STATE(17)] = 1059,
  [SMALL_STATE(18)] = 1200,
  [SMALL_STATE(19)] = 1338,
  [SMALL_STATE(20)] = 1476,
  [SMALL_STATE(21)] = 1614,
  [SMALL_STATE(22)] = 1752,
  [SMALL_STATE(23)] = 1890,
  [SMALL_STATE(24)] = 2028,
  [SMALL_STATE(25)] = 2166,
  [SMALL_STATE(26)] = 2304,
  [SMALL_STATE(27)] = 2442,
  [SMALL_STATE(28)] = 2580,
  [SMALL_STATE(29)] = 2718,
  [SMALL_STATE(30)] = 2856,
  [SMALL_STATE(31)] = 2994,
  [SMALL_STATE(32)] = 3132,
  [SMALL_STATE(33)] = 3267,
  [SMALL_STATE(34)] = 3402,
  [SMALL_STATE(35)] = 3537,
  [SMALL_STATE(36)] = 3672,
  [SMALL_STATE(37)] = 3807,
  [SMALL_STATE(38)] = 3942,
  [SMALL_STATE(39)] = 4077,
  [SMALL_STATE(40)] = 4212,
  [SMALL_STATE(41)] = 4347,
  [SMALL_STATE(42)] = 4482,
  [SMALL_STATE(43)] = 4617,
  [SMALL_STATE(44)] = 4752,
  [SMALL_STATE(45)] = 4887,
  [SMALL_STATE(46)] = 5022,
  [SMALL_STATE(47)] = 5157,
  [SMALL_STATE(48)] = 5292,
  [SMALL_STATE(49)] = 5427,
  [SMALL_STATE(50)] = 5562,
  [SMALL_STATE(51)] = 5697,
  [SMALL_STATE(52)] = 5832,
  [SMALL_STATE(53)] = 5967,
  [SMALL_STATE(54)] = 6102,
  [SMALL_STATE(55)] = 6237,
  [SMALL_STATE(56)] = 6372,
  [SMALL_STATE(57)] = 6507,
  [SMALL_STATE(58)] = 6642,
  [SMALL_STATE(59)] = 6777,
  [SMALL_STATE(60)] = 6912,
  [SMALL_STATE(61)] = 7047,
  [SMALL_STATE(62)] = 7182,
  [SMALL_STATE(63)] = 7317,
  [SMALL_STATE(64)] = 7452,
  [SMALL_STATE(65)] = 7587,
  [SMALL_STATE(66)] = 7722,
  [SMALL_STATE(67)] = 7857,
  [SMALL_STATE(68)] = 7992,
  [SMALL_STATE(69)] = 8127,
  [SMALL_STATE(70)] = 8262,
  [SMALL_STATE(71)] = 8397,
  [SMALL_STATE(72)] = 8532,
  [SMALL_STATE(73)] = 8667,
  [SMALL_STATE(74)] = 8769,
  [SMALL_STATE(75)] = 8900,
  [SMALL_STATE(76)] = 9031,
  [SMALL_STATE(77)] = 9162,
  [SMALL_STATE(78)] = 9261,
  [SMALL_STATE(79)] = 9392,
  [SMALL_STATE(80)] = 9523,
  [SMALL_STATE(81)] = 9654,
  [SMALL_STATE(82)] = 9755,
  [SMALL_STATE(83)] = 9856,
  [SMALL_STATE(84)] = 9957,
  [SMALL_STATE(85)] = 10058,
  [SMALL_STATE(86)] = 10156,
  [SMALL_STATE(87)] = 10254,
  [SMALL_STATE(88)] = 10352,
  [SMALL_STATE(89)] = 10450,
  [SMALL_STATE(90)] = 10506,
  [SMALL_STATE(91)] = 10562,
  [SMALL_STATE(92)] = 10618,
  [SMALL_STATE(93)] = 10675,
  [SMALL_STATE(94)] = 10730,
  [SMALL_STATE(95)] = 10785,
  [SMALL_STATE(96)] = 10840,
  [SMALL_STATE(97)] = 10895,
  [SMALL_STATE(98)] = 10950,
  [SMALL_STATE(99)] = 11005,
  [SMALL_STATE(100)] = 11060,
  [SMALL_STATE(101)] = 11115,
  [SMALL_STATE(102)] = 11170,
  [SMALL_STATE(103)] = 11225,
  [SMALL_STATE(104)] = 11280,
  [SMALL_STATE(105)] = 11335,
  [SMALL_STATE(106)] = 11390,
  [SMALL_STATE(107)] = 11445,
  [SMALL_STATE(108)] = 11500,
  [SMALL_STATE(109)] = 11555,
  [SMALL_STATE(110)] = 11610,
  [SMALL_STATE(111)] = 11665,
  [SMALL_STATE(112)] = 11720,
  [SMALL_STATE(113)] = 11775,
  [SMALL_STATE(114)] = 11830,
  [SMALL_STATE(115)] = 11885,
  [SMALL_STATE(116)] = 11940,
  [SMALL_STATE(117)] = 11995,
  [SMALL_STATE(118)] = 12050,
  [SMALL_STATE(119)] = 12107,
  [SMALL_STATE(120)] = 12162,
  [SMALL_STATE(121)] = 12219,
  [SMALL_STATE(122)] = 12274,
  [SMALL_STATE(123)] = 12329,
  [SMALL_STATE(124)] = 12386,
  [SMALL_STATE(125)] = 12441,
  [SMALL_STATE(126)] = 12496,
  [SMALL_STATE(127)] = 12551,
  [SMALL_STATE(128)] = 12606,
  [SMALL_STATE(129)] = 12661,
  [SMALL_STATE(130)] = 12777,
  [SMALL_STATE(131)] = 12893,
  [SMALL_STATE(132)] = 13009,
  [SMALL_STATE(133)] = 13125,
  [SMALL_STATE(134)] = 13241,
  [SMALL_STATE(135)] = 13357,
  [SMALL_STATE(136)] = 13473,
  [SMALL_STATE(137)] = 13589,
  [SMALL_STATE(138)] = 13705,
  [SMALL_STATE(139)] = 13821,
  [SMALL_STATE(140)] = 13937,
  [SMALL_STATE(141)] = 14053,
  [SMALL_STATE(142)] = 14169,
  [SMALL_STATE(143)] = 14223,
  [SMALL_STATE(144)] = 14277,
  [SMALL_STATE(145)] = 14331,
  [SMALL_STATE(146)] = 14385,
  [SMALL_STATE(147)] = 14501,
  [SMALL_STATE(148)] = 14555,
  [SMALL_STATE(149)] = 14671,
  [SMALL_STATE(150)] = 14787,
  [SMALL_STATE(151)] = 14841,
  [SMALL_STATE(152)] = 14895,
  [SMALL_STATE(153)] = 15011,
  [SMALL_STATE(154)] = 15127,
  [SMALL_STATE(155)] = 15181,
  [SMALL_STATE(156)] = 15297,
  [SMALL_STATE(157)] = 15407,
  [SMALL_STATE(158)] = 15517,
  [SMALL_STATE(159)] = 15624,
  [SMALL_STATE(160)] = 15731,
  [SMALL_STATE(161)] = 15838,
  [SMALL_STATE(162)] = 15945,
  [SMALL_STATE(163)] = 16052,
  [SMALL_STATE(164)] = 16159,
  [SMALL_STATE(165)] = 16266,
  [SMALL_STATE(166)] = 16373,
  [SMALL_STATE(167)] = 16480,
  [SMALL_STATE(168)] = 16587,
  [SMALL_STATE(169)] = 16694,
  [SMALL_STATE(170)] = 16801,
  [SMALL_STATE(171)] = 16908,
  [SMALL_STATE(172)] = 17015,
  [SMALL_STATE(173)] = 17122,
  [SMALL_STATE(174)] = 17229,
  [SMALL_STATE(175)] = 17336,
  [SMALL_STATE(176)] = 17443,
  [SMALL_STATE(177)] = 17550,
  [SMALL_STATE(178)] = 17657,
  [SMALL_STATE(179)] = 17764,
  [SMALL_STATE(180)] = 17871,
  [SMALL_STATE(181)] = 17978,
  [SMALL_STATE(182)] = 18085,
  [SMALL_STATE(183)] = 18192,
  [SMALL_STATE(184)] = 18299,
  [SMALL_STATE(185)] = 18406,
  [SMALL_STATE(186)] = 18513,
  [SMALL_STATE(187)] = 18620,
  [SMALL_STATE(188)] = 18727,
  [SMALL_STATE(189)] = 18834,
  [SMALL_STATE(190)] = 18941,
  [SMALL_STATE(191)] = 19048,
  [SMALL_STATE(192)] = 19155,
  [SMALL_STATE(193)] = 19262,
  [SMALL_STATE(194)] = 19369,
  [SMALL_STATE(195)] = 19476,
  [SMALL_STATE(196)] = 19583,
  [SMALL_STATE(197)] = 19690,
  [SMALL_STATE(198)] = 19797,
  [SMALL_STATE(199)] = 19904,
  [SMALL_STATE(200)] = 20011,
  [SMALL_STATE(201)] = 20118,
  [SMALL_STATE(202)] = 20225,
  [SMALL_STATE(203)] = 20332,
  [SMALL_STATE(204)] = 20439,
  [SMALL_STATE(205)] = 20546,
  [SMALL_STATE(206)] = 20653,
  [SMALL_STATE(207)] = 20760,
  [SMALL_STATE(208)] = 20867,
  [SMALL_STATE(209)] = 20974,
  [SMALL_STATE(210)] = 21081,
  [SMALL_STATE(211)] = 21188,
  [SMALL_STATE(212)] = 21295,
  [SMALL_STATE(213)] = 21402,
  [SMALL_STATE(214)] = 21509,
  [SMALL_STATE(215)] = 21616,
  [SMALL_STATE(216)] = 21723,
  [SMALL_STATE(217)] = 21830,
  [SMALL_STATE(218)] = 21937,
  [SMALL_STATE(219)] = 22044,
  [SMALL_STATE(220)] = 22151,
  [SMALL_STATE(221)] = 22258,
  [SMALL_STATE(222)] = 22365,
  [SMALL_STATE(223)] = 22472,
  [SMALL_STATE(224)] = 22579,
  [SMALL_STATE(225)] = 22628,
  [SMALL_STATE(226)] = 22677,
  [SMALL_STATE(227)] = 22726,
  [SMALL_STATE(228)] = 22775,
  [SMALL_STATE(229)] = 22824,
  [SMALL_STATE(230)] = 22873,
  [SMALL_STATE(231)] = 22922,
  [SMALL_STATE(232)] = 22971,
  [SMALL_STATE(233)] = 23022,
  [SMALL_STATE(234)] = 23071,
  [SMALL_STATE(235)] = 23120,
  [SMALL_STATE(236)] = 23169,
  [SMALL_STATE(237)] = 23218,
  [SMALL_STATE(238)] = 23267,
  [SMALL_STATE(239)] = 23316,
  [SMALL_STATE(240)] = 23365,
  [SMALL_STATE(241)] = 23414,
  [SMALL_STATE(242)] = 23463,
  [SMALL_STATE(243)] = 23512,
  [SMALL_STATE(244)] = 23561,
  [SMALL_STATE(245)] = 23610,
  [SMALL_STATE(246)] = 23659,
  [SMALL_STATE(247)] = 23708,
  [SMALL_STATE(248)] = 23757,
  [SMALL_STATE(249)] = 23806,
  [SMALL_STATE(250)] = 23855,
  [SMALL_STATE(251)] = 23906,
  [SMALL_STATE(252)] = 23955,
  [SMALL_STATE(253)] = 24006,
  [SMALL_STATE(254)] = 24057,
  [SMALL_STATE(255)] = 24106,
  [SMALL_STATE(256)] = 24155,
  [SMALL_STATE(257)] = 24204,
  [SMALL_STATE(258)] = 24253,
  [SMALL_STATE(259)] = 24302,
  [SMALL_STATE(260)] = 24351,
  [SMALL_STATE(261)] = 24400,
  [SMALL_STATE(262)] = 24449,
  [SMALL_STATE(263)] = 24498,
  [SMALL_STATE(264)] = 24547,
  [SMALL_STATE(265)] = 24595,
  [SMALL_STATE(266)] = 24643,
  [SMALL_STATE(267)] = 24691,
  [SMALL_STATE(268)] = 24739,
  [SMALL_STATE(269)] = 24787,
  [SMALL_STATE(270)] = 24835,
  [SMALL_STATE(271)] = 24883,
  [SMALL_STATE(272)] = 24931,
  [SMALL_STATE(273)] = 24979,
  [SMALL_STATE(274)] = 25027,
  [SMALL_STATE(275)] = 25075,
  [SMALL_STATE(276)] = 25123,
  [SMALL_STATE(277)] = 25171,
  [SMALL_STATE(278)] = 25219,
  [SMALL_STATE(279)] = 25267,
  [SMALL_STATE(280)] = 25315,
  [SMALL_STATE(281)] = 25363,
  [SMALL_STATE(282)] = 25411,
  [SMALL_STATE(283)] = 25459,
  [SMALL_STATE(284)] = 25507,
  [SMALL_STATE(285)] = 25555,
  [SMALL_STATE(286)] = 25603,
  [SMALL_STATE(287)] = 25651,
  [SMALL_STATE(288)] = 25699,
  [SMALL_STATE(289)] = 25747,
  [SMALL_STATE(290)] = 25797,
  [SMALL_STATE(291)] = 25845,
  [SMALL_STATE(292)] = 25893,
  [SMALL_STATE(293)] = 25941,
  [SMALL_STATE(294)] = 25991,
  [SMALL_STATE(295)] = 26039,
  [SMALL_STATE(296)] = 26087,
  [SMALL_STATE(297)] = 26135,
  [SMALL_STATE(298)] = 26185,
  [SMALL_STATE(299)] = 26233,
  [SMALL_STATE(300)] = 26281,
  [SMALL_STATE(301)] = 26329,
  [SMALL_STATE(302)] = 26377,
  [SMALL_STATE(303)] = 26425,
  [SMALL_STATE(304)] = 26473,
  [SMALL_STATE(305)] = 26521,
  [SMALL_STATE(306)] = 26569,
  [SMALL_STATE(307)] = 26619,
  [SMALL_STATE(308)] = 26667,
  [SMALL_STATE(309)] = 26715,
  [SMALL_STATE(310)] = 26763,
  [SMALL_STATE(311)] = 26811,
  [SMALL_STATE(312)] = 26859,
  [SMALL_STATE(313)] = 26907,
  [SMALL_STATE(314)] = 26955,
  [SMALL_STATE(315)] = 27003,
  [SMALL_STATE(316)] = 27051,
  [SMALL_STATE(317)] = 27099,
  [SMALL_STATE(318)] = 27147,
  [SMALL_STATE(319)] = 27195,
  [SMALL_STATE(320)] = 27243,
  [SMALL_STATE(321)] = 27291,
  [SMALL_STATE(322)] = 27339,
  [SMALL_STATE(323)] = 27387,
  [SMALL_STATE(324)] = 27435,
  [SMALL_STATE(325)] = 27483,
  [SMALL_STATE(326)] = 27531,
  [SMALL_STATE(327)] = 27581,
  [SMALL_STATE(328)] = 27629,
  [SMALL_STATE(329)] = 27679,
  [SMALL_STATE(330)] = 27727,
  [SMALL_STATE(331)] = 27775,
  [SMALL_STATE(332)] = 27823,
  [SMALL_STATE(333)] = 27871,
  [SMALL_STATE(334)] = 27919,
  [SMALL_STATE(335)] = 27967,
  [SMALL_STATE(336)] = 28015,
  [SMALL_STATE(337)] = 28065,
  [SMALL_STATE(338)] = 28113,
  [SMALL_STATE(339)] = 28161,
  [SMALL_STATE(340)] = 28209,
  [SMALL_STATE(341)] = 28259,
  [SMALL_STATE(342)] = 28307,
  [SMALL_STATE(343)] = 28355,
  [SMALL_STATE(344)] = 28405,
  [SMALL_STATE(345)] = 28453,
  [SMALL_STATE(346)] = 28501,
  [SMALL_STATE(347)] = 28549,
  [SMALL_STATE(348)] = 28597,
  [SMALL_STATE(349)] = 28645,
  [SMALL_STATE(350)] = 28693,
  [SMALL_STATE(351)] = 28741,
  [SMALL_STATE(352)] = 28789,
  [SMALL_STATE(353)] = 28839,
  [SMALL_STATE(354)] = 28887,
  [SMALL_STATE(355)] = 28935,
  [SMALL_STATE(356)] = 28983,
  [SMALL_STATE(357)] = 29031,
  [SMALL_STATE(358)] = 29079,
  [SMALL_STATE(359)] = 29127,
  [SMALL_STATE(360)] = 29175,
  [SMALL_STATE(361)] = 29223,
  [SMALL_STATE(362)] = 29271,
  [SMALL_STATE(363)] = 29321,
  [SMALL_STATE(364)] = 29369,
  [SMALL_STATE(365)] = 29417,
  [SMALL_STATE(366)] = 29465,
  [SMALL_STATE(367)] = 29513,
  [SMALL_STATE(368)] = 29563,
  [SMALL_STATE(369)] = 29611,
  [SMALL_STATE(370)] = 29659,
  [SMALL_STATE(371)] = 29707,
  [SMALL_STATE(372)] = 29755,
  [SMALL_STATE(373)] = 29803,
  [SMALL_STATE(374)] = 29851,
  [SMALL_STATE(375)] = 29899,
  [SMALL_STATE(376)] = 29949,
  [SMALL_STATE(377)] = 29999,
  [SMALL_STATE(378)] = 30047,
  [SMALL_STATE(379)] = 30095,
  [SMALL_STATE(380)] = 30143,
  [SMALL_STATE(381)] = 30191,
  [SMALL_STATE(382)] = 30239,
  [SMALL_STATE(383)] = 30287,
  [SMALL_STATE(384)] = 30335,
  [SMALL_STATE(385)] = 30383,
  [SMALL_STATE(386)] = 30431,
  [SMALL_STATE(387)] = 30479,
  [SMALL_STATE(388)] = 30529,
  [SMALL_STATE(389)] = 30577,
  [SMALL_STATE(390)] = 30625,
  [SMALL_STATE(391)] = 30673,
  [SMALL_STATE(392)] = 30721,
  [SMALL_STATE(393)] = 30769,
  [SMALL_STATE(394)] = 30817,
  [SMALL_STATE(395)] = 30865,
  [SMALL_STATE(396)] = 30913,
  [SMALL_STATE(397)] = 30961,
  [SMALL_STATE(398)] = 31009,
  [SMALL_STATE(399)] = 31057,
  [SMALL_STATE(400)] = 31105,
  [SMALL_STATE(401)] = 31153,
  [SMALL_STATE(402)] = 31201,
  [SMALL_STATE(403)] = 31251,
  [SMALL_STATE(404)] = 31299,
  [SMALL_STATE(405)] = 31347,
  [SMALL_STATE(406)] = 31395,
  [SMALL_STATE(407)] = 31443,
  [SMALL_STATE(408)] = 31491,
  [SMALL_STATE(409)] = 31539,
  [SMALL_STATE(410)] = 31587,
  [SMALL_STATE(411)] = 31635,
  [SMALL_STATE(412)] = 31683,
  [SMALL_STATE(413)] = 31731,
  [SMALL_STATE(414)] = 31779,
  [SMALL_STATE(415)] = 31827,
  [SMALL_STATE(416)] = 31875,
  [SMALL_STATE(417)] = 31923,
  [SMALL_STATE(418)] = 31971,
  [SMALL_STATE(419)] = 32019,
  [SMALL_STATE(420)] = 32067,
  [SMALL_STATE(421)] = 32115,
  [SMALL_STATE(422)] = 32163,
  [SMALL_STATE(423)] = 32211,
  [SMALL_STATE(424)] = 32259,
  [SMALL_STATE(425)] = 32307,
  [SMALL_STATE(426)] = 32355,
  [SMALL_STATE(427)] = 32403,
  [SMALL_STATE(428)] = 32451,
  [SMALL_STATE(429)] = 32499,
  [SMALL_STATE(430)] = 32547,
  [SMALL_STATE(431)] = 32595,
  [SMALL_STATE(432)] = 32643,
  [SMALL_STATE(433)] = 32690,
  [SMALL_STATE(434)] = 32737,
  [SMALL_STATE(435)] = 32784,
  [SMALL_STATE(436)] = 32831,
  [SMALL_STATE(437)] = 32878,
  [SMALL_STATE(438)] = 32925,
  [SMALL_STATE(439)] = 32972,
  [SMALL_STATE(440)] = 33019,
  [SMALL_STATE(441)] = 33066,
  [SMALL_STATE(442)] = 33113,
  [SMALL_STATE(443)] = 33160,
  [SMALL_STATE(444)] = 33207,
  [SMALL_STATE(445)] = 33254,
  [SMALL_STATE(446)] = 33301,
  [SMALL_STATE(447)] = 33348,
  [SMALL_STATE(448)] = 33395,
  [SMALL_STATE(449)] = 33442,
  [SMALL_STATE(450)] = 33489,
  [SMALL_STATE(451)] = 33536,
  [SMALL_STATE(452)] = 33583,
  [SMALL_STATE(453)] = 33630,
  [SMALL_STATE(454)] = 33677,
  [SMALL_STATE(455)] = 33724,
  [SMALL_STATE(456)] = 33771,
  [SMALL_STATE(457)] = 33818,
  [SMALL_STATE(458)] = 33865,
  [SMALL_STATE(459)] = 33912,
  [SMALL_STATE(460)] = 33959,
  [SMALL_STATE(461)] = 34006,
  [SMALL_STATE(462)] = 34053,
  [SMALL_STATE(463)] = 34100,
  [SMALL_STATE(464)] = 34147,
  [SMALL_STATE(465)] = 34239,
  [SMALL_STATE(466)] = 34315,
  [SMALL_STATE(467)] = 34393,
  [SMALL_STATE(468)] = 34475,
  [SMALL_STATE(469)] = 34549,
  [SMALL_STATE(470)] = 34619,
  [SMALL_STATE(471)] = 34685,
  [SMALL_STATE(472)] = 34749,
  [SMALL_STATE(473)] = 34811,
  [SMALL_STATE(474)] = 34871,
  [SMALL_STATE(475)] = 34937,
  [SMALL_STATE(476)] = 34997,
  [SMALL_STATE(477)] = 35079,
  [SMALL_STATE(478)] = 35160,
  [SMALL_STATE(479)] = 35253,
  [SMALL_STATE(480)] = 35346,
  [SMALL_STATE(481)] = 35439,
  [SMALL_STATE(482)] = 35524,
  [SMALL_STATE(483)] = 35617,
  [SMALL_STATE(484)] = 35710,
  [SMALL_STATE(485)] = 35786,
  [SMALL_STATE(486)] = 35876,
  [SMALL_STATE(487)] = 35952,
  [SMALL_STATE(488)] = 36028,
  [SMALL_STATE(489)] = 36112,
  [SMALL_STATE(490)] = 36188,
  [SMALL_STATE(491)] = 36272,
  [SMALL_STATE(492)] = 36362,
  [SMALL_STATE(493)] = 36438,
  [SMALL_STATE(494)] = 36522,
  [SMALL_STATE(495)] = 36612,
  [SMALL_STATE(496)] = 36702,
  [SMALL_STATE(497)] = 36792,
  [SMALL_STATE(498)] = 36882,
  [SMALL_STATE(499)] = 36966,
  [SMALL_STATE(500)] = 37056,
  [SMALL_STATE(501)] = 37132,
  [SMALL_STATE(502)] = 37220,
  [SMALL_STATE(503)] = 37307,
  [SMALL_STATE(504)] = 37394,
  [SMALL_STATE(505)] = 37481,
  [SMALL_STATE(506)] = 37568,
  [SMALL_STATE(507)] = 37655,
  [SMALL_STATE(508)] = 37742,
  [SMALL_STATE(509)] = 37829,
  [SMALL_STATE(510)] = 37916,
  [SMALL_STATE(511)] = 38003,
  [SMALL_STATE(512)] = 38090,
  [SMALL_STATE(513)] = 38177,
  [SMALL_STATE(514)] = 38264,
  [SMALL_STATE(515)] = 38351,
  [SMALL_STATE(516)] = 38438,
  [SMALL_STATE(517)] = 38525,
  [SMALL_STATE(518)] = 38612,
  [SMALL_STATE(519)] = 38666,
  [SMALL_STATE(520)] = 38734,
  [SMALL_STATE(521)] = 38810,
  [SMALL_STATE(522)] = 38880,
  [SMALL_STATE(523)] = 38944,
  [SMALL_STATE(524)] = 39028,
  [SMALL_STATE(525)] = 39088,
  [SMALL_STATE(526)] = 39160,
  [SMALL_STATE(527)] = 39244,
  [SMALL_STATE(528)] = 39302,
  [SMALL_STATE(529)] = 39358,
  [SMALL_STATE(530)] = 39418,
  [SMALL_STATE(531)] = 39494,
  [SMALL_STATE(532)] = 39548,
  [SMALL_STATE(533)] = 39620,
  [SMALL_STATE(534)] = 39679,
  [SMALL_STATE(535)] = 39750,
  [SMALL_STATE(536)] = 39831,
  [SMALL_STATE(537)] = 39912,
  [SMALL_STATE(538)] = 39993,
  [SMALL_STATE(539)] = 40046,
  [SMALL_STATE(540)] = 40115,
  [SMALL_STATE(541)] = 40190,
  [SMALL_STATE(542)] = 40257,
  [SMALL_STATE(543)] = 40310,
  [SMALL_STATE(544)] = 40373,
  [SMALL_STATE(545)] = 40432,
  [SMALL_STATE(546)] = 40507,
  [SMALL_STATE(547)] = 40566,
  [SMALL_STATE(548)] = 40623,
  [SMALL_STATE(549)] = 40698,
  [SMALL_STATE(550)] = 40753,
  [SMALL_STATE(551)] = 40806,
  [SMALL_STATE(552)] = 40865,
  [SMALL_STATE(553)] = 40918,
  [SMALL_STATE(554)] = 40993,
  [SMALL_STATE(555)] = 41052,
  [SMALL_STATE(556)] = 41105,
  [SMALL_STATE(557)] = 41164,
  [SMALL_STATE(558)] = 41239,
  [SMALL_STATE(559)] = 41314,
  [SMALL_STATE(560)] = 41367,
  [SMALL_STATE(561)] = 41420,
  [SMALL_STATE(562)] = 41475,
  [SMALL_STATE(563)] = 41532,
  [SMALL_STATE(564)] = 41587,
  [SMALL_STATE(565)] = 41644,
  [SMALL_STATE(566)] = 41703,
  [SMALL_STATE(567)] = 41766,
  [SMALL_STATE(568)] = 41819,
  [SMALL_STATE(569)] = 41886,
  [SMALL_STATE(570)] = 41955,
  [SMALL_STATE(571)] = 42010,
  [SMALL_STATE(572)] = 42081,
  [SMALL_STATE(573)] = 42140,
  [SMALL_STATE(574)] = 42197,
  [SMALL_STATE(575)] = 42260,
  [SMALL_STATE(576)] = 42327,
  [SMALL_STATE(577)] = 42396,
  [SMALL_STATE(578)] = 42459,
  [SMALL_STATE(579)] = 42530,
  [SMALL_STATE(580)] = 42597,
  [SMALL_STATE(581)] = 42678,
  [SMALL_STATE(582)] = 42753,
  [SMALL_STATE(583)] = 42828,
  [SMALL_STATE(584)] = 42897,
  [SMALL_STATE(585)] = 42968,
  [SMALL_STATE(586)] = 43004,
  [SMALL_STATE(587)] = 43040,
  [SMALL_STATE(588)] = 43076,
  [SMALL_STATE(589)] = 43112,
  [SMALL_STATE(590)] = 43148,
  [SMALL_STATE(591)] = 43184,
  [SMALL_STATE(592)] = 43220,
  [SMALL_STATE(593)] = 43296,
  [SMALL_STATE(594)] = 43372,
  [SMALL_STATE(595)] = 43408,
  [SMALL_STATE(596)] = 43476,
  [SMALL_STATE(597)] = 43544,
  [SMALL_STATE(598)] = 43614,
  [SMALL_STATE(599)] = 43682,
  [SMALL_STATE(600)] = 43747,
  [SMALL_STATE(601)] = 43812,
  [SMALL_STATE(602)] = 43877,
  [SMALL_STATE(603)] = 43942,
  [SMALL_STATE(604)] = 44007,
  [SMALL_STATE(605)] = 44072,
  [SMALL_STATE(606)] = 44137,
  [SMALL_STATE(607)] = 44170,
  [SMALL_STATE(608)] = 44202,
  [SMALL_STATE(609)] = 44234,
  [SMALL_STATE(610)] = 44296,
  [SMALL_STATE(611)] = 44358,
  [SMALL_STATE(612)] = 44420,
  [SMALL_STATE(613)] = 44484,
  [SMALL_STATE(614)] = 44516,
  [SMALL_STATE(615)] = 44578,
  [SMALL_STATE(616)] = 44610,
  [SMALL_STATE(617)] = 44672,
  [SMALL_STATE(618)] = 44734,
  [SMALL_STATE(619)] = 44796,
  [SMALL_STATE(620)] = 44828,
  [SMALL_STATE(621)] = 44860,
  [SMALL_STATE(622)] = 44892,
  [SMALL_STATE(623)] = 44924,
  [SMALL_STATE(624)] = 44986,
  [SMALL_STATE(625)] = 45042,
  [SMALL_STATE(626)] = 45098,
  [SMALL_STATE(627)] = 45126,
  [SMALL_STATE(628)] = 45154,
  [SMALL_STATE(629)] = 45182,
  [SMALL_STATE(630)] = 45206,
  [SMALL_STATE(631)] = 45230,
  [SMALL_STATE(632)] = 45254,
  [SMALL_STATE(633)] = 45278,
  [SMALL_STATE(634)] = 45302,
  [SMALL_STATE(635)] = 45327,
  [SMALL_STATE(636)] = 45374,
  [SMALL_STATE(637)] = 45421,
  [SMALL_STATE(638)] = 45468,
  [SMALL_STATE(639)] = 45515,
  [SMALL_STATE(640)] = 45562,
  [SMALL_STATE(641)] = 45609,
  [SMALL_STATE(642)] = 45656,
  [SMALL_STATE(643)] = 45679,
  [SMALL_STATE(644)] = 45701,
  [SMALL_STATE(645)] = 45745,
  [SMALL_STATE(646)] = 45789,
  [SMALL_STATE(647)] = 45811,
  [SMALL_STATE(648)] = 45855,
  [SMALL_STATE(649)] = 45877,
  [SMALL_STATE(650)] = 45921,
  [SMALL_STATE(651)] = 45965,
  [SMALL_STATE(652)] = 45987,
  [SMALL_STATE(653)] = 46009,
  [SMALL_STATE(654)] = 46031,
  [SMALL_STATE(655)] = 46053,
  [SMALL_STATE(656)] = 46075,
  [SMALL_STATE(657)] = 46119,
  [SMALL_STATE(658)] = 46141,
  [SMALL_STATE(659)] = 46163,
  [SMALL_STATE(660)] = 46185,
  [SMALL_STATE(661)] = 46207,
  [SMALL_STATE(662)] = 46229,
  [SMALL_STATE(663)] = 46251,
  [SMALL_STATE(664)] = 46273,
  [SMALL_STATE(665)] = 46295,
  [SMALL_STATE(666)] = 46317,
  [SMALL_STATE(667)] = 46339,
  [SMALL_STATE(668)] = 46361,
  [SMALL_STATE(669)] = 46383,
  [SMALL_STATE(670)] = 46405,
  [SMALL_STATE(671)] = 46427,
  [SMALL_STATE(672)] = 46449,
  [SMALL_STATE(673)] = 46471,
  [SMALL_STATE(674)] = 46493,
  [SMALL_STATE(675)] = 46515,
  [SMALL_STATE(676)] = 46559,
  [SMALL_STATE(677)] = 46581,
  [SMALL_STATE(678)] = 46602,
  [SMALL_STATE(679)] = 46623,
  [SMALL_STATE(680)] = 46644,
  [SMALL_STATE(681)] = 46665,
  [SMALL_STATE(682)] = 46702,
  [SMALL_STATE(683)] = 46723,
  [SMALL_STATE(684)] = 46749,
  [SMALL_STATE(685)] = 46775,
  [SMALL_STATE(686)] = 46794,
  [SMALL_STATE(687)] = 46813,
  [SMALL_STATE(688)] = 46832,
  [SMALL_STATE(689)] = 46851,
  [SMALL_STATE(690)] = 46870,
  [SMALL_STATE(691)] = 46889,
  [SMALL_STATE(692)] = 46915,
  [SMALL_STATE(693)] = 46933,
  [SMALL_STATE(694)] = 46959,
  [SMALL_STATE(695)] = 46985,
  [SMALL_STATE(696)] = 47003,
  [SMALL_STATE(697)] = 47029,
  [SMALL_STATE(698)] = 47055,
  [SMALL_STATE(699)] = 47081,
  [SMALL_STATE(700)] = 47099,
  [SMALL_STATE(701)] = 47125,
  [SMALL_STATE(702)] = 47143,
  [SMALL_STATE(703)] = 47161,
  [SMALL_STATE(704)] = 47181,
  [SMALL_STATE(705)] = 47199,
  [SMALL_STATE(706)] = 47225,
  [SMALL_STATE(707)] = 47243,
  [SMALL_STATE(708)] = 47269,
  [SMALL_STATE(709)] = 47287,
  [SMALL_STATE(710)] = 47313,
  [SMALL_STATE(711)] = 47333,
  [SMALL_STATE(712)] = 47351,
  [SMALL_STATE(713)] = 47369,
  [SMALL_STATE(714)] = 47399,
  [SMALL_STATE(715)] = 47417,
  [SMALL_STATE(716)] = 47443,
  [SMALL_STATE(717)] = 47461,
  [SMALL_STATE(718)] = 47487,
  [SMALL_STATE(719)] = 47513,
  [SMALL_STATE(720)] = 47531,
  [SMALL_STATE(721)] = 47557,
  [SMALL_STATE(722)] = 47583,
  [SMALL_STATE(723)] = 47610,
  [SMALL_STATE(724)] = 47637,
  [SMALL_STATE(725)] = 47656,
  [SMALL_STATE(726)] = 47675,
  [SMALL_STATE(727)] = 47702,
  [SMALL_STATE(728)] = 47719,
  [SMALL_STATE(729)] = 47746,
  [SMALL_STATE(730)] = 47773,
  [SMALL_STATE(731)] = 47800,
  [SMALL_STATE(732)] = 47825,
  [SMALL_STATE(733)] = 47852,
  [SMALL_STATE(734)] = 47879,
  [SMALL_STATE(735)] = 47906,
  [SMALL_STATE(736)] = 47933,
  [SMALL_STATE(737)] = 47960,
  [SMALL_STATE(738)] = 47987,
  [SMALL_STATE(739)] = 48004,
  [SMALL_STATE(740)] = 48023,
  [SMALL_STATE(741)] = 48050,
  [SMALL_STATE(742)] = 48067,
  [SMALL_STATE(743)] = 48094,
  [SMALL_STATE(744)] = 48113,
  [SMALL_STATE(745)] = 48140,
  [SMALL_STATE(746)] = 48162,
  [SMALL_STATE(747)] = 48184,
  [SMALL_STATE(748)] = 48202,
  [SMALL_STATE(749)] = 48218,
  [SMALL_STATE(750)] = 48234,
  [SMALL_STATE(751)] = 48256,
  [SMALL_STATE(752)] = 48272,
  [SMALL_STATE(753)] = 48288,
  [SMALL_STATE(754)] = 48316,
  [SMALL_STATE(755)] = 48332,
  [SMALL_STATE(756)] = 48354,
  [SMALL_STATE(757)] = 48376,
  [SMALL_STATE(758)] = 48398,
  [SMALL_STATE(759)] = 48420,
  [SMALL_STATE(760)] = 48436,
  [SMALL_STATE(761)] = 48458,
  [SMALL_STATE(762)] = 48480,
  [SMALL_STATE(763)] = 48502,
  [SMALL_STATE(764)] = 48518,
  [SMALL_STATE(765)] = 48546,
  [SMALL_STATE(766)] = 48568,
  [SMALL_STATE(767)] = 48596,
  [SMALL_STATE(768)] = 48612,
  [SMALL_STATE(769)] = 48630,
  [SMALL_STATE(770)] = 48652,
  [SMALL_STATE(771)] = 48674,
  [SMALL_STATE(772)] = 48696,
  [SMALL_STATE(773)] = 48714,
  [SMALL_STATE(774)] = 48742,
  [SMALL_STATE(775)] = 48760,
  [SMALL_STATE(776)] = 48782,
  [SMALL_STATE(777)] = 48810,
  [SMALL_STATE(778)] = 48838,
  [SMALL_STATE(779)] = 48854,
  [SMALL_STATE(780)] = 48876,
  [SMALL_STATE(781)] = 48898,
  [SMALL_STATE(782)] = 48920,
  [SMALL_STATE(783)] = 48942,
  [SMALL_STATE(784)] = 48970,
  [SMALL_STATE(785)] = 48993,
  [SMALL_STATE(786)] = 49016,
  [SMALL_STATE(787)] = 49039,
  [SMALL_STATE(788)] = 49052,
  [SMALL_STATE(789)] = 49075,
  [SMALL_STATE(790)] = 49098,
  [SMALL_STATE(791)] = 49121,
  [SMALL_STATE(792)] = 49144,
  [SMALL_STATE(793)] = 49167,
  [SMALL_STATE(794)] = 49190,
  [SMALL_STATE(795)] = 49213,
  [SMALL_STATE(796)] = 49236,
  [SMALL_STATE(797)] = 49259,
  [SMALL_STATE(798)] = 49282,
  [SMALL_STATE(799)] = 49305,
  [SMALL_STATE(800)] = 49328,
  [SMALL_STATE(801)] = 49351,
  [SMALL_STATE(802)] = 49374,
  [SMALL_STATE(803)] = 49397,
  [SMALL_STATE(804)] = 49420,
  [SMALL_STATE(805)] = 49433,
  [SMALL_STATE(806)] = 49456,
  [SMALL_STATE(807)] = 49479,
  [SMALL_STATE(808)] = 49502,
  [SMALL_STATE(809)] = 49525,
  [SMALL_STATE(810)] = 49548,
  [SMALL_STATE(811)] = 49571,
  [SMALL_STATE(812)] = 49594,
  [SMALL_STATE(813)] = 49617,
  [SMALL_STATE(814)] = 49640,
  [SMALL_STATE(815)] = 49663,
  [SMALL_STATE(816)] = 49686,
  [SMALL_STATE(817)] = 49709,
  [SMALL_STATE(818)] = 49732,
  [SMALL_STATE(819)] = 49755,
  [SMALL_STATE(820)] = 49778,
  [SMALL_STATE(821)] = 49801,
  [SMALL_STATE(822)] = 49824,
  [SMALL_STATE(823)] = 49847,
  [SMALL_STATE(824)] = 49870,
  [SMALL_STATE(825)] = 49893,
  [SMALL_STATE(826)] = 49916,
  [SMALL_STATE(827)] = 49930,
  [SMALL_STATE(828)] = 49952,
  [SMALL_STATE(829)] = 49966,
  [SMALL_STATE(830)] = 49986,
  [SMALL_STATE(831)] = 50006,
  [SMALL_STATE(832)] = 50026,
  [SMALL_STATE(833)] = 50040,
  [SMALL_STATE(834)] = 50062,
  [SMALL_STATE(835)] = 50082,
  [SMALL_STATE(836)] = 50102,
  [SMALL_STATE(837)] = 50124,
  [SMALL_STATE(838)] = 50144,
  [SMALL_STATE(839)] = 50164,
  [SMALL_STATE(840)] = 50176,
  [SMALL_STATE(841)] = 50194,
  [SMALL_STATE(842)] = 50216,
  [SMALL_STATE(843)] = 50236,
  [SMALL_STATE(844)] = 50258,
  [SMALL_STATE(845)] = 50276,
  [SMALL_STATE(846)] = 50293,
  [SMALL_STATE(847)] = 50310,
  [SMALL_STATE(848)] = 50323,
  [SMALL_STATE(849)] = 50340,
  [SMALL_STATE(850)] = 50357,
  [SMALL_STATE(851)] = 50374,
  [SMALL_STATE(852)] = 50391,
  [SMALL_STATE(853)] = 50408,
  [SMALL_STATE(854)] = 50421,
  [SMALL_STATE(855)] = 50438,
  [SMALL_STATE(856)] = 50451,
  [SMALL_STATE(857)] = 50468,
  [SMALL_STATE(858)] = 50485,
  [SMALL_STATE(859)] = 50498,
  [SMALL_STATE(860)] = 50511,
  [SMALL_STATE(861)] = 50523,
  [SMALL_STATE(862)] = 50539,
  [SMALL_STATE(863)] = 50549,
  [SMALL_STATE(864)] = 50559,
  [SMALL_STATE(865)] = 50575,
  [SMALL_STATE(866)] = 50587,
  [SMALL_STATE(867)] = 50597,
  [SMALL_STATE(868)] = 50607,
  [SMALL_STATE(869)] = 50621,
  [SMALL_STATE(870)] = 50631,
  [SMALL_STATE(871)] = 50641,
  [SMALL_STATE(872)] = 50651,
  [SMALL_STATE(873)] = 50667,
  [SMALL_STATE(874)] = 50677,
  [SMALL_STATE(875)] = 50687,
  [SMALL_STATE(876)] = 50697,
  [SMALL_STATE(877)] = 50713,
  [SMALL_STATE(878)] = 50723,
  [SMALL_STATE(879)] = 50733,
  [SMALL_STATE(880)] = 50749,
  [SMALL_STATE(881)] = 50759,
  [SMALL_STATE(882)] = 50775,
  [SMALL_STATE(883)] = 50785,
  [SMALL_STATE(884)] = 50795,
  [SMALL_STATE(885)] = 50805,
  [SMALL_STATE(886)] = 50815,
  [SMALL_STATE(887)] = 50831,
  [SMALL_STATE(888)] = 50841,
  [SMALL_STATE(889)] = 50853,
  [SMALL_STATE(890)] = 50867,
  [SMALL_STATE(891)] = 50877,
  [SMALL_STATE(892)] = 50887,
  [SMALL_STATE(893)] = 50899,
  [SMALL_STATE(894)] = 50909,
  [SMALL_STATE(895)] = 50925,
  [SMALL_STATE(896)] = 50935,
  [SMALL_STATE(897)] = 50945,
  [SMALL_STATE(898)] = 50961,
  [SMALL_STATE(899)] = 50977,
  [SMALL_STATE(900)] = 50987,
  [SMALL_STATE(901)] = 50997,
  [SMALL_STATE(902)] = 51013,
  [SMALL_STATE(903)] = 51023,
  [SMALL_STATE(904)] = 51039,
  [SMALL_STATE(905)] = 51055,
  [SMALL_STATE(906)] = 51065,
  [SMALL_STATE(907)] = 51081,
  [SMALL_STATE(908)] = 51094,
  [SMALL_STATE(909)] = 51107,
  [SMALL_STATE(910)] = 51120,
  [SMALL_STATE(911)] = 51133,
  [SMALL_STATE(912)] = 51146,
  [SMALL_STATE(913)] = 51159,
  [SMALL_STATE(914)] = 51172,
  [SMALL_STATE(915)] = 51185,
  [SMALL_STATE(916)] = 51198,
  [SMALL_STATE(917)] = 51209,
  [SMALL_STATE(918)] = 51218,
  [SMALL_STATE(919)] = 51231,
  [SMALL_STATE(920)] = 51244,
  [SMALL_STATE(921)] = 51253,
  [SMALL_STATE(922)] = 51266,
  [SMALL_STATE(923)] = 51279,
  [SMALL_STATE(924)] = 51292,
  [SMALL_STATE(925)] = 51305,
  [SMALL_STATE(926)] = 51314,
  [SMALL_STATE(927)] = 51325,
  [SMALL_STATE(928)] = 51338,
  [SMALL_STATE(929)] = 51347,
  [SMALL_STATE(930)] = 51358,
  [SMALL_STATE(931)] = 51371,
  [SMALL_STATE(932)] = 51380,
  [SMALL_STATE(933)] = 51391,
  [SMALL_STATE(934)] = 51404,
  [SMALL_STATE(935)] = 51417,
  [SMALL_STATE(936)] = 51428,
  [SMALL_STATE(937)] = 51441,
  [SMALL_STATE(938)] = 51452,
  [SMALL_STATE(939)] = 51465,
  [SMALL_STATE(940)] = 51478,
  [SMALL_STATE(941)] = 51491,
  [SMALL_STATE(942)] = 51502,
  [SMALL_STATE(943)] = 51515,
  [SMALL_STATE(944)] = 51528,
  [SMALL_STATE(945)] = 51539,
  [SMALL_STATE(946)] = 51552,
  [SMALL_STATE(947)] = 51563,
  [SMALL_STATE(948)] = 51574,
  [SMALL_STATE(949)] = 51587,
  [SMALL_STATE(950)] = 51598,
  [SMALL_STATE(951)] = 51611,
  [SMALL_STATE(952)] = 51624,
  [SMALL_STATE(953)] = 51637,
  [SMALL_STATE(954)] = 51648,
  [SMALL_STATE(955)] = 51661,
  [SMALL_STATE(956)] = 51670,
  [SMALL_STATE(957)] = 51683,
  [SMALL_STATE(958)] = 51696,
  [SMALL_STATE(959)] = 51709,
  [SMALL_STATE(960)] = 51722,
  [SMALL_STATE(961)] = 51733,
  [SMALL_STATE(962)] = 51744,
  [SMALL_STATE(963)] = 51753,
  [SMALL_STATE(964)] = 51766,
  [SMALL_STATE(965)] = 51777,
  [SMALL_STATE(966)] = 51790,
  [SMALL_STATE(967)] = 51801,
  [SMALL_STATE(968)] = 51812,
  [SMALL_STATE(969)] = 51825,
  [SMALL_STATE(970)] = 51836,
  [SMALL_STATE(971)] = 51849,
  [SMALL_STATE(972)] = 51860,
  [SMALL_STATE(973)] = 51873,
  [SMALL_STATE(974)] = 51882,
  [SMALL_STATE(975)] = 51893,
  [SMALL_STATE(976)] = 51902,
  [SMALL_STATE(977)] = 51915,
  [SMALL_STATE(978)] = 51926,
  [SMALL_STATE(979)] = 51935,
  [SMALL_STATE(980)] = 51948,
  [SMALL_STATE(981)] = 51961,
  [SMALL_STATE(982)] = 51972,
  [SMALL_STATE(983)] = 51983,
  [SMALL_STATE(984)] = 51996,
  [SMALL_STATE(985)] = 52007,
  [SMALL_STATE(986)] = 52018,
  [SMALL_STATE(987)] = 52027,
  [SMALL_STATE(988)] = 52036,
  [SMALL_STATE(989)] = 52047,
  [SMALL_STATE(990)] = 52058,
  [SMALL_STATE(991)] = 52069,
  [SMALL_STATE(992)] = 52080,
  [SMALL_STATE(993)] = 52089,
  [SMALL_STATE(994)] = 52100,
  [SMALL_STATE(995)] = 52113,
  [SMALL_STATE(996)] = 52126,
  [SMALL_STATE(997)] = 52139,
  [SMALL_STATE(998)] = 52152,
  [SMALL_STATE(999)] = 52161,
  [SMALL_STATE(1000)] = 52170,
  [SMALL_STATE(1001)] = 52181,
  [SMALL_STATE(1002)] = 52194,
  [SMALL_STATE(1003)] = 52204,
  [SMALL_STATE(1004)] = 52214,
  [SMALL_STATE(1005)] = 52222,
  [SMALL_STATE(1006)] = 52230,
  [SMALL_STATE(1007)] = 52238,
  [SMALL_STATE(1008)] = 52246,
  [SMALL_STATE(1009)] = 52256,
  [SMALL_STATE(1010)] = 52264,
  [SMALL_STATE(1011)] = 52274,
  [SMALL_STATE(1012)] = 52282,
  [SMALL_STATE(1013)] = 52290,
  [SMALL_STATE(1014)] = 52300,
  [SMALL_STATE(1015)] = 52310,
  [SMALL_STATE(1016)] = 52320,
  [SMALL_STATE(1017)] = 52328,
  [SMALL_STATE(1018)] = 52336,
  [SMALL_STATE(1019)] = 52346,
  [SMALL_STATE(1020)] = 52354,
  [SMALL_STATE(1021)] = 52364,
  [SMALL_STATE(1022)] = 52374,
  [SMALL_STATE(1023)] = 52384,
  [SMALL_STATE(1024)] = 52392,
  [SMALL_STATE(1025)] = 52402,
  [SMALL_STATE(1026)] = 52410,
  [SMALL_STATE(1027)] = 52420,
  [SMALL_STATE(1028)] = 52428,
  [SMALL_STATE(1029)] = 52438,
  [SMALL_STATE(1030)] = 52446,
  [SMALL_STATE(1031)] = 52456,
  [SMALL_STATE(1032)] = 52466,
  [SMALL_STATE(1033)] = 52474,
  [SMALL_STATE(1034)] = 52484,
  [SMALL_STATE(1035)] = 52494,
  [SMALL_STATE(1036)] = 52504,
  [SMALL_STATE(1037)] = 52514,
  [SMALL_STATE(1038)] = 52524,
  [SMALL_STATE(1039)] = 52532,
  [SMALL_STATE(1040)] = 52542,
  [SMALL_STATE(1041)] = 52552,
  [SMALL_STATE(1042)] = 52560,
  [SMALL_STATE(1043)] = 52568,
  [SMALL_STATE(1044)] = 52578,
  [SMALL_STATE(1045)] = 52586,
  [SMALL_STATE(1046)] = 52596,
  [SMALL_STATE(1047)] = 52604,
  [SMALL_STATE(1048)] = 52612,
  [SMALL_STATE(1049)] = 52619,
  [SMALL_STATE(1050)] = 52626,
  [SMALL_STATE(1051)] = 52633,
  [SMALL_STATE(1052)] = 52640,
  [SMALL_STATE(1053)] = 52647,
  [SMALL_STATE(1054)] = 52654,
  [SMALL_STATE(1055)] = 52661,
  [SMALL_STATE(1056)] = 52668,
  [SMALL_STATE(1057)] = 52675,
  [SMALL_STATE(1058)] = 52682,
  [SMALL_STATE(1059)] = 52689,
  [SMALL_STATE(1060)] = 52696,
  [SMALL_STATE(1061)] = 52703,
  [SMALL_STATE(1062)] = 52710,
  [SMALL_STATE(1063)] = 52717,
  [SMALL_STATE(1064)] = 52724,
  [SMALL_STATE(1065)] = 52731,
  [SMALL_STATE(1066)] = 52738,
  [SMALL_STATE(1067)] = 52745,
  [SMALL_STATE(1068)] = 52752,
  [SMALL_STATE(1069)] = 52759,
  [SMALL_STATE(1070)] = 52766,
  [SMALL_STATE(1071)] = 52773,
  [SMALL_STATE(1072)] = 52780,
  [SMALL_STATE(1073)] = 52787,
  [SMALL_STATE(1074)] = 52794,
  [SMALL_STATE(1075)] = 52801,
  [SMALL_STATE(1076)] = 52808,
  [SMALL_STATE(1077)] = 52815,
  [SMALL_STATE(1078)] = 52822,
  [SMALL_STATE(1079)] = 52829,
  [SMALL_STATE(1080)] = 52836,
  [SMALL_STATE(1081)] = 52843,
  [SMALL_STATE(1082)] = 52850,
  [SMALL_STATE(1083)] = 52857,
  [SMALL_STATE(1084)] = 52864,
  [SMALL_STATE(1085)] = 52871,
  [SMALL_STATE(1086)] = 52878,
  [SMALL_STATE(1087)] = 52885,
  [SMALL_STATE(1088)] = 52892,
  [SMALL_STATE(1089)] = 52899,
  [SMALL_STATE(1090)] = 52906,
  [SMALL_STATE(1091)] = 52913,
  [SMALL_STATE(1092)] = 52920,
  [SMALL_STATE(1093)] = 52927,
  [SMALL_STATE(1094)] = 52934,
  [SMALL_STATE(1095)] = 52941,
  [SMALL_STATE(1096)] = 52948,
  [SMALL_STATE(1097)] = 52955,
  [SMALL_STATE(1098)] = 52962,
  [SMALL_STATE(1099)] = 52969,
  [SMALL_STATE(1100)] = 52976,
  [SMALL_STATE(1101)] = 52983,
  [SMALL_STATE(1102)] = 52990,
  [SMALL_STATE(1103)] = 52997,
  [SMALL_STATE(1104)] = 53004,
  [SMALL_STATE(1105)] = 53011,
  [SMALL_STATE(1106)] = 53018,
  [SMALL_STATE(1107)] = 53025,
  [SMALL_STATE(1108)] = 53032,
  [SMALL_STATE(1109)] = 53039,
  [SMALL_STATE(1110)] = 53046,
  [SMALL_STATE(1111)] = 53053,
  [SMALL_STATE(1112)] = 53060,
  [SMALL_STATE(1113)] = 53067,
  [SMALL_STATE(1114)] = 53074,
  [SMALL_STATE(1115)] = 53081,
  [SMALL_STATE(1116)] = 53088,
  [SMALL_STATE(1117)] = 53095,
  [SMALL_STATE(1118)] = 53102,
  [SMALL_STATE(1119)] = 53109,
  [SMALL_STATE(1120)] = 53116,
  [SMALL_STATE(1121)] = 53123,
  [SMALL_STATE(1122)] = 53130,
  [SMALL_STATE(1123)] = 53137,
  [SMALL_STATE(1124)] = 53144,
  [SMALL_STATE(1125)] = 53151,
  [SMALL_STATE(1126)] = 53158,
  [SMALL_STATE(1127)] = 53165,
  [SMALL_STATE(1128)] = 53172,
  [SMALL_STATE(1129)] = 53179,
  [SMALL_STATE(1130)] = 53186,
  [SMALL_STATE(1131)] = 53193,
  [SMALL_STATE(1132)] = 53200,
  [SMALL_STATE(1133)] = 53207,
  [SMALL_STATE(1134)] = 53214,
  [SMALL_STATE(1135)] = 53221,
  [SMALL_STATE(1136)] = 53228,
  [SMALL_STATE(1137)] = 53235,
  [SMALL_STATE(1138)] = 53242,
  [SMALL_STATE(1139)] = 53249,
  [SMALL_STATE(1140)] = 53256,
  [SMALL_STATE(1141)] = 53263,
  [SMALL_STATE(1142)] = 53270,
  [SMALL_STATE(1143)] = 53277,
  [SMALL_STATE(1144)] = 53284,
  [SMALL_STATE(1145)] = 53291,
  [SMALL_STATE(1146)] = 53298,
  [SMALL_STATE(1147)] = 53305,
  [SMALL_STATE(1148)] = 53312,
  [SMALL_STATE(1149)] = 53319,
  [SMALL_STATE(1150)] = 53326,
  [SMALL_STATE(1151)] = 53333,
  [SMALL_STATE(1152)] = 53340,
  [SMALL_STATE(1153)] = 53347,
  [SMALL_STATE(1154)] = 53354,
  [SMALL_STATE(1155)] = 53361,
  [SMALL_STATE(1156)] = 53368,
  [SMALL_STATE(1157)] = 53375,
  [SMALL_STATE(1158)] = 53382,
  [SMALL_STATE(1159)] = 53389,
  [SMALL_STATE(1160)] = 53396,
  [SMALL_STATE(1161)] = 53403,
  [SMALL_STATE(1162)] = 53410,
  [SMALL_STATE(1163)] = 53417,
  [SMALL_STATE(1164)] = 53424,
  [SMALL_STATE(1165)] = 53431,
  [SMALL_STATE(1166)] = 53438,
  [SMALL_STATE(1167)] = 53445,
  [SMALL_STATE(1168)] = 53452,
  [SMALL_STATE(1169)] = 53459,
  [SMALL_STATE(1170)] = 53466,
  [SMALL_STATE(1171)] = 53473,
  [SMALL_STATE(1172)] = 53480,
  [SMALL_STATE(1173)] = 53487,
  [SMALL_STATE(1174)] = 53494,
  [SMALL_STATE(1175)] = 53501,
  [SMALL_STATE(1176)] = 53508,
  [SMALL_STATE(1177)] = 53515,
  [SMALL_STATE(1178)] = 53522,
  [SMALL_STATE(1179)] = 53529,
  [SMALL_STATE(1180)] = 53536,
  [SMALL_STATE(1181)] = 53543,
  [SMALL_STATE(1182)] = 53550,
  [SMALL_STATE(1183)] = 53557,
  [SMALL_STATE(1184)] = 53564,
  [SMALL_STATE(1185)] = 53571,
  [SMALL_STATE(1186)] = 53578,
  [SMALL_STATE(1187)] = 53585,
  [SMALL_STATE(1188)] = 53592,
  [SMALL_STATE(1189)] = 53599,
  [SMALL_STATE(1190)] = 53606,
  [SMALL_STATE(1191)] = 53613,
  [SMALL_STATE(1192)] = 53620,
  [SMALL_STATE(1193)] = 53627,
  [SMALL_STATE(1194)] = 53634,
  [SMALL_STATE(1195)] = 53641,
  [SMALL_STATE(1196)] = 53648,
  [SMALL_STATE(1197)] = 53655,
  [SMALL_STATE(1198)] = 53662,
  [SMALL_STATE(1199)] = 53669,
  [SMALL_STATE(1200)] = 53676,
  [SMALL_STATE(1201)] = 53683,
  [SMALL_STATE(1202)] = 53690,
  [SMALL_STATE(1203)] = 53697,
  [SMALL_STATE(1204)] = 53704,
  [SMALL_STATE(1205)] = 53711,
  [SMALL_STATE(1206)] = 53718,
  [SMALL_STATE(1207)] = 53725,
  [SMALL_STATE(1208)] = 53732,
  [SMALL_STATE(1209)] = 53739,
  [SMALL_STATE(1210)] = 53746,
  [SMALL_STATE(1211)] = 53753,
  [SMALL_STATE(1212)] = 53760,
  [SMALL_STATE(1213)] = 53767,
  [SMALL_STATE(1214)] = 53774,
  [SMALL_STATE(1215)] = 53781,
  [SMALL_STATE(1216)] = 53788,
  [SMALL_STATE(1217)] = 53795,
  [SMALL_STATE(1218)] = 53802,
  [SMALL_STATE(1219)] = 53809,
  [SMALL_STATE(1220)] = 53816,
  [SMALL_STATE(1221)] = 53823,
  [SMALL_STATE(1222)] = 53830,
  [SMALL_STATE(1223)] = 53837,
  [SMALL_STATE(1224)] = 53844,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(266),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(480),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(611),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1199),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(55),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1014),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(980),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(486),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(274),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(275),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(279),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1164),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(98),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(610),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1144),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1022),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1221),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(945),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(484),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(128),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(127),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(124),
  [85] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [87] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1204),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(606),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1203),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1201),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_atom, 1, 0, 0),
  [119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_atom, 1, 0, 0),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1147),
  [123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_expr, 1, 0, 0),
  [125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_expr, 1, 0, 0),
  [127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(331),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(616),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1127),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(58),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1028),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(918),
  [203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(492),
  [205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(334),
  [207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(335),
  [213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(268),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1130),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(282),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(609),
  [235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1186),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(45),
  [241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1015),
  [243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(908),
  [245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(500),
  [247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(281),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11),
  [253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(374),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(288),
  [273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(618),
  [277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1158),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(66),
  [283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1021),
  [285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(927),
  [287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(489),
  [289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(283),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
  [295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(273),
  [297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(263),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(614),
  [319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(71),
  [325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1018),
  [327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(983),
  [329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(487),
  [331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(262),
  [333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
  [337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(226),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(667),
  [355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1066),
  [357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(921),
  [359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1038),
  [361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(992),
  [363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1138),
  [365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(972),
  [367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1025),
  [369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_tag, 1, 0, 0),
  [371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_tag, 1, 0, 0),
  [373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_enum_tag, 3, 0, 0),
  [375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_enum_tag, 3, 0, 0),
  [377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_enum_tag, 2, 0, 0),
  [379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_enum_tag, 2, 0, 0),
  [381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_applicative, 1, 0, 0),
  [383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_applicative, 1, 0, 0),
  [385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(842),
  [387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_atom, 4, 0, 36),
  [389] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_atom, 4, 0, 36),
  [391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_atom, 4, 0, 41),
  [393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_atom, 4, 0, 41),
  [395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_atom, 5, 0, 53),
  [397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_atom, 5, 0, 53),
  [399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_uni_record, 5, 0, 54),
  [401] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_uni_record, 5, 0, 54),
  [403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_uni_record, 5, 0, 56),
  [405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_uni_record, 5, 0, 56),
  [407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_atom, 4, 0, 40),
  [409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_atom, 4, 0, 40),
  [411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_atom, 5, 0, 57),
  [413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_atom, 5, 0, 57),
  [415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_atom, 5, 0, 58),
  [417] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_atom, 5, 0, 58),
  [419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_uni_record, 6, 0, 64),
  [421] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_uni_record, 6, 0, 64),
  [423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_atom, 6, 0, 66),
  [425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_atom, 6, 0, 66),
  [427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_uni_record, 4, 0, 38),
  [429] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_uni_record, 4, 0, 38),
  [431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_uni_record, 4, 0, 36),
  [433] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_uni_record, 4, 0, 36),
  [435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_operation_chain, 3, 0, 23),
  [437] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_operation_chain, 3, 0, 23),
  [439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_str_chunks, 1, 0, 0),
  [441] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_str_chunks, 1, 0, 0),
  [443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_operation_chain, 3, 0, 22),
  [445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_operation_chain, 3, 0, 22),
  [447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_atom, 3, 0, 21),
  [449] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_atom, 3, 0, 21),
  [451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_builtin, 3, 0, 0),
  [453] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_builtin, 3, 0, 0),
  [455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_str_chunks_multi, 2, 0, 1),
  [457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_str_chunks_multi, 2, 0, 1),
  [459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_str_chunks_single, 2, 0, 0),
  [461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_str_chunks_single, 2, 0, 0),
  [463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_atom, 3, 0, 20),
  [465] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_atom, 3, 0, 20),
  [467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_atom, 3, 0, 0),
  [469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_atom, 3, 0, 0),
  [471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_uni_record, 3, 0, 19),
  [473] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_uni_record, 3, 0, 19),
  [475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_uni_record, 3, 0, 17),
  [477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_uni_record, 3, 0, 17),
  [479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_str_chunks_multi, 3, 0, 11),
  [481] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_str_chunks_multi, 3, 0, 11),
  [483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_variant, 2, 0, 8),
  [485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_variant, 2, 0, 8),
  [487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_str_chunks_single, 3, 0, 12),
  [489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_str_chunks_single, 3, 0, 12),
  [491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_applicative, 2, 0, 7),
  [493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_applicative, 2, 0, 7),
  [495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_atom, 2, 0, 0),
  [497] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_atom, 2, 0, 0),
  [499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_atom, 2, 0, 0),
  [501] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_atom, 2, 0, 0),
  [503] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_array, 2, 0, 0),
  [505] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_array, 2, 0, 0),
  [507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bool, 1, 0, 0),
  [509] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bool, 1, 0, 0),
  [511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_uni_record, 2, 0, 0),
  [513] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_uni_record, 2, 0, 0),
  [515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_operand, 1, 0, 0),
  [517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_operand, 1, 0, 0),
  [519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_atom, 1, 0, 0),
  [521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_atom, 1, 0, 0),
  [523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_builtin, 1, 0, 0),
  [525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_builtin, 1, 0, 0),
  [527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_applicative, 2, 0, 4),
  [529] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_applicative, 2, 0, 4),
  [531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_static_string, 3, 0, 0),
  [533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_static_string, 3, 0, 0),
  [535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_expr, 3, 0, 0),
  [537] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_expr, 3, 0, 0),
  [539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_expr, 5, 0, 52),
  [541] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_expr, 5, 0, 52),
  [543] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_static_string, 2, 0, 0),
  [545] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_static_string, 2, 0, 0),
  [547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_expr, 6, 0, 63),
  [549] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_expr, 6, 0, 63),
  [551] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_expr, 4, 0, 35),
  [553] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_expr, 4, 0, 35),
  [555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_b_op_4, 1, 0, 0),
  [557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_u_op_or_lazy_b_op, 1, 0, 0),
  [559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(834),
  [561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(829),
  [563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(837),
  [565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(831),
  [567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(838),
  [569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(79),
  [571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_uni_term, 1, 0, 0),
  [575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_uni_term, 1, 0, 0),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(620),
  [583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(607),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(619),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_expr, 3, 0, 25),
  [601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_expr, 3, 0, 25),
  [603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_expr, 2, 0, 5),
  [605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_expr, 2, 0, 5),
  [607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_types, 1, 0, 0),
  [609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_types, 1, 0, 0),
  [611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(882),
  [615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 1, 0, 0),
  [619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(884),
  [623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15),
  [627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(887),
  [629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(678),
  [631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(768),
  [645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(706),
  [653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(485),
  [671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(587),
  [675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(74),
  [677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(591),
  [689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(75),
  [691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(78),
  [697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(889),
  [703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(80),
  [713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1148),
  [719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [743] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(706),
  [746] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(768),
  [749] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(627),
  [752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(833),
  [755] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(596),
  [758] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(706),
  [761] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(483),
  [764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0),
  [766] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(725),
  [769] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(678),
  [772] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(745),
  [775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(807),
  [778] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(797),
  [781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(585),
  [785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(586),
  [797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(590),
  [801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(594),
  [811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(703),
  [815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_pattern, 1, 0, 0),
  [817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(741),
  [821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_pattern_parens, 1, 0, 0),
  [823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_in_block, 5, 0, 44),
  [825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_in_block, 5, 0, 44),
  [827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_in_block, 4, 0, 32),
  [829] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_in_block, 4, 0, 32),
  [831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_in_block, 2, 0, 0),
  [833] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_in_block, 2, 0, 0),
  [835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_in_block, 4, 0, 28),
  [837] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_in_block, 4, 0, 28),
  [839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_in_block, 3, 0, 13),
  [841] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_in_block, 3, 0, 13),
  [843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_in_block, 6, 0, 59),
  [845] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_in_block, 6, 0, 59),
  [847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_in_block, 3, 0, 0),
  [849] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_in_block, 3, 0, 0),
  [851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(739),
  [853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_in_block, 5, 0, 49),
  [855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_in_block, 5, 0, 49),
  [857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(711),
  [859] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_pattern, 1, 0, 0),
  [861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(634),
  [865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(669),
  [875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(653),
  [879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(661),
  [881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [895] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fun_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(669),
  [898] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_fun_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(634),
  [901] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fun_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(660),
  [904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_fun_expr_repeat1, 2, 0, 0),
  [906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fun_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(841),
  [909] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fun_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(598),
  [912] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_fun_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(669),
  [915] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fun_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(479),
  [918] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_fun_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(653),
  [921] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_fun_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(661),
  [924] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fun_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(782),
  [927] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fun_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(788),
  [930] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fun_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(799),
  [933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_u_op_5, 1, 0, 0),
  [937] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_u_op_5, 1, 0, 0),
  [939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_b_op_6, 1, 0, 0),
  [941] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_b_op_6, 1, 0, 0),
  [943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_b_op_8, 1, 0, 0),
  [945] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_b_op_8, 1, 0, 0),
  [947] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_lazy_b_op_10, 1, 0, 0),
  [949] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_lazy_b_op_10, 1, 0, 0),
  [951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_lazy_b_op_9, 1, 0, 0),
  [953] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_lazy_b_op_9, 1, 0, 0),
  [955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_b_op_7, 1, 0, 0),
  [957] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_b_op_7, 1, 0, 0),
  [959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_b_op_4, 1, 0, 0),
  [961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_b_op_2, 1, 0, 0),
  [963] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_b_op_2, 1, 0, 0),
  [965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_b_op_3, 1, 0, 0),
  [967] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_b_op_3, 1, 0, 0),
  [969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_or_pattern_unparens_repeat1, 2, 0, 0), SHIFT_REPEAT(706),
  [972] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_or_pattern_unparens_repeat1, 2, 0, 0), SHIFT_REPEAT(711),
  [975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_or_pattern_unparens_repeat1, 2, 0, 0), SHIFT_REPEAT(680),
  [978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_or_pattern_unparens_repeat1, 2, 0, 0), SHIFT_REPEAT(833),
  [981] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_or_pattern_unparens_repeat1, 2, 0, 0), SHIFT_REPEAT(595),
  [984] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_or_pattern_unparens_repeat1, 2, 0, 0), SHIFT_REPEAT(706),
  [987] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_or_pattern_unparens_repeat1, 2, 0, 0), SHIFT_REPEAT(483),
  [990] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_or_pattern_unparens_repeat1, 2, 0, 0), SHIFT_REPEAT(678),
  [993] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_or_pattern_unparens_repeat1, 2, 0, 0), SHIFT_REPEAT(745),
  [996] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_or_pattern_unparens_repeat1, 2, 0, 0), SHIFT_REPEAT(807),
  [999] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_or_pattern_unparens_repeat1, 2, 0, 0), SHIFT_REPEAT(796),
  [1002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [1004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(672),
  [1006] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_fun, 1, 0, 2),
  [1008] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_fun, 1, 0, 2),
  [1010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [1014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [1018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [1020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1006),
  [1022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [1024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [1026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1044),
  [1028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [1030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [1032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1007),
  [1034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [1038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1011),
  [1040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [1044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [1046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [1048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [1050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1012),
  [1052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [1054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [1056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1005),
  [1058] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_array_pattern_repeat1, 2, 0, 0),
  [1060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annot_atom, 3, 0, 42),
  [1062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annot_atom, 3, 0, 42),
  [1064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [1066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [1068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [1070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [1076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annot_atom, 2, 0, 24),
  [1078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annot_atom, 2, 0, 24),
  [1080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [1084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [1086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [1088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 3, 0, 17),
  [1090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 3, 0, 17),
  [1092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 4, 0, 48),
  [1094] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_pattern, 4, 0, 48),
  [1096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annot_atom, 3, 0, 43),
  [1098] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annot_atom, 3, 0, 43),
  [1100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [1102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [1104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annot_atom, 3, 0, 0),
  [1106] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annot_atom, 3, 0, 0),
  [1108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_forall, 4, 0, 39),
  [1110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_forall, 4, 0, 39),
  [1112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 2, 0, 0),
  [1114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 2, 0, 0),
  [1116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_pattern_parens, 1, 0, 0),
  [1118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 3, 0, 31),
  [1120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 3, 0, 31),
  [1122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annot_atom, 2, 0, 0),
  [1124] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annot_atom, 2, 0, 0),
  [1126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or_pattern_parens, 3, 0, 0),
  [1128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_or_pattern_parens, 3, 0, 0),
  [1130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constant_pattern, 1, 0, 0),
  [1132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constant_pattern, 1, 0, 0),
  [1134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 3, 0, 17),
  [1136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_pattern, 3, 0, 17),
  [1138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 3, 0, 31),
  [1140] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_pattern, 3, 0, 31),
  [1142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_fun, 3, 0, 27),
  [1144] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_fun, 3, 0, 27),
  [1146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_pattern, 2, 0, 0),
  [1148] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_pattern, 2, 0, 0),
  [1150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_pattern_parens, 3, 0, 0),
  [1152] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_pattern_parens, 3, 0, 0),
  [1154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [1156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [1158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 4, 0, 48),
  [1160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 4, 0, 48),
  [1162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_or_pattern_unparens_repeat1, 2, 0, 0),
  [1164] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_or_pattern_unparens_repeat1, 2, 0, 0),
  [1166] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_uni_record_repeat1, 2, 0, 0), SHIFT_REPEAT(804),
  [1169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_uni_record_repeat1, 2, 0, 0),
  [1171] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_uni_record_repeat1, 2, 0, 0), SHIFT_REPEAT(697),
  [1174] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_uni_record_repeat1, 2, 0, 0), SHIFT_REPEAT(735),
  [1177] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0), SHIFT_REPEAT(79),
  [1180] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0), SHIFT_REPEAT(139),
  [1183] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0),
  [1185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0),
  [1187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [1189] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annot, 1, 0, 10),
  [1191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annot, 1, 0, 10),
  [1193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_expr, 2, 0, 6),
  [1195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_expr, 2, 0, 6),
  [1197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotated_infix_expr, 2, 0, 9),
  [1199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotated_infix_expr, 2, 0, 9),
  [1201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fun_expr, 4, 0, 34),
  [1203] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fun_expr, 4, 0, 34),
  [1205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_term, 1, 0, 0),
  [1207] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_term, 1, 0, 0),
  [1209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ite_expr, 6, 0, 65),
  [1211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ite_expr, 6, 0, 65),
  [1213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(828),
  [1215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(832),
  [1217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [1219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [1223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [1225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [1227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [1229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [1231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [1233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [1235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [1237] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_str_chunks_multi_repeat1, 2, 0, 0), SHIFT_REPEAT(828),
  [1240] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_str_chunks_multi_repeat1, 2, 0, 0), SHIFT_REPEAT(832),
  [1243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_str_chunks_multi_repeat1, 2, 0, 0),
  [1245] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_str_chunks_multi_repeat1, 2, 0, 0), SHIFT_REPEAT(44),
  [1248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [1250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or_pattern_unparens, 2, 0, 16),
  [1252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_or_pattern_unparens, 2, 0, 16),
  [1254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [1256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_or_branch, 1, 0, 0),
  [1258] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_or_branch, 1, 0, 0),
  [1260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [1262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 1, 0, 14),
  [1264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [1266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [1268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [1270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [1272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [1276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(853),
  [1278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [1280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(847),
  [1282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [1284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [1286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1288] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or_pattern, 1, 0, 0),
  [1290] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_or_pattern, 1, 0, 0),
  [1292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern, 1, 0, 2),
  [1294] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern, 1, 0, 2),
  [1296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [1298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_variant_pattern, 2, 0, 15),
  [1300] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_variant_pattern, 2, 0, 15),
  [1302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [1304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [1306] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_str_chunks_single_repeat1, 2, 0, 0), SHIFT_REPEAT(853),
  [1309] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_str_chunks_single_repeat1, 2, 0, 0), SHIFT_REPEAT(847),
  [1312] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_str_chunks_single_repeat1, 2, 0, 0), SHIFT_REPEAT(847),
  [1315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_str_chunks_single_repeat1, 2, 0, 0),
  [1317] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_str_chunks_single_repeat1, 2, 0, 0), SHIFT_REPEAT(40),
  [1320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [1322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_field, 1, 0, 3),
  [1324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [1326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [1328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [1332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [1334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [1336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern, 3, 0, 27),
  [1338] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern, 3, 0, 27),
  [1340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [1342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [1344] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_pattern, 3, 0, 0),
  [1346] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_pattern, 3, 0, 0),
  [1348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [1350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(858),
  [1352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(855),
  [1354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [1356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [1358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_path, 2, 0, 0),
  [1360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [1362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [1364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1191),
  [1366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [1368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [1370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [1372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [1374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [1376] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_static_string_repeat2, 2, 0, 0), SHIFT_REPEAT(858),
  [1379] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_static_string_repeat2, 2, 0, 0), SHIFT_REPEAT(855),
  [1382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_static_string_repeat2, 2, 0, 0),
  [1384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [1386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [1388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1163),
  [1390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [1392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [1394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [1396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [1398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [1400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [1402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [1404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [1406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_path, 1, 0, 0),
  [1408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [1410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [1412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_path_repeat1, 2, 0, 0),
  [1414] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_path_repeat1, 2, 0, 0), SHIFT_REPEAT(800),
  [1417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [1419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [1421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [1423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1135),
  [1425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [1427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [1429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [1431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [1433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [1435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [1437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [1439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(860),
  [1441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [1443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(892),
  [1445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [1447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [1449] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_static_string_repeat1, 2, 0, 0), SHIFT_REPEAT(860),
  [1452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_static_string_repeat1, 2, 0, 0), SHIFT_REPEAT(892),
  [1455] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_static_string_repeat1, 2, 0, 0), SHIFT_REPEAT(892),
  [1458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_static_string_repeat1, 2, 0, 0),
  [1460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [1462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(651),
  [1464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [1466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [1468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [1470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [1472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_path_elem, 1, 0, 0),
  [1476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [1478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [1480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [1482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [1488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [1490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [1492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [1494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [1496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [1498] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_chunk_expr, 3, 0, 26),
  [1500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk_expr, 3, 0, 26),
  [1502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [1504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [1506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [1508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_percent, 1, 0, 0),
  [1510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_percent, 1, 0, 0),
  [1512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [1514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [1516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [1518] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_chunk_literal_multi, 1, 0, 0),
  [1520] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk_literal_multi, 1, 0, 0),
  [1522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [1524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [1526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [1528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [1530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0), SHIFT_REPEAT(74),
  [1535] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0), SHIFT_REPEAT(137),
  [1538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [1540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [1542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [1544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [1546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [1548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0), SHIFT_REPEAT(75),
  [1551] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0), SHIFT_REPEAT(155),
  [1554] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_chunk_literal_single, 1, 0, 0),
  [1556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk_literal_single, 1, 0, 0),
  [1558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [1560] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0), SHIFT_REPEAT(76),
  [1563] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0), SHIFT_REPEAT(130),
  [1566] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0), SHIFT_REPEAT(78),
  [1569] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0), SHIFT_REPEAT(129),
  [1572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [1574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [1576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 2, 0, 29),
  [1578] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(713),
  [1581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_pattern_repeat1, 2, 0, 0),
  [1583] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0), SHIFT_REPEAT(80),
  [1586] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annot_repeat1, 2, 0, 0), SHIFT_REPEAT(136),
  [1589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [1593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [1595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [1597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [1599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [1601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [1603] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_atom_repeat1, 2, 0, 0), SHIFT_REPEAT(836),
  [1606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_atom_repeat1, 2, 0, 0),
  [1608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [1610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [1612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [1614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [1616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [1618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [1620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [1622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [1624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1154),
  [1626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [1628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [1630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_field, 2, 0, 18),
  [1632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [1634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [1636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [1638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [1640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [1642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1156),
  [1644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [1646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1157),
  [1648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [1652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [1654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [1656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [1660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [1662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [1664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [1666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [1668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [1670] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_forall_repeat1, 2, 0, 0), SHIFT_REPEAT(909),
  [1673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_forall_repeat1, 2, 0, 0),
  [1675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [1677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [1679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [1681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [1683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [1685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [1687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [1689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [1691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1099),
  [1693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(762),
  [1695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [1697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [1699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_field, 4, 0, 55),
  [1701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [1703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [1705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [1707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [1709] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_match_expr_repeat1, 2, 0, 0), SHIFT_REPEAT(523),
  [1712] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_match_expr_repeat1, 2, 0, 0),
  [1714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [1716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [1718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [1720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [1722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [1724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [1726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [1728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [1730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [1734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [1736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [1738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [1740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [1742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_last_field, 1, 0, 0),
  [1744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [1746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [1748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [1750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [1752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [1754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [1756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [1758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [1760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [1762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [1764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [1768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [1770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [1772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [1774] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_atom_repeat1, 2, 0, 0), SHIFT_REPEAT(61),
  [1777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_atom_repeat1, 2, 0, 0),
  [1779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [1781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [1783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [1785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [1787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 2, 0, 30),
  [1789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [1791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [1793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [1795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [1797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [1799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [1801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 3, 0, 47),
  [1803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [1805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [1807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [1809] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_in_block_repeat1, 2, 0, 0), SHIFT_REPEAT(526),
  [1812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_let_in_block_repeat1, 2, 0, 0),
  [1814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [1816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [1818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [1820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [1822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [1824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [1826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [1828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [1830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [1832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [1834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_annot, 2, 0, 46),
  [1836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_field, 3, 0, 37),
  [1838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [1840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [1842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [1844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_elem_pat, 1, 0, 0),
  [1846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [1848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [1850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [1852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [1854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [1856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [1858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [1860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [1862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [1864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [1866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [1868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [1870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [1872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [1874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [1876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [1878] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 3, 0, 33),
  [1880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [1882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [1884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [1886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [1888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 3, 0, 45),
  [1890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [1892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [1894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [1896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [1898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_field_pat, 1, 0, 0),
  [1900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 4, 0, 50),
  [1902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [1904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_branch, 3, 0, 51),
  [1906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [1908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [1910] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 4, 0, 61),
  [1912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [1914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [1916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [1918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [1920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [1922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [1924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [1926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [1928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [1930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [1932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [1934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [1936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [1938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [1940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [1942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 4, 0, 60),
  [1944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [1948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [1950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [1952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [1954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 5, 0, 67),
  [1956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_branch, 4, 0, 62),
  [1958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [1960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [1962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [1964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [1966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [1968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_field_pat, 2, 0, 0),
  [1970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [1972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [1974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [1976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [1978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [1980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [1982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [1984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [1986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [1988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [1990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1160),
  [1992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [1994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [1996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [1998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [2000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [2002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [2004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [2006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [2008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [2010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [2012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [2014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [2016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [2018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [2020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [2022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [2024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [2026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [2028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [2030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [2032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [2034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [2036] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row_tail, 1, 0, 0),
  [2038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [2040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [2042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [2044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [2046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [2048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [2050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [2052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [2054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_guard, 2, 0, 0),
  [2056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [2058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [2060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [2062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [2064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_elem_pat, 2, 0, 0),
  [2066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [2068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [2070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [2072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [2074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [2076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [2078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [2080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [2082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(654),
  [2084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(676),
  [2086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [2088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [2090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [2092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [2094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [2096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [2098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [2100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [2102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [2104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [2106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [2108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [2110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [2112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [2114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [2116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [2118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [2120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [2122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [2124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [2126] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [2130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(670),
  [2132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [2134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [2136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [2138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [2140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [2142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [2144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [2146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [2148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [2150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [2152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [2154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1179),
  [2156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [2158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [2160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1159),
  [2162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [2164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [2166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [2168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [2170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [2172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [2174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [2176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [2178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [2180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [2182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [2184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_op, 1, 0, 0),
  [2186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [2188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [2190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_b_op, 1, 0, 0),
  [2192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [2194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [2196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [2198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [2200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [2202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [2204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [2206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [2208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [2210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [2212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [2214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [2216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [2218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [2220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [2222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [2224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [2226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [2228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [2232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [2234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_curried_op, 1, 0, 0),
  [2236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [2238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [2240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_multstr_start = 0,
  ts_external_token_multstr_end = 1,
  ts_external_token__str_start = 2,
  ts_external_token__str_end = 3,
  ts_external_token_interpolation_start = 4,
  ts_external_token_interpolation_end = 5,
  ts_external_token_quoted_enum_tag_start = 6,
  ts_external_token_comment = 7,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_multstr_start] = sym_multstr_start,
  [ts_external_token_multstr_end] = sym_multstr_end,
  [ts_external_token__str_start] = sym__str_start,
  [ts_external_token__str_end] = sym__str_end,
  [ts_external_token_interpolation_start] = sym_interpolation_start,
  [ts_external_token_interpolation_end] = sym_interpolation_end,
  [ts_external_token_quoted_enum_tag_start] = sym_quoted_enum_tag_start,
  [ts_external_token_comment] = sym_comment,
};

static const bool ts_external_scanner_states[12][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_multstr_start] = true,
    [ts_external_token_multstr_end] = true,
    [ts_external_token__str_start] = true,
    [ts_external_token__str_end] = true,
    [ts_external_token_interpolation_start] = true,
    [ts_external_token_interpolation_end] = true,
    [ts_external_token_quoted_enum_tag_start] = true,
    [ts_external_token_comment] = true,
  },
  [2] = {
    [ts_external_token_multstr_start] = true,
    [ts_external_token__str_start] = true,
    [ts_external_token_quoted_enum_tag_start] = true,
    [ts_external_token_comment] = true,
  },
  [3] = {
    [ts_external_token_multstr_start] = true,
    [ts_external_token__str_start] = true,
    [ts_external_token_interpolation_end] = true,
    [ts_external_token_quoted_enum_tag_start] = true,
    [ts_external_token_comment] = true,
  },
  [4] = {
    [ts_external_token_comment] = true,
  },
  [5] = {
    [ts_external_token_interpolation_end] = true,
    [ts_external_token_comment] = true,
  },
  [6] = {
    [ts_external_token_multstr_start] = true,
    [ts_external_token__str_start] = true,
    [ts_external_token_comment] = true,
  },
  [7] = {
    [ts_external_token_multstr_end] = true,
    [ts_external_token_interpolation_start] = true,
    [ts_external_token_comment] = true,
  },
  [8] = {
    [ts_external_token__str_end] = true,
    [ts_external_token_interpolation_start] = true,
    [ts_external_token_comment] = true,
  },
  [9] = {
    [ts_external_token_multstr_end] = true,
    [ts_external_token_comment] = true,
  },
  [10] = {
    [ts_external_token_quoted_enum_tag_start] = true,
    [ts_external_token_comment] = true,
  },
  [11] = {
    [ts_external_token__str_end] = true,
    [ts_external_token_comment] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_nickel_external_scanner_create(void);
void tree_sitter_nickel_external_scanner_destroy(void *);
bool tree_sitter_nickel_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_nickel_external_scanner_serialize(void *, char *);
void tree_sitter_nickel_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_nickel(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_keyword,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_nickel_external_scanner_create,
      tree_sitter_nickel_external_scanner_destroy,
      tree_sitter_nickel_external_scanner_scan,
      tree_sitter_nickel_external_scanner_serialize,
      tree_sitter_nickel_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
