#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1674
#define LARGE_STATE_COUNT 510
#define SYMBOL_COUNT 273
#define ALIAS_COUNT 0
#define TOKEN_COUNT 130
#define EXTERNAL_TOKEN_COUNT 3
#define FIELD_COUNT 37
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define PRODUCTION_ID_COUNT 143

enum ts_symbol_identifiers {
  sym_identifier = 1,
  anon_sym_LPAREN = 2,
  anon_sym_RPAREN = 3,
  anon_sym_BANG = 4,
  anon_sym_TILDE = 5,
  anon_sym_DASH = 6,
  anon_sym_PLUS = 7,
  anon_sym_AMP = 8,
  anon_sym_DOT_DOT_DOT = 9,
  anon_sym_STAR = 10,
  anon_sym_SLASH = 11,
  anon_sym_PERCENT = 12,
  anon_sym_PIPE_PIPE = 13,
  anon_sym_AMP_AMP = 14,
  anon_sym_PIPE = 15,
  anon_sym_CARET = 16,
  anon_sym_EQ_EQ = 17,
  anon_sym_BANG_EQ = 18,
  anon_sym_GT = 19,
  anon_sym_GT_EQ = 20,
  anon_sym_LT_EQ = 21,
  anon_sym_LT = 22,
  anon_sym_LT_LT = 23,
  anon_sym_GT_GT = 24,
  anon_sym_GT_GT_GT = 25,
  anon_sym_POUNDinclude = 26,
  anon_sym_POUNDtryinclude = 27,
  anon_sym_POUNDdefine = 28,
  anon_sym_COMMA = 29,
  sym_macro_param = 30,
  anon_sym_POUNDundef = 31,
  anon_sym_POUNDif = 32,
  anon_sym_POUNDelseif = 33,
  anon_sym_POUNDassert = 34,
  anon_sym_defined = 35,
  sym_preproc_else = 36,
  sym_preproc_endif = 37,
  sym_preproc_endinput = 38,
  anon_sym_POUNDpragma = 39,
  anon_sym_POUNDerror = 40,
  anon_sym_POUNDwarning = 41,
  anon_sym_using__intrinsics__DOTHandle = 42,
  anon_sym_assert = 43,
  anon_sym_static_assert = 44,
  anon_sym_EQ = 45,
  anon_sym_forward = 46,
  anon_sym_native = 47,
  sym_alias_operator = 48,
  anon_sym_operator = 49,
  anon_sym_COLON = 50,
  anon_sym_const = 51,
  anon_sym_public = 52,
  anon_sym_stock = 53,
  anon_sym_static = 54,
  anon_sym_new = 55,
  anon_sym_decl = 56,
  anon_sym_enum = 57,
  anon_sym_PLUS_EQ = 58,
  anon_sym_DASH_EQ = 59,
  anon_sym_STAR_EQ = 60,
  anon_sym_SLASH_EQ = 61,
  anon_sym_PIPE_EQ = 62,
  anon_sym_AMP_EQ = 63,
  anon_sym_CARET_EQ = 64,
  anon_sym_TILDE_EQ = 65,
  anon_sym_LT_LT_EQ = 66,
  anon_sym_GT_GT_EQ = 67,
  anon_sym_LBRACE = 68,
  anon_sym_RBRACE = 69,
  anon_sym_struct = 70,
  anon_sym_typedef = 71,
  anon_sym_typeset = 72,
  anon_sym_function = 73,
  anon_sym_funcenum = 74,
  anon_sym_functag = 75,
  anon_sym_methodmap = 76,
  anon_sym___nullable__ = 77,
  anon_sym_property = 78,
  anon_sym_get = 79,
  anon_sym_set = 80,
  anon_sym_LBRACK = 81,
  anon_sym_RBRACK = 82,
  anon_sym_void = 83,
  anon_sym_bool = 84,
  anon_sym_int = 85,
  anon_sym_float = 86,
  anon_sym_char = 87,
  anon_sym__ = 88,
  anon_sym_Float = 89,
  anon_sym_String = 90,
  sym_any_type = 91,
  anon_sym_for = 92,
  anon_sym_while = 93,
  anon_sym_do = 94,
  anon_sym_break = 95,
  anon_sym_continue = 96,
  anon_sym_if = 97,
  anon_sym_else = 98,
  anon_sym_switch = 99,
  anon_sym_case = 100,
  anon_sym_COLON2 = 101,
  anon_sym_default = 102,
  anon_sym_return = 103,
  anon_sym_delete = 104,
  anon_sym_SEMI = 105,
  anon_sym_GT_GT_GT_EQ = 106,
  anon_sym_PERCENT_EQ = 107,
  anon_sym_DOT = 108,
  anon_sym_QMARK = 109,
  anon_sym_COLON_COLON = 110,
  anon_sym_DASH_DASH = 111,
  anon_sym_PLUS_PLUS = 112,
  anon_sym_sizeof = 113,
  anon_sym_view_as = 114,
  sym_int_literal = 115,
  sym_float_literal = 116,
  anon_sym_SQUOTE = 117,
  aux_sym_char_literal_token1 = 118,
  anon_sym_DQUOTE = 119,
  aux_sym_string_literal_token1 = 120,
  sym_escape_sequence = 121,
  sym_bool_literal = 122,
  sym_null = 123,
  sym_this = 124,
  sym_system_lib_string = 125,
  sym_comment = 126,
  sym__automatic_semicolon = 127,
  sym__ternary_colon = 128,
  sym_preproc_arg = 129,
  sym_source_file = 130,
  sym__preproc_expression = 131,
  sym_preproc_parenthesized_expression = 132,
  sym_preproc_unary_expression = 133,
  sym_preproc_binary_expression = 134,
  sym_preproc_include = 135,
  sym_preproc_tryinclude = 136,
  sym_preproc_macro = 137,
  sym_preproc_define = 138,
  sym_preproc_undefine = 139,
  sym_preproc_if = 140,
  sym_preproc_elseif = 141,
  sym_preproc_assert = 142,
  sym_preproc_defined_condition = 143,
  sym_preproc_pragma = 144,
  sym_preproc_error = 145,
  sym_preproc_warning = 146,
  sym_hardcoded_symbol = 147,
  sym_assertion = 148,
  sym_function_definition = 149,
  sym_function_declaration = 150,
  sym_function_declaration_kind = 151,
  sym_parameter_declarations = 152,
  sym_parameter_declaration = 153,
  sym_rest_parameter = 154,
  sym_alias_declaration = 155,
  sym_alias_assignment = 156,
  sym_global_variable_declaration = 157,
  sym_variable_declaration_statement = 158,
  sym_variable_storage_class = 159,
  sym_visibility = 160,
  sym_variable_declaration = 161,
  sym_dynamic_array_declaration = 162,
  sym_dynamic_array = 163,
  sym_new_expression = 164,
  sym_old_global_variable_declaration = 165,
  sym_old_variable_declaration_statement = 166,
  sym_old_for_loop_variable_declaration_statement = 167,
  sym_old_variable_declaration = 168,
  sym_enum = 169,
  sym_enum_entries = 170,
  sym_enum_entry = 171,
  sym_enum_struct = 172,
  sym_enum_struct_field = 173,
  sym_enum_struct_method = 174,
  sym_typedef = 175,
  sym_typeset = 176,
  sym_typedef_expression = 177,
  sym_funcenum = 178,
  sym_funcenum_member = 179,
  sym_functag = 180,
  sym_methodmap = 181,
  sym_methodmap_alias = 182,
  sym_methodmap_native = 183,
  sym_methodmap_native_constructor = 184,
  sym_methodmap_native_destructor = 185,
  sym_methodmap_method = 186,
  sym_methodmap_method_constructor = 187,
  sym_methodmap_method_destructor = 188,
  sym_methodmap_property = 189,
  sym_methodmap_property_alias = 190,
  sym_methodmap_property_native = 191,
  sym_methodmap_property_method = 192,
  sym_methodmap_property_getter = 193,
  sym_methodmap_property_setter = 194,
  sym_struct = 195,
  sym_struct_field = 196,
  sym_struct_declaration = 197,
  sym_struct_constructor = 198,
  sym_struct_field_value = 199,
  sym_type = 200,
  sym_array_type = 201,
  sym_old_type = 202,
  sym_dimension = 203,
  sym_fixed_dimension = 204,
  sym_builtin_type = 205,
  sym_old_builtin_type = 206,
  sym_block = 207,
  sym_for_statement = 208,
  sym_while_statement = 209,
  sym_do_while_statement = 210,
  sym_break_statement = 211,
  sym_continue_statement = 212,
  sym_condition_statement = 213,
  sym_switch_statement = 214,
  sym_switch_case = 215,
  sym_expression_statement = 216,
  sym_return_statement = 217,
  sym_delete_statement = 218,
  sym__manual_semicolon = 219,
  sym__semicolon = 220,
  sym__expression = 221,
  sym__case_expression = 222,
  sym_assignment_expression = 223,
  sym_call_expression = 224,
  sym_call_arguments = 225,
  sym_named_arg = 226,
  sym_ignore_argument = 227,
  sym_array_indexed_access = 228,
  sym_parenthesized_expression = 229,
  sym_comma_expression = 230,
  sym_ternary_expression = 231,
  sym_field_access = 232,
  sym_scope_access = 233,
  sym_unary_expression = 234,
  sym_case_unary_expression = 235,
  sym_binary_expression = 236,
  sym_case_binary_expression = 237,
  sym_update_expression = 238,
  sym__sizeof_call_expression = 239,
  sym_array_scope_access = 240,
  sym_sizeof_expression = 241,
  sym_view_as = 242,
  sym_old_type_cast = 243,
  sym_array_literal = 244,
  sym__literal = 245,
  sym_char_literal = 246,
  sym_string_literal = 247,
  sym_rest_operator = 248,
  aux_sym_source_file_repeat1 = 249,
  aux_sym_preproc_macro_repeat1 = 250,
  aux_sym_function_definition_repeat1 = 251,
  aux_sym_parameter_declarations_repeat1 = 252,
  aux_sym_parameter_declaration_repeat1 = 253,
  aux_sym_global_variable_declaration_repeat1 = 254,
  aux_sym_variable_declaration_statement_repeat1 = 255,
  aux_sym_dynamic_array_repeat1 = 256,
  aux_sym_old_global_variable_declaration_repeat1 = 257,
  aux_sym_enum_entries_repeat1 = 258,
  aux_sym_enum_struct_repeat1 = 259,
  aux_sym_typeset_repeat1 = 260,
  aux_sym_funcenum_repeat1 = 261,
  aux_sym_methodmap_repeat1 = 262,
  aux_sym_methodmap_property_repeat1 = 263,
  aux_sym_struct_repeat1 = 264,
  aux_sym_struct_constructor_repeat1 = 265,
  aux_sym_block_repeat1 = 266,
  aux_sym_for_statement_repeat1 = 267,
  aux_sym_switch_statement_repeat1 = 268,
  aux_sym_switch_case_repeat1 = 269,
  aux_sym_call_arguments_repeat1 = 270,
  aux_sym_array_literal_repeat1 = 271,
  aux_sym_string_literal_repeat1 = 272,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_BANG] = "!",
  [anon_sym_TILDE] = "~",
  [anon_sym_DASH] = "-",
  [anon_sym_PLUS] = "+",
  [anon_sym_AMP] = "&",
  [anon_sym_DOT_DOT_DOT] = "...",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE] = "|",
  [anon_sym_CARET] = "^",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_LT] = "<",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_GT_GT_GT] = ">>>",
  [anon_sym_POUNDinclude] = "#include",
  [anon_sym_POUNDtryinclude] = "#tryinclude",
  [anon_sym_POUNDdefine] = "#define",
  [anon_sym_COMMA] = ",",
  [sym_macro_param] = "macro_param",
  [anon_sym_POUNDundef] = "#undef",
  [anon_sym_POUNDif] = "#if",
  [anon_sym_POUNDelseif] = "#elseif",
  [anon_sym_POUNDassert] = "#assert",
  [anon_sym_defined] = "defined",
  [sym_preproc_else] = "preproc_else",
  [sym_preproc_endif] = "preproc_endif",
  [sym_preproc_endinput] = "preproc_endinput",
  [anon_sym_POUNDpragma] = "#pragma",
  [anon_sym_POUNDerror] = "#error",
  [anon_sym_POUNDwarning] = "#warning",
  [anon_sym_using__intrinsics__DOTHandle] = "using __intrinsics__.Handle",
  [anon_sym_assert] = "assert",
  [anon_sym_static_assert] = "static_assert",
  [anon_sym_EQ] = "=",
  [anon_sym_forward] = "forward",
  [anon_sym_native] = "native",
  [sym_alias_operator] = "alias_operator",
  [anon_sym_operator] = "operator",
  [anon_sym_COLON] = ":",
  [anon_sym_const] = "const",
  [anon_sym_public] = "public",
  [anon_sym_stock] = "stock",
  [anon_sym_static] = "static",
  [anon_sym_new] = "new",
  [anon_sym_decl] = "decl",
  [anon_sym_enum] = "enum",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_TILDE_EQ] = "~=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_struct] = "struct",
  [anon_sym_typedef] = "typedef",
  [anon_sym_typeset] = "typeset",
  [anon_sym_function] = "function",
  [anon_sym_funcenum] = "funcenum",
  [anon_sym_functag] = "functag",
  [anon_sym_methodmap] = "methodmap",
  [anon_sym___nullable__] = "__nullable__",
  [anon_sym_property] = "property",
  [anon_sym_get] = "get",
  [anon_sym_set] = "set",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_void] = "void",
  [anon_sym_bool] = "bool",
  [anon_sym_int] = "int",
  [anon_sym_float] = "float",
  [anon_sym_char] = "char",
  [anon_sym__] = "_",
  [anon_sym_Float] = "Float",
  [anon_sym_String] = "String",
  [sym_any_type] = "any_type",
  [anon_sym_for] = "for",
  [anon_sym_while] = "while",
  [anon_sym_do] = "do",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_if] = "if",
  [anon_sym_else] = "else",
  [anon_sym_switch] = "switch",
  [anon_sym_case] = "case",
  [anon_sym_COLON2] = ":",
  [anon_sym_default] = "default",
  [anon_sym_return] = "return",
  [anon_sym_delete] = "delete",
  [anon_sym_SEMI] = ";",
  [anon_sym_GT_GT_GT_EQ] = ">>>=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_DOT] = ".",
  [anon_sym_QMARK] = "\?",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_sizeof] = "sizeof",
  [anon_sym_view_as] = "view_as",
  [sym_int_literal] = "int_literal",
  [sym_float_literal] = "float_literal",
  [anon_sym_SQUOTE] = "'",
  [aux_sym_char_literal_token1] = "character",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_string_literal_token1] = "string_literal_token1",
  [sym_escape_sequence] = "escape_sequence",
  [sym_bool_literal] = "bool_literal",
  [sym_null] = "null",
  [sym_this] = "this",
  [sym_system_lib_string] = "system_lib_string",
  [sym_comment] = "comment",
  [sym__automatic_semicolon] = "_automatic_semicolon",
  [sym__ternary_colon] = "_ternary_colon",
  [sym_preproc_arg] = "preproc_arg",
  [sym_source_file] = "source_file",
  [sym__preproc_expression] = "_preproc_expression",
  [sym_preproc_parenthesized_expression] = "preproc_parenthesized_expression",
  [sym_preproc_unary_expression] = "preproc_unary_expression",
  [sym_preproc_binary_expression] = "preproc_binary_expression",
  [sym_preproc_include] = "preproc_include",
  [sym_preproc_tryinclude] = "preproc_tryinclude",
  [sym_preproc_macro] = "preproc_macro",
  [sym_preproc_define] = "preproc_define",
  [sym_preproc_undefine] = "preproc_undefine",
  [sym_preproc_if] = "preproc_if",
  [sym_preproc_elseif] = "preproc_elseif",
  [sym_preproc_assert] = "preproc_assert",
  [sym_preproc_defined_condition] = "preproc_defined_condition",
  [sym_preproc_pragma] = "preproc_pragma",
  [sym_preproc_error] = "preproc_error",
  [sym_preproc_warning] = "preproc_warning",
  [sym_hardcoded_symbol] = "hardcoded_symbol",
  [sym_assertion] = "assertion",
  [sym_function_definition] = "function_definition",
  [sym_function_declaration] = "function_declaration",
  [sym_function_declaration_kind] = "function_declaration_kind",
  [sym_parameter_declarations] = "parameter_declarations",
  [sym_parameter_declaration] = "parameter_declaration",
  [sym_rest_parameter] = "rest_parameter",
  [sym_alias_declaration] = "alias_declaration",
  [sym_alias_assignment] = "alias_assignment",
  [sym_global_variable_declaration] = "global_variable_declaration",
  [sym_variable_declaration_statement] = "variable_declaration_statement",
  [sym_variable_storage_class] = "variable_storage_class",
  [sym_visibility] = "visibility",
  [sym_variable_declaration] = "variable_declaration",
  [sym_dynamic_array_declaration] = "dynamic_array_declaration",
  [sym_dynamic_array] = "dynamic_array",
  [sym_new_expression] = "new_expression",
  [sym_old_global_variable_declaration] = "old_global_variable_declaration",
  [sym_old_variable_declaration_statement] = "old_variable_declaration_statement",
  [sym_old_for_loop_variable_declaration_statement] = "old_for_loop_variable_declaration_statement",
  [sym_old_variable_declaration] = "old_variable_declaration",
  [sym_enum] = "enum",
  [sym_enum_entries] = "enum_entries",
  [sym_enum_entry] = "enum_entry",
  [sym_enum_struct] = "enum_struct",
  [sym_enum_struct_field] = "enum_struct_field",
  [sym_enum_struct_method] = "enum_struct_method",
  [sym_typedef] = "typedef",
  [sym_typeset] = "typeset",
  [sym_typedef_expression] = "typedef_expression",
  [sym_funcenum] = "funcenum",
  [sym_funcenum_member] = "funcenum_member",
  [sym_functag] = "functag",
  [sym_methodmap] = "methodmap",
  [sym_methodmap_alias] = "methodmap_alias",
  [sym_methodmap_native] = "methodmap_native",
  [sym_methodmap_native_constructor] = "methodmap_native_constructor",
  [sym_methodmap_native_destructor] = "methodmap_native_destructor",
  [sym_methodmap_method] = "methodmap_method",
  [sym_methodmap_method_constructor] = "methodmap_method_constructor",
  [sym_methodmap_method_destructor] = "methodmap_method_destructor",
  [sym_methodmap_property] = "methodmap_property",
  [sym_methodmap_property_alias] = "methodmap_property_alias",
  [sym_methodmap_property_native] = "methodmap_property_native",
  [sym_methodmap_property_method] = "methodmap_property_method",
  [sym_methodmap_property_getter] = "methodmap_property_getter",
  [sym_methodmap_property_setter] = "methodmap_property_setter",
  [sym_struct] = "struct",
  [sym_struct_field] = "struct_field",
  [sym_struct_declaration] = "struct_declaration",
  [sym_struct_constructor] = "struct_constructor",
  [sym_struct_field_value] = "struct_field_value",
  [sym_type] = "type",
  [sym_array_type] = "array_type",
  [sym_old_type] = "old_type",
  [sym_dimension] = "dimension",
  [sym_fixed_dimension] = "fixed_dimension",
  [sym_builtin_type] = "builtin_type",
  [sym_old_builtin_type] = "old_builtin_type",
  [sym_block] = "block",
  [sym_for_statement] = "for_statement",
  [sym_while_statement] = "while_statement",
  [sym_do_while_statement] = "do_while_statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_condition_statement] = "condition_statement",
  [sym_switch_statement] = "switch_statement",
  [sym_switch_case] = "switch_case",
  [sym_expression_statement] = "expression_statement",
  [sym_return_statement] = "return_statement",
  [sym_delete_statement] = "delete_statement",
  [sym__manual_semicolon] = "_manual_semicolon",
  [sym__semicolon] = "_semicolon",
  [sym__expression] = "_expression",
  [sym__case_expression] = "_case_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym_call_expression] = "call_expression",
  [sym_call_arguments] = "call_arguments",
  [sym_named_arg] = "named_arg",
  [sym_ignore_argument] = "ignore_argument",
  [sym_array_indexed_access] = "array_indexed_access",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_comma_expression] = "comma_expression",
  [sym_ternary_expression] = "ternary_expression",
  [sym_field_access] = "field_access",
  [sym_scope_access] = "scope_access",
  [sym_unary_expression] = "unary_expression",
  [sym_case_unary_expression] = "case_unary_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_case_binary_expression] = "case_binary_expression",
  [sym_update_expression] = "update_expression",
  [sym__sizeof_call_expression] = "_sizeof_call_expression",
  [sym_array_scope_access] = "array_scope_access",
  [sym_sizeof_expression] = "sizeof_expression",
  [sym_view_as] = "view_as",
  [sym_old_type_cast] = "old_type_cast",
  [sym_array_literal] = "array_literal",
  [sym__literal] = "_literal",
  [sym_char_literal] = "char_literal",
  [sym_string_literal] = "string_literal",
  [sym_rest_operator] = "rest_operator",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_preproc_macro_repeat1] = "preproc_macro_repeat1",
  [aux_sym_function_definition_repeat1] = "function_definition_repeat1",
  [aux_sym_parameter_declarations_repeat1] = "parameter_declarations_repeat1",
  [aux_sym_parameter_declaration_repeat1] = "parameter_declaration_repeat1",
  [aux_sym_global_variable_declaration_repeat1] = "global_variable_declaration_repeat1",
  [aux_sym_variable_declaration_statement_repeat1] = "variable_declaration_statement_repeat1",
  [aux_sym_dynamic_array_repeat1] = "dynamic_array_repeat1",
  [aux_sym_old_global_variable_declaration_repeat1] = "old_global_variable_declaration_repeat1",
  [aux_sym_enum_entries_repeat1] = "enum_entries_repeat1",
  [aux_sym_enum_struct_repeat1] = "enum_struct_repeat1",
  [aux_sym_typeset_repeat1] = "typeset_repeat1",
  [aux_sym_funcenum_repeat1] = "funcenum_repeat1",
  [aux_sym_methodmap_repeat1] = "methodmap_repeat1",
  [aux_sym_methodmap_property_repeat1] = "methodmap_property_repeat1",
  [aux_sym_struct_repeat1] = "struct_repeat1",
  [aux_sym_struct_constructor_repeat1] = "struct_constructor_repeat1",
  [aux_sym_block_repeat1] = "block_repeat1",
  [aux_sym_for_statement_repeat1] = "for_statement_repeat1",
  [aux_sym_switch_statement_repeat1] = "switch_statement_repeat1",
  [aux_sym_switch_case_repeat1] = "switch_case_repeat1",
  [aux_sym_call_arguments_repeat1] = "call_arguments_repeat1",
  [aux_sym_array_literal_repeat1] = "array_literal_repeat1",
  [aux_sym_string_literal_repeat1] = "string_literal_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_DOT_DOT_DOT] = anon_sym_DOT_DOT_DOT,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_GT_GT_GT] = anon_sym_GT_GT_GT,
  [anon_sym_POUNDinclude] = anon_sym_POUNDinclude,
  [anon_sym_POUNDtryinclude] = anon_sym_POUNDtryinclude,
  [anon_sym_POUNDdefine] = anon_sym_POUNDdefine,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [sym_macro_param] = sym_macro_param,
  [anon_sym_POUNDundef] = anon_sym_POUNDundef,
  [anon_sym_POUNDif] = anon_sym_POUNDif,
  [anon_sym_POUNDelseif] = anon_sym_POUNDelseif,
  [anon_sym_POUNDassert] = anon_sym_POUNDassert,
  [anon_sym_defined] = anon_sym_defined,
  [sym_preproc_else] = sym_preproc_else,
  [sym_preproc_endif] = sym_preproc_endif,
  [sym_preproc_endinput] = sym_preproc_endinput,
  [anon_sym_POUNDpragma] = anon_sym_POUNDpragma,
  [anon_sym_POUNDerror] = anon_sym_POUNDerror,
  [anon_sym_POUNDwarning] = anon_sym_POUNDwarning,
  [anon_sym_using__intrinsics__DOTHandle] = anon_sym_using__intrinsics__DOTHandle,
  [anon_sym_assert] = anon_sym_assert,
  [anon_sym_static_assert] = anon_sym_static_assert,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_forward] = anon_sym_forward,
  [anon_sym_native] = anon_sym_native,
  [sym_alias_operator] = sym_alias_operator,
  [anon_sym_operator] = anon_sym_operator,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_public] = anon_sym_public,
  [anon_sym_stock] = anon_sym_stock,
  [anon_sym_static] = anon_sym_static,
  [anon_sym_new] = anon_sym_new,
  [anon_sym_decl] = anon_sym_decl,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_TILDE_EQ] = anon_sym_TILDE_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_typedef] = anon_sym_typedef,
  [anon_sym_typeset] = anon_sym_typeset,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_funcenum] = anon_sym_funcenum,
  [anon_sym_functag] = anon_sym_functag,
  [anon_sym_methodmap] = anon_sym_methodmap,
  [anon_sym___nullable__] = anon_sym___nullable__,
  [anon_sym_property] = anon_sym_property,
  [anon_sym_get] = anon_sym_get,
  [anon_sym_set] = anon_sym_set,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_void] = anon_sym_void,
  [anon_sym_bool] = anon_sym_bool,
  [anon_sym_int] = anon_sym_int,
  [anon_sym_float] = anon_sym_float,
  [anon_sym_char] = anon_sym_char,
  [anon_sym__] = anon_sym__,
  [anon_sym_Float] = anon_sym_Float,
  [anon_sym_String] = anon_sym_String,
  [sym_any_type] = sym_any_type,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_COLON2] = anon_sym_COLON,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_delete] = anon_sym_delete,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_GT_GT_GT_EQ] = anon_sym_GT_GT_GT_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_sizeof] = anon_sym_sizeof,
  [anon_sym_view_as] = anon_sym_view_as,
  [sym_int_literal] = sym_int_literal,
  [sym_float_literal] = sym_float_literal,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym_char_literal_token1] = aux_sym_char_literal_token1,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_string_literal_token1] = aux_sym_string_literal_token1,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_bool_literal] = sym_bool_literal,
  [sym_null] = sym_null,
  [sym_this] = sym_this,
  [sym_system_lib_string] = sym_system_lib_string,
  [sym_comment] = sym_comment,
  [sym__automatic_semicolon] = sym__automatic_semicolon,
  [sym__ternary_colon] = sym__ternary_colon,
  [sym_preproc_arg] = sym_preproc_arg,
  [sym_source_file] = sym_source_file,
  [sym__preproc_expression] = sym__preproc_expression,
  [sym_preproc_parenthesized_expression] = sym_preproc_parenthesized_expression,
  [sym_preproc_unary_expression] = sym_preproc_unary_expression,
  [sym_preproc_binary_expression] = sym_preproc_binary_expression,
  [sym_preproc_include] = sym_preproc_include,
  [sym_preproc_tryinclude] = sym_preproc_tryinclude,
  [sym_preproc_macro] = sym_preproc_macro,
  [sym_preproc_define] = sym_preproc_define,
  [sym_preproc_undefine] = sym_preproc_undefine,
  [sym_preproc_if] = sym_preproc_if,
  [sym_preproc_elseif] = sym_preproc_elseif,
  [sym_preproc_assert] = sym_preproc_assert,
  [sym_preproc_defined_condition] = sym_preproc_defined_condition,
  [sym_preproc_pragma] = sym_preproc_pragma,
  [sym_preproc_error] = sym_preproc_error,
  [sym_preproc_warning] = sym_preproc_warning,
  [sym_hardcoded_symbol] = sym_hardcoded_symbol,
  [sym_assertion] = sym_assertion,
  [sym_function_definition] = sym_function_definition,
  [sym_function_declaration] = sym_function_declaration,
  [sym_function_declaration_kind] = sym_function_declaration_kind,
  [sym_parameter_declarations] = sym_parameter_declarations,
  [sym_parameter_declaration] = sym_parameter_declaration,
  [sym_rest_parameter] = sym_rest_parameter,
  [sym_alias_declaration] = sym_alias_declaration,
  [sym_alias_assignment] = sym_alias_assignment,
  [sym_global_variable_declaration] = sym_global_variable_declaration,
  [sym_variable_declaration_statement] = sym_variable_declaration_statement,
  [sym_variable_storage_class] = sym_variable_storage_class,
  [sym_visibility] = sym_visibility,
  [sym_variable_declaration] = sym_variable_declaration,
  [sym_dynamic_array_declaration] = sym_dynamic_array_declaration,
  [sym_dynamic_array] = sym_dynamic_array,
  [sym_new_expression] = sym_new_expression,
  [sym_old_global_variable_declaration] = sym_old_global_variable_declaration,
  [sym_old_variable_declaration_statement] = sym_old_variable_declaration_statement,
  [sym_old_for_loop_variable_declaration_statement] = sym_old_for_loop_variable_declaration_statement,
  [sym_old_variable_declaration] = sym_old_variable_declaration,
  [sym_enum] = sym_enum,
  [sym_enum_entries] = sym_enum_entries,
  [sym_enum_entry] = sym_enum_entry,
  [sym_enum_struct] = sym_enum_struct,
  [sym_enum_struct_field] = sym_enum_struct_field,
  [sym_enum_struct_method] = sym_enum_struct_method,
  [sym_typedef] = sym_typedef,
  [sym_typeset] = sym_typeset,
  [sym_typedef_expression] = sym_typedef_expression,
  [sym_funcenum] = sym_funcenum,
  [sym_funcenum_member] = sym_funcenum_member,
  [sym_functag] = sym_functag,
  [sym_methodmap] = sym_methodmap,
  [sym_methodmap_alias] = sym_methodmap_alias,
  [sym_methodmap_native] = sym_methodmap_native,
  [sym_methodmap_native_constructor] = sym_methodmap_native_constructor,
  [sym_methodmap_native_destructor] = sym_methodmap_native_destructor,
  [sym_methodmap_method] = sym_methodmap_method,
  [sym_methodmap_method_constructor] = sym_methodmap_method_constructor,
  [sym_methodmap_method_destructor] = sym_methodmap_method_destructor,
  [sym_methodmap_property] = sym_methodmap_property,
  [sym_methodmap_property_alias] = sym_methodmap_property_alias,
  [sym_methodmap_property_native] = sym_methodmap_property_native,
  [sym_methodmap_property_method] = sym_methodmap_property_method,
  [sym_methodmap_property_getter] = sym_methodmap_property_getter,
  [sym_methodmap_property_setter] = sym_methodmap_property_setter,
  [sym_struct] = sym_struct,
  [sym_struct_field] = sym_struct_field,
  [sym_struct_declaration] = sym_struct_declaration,
  [sym_struct_constructor] = sym_struct_constructor,
  [sym_struct_field_value] = sym_struct_field_value,
  [sym_type] = sym_type,
  [sym_array_type] = sym_array_type,
  [sym_old_type] = sym_old_type,
  [sym_dimension] = sym_dimension,
  [sym_fixed_dimension] = sym_fixed_dimension,
  [sym_builtin_type] = sym_builtin_type,
  [sym_old_builtin_type] = sym_old_builtin_type,
  [sym_block] = sym_block,
  [sym_for_statement] = sym_for_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_do_while_statement] = sym_do_while_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_condition_statement] = sym_condition_statement,
  [sym_switch_statement] = sym_switch_statement,
  [sym_switch_case] = sym_switch_case,
  [sym_expression_statement] = sym_expression_statement,
  [sym_return_statement] = sym_return_statement,
  [sym_delete_statement] = sym_delete_statement,
  [sym__manual_semicolon] = sym__manual_semicolon,
  [sym__semicolon] = sym__semicolon,
  [sym__expression] = sym__expression,
  [sym__case_expression] = sym__case_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_call_expression] = sym_call_expression,
  [sym_call_arguments] = sym_call_arguments,
  [sym_named_arg] = sym_named_arg,
  [sym_ignore_argument] = sym_ignore_argument,
  [sym_array_indexed_access] = sym_array_indexed_access,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_comma_expression] = sym_comma_expression,
  [sym_ternary_expression] = sym_ternary_expression,
  [sym_field_access] = sym_field_access,
  [sym_scope_access] = sym_scope_access,
  [sym_unary_expression] = sym_unary_expression,
  [sym_case_unary_expression] = sym_case_unary_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_case_binary_expression] = sym_case_binary_expression,
  [sym_update_expression] = sym_update_expression,
  [sym__sizeof_call_expression] = sym__sizeof_call_expression,
  [sym_array_scope_access] = sym_array_scope_access,
  [sym_sizeof_expression] = sym_sizeof_expression,
  [sym_view_as] = sym_view_as,
  [sym_old_type_cast] = sym_old_type_cast,
  [sym_array_literal] = sym_array_literal,
  [sym__literal] = sym__literal,
  [sym_char_literal] = sym_char_literal,
  [sym_string_literal] = sym_string_literal,
  [sym_rest_operator] = sym_rest_operator,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_preproc_macro_repeat1] = aux_sym_preproc_macro_repeat1,
  [aux_sym_function_definition_repeat1] = aux_sym_function_definition_repeat1,
  [aux_sym_parameter_declarations_repeat1] = aux_sym_parameter_declarations_repeat1,
  [aux_sym_parameter_declaration_repeat1] = aux_sym_parameter_declaration_repeat1,
  [aux_sym_global_variable_declaration_repeat1] = aux_sym_global_variable_declaration_repeat1,
  [aux_sym_variable_declaration_statement_repeat1] = aux_sym_variable_declaration_statement_repeat1,
  [aux_sym_dynamic_array_repeat1] = aux_sym_dynamic_array_repeat1,
  [aux_sym_old_global_variable_declaration_repeat1] = aux_sym_old_global_variable_declaration_repeat1,
  [aux_sym_enum_entries_repeat1] = aux_sym_enum_entries_repeat1,
  [aux_sym_enum_struct_repeat1] = aux_sym_enum_struct_repeat1,
  [aux_sym_typeset_repeat1] = aux_sym_typeset_repeat1,
  [aux_sym_funcenum_repeat1] = aux_sym_funcenum_repeat1,
  [aux_sym_methodmap_repeat1] = aux_sym_methodmap_repeat1,
  [aux_sym_methodmap_property_repeat1] = aux_sym_methodmap_property_repeat1,
  [aux_sym_struct_repeat1] = aux_sym_struct_repeat1,
  [aux_sym_struct_constructor_repeat1] = aux_sym_struct_constructor_repeat1,
  [aux_sym_block_repeat1] = aux_sym_block_repeat1,
  [aux_sym_for_statement_repeat1] = aux_sym_for_statement_repeat1,
  [aux_sym_switch_statement_repeat1] = aux_sym_switch_statement_repeat1,
  [aux_sym_switch_case_repeat1] = aux_sym_switch_case_repeat1,
  [aux_sym_call_arguments_repeat1] = aux_sym_call_arguments_repeat1,
  [aux_sym_array_literal_repeat1] = aux_sym_array_literal_repeat1,
  [aux_sym_string_literal_repeat1] = aux_sym_string_literal_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDinclude] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDtryinclude] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDdefine] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [sym_macro_param] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_POUNDundef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDelseif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDassert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_defined] = {
    .visible = true,
    .named = false,
  },
  [sym_preproc_else] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_endif] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_endinput] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_POUNDpragma] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDerror] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDwarning] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_using__intrinsics__DOTHandle] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_static_assert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_forward] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_native] = {
    .visible = true,
    .named = false,
  },
  [sym_alias_operator] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_operator] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_public] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_stock] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_static] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_decl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typedef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typeset] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_funcenum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_functag] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_methodmap] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___nullable__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_property] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_get] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_void] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bool] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_float] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_char] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Float] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_String] = {
    .visible = true,
    .named = false,
  },
  [sym_any_type] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_delete] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sizeof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_view_as] = {
    .visible = true,
    .named = false,
  },
  [sym_int_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_float_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_char_literal_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_bool_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_null] = {
    .visible = true,
    .named = true,
  },
  [sym_this] = {
    .visible = true,
    .named = true,
  },
  [sym_system_lib_string] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym__automatic_semicolon] = {
    .visible = false,
    .named = true,
  },
  [sym__ternary_colon] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_arg] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym__preproc_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_include] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_tryinclude] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_macro] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_define] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_undefine] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elseif] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_assert] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_defined_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_pragma] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_error] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_warning] = {
    .visible = true,
    .named = true,
  },
  [sym_hardcoded_symbol] = {
    .visible = true,
    .named = true,
  },
  [sym_assertion] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_function_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_function_declaration_kind] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_declarations] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_rest_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_alias_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_alias_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_global_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declaration_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_storage_class] = {
    .visible = true,
    .named = true,
  },
  [sym_visibility] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_dynamic_array_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_dynamic_array] = {
    .visible = true,
    .named = true,
  },
  [sym_new_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_old_global_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_old_variable_declaration_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_old_for_loop_variable_declaration_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_old_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_enum] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_entries] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_entry] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_struct] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_struct_field] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_struct_method] = {
    .visible = true,
    .named = true,
  },
  [sym_typedef] = {
    .visible = true,
    .named = true,
  },
  [sym_typeset] = {
    .visible = true,
    .named = true,
  },
  [sym_typedef_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_funcenum] = {
    .visible = true,
    .named = true,
  },
  [sym_funcenum_member] = {
    .visible = true,
    .named = true,
  },
  [sym_functag] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap_alias] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap_native] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap_native_constructor] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap_native_destructor] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap_method] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap_method_constructor] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap_method_destructor] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap_property] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap_property_alias] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap_property_native] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap_property_method] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap_property_getter] = {
    .visible = true,
    .named = true,
  },
  [sym_methodmap_property_setter] = {
    .visible = true,
    .named = true,
  },
  [sym_struct] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_field] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_constructor] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_field_value] = {
    .visible = true,
    .named = true,
  },
  [sym_type] = {
    .visible = true,
    .named = true,
  },
  [sym_array_type] = {
    .visible = true,
    .named = true,
  },
  [sym_old_type] = {
    .visible = true,
    .named = true,
  },
  [sym_dimension] = {
    .visible = true,
    .named = true,
  },
  [sym_fixed_dimension] = {
    .visible = true,
    .named = true,
  },
  [sym_builtin_type] = {
    .visible = true,
    .named = true,
  },
  [sym_old_builtin_type] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_do_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_condition_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_case] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_delete_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__manual_semicolon] = {
    .visible = false,
    .named = true,
  },
  [sym__semicolon] = {
    .visible = false,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__case_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_named_arg] = {
    .visible = true,
    .named = true,
  },
  [sym_ignore_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_array_indexed_access] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_comma_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_ternary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_field_access] = {
    .visible = true,
    .named = true,
  },
  [sym_scope_access] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_case_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_case_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_update_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__sizeof_call_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_array_scope_access] = {
    .visible = true,
    .named = true,
  },
  [sym_sizeof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_view_as] = {
    .visible = true,
    .named = true,
  },
  [sym_old_type_cast] = {
    .visible = true,
    .named = true,
  },
  [sym_array_literal] = {
    .visible = true,
    .named = true,
  },
  [sym__literal] = {
    .visible = false,
    .named = true,
  },
  [sym_char_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_rest_operator] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_macro_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameter_declarations_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameter_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_global_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_declaration_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dynamic_array_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_old_global_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_entries_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_struct_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_typeset_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_funcenum_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_methodmap_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_methodmap_property_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_constructor_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_for_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_case_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_call_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_alternative = 1,
  field_arg_name = 2,
  field_argument = 3,
  field_arguments = 4,
  field_array = 5,
  field_body = 6,
  field_class = 7,
  field_condition = 8,
  field_consequence = 9,
  field_defaultValue = 10,
  field_entries = 11,
  field_expression = 12,
  field_falsePath = 13,
  field_field = 14,
  field_free = 15,
  field_function = 16,
  field_index = 17,
  field_inherits = 18,
  field_initialValue = 19,
  field_initialization = 20,
  field_iteration = 21,
  field_kind = 22,
  field_left = 23,
  field_name = 24,
  field_operator = 25,
  field_parameter = 26,
  field_parameters = 27,
  field_path = 28,
  field_returnType = 29,
  field_right = 30,
  field_scope = 31,
  field_storage_class = 32,
  field_target = 33,
  field_truePath = 34,
  field_type = 35,
  field_value = 36,
  field_visibility = 37,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alternative] = "alternative",
  [field_arg_name] = "arg_name",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_array] = "array",
  [field_body] = "body",
  [field_class] = "class",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_defaultValue] = "defaultValue",
  [field_entries] = "entries",
  [field_expression] = "expression",
  [field_falsePath] = "falsePath",
  [field_field] = "field",
  [field_free] = "free",
  [field_function] = "function",
  [field_index] = "index",
  [field_inherits] = "inherits",
  [field_initialValue] = "initialValue",
  [field_initialization] = "initialization",
  [field_iteration] = "iteration",
  [field_kind] = "kind",
  [field_left] = "left",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_parameter] = "parameter",
  [field_parameters] = "parameters",
  [field_path] = "path",
  [field_returnType] = "returnType",
  [field_right] = "right",
  [field_scope] = "scope",
  [field_storage_class] = "storage_class",
  [field_target] = "target",
  [field_truePath] = "truePath",
  [field_type] = "type",
  [field_value] = "value",
  [field_visibility] = "visibility",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 1},
  [5] = {.index = 4, .length = 1},
  [6] = {.index = 5, .length = 2},
  [7] = {.index = 7, .length = 2},
  [8] = {.index = 9, .length = 2},
  [9] = {.index = 11, .length = 3},
  [10] = {.index = 14, .length = 3},
  [11] = {.index = 17, .length = 1},
  [12] = {.index = 18, .length = 1},
  [13] = {.index = 19, .length = 1},
  [14] = {.index = 20, .length = 2},
  [15] = {.index = 22, .length = 1},
  [16] = {.index = 23, .length = 2},
  [17] = {.index = 25, .length = 2},
  [18] = {.index = 27, .length = 2},
  [19] = {.index = 29, .length = 1},
  [20] = {.index = 30, .length = 3},
  [21] = {.index = 33, .length = 2},
  [22] = {.index = 35, .length = 2},
  [23] = {.index = 37, .length = 1},
  [24] = {.index = 38, .length = 1},
  [25] = {.index = 39, .length = 3},
  [26] = {.index = 42, .length = 3},
  [27] = {.index = 45, .length = 2},
  [28] = {.index = 47, .length = 4},
  [29] = {.index = 51, .length = 2},
  [30] = {.index = 53, .length = 2},
  [31] = {.index = 55, .length = 2},
  [32] = {.index = 57, .length = 4},
  [33] = {.index = 61, .length = 4},
  [34] = {.index = 65, .length = 4},
  [35] = {.index = 69, .length = 2},
  [36] = {.index = 71, .length = 3},
  [37] = {.index = 74, .length = 2},
  [38] = {.index = 76, .length = 2},
  [39] = {.index = 78, .length = 3},
  [40] = {.index = 81, .length = 3},
  [41] = {.index = 84, .length = 3},
  [42] = {.index = 87, .length = 1},
  [43] = {.index = 88, .length = 1},
  [44] = {.index = 89, .length = 3},
  [45] = {.index = 92, .length = 3},
  [46] = {.index = 95, .length = 2},
  [47] = {.index = 97, .length = 2},
  [48] = {.index = 99, .length = 3},
  [49] = {.index = 102, .length = 2},
  [50] = {.index = 104, .length = 2},
  [51] = {.index = 106, .length = 1},
  [52] = {.index = 107, .length = 4},
  [53] = {.index = 111, .length = 3},
  [54] = {.index = 114, .length = 5},
  [55] = {.index = 119, .length = 3},
  [56] = {.index = 122, .length = 2},
  [57] = {.index = 124, .length = 5},
  [58] = {.index = 129, .length = 4},
  [59] = {.index = 133, .length = 5},
  [60] = {.index = 138, .length = 2},
  [61] = {.index = 140, .length = 1},
  [62] = {.index = 141, .length = 2},
  [63] = {.index = 143, .length = 4},
  [64] = {.index = 147, .length = 1},
  [65] = {.index = 148, .length = 3},
  [66] = {.index = 151, .length = 2},
  [67] = {.index = 153, .length = 2},
  [68] = {.index = 155, .length = 2},
  [69] = {.index = 157, .length = 2},
  [70] = {.index = 159, .length = 2},
  [71] = {.index = 161, .length = 2},
  [72] = {.index = 163, .length = 4},
  [73] = {.index = 167, .length = 3},
  [74] = {.index = 170, .length = 3},
  [75] = {.index = 173, .length = 3},
  [76] = {.index = 176, .length = 5},
  [77] = {.index = 181, .length = 3},
  [78] = {.index = 184, .length = 6},
  [79] = {.index = 190, .length = 6},
  [80] = {.index = 196, .length = 2},
  [81] = {.index = 198, .length = 3},
  [82] = {.index = 201, .length = 5},
  [83] = {.index = 206, .length = 2},
  [84] = {.index = 208, .length = 2},
  [85] = {.index = 210, .length = 3},
  [86] = {.index = 213, .length = 3},
  [87] = {.index = 216, .length = 2},
  [88] = {.index = 218, .length = 3},
  [89] = {.index = 221, .length = 4},
  [90] = {.index = 225, .length = 3},
  [91] = {.index = 228, .length = 3},
  [92] = {.index = 231, .length = 4},
  [93] = {.index = 235, .length = 3},
  [94] = {.index = 238, .length = 3},
  [95] = {.index = 241, .length = 2},
  [96] = {.index = 243, .length = 2},
  [97] = {.index = 245, .length = 2},
  [98] = {.index = 247, .length = 2},
  [99] = {.index = 249, .length = 5},
  [100] = {.index = 254, .length = 3},
  [101] = {.index = 257, .length = 3},
  [102] = {.index = 260, .length = 2},
  [103] = {.index = 262, .length = 2},
  [104] = {.index = 264, .length = 4},
  [105] = {.index = 268, .length = 5},
  [106] = {.index = 273, .length = 4},
  [107] = {.index = 277, .length = 4},
  [108] = {.index = 281, .length = 1},
  [109] = {.index = 282, .length = 2},
  [110] = {.index = 284, .length = 1},
  [111] = {.index = 285, .length = 2},
  [112] = {.index = 287, .length = 3},
  [113] = {.index = 290, .length = 2},
  [114] = {.index = 292, .length = 3},
  [115] = {.index = 295, .length = 2},
  [116] = {.index = 297, .length = 1},
  [117] = {.index = 298, .length = 4},
  [118] = {.index = 302, .length = 3},
  [119] = {.index = 305, .length = 4},
  [120] = {.index = 309, .length = 2},
  [121] = {.index = 311, .length = 5},
  [122] = {.index = 316, .length = 2},
  [123] = {.index = 318, .length = 2},
  [124] = {.index = 320, .length = 2},
  [125] = {.index = 322, .length = 3},
  [126] = {.index = 325, .length = 3},
  [127] = {.index = 328, .length = 2},
  [128] = {.index = 330, .length = 4},
  [129] = {.index = 334, .length = 5},
  [130] = {.index = 339, .length = 1},
  [131] = {.index = 340, .length = 3},
  [132] = {.index = 343, .length = 3},
  [133] = {.index = 346, .length = 3},
  [134] = {.index = 349, .length = 3},
  [135] = {.index = 352, .length = 1},
  [136] = {.index = 353, .length = 4},
  [137] = {.index = 357, .length = 4},
  [138] = {.index = 361, .length = 4},
  [139] = {.index = 365, .length = 2},
  [140] = {.index = 367, .length = 2},
  [141] = {.index = 369, .length = 5},
  [142] = {.index = 374, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 0},
  [1] =
    {field_path, 1},
  [2] =
    {field_name, 1},
  [3] =
    {field_condition, 1},
  [4] =
    {field_entries, 1},
  [5] =
    {field_name, 1},
    {field_type, 0},
  [7] =
    {field_name, 1},
    {field_value, 2},
  [9] =
    {field_entries, 2},
    {field_name, 1},
  [11] =
    {field_initialValue, 1},
    {field_initialValue, 2},
    {field_name, 0},
  [14] =
    {field_body, 2},
    {field_name, 0},
    {field_parameters, 1},
  [17] =
    {field_storage_class, 0},
  [18] =
    {field_visibility, 0},
  [19] =
    {field_type, 0},
  [20] =
    {field_argument, 1},
    {field_operator, 0},
  [22] =
    {field_type, 1},
  [23] =
    {field_arguments, 1},
    {field_function, 0},
  [25] =
    {field_type, 0},
    {field_value, 1},
  [27] =
    {field_argument, 0},
    {field_operator, 1},
  [29] =
    {field_storage_class, 1},
  [30] =
    {field_entries, 3},
    {field_name, 1},
    {field_name, 2},
  [33] =
    {field_name, 1},
    {field_parameters, 3},
  [35] =
    {field_name, 1},
    {field_storage_class, 0},
  [37] =
    {field_expression, 1},
  [38] =
    {field_free, 1},
  [39] =
    {field_initialValue, 2},
    {field_initialValue, 3},
    {field_name, 0},
  [42] =
    {field_kind, 0},
    {field_name, 1},
    {field_parameters, 2},
  [45] =
    {field_storage_class, 0},
    {field_type, 1},
  [47] =
    {field_body, 3},
    {field_name, 1},
    {field_parameters, 2},
    {field_visibility, 0},
  [51] =
    {field_storage_class, 1},
    {field_visibility, 0},
  [53] =
    {field_type, 1},
    {field_visibility, 0},
  [55] =
    {field_initialValue, 2},
    {field_name, 0},
  [57] =
    {field_body, 3},
    {field_name, 1},
    {field_parameters, 2},
    {field_returnType, 0},
  [61] =
    {field_initialValue, 2},
    {field_initialValue, 3},
    {field_name, 1},
    {field_type, 0},
  [65] =
    {field_name, 1},
    {field_parameters, 2},
    {field_parameters, 3},
    {field_value, 4},
  [69] =
    {field_arguments, 2},
    {field_class, 1},
  [71] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [74] =
    {field_field, 2},
    {field_scope, 0},
  [76] =
    {field_field, 2},
    {field_target, 0},
  [78] =
    {field_name, 2},
    {field_type, 1},
    {field_value, 4},
  [81] =
    {field_name, 0},
    {field_value, 1},
    {field_value, 2},
  [84] =
    {field_name, 2},
    {field_type, 0},
    {field_type, 1},
  [87] =
    {field_name, 2},
  [88] =
    {field_parameters, 1},
  [89] =
    {field_name, 3},
    {field_parameters, 4},
    {field_returnType, 2},
  [92] =
    {field_name, 1},
    {field_parameters, 4},
    {field_returnType, 2},
  [95] =
    {field_defaultValue, 2},
    {field_name, 0},
  [97] =
    {field_name, 2},
    {field_storage_class, 0},
  [99] =
    {field_name, 2},
    {field_storage_class, 0},
    {field_type, 1},
  [102] =
    {field_name, 2},
    {field_type, 0},
  [104] =
    {field_left, 0},
    {field_right, 2},
  [106] =
    {field_parameters, 3},
  [107] =
    {field_kind, 0},
    {field_name, 2},
    {field_parameters, 3},
    {field_returnType, 1},
  [111] =
    {field_storage_class, 1},
    {field_type, 2},
    {field_visibility, 0},
  [114] =
    {field_body, 4},
    {field_name, 2},
    {field_parameters, 3},
    {field_returnType, 1},
    {field_visibility, 0},
  [119] =
    {field_body, 4},
    {field_parameters, 3},
    {field_returnType, 0},
  [122] =
    {field_initialValue, 3},
    {field_name, 0},
  [124] =
    {field_body, 4},
    {field_name, 2},
    {field_parameters, 3},
    {field_returnType, 0},
    {field_returnType, 1},
  [129] =
    {field_initialValue, 3},
    {field_initialValue, 4},
    {field_name, 1},
    {field_type, 0},
  [133] =
    {field_name, 1},
    {field_parameters, 2},
    {field_parameters, 3},
    {field_parameters, 4},
    {field_value, 5},
  [138] =
    {field_arg_name, 1},
    {field_value, 3},
  [140] =
    {field_type, 2},
  [141] =
    {field_array, 0},
    {field_index, 2},
  [143] =
    {field_name, 3},
    {field_type, 1},
    {field_type, 2},
    {field_value, 5},
  [147] =
    {field_entries, 5},
  [148] =
    {field_name, 0},
    {field_value, 2},
    {field_value, 3},
  [151] =
    {field_name, 2},
    {field_type, 1},
  [153] =
    {field_parameters, 2},
    {field_returnType, 1},
  [155] =
    {field_parameters, 2},
    {field_returnType, 0},
  [157] =
    {field_inherits, 3},
    {field_name, 1},
  [159] =
    {field_defaultValue, 3},
    {field_name, 1},
  [161] =
    {field_defaultValue, 3},
    {field_name, 0},
  [163] =
    {field_name, 3},
    {field_storage_class, 0},
    {field_type, 1},
    {field_type, 2},
  [167] =
    {field_defaultValue, 3},
    {field_name, 1},
    {field_storage_class, 0},
  [170] =
    {field_name, 3},
    {field_storage_class, 0},
    {field_type, 1},
  [173] =
    {field_defaultValue, 3},
    {field_name, 1},
    {field_type, 0},
  [176] =
    {field_kind, 0},
    {field_name, 3},
    {field_parameters, 4},
    {field_returnType, 1},
    {field_returnType, 2},
  [181] =
    {field_body, 5},
    {field_parameters, 4},
    {field_returnType, 1},
  [184] =
    {field_body, 5},
    {field_name, 3},
    {field_parameters, 4},
    {field_returnType, 1},
    {field_returnType, 2},
    {field_visibility, 0},
  [190] =
    {field_name, 1},
    {field_parameters, 2},
    {field_parameters, 3},
    {field_parameters, 4},
    {field_parameters, 5},
    {field_value, 6},
  [196] =
    {field_field, 3},
    {field_scope, 0},
  [198] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [201] =
    {field_name, 2},
    {field_type, 0},
    {field_type, 1},
    {field_value, 3},
    {field_value, 4},
  [206] =
    {field_entries, 6},
    {field_name, 1},
  [208] =
    {field_name, 3},
    {field_type, 2},
  [210] =
    {field_name, 3},
    {field_type, 1},
    {field_type, 2},
  [213] =
    {field_parameters, 3},
    {field_returnType, 1},
    {field_returnType, 2},
  [216] =
    {field_name, 2},
    {field_parameters, 3},
  [218] =
    {field_body, 3},
    {field_name, 1},
    {field_parameters, 2},
  [221] =
    {field_defaultValue, 4},
    {field_name, 2},
    {field_type, 0},
    {field_type, 1},
  [225] =
    {field_defaultValue, 4},
    {field_name, 2},
    {field_storage_class, 0},
  [228] =
    {field_defaultValue, 4},
    {field_name, 1},
    {field_storage_class, 0},
  [231] =
    {field_defaultValue, 4},
    {field_name, 2},
    {field_storage_class, 0},
    {field_type, 1},
  [235] =
    {field_defaultValue, 4},
    {field_name, 2},
    {field_type, 0},
  [238] =
    {field_defaultValue, 4},
    {field_name, 1},
    {field_type, 0},
  [241] =
    {field_body, 4},
    {field_condition, 2},
  [243] =
    {field_condition, 2},
    {field_truePath, 4},
  [245] =
    {field_parameters, 3},
    {field_returnType, 0},
  [247] =
    {field_field, 0},
    {field_value, 2},
  [249] =
    {field_name, 2},
    {field_type, 0},
    {field_type, 1},
    {field_value, 4},
    {field_value, 5},
  [254] =
    {field_entries, 7},
    {field_name, 1},
    {field_name, 2},
  [257] =
    {field_name, 4},
    {field_type, 2},
    {field_type, 3},
  [260] =
    {field_parameters, 3},
    {field_returnType, 2},
  [262] =
    {field_name, 3},
    {field_parameters, 4},
  [264] =
    {field_body, 4},
    {field_name, 2},
    {field_parameters, 3},
    {field_returnType, 1},
  [268] =
    {field_defaultValue, 5},
    {field_name, 3},
    {field_storage_class, 0},
    {field_type, 1},
    {field_type, 2},
  [273] =
    {field_defaultValue, 5},
    {field_name, 3},
    {field_storage_class, 0},
    {field_type, 1},
  [277] =
    {field_defaultValue, 5},
    {field_name, 2},
    {field_storage_class, 0},
    {field_type, 1},
  [281] =
    {field_body, 5},
  [282] =
    {field_body, 1},
    {field_condition, 4},
  [284] =
    {field_condition, 2},
  [285] =
    {field_parameters, 4},
    {field_returnType, 1},
  [287] =
    {field_parameters, 4},
    {field_returnType, 0},
    {field_returnType, 1},
  [290] =
    {field_type, 2},
    {field_value, 5},
  [292] =
    {field_parameters, 4},
    {field_returnType, 2},
    {field_returnType, 3},
  [295] =
    {field_body, 5},
    {field_name, 2},
  [297] =
    {field_name, 3},
  [298] =
    {field_name, 4},
    {field_parameters, 5},
    {field_returnType, 2},
    {field_returnType, 3},
  [302] =
    {field_name, 4},
    {field_parameters, 5},
    {field_returnType, 3},
  [305] =
    {field_body, 5},
    {field_name, 3},
    {field_parameters, 4},
    {field_returnType, 2},
  [309] =
    {field_function, 5},
    {field_name, 1},
  [311] =
    {field_body, 5},
    {field_name, 3},
    {field_parameters, 4},
    {field_returnType, 1},
    {field_returnType, 2},
  [316] =
    {field_body, 6},
    {field_initialization, 2},
  [318] =
    {field_body, 6},
    {field_iteration, 4},
  [320] =
    {field_body, 6},
    {field_condition, 3},
  [322] =
    {field_condition, 2},
    {field_falsePath, 6},
    {field_truePath, 4},
  [325] =
    {field_parameters, 5},
    {field_returnType, 1},
    {field_returnType, 2},
  [328] =
    {field_function, 6},
    {field_name, 2},
  [330] =
    {field_name, 5},
    {field_parameters, 6},
    {field_returnType, 3},
    {field_returnType, 4},
  [334] =
    {field_body, 6},
    {field_name, 4},
    {field_parameters, 5},
    {field_returnType, 2},
    {field_returnType, 3},
  [339] =
    {field_body, 2},
  [340] =
    {field_body, 7},
    {field_initialization, 2},
    {field_iteration, 5},
  [343] =
    {field_body, 7},
    {field_condition, 4},
    {field_initialization, 2},
  [346] =
    {field_body, 7},
    {field_condition, 3},
    {field_iteration, 5},
  [349] =
    {field_body, 7},
    {field_initialization, 2},
    {field_initialization, 3},
  [352] =
    {field_function, 3},
  [353] =
    {field_body, 8},
    {field_condition, 4},
    {field_initialization, 2},
    {field_iteration, 6},
  [357] =
    {field_body, 8},
    {field_initialization, 2},
    {field_initialization, 3},
    {field_iteration, 6},
  [361] =
    {field_body, 8},
    {field_condition, 5},
    {field_initialization, 2},
    {field_initialization, 3},
  [365] =
    {field_body, 3},
    {field_value, 1},
  [367] =
    {field_name, 0},
    {field_parameter, 2},
  [369] =
    {field_body, 9},
    {field_condition, 5},
    {field_initialization, 2},
    {field_initialization, 3},
    {field_iteration, 7},
  [374] =
    {field_body, 4},
    {field_value, 1},
    {field_value, 2},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 7,
  [9] = 9,
  [10] = 5,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 19,
  [36] = 16,
  [37] = 17,
  [38] = 18,
  [39] = 39,
  [40] = 20,
  [41] = 21,
  [42] = 22,
  [43] = 23,
  [44] = 24,
  [45] = 26,
  [46] = 27,
  [47] = 28,
  [48] = 30,
  [49] = 34,
  [50] = 19,
  [51] = 16,
  [52] = 17,
  [53] = 18,
  [54] = 39,
  [55] = 20,
  [56] = 21,
  [57] = 22,
  [58] = 23,
  [59] = 24,
  [60] = 26,
  [61] = 27,
  [62] = 28,
  [63] = 30,
  [64] = 64,
  [65] = 65,
  [66] = 33,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 34,
  [72] = 39,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 4,
  [77] = 77,
  [78] = 78,
  [79] = 78,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 9,
  [84] = 64,
  [85] = 12,
  [86] = 67,
  [87] = 74,
  [88] = 73,
  [89] = 75,
  [90] = 11,
  [91] = 91,
  [92] = 80,
  [93] = 77,
  [94] = 81,
  [95] = 82,
  [96] = 91,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 128,
  [150] = 150,
  [151] = 151,
  [152] = 99,
  [153] = 101,
  [154] = 100,
  [155] = 97,
  [156] = 98,
  [157] = 103,
  [158] = 108,
  [159] = 159,
  [160] = 107,
  [161] = 159,
  [162] = 159,
  [163] = 102,
  [164] = 104,
  [165] = 106,
  [166] = 105,
  [167] = 127,
  [168] = 150,
  [169] = 117,
  [170] = 109,
  [171] = 118,
  [172] = 144,
  [173] = 129,
  [174] = 130,
  [175] = 131,
  [176] = 110,
  [177] = 134,
  [178] = 119,
  [179] = 112,
  [180] = 115,
  [181] = 116,
  [182] = 120,
  [183] = 121,
  [184] = 124,
  [185] = 132,
  [186] = 133,
  [187] = 135,
  [188] = 141,
  [189] = 142,
  [190] = 137,
  [191] = 138,
  [192] = 123,
  [193] = 139,
  [194] = 140,
  [195] = 111,
  [196] = 146,
  [197] = 143,
  [198] = 113,
  [199] = 114,
  [200] = 126,
  [201] = 147,
  [202] = 148,
  [203] = 145,
  [204] = 122,
  [205] = 136,
  [206] = 125,
  [207] = 91,
  [208] = 208,
  [209] = 209,
  [210] = 210,
  [211] = 211,
  [212] = 210,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 215,
  [217] = 217,
  [218] = 98,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 11,
  [224] = 224,
  [225] = 225,
  [226] = 226,
  [227] = 97,
  [228] = 228,
  [229] = 228,
  [230] = 230,
  [231] = 108,
  [232] = 228,
  [233] = 228,
  [234] = 107,
  [235] = 228,
  [236] = 236,
  [237] = 237,
  [238] = 238,
  [239] = 4,
  [240] = 240,
  [241] = 241,
  [242] = 242,
  [243] = 237,
  [244] = 237,
  [245] = 237,
  [246] = 237,
  [247] = 247,
  [248] = 104,
  [249] = 249,
  [250] = 250,
  [251] = 251,
  [252] = 252,
  [253] = 251,
  [254] = 254,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 147,
  [262] = 252,
  [263] = 148,
  [264] = 264,
  [265] = 254,
  [266] = 255,
  [267] = 259,
  [268] = 257,
  [269] = 258,
  [270] = 259,
  [271] = 271,
  [272] = 252,
  [273] = 273,
  [274] = 254,
  [275] = 252,
  [276] = 276,
  [277] = 260,
  [278] = 276,
  [279] = 255,
  [280] = 260,
  [281] = 276,
  [282] = 251,
  [283] = 252,
  [284] = 258,
  [285] = 256,
  [286] = 257,
  [287] = 256,
  [288] = 288,
  [289] = 288,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 288,
  [295] = 295,
  [296] = 296,
  [297] = 293,
  [298] = 298,
  [299] = 293,
  [300] = 296,
  [301] = 301,
  [302] = 298,
  [303] = 303,
  [304] = 9,
  [305] = 303,
  [306] = 296,
  [307] = 298,
  [308] = 303,
  [309] = 293,
  [310] = 298,
  [311] = 298,
  [312] = 288,
  [313] = 288,
  [314] = 314,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 4,
  [319] = 319,
  [320] = 320,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 316,
  [330] = 330,
  [331] = 331,
  [332] = 315,
  [333] = 333,
  [334] = 334,
  [335] = 335,
  [336] = 336,
  [337] = 337,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 334,
  [342] = 342,
  [343] = 314,
  [344] = 344,
  [345] = 319,
  [346] = 320,
  [347] = 321,
  [348] = 322,
  [349] = 316,
  [350] = 323,
  [351] = 324,
  [352] = 325,
  [353] = 326,
  [354] = 327,
  [355] = 328,
  [356] = 319,
  [357] = 320,
  [358] = 321,
  [359] = 322,
  [360] = 323,
  [361] = 324,
  [362] = 325,
  [363] = 326,
  [364] = 327,
  [365] = 328,
  [366] = 366,
  [367] = 336,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 371,
  [372] = 372,
  [373] = 373,
  [374] = 374,
  [375] = 338,
  [376] = 336,
  [377] = 377,
  [378] = 378,
  [379] = 379,
  [380] = 380,
  [381] = 381,
  [382] = 382,
  [383] = 383,
  [384] = 384,
  [385] = 4,
  [386] = 386,
  [387] = 337,
  [388] = 340,
  [389] = 373,
  [390] = 316,
  [391] = 333,
  [392] = 392,
  [393] = 335,
  [394] = 394,
  [395] = 395,
  [396] = 336,
  [397] = 342,
  [398] = 398,
  [399] = 399,
  [400] = 400,
  [401] = 401,
  [402] = 340,
  [403] = 373,
  [404] = 404,
  [405] = 316,
  [406] = 319,
  [407] = 340,
  [408] = 373,
  [409] = 320,
  [410] = 321,
  [411] = 322,
  [412] = 412,
  [413] = 404,
  [414] = 412,
  [415] = 335,
  [416] = 330,
  [417] = 331,
  [418] = 323,
  [419] = 386,
  [420] = 394,
  [421] = 324,
  [422] = 422,
  [423] = 404,
  [424] = 412,
  [425] = 335,
  [426] = 330,
  [427] = 331,
  [428] = 394,
  [429] = 325,
  [430] = 404,
  [431] = 412,
  [432] = 335,
  [433] = 394,
  [434] = 326,
  [435] = 394,
  [436] = 327,
  [437] = 328,
  [438] = 392,
  [439] = 439,
  [440] = 440,
  [441] = 441,
  [442] = 442,
  [443] = 443,
  [444] = 12,
  [445] = 64,
  [446] = 446,
  [447] = 447,
  [448] = 448,
  [449] = 449,
  [450] = 450,
  [451] = 451,
  [452] = 452,
  [453] = 453,
  [454] = 67,
  [455] = 455,
  [456] = 456,
  [457] = 457,
  [458] = 458,
  [459] = 459,
  [460] = 460,
  [461] = 461,
  [462] = 462,
  [463] = 463,
  [464] = 464,
  [465] = 465,
  [466] = 466,
  [467] = 467,
  [468] = 468,
  [469] = 469,
  [470] = 4,
  [471] = 471,
  [472] = 472,
  [473] = 473,
  [474] = 474,
  [475] = 475,
  [476] = 476,
  [477] = 74,
  [478] = 478,
  [479] = 479,
  [480] = 480,
  [481] = 75,
  [482] = 13,
  [483] = 483,
  [484] = 9,
  [485] = 73,
  [486] = 11,
  [487] = 80,
  [488] = 67,
  [489] = 214,
  [490] = 82,
  [491] = 67,
  [492] = 211,
  [493] = 12,
  [494] = 213,
  [495] = 12,
  [496] = 77,
  [497] = 81,
  [498] = 12,
  [499] = 64,
  [500] = 67,
  [501] = 217,
  [502] = 222,
  [503] = 74,
  [504] = 226,
  [505] = 220,
  [506] = 224,
  [507] = 225,
  [508] = 219,
  [509] = 221,
  [510] = 81,
  [511] = 230,
  [512] = 75,
  [513] = 73,
  [514] = 81,
  [515] = 249,
  [516] = 250,
  [517] = 241,
  [518] = 238,
  [519] = 291,
  [520] = 80,
  [521] = 236,
  [522] = 81,
  [523] = 242,
  [524] = 77,
  [525] = 82,
  [526] = 460,
  [527] = 240,
  [528] = 528,
  [529] = 529,
  [530] = 264,
  [531] = 271,
  [532] = 529,
  [533] = 529,
  [534] = 528,
  [535] = 529,
  [536] = 273,
  [537] = 528,
  [538] = 528,
  [539] = 529,
  [540] = 528,
  [541] = 295,
  [542] = 290,
  [543] = 292,
  [544] = 301,
  [545] = 459,
  [546] = 442,
  [547] = 453,
  [548] = 465,
  [549] = 468,
  [550] = 451,
  [551] = 471,
  [552] = 472,
  [553] = 446,
  [554] = 440,
  [555] = 461,
  [556] = 463,
  [557] = 475,
  [558] = 479,
  [559] = 443,
  [560] = 476,
  [561] = 456,
  [562] = 457,
  [563] = 480,
  [564] = 458,
  [565] = 462,
  [566] = 467,
  [567] = 473,
  [568] = 474,
  [569] = 447,
  [570] = 455,
  [571] = 439,
  [572] = 469,
  [573] = 448,
  [574] = 441,
  [575] = 575,
  [576] = 449,
  [577] = 450,
  [578] = 452,
  [579] = 466,
  [580] = 580,
  [581] = 575,
  [582] = 575,
  [583] = 575,
  [584] = 478,
  [585] = 575,
  [586] = 108,
  [587] = 587,
  [588] = 588,
  [589] = 107,
  [590] = 590,
  [591] = 101,
  [592] = 592,
  [593] = 593,
  [594] = 594,
  [595] = 595,
  [596] = 596,
  [597] = 597,
  [598] = 598,
  [599] = 599,
  [600] = 600,
  [601] = 601,
  [602] = 602,
  [603] = 603,
  [604] = 604,
  [605] = 605,
  [606] = 606,
  [607] = 607,
  [608] = 608,
  [609] = 609,
  [610] = 610,
  [611] = 98,
  [612] = 100,
  [613] = 97,
  [614] = 99,
  [615] = 615,
  [616] = 616,
  [617] = 617,
  [618] = 618,
  [619] = 619,
  [620] = 620,
  [621] = 106,
  [622] = 622,
  [623] = 623,
  [624] = 134,
  [625] = 148,
  [626] = 147,
  [627] = 139,
  [628] = 136,
  [629] = 137,
  [630] = 104,
  [631] = 127,
  [632] = 117,
  [633] = 143,
  [634] = 123,
  [635] = 464,
  [636] = 129,
  [637] = 131,
  [638] = 122,
  [639] = 639,
  [640] = 640,
  [641] = 641,
  [642] = 642,
  [643] = 643,
  [644] = 644,
  [645] = 645,
  [646] = 646,
  [647] = 647,
  [648] = 648,
  [649] = 649,
  [650] = 650,
  [651] = 651,
  [652] = 652,
  [653] = 653,
  [654] = 654,
  [655] = 655,
  [656] = 656,
  [657] = 657,
  [658] = 658,
  [659] = 113,
  [660] = 660,
  [661] = 661,
  [662] = 114,
  [663] = 145,
  [664] = 125,
  [665] = 150,
  [666] = 666,
  [667] = 109,
  [668] = 668,
  [669] = 118,
  [670] = 670,
  [671] = 671,
  [672] = 672,
  [673] = 138,
  [674] = 674,
  [675] = 675,
  [676] = 676,
  [677] = 677,
  [678] = 678,
  [679] = 679,
  [680] = 680,
  [681] = 681,
  [682] = 682,
  [683] = 683,
  [684] = 684,
  [685] = 685,
  [686] = 686,
  [687] = 687,
  [688] = 688,
  [689] = 689,
  [690] = 690,
  [691] = 691,
  [692] = 692,
  [693] = 693,
  [694] = 694,
  [695] = 130,
  [696] = 696,
  [697] = 697,
  [698] = 698,
  [699] = 699,
  [700] = 700,
  [701] = 119,
  [702] = 112,
  [703] = 115,
  [704] = 116,
  [705] = 120,
  [706] = 121,
  [707] = 124,
  [708] = 132,
  [709] = 133,
  [710] = 135,
  [711] = 141,
  [712] = 142,
  [713] = 713,
  [714] = 714,
  [715] = 140,
  [716] = 716,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 720,
  [721] = 146,
  [722] = 722,
  [723] = 723,
  [724] = 724,
  [725] = 725,
  [726] = 726,
  [727] = 727,
  [728] = 728,
  [729] = 111,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 733,
  [734] = 734,
  [735] = 735,
  [736] = 736,
  [737] = 737,
  [738] = 738,
  [739] = 739,
  [740] = 740,
  [741] = 741,
  [742] = 742,
  [743] = 98,
  [744] = 744,
  [745] = 99,
  [746] = 100,
  [747] = 744,
  [748] = 744,
  [749] = 101,
  [750] = 97,
  [751] = 751,
  [752] = 752,
  [753] = 751,
  [754] = 754,
  [755] = 751,
  [756] = 756,
  [757] = 751,
  [758] = 758,
  [759] = 751,
  [760] = 145,
  [761] = 761,
  [762] = 754,
  [763] = 101,
  [764] = 752,
  [765] = 765,
  [766] = 766,
  [767] = 767,
  [768] = 768,
  [769] = 100,
  [770] = 770,
  [771] = 144,
  [772] = 758,
  [773] = 145,
  [774] = 774,
  [775] = 775,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 781,
  [782] = 782,
  [783] = 783,
  [784] = 784,
  [785] = 785,
  [786] = 786,
  [787] = 106,
  [788] = 788,
  [789] = 789,
  [790] = 790,
  [791] = 107,
  [792] = 792,
  [793] = 793,
  [794] = 782,
  [795] = 778,
  [796] = 780,
  [797] = 797,
  [798] = 798,
  [799] = 770,
  [800] = 109,
  [801] = 790,
  [802] = 108,
  [803] = 782,
  [804] = 778,
  [805] = 780,
  [806] = 797,
  [807] = 798,
  [808] = 770,
  [809] = 756,
  [810] = 790,
  [811] = 797,
  [812] = 812,
  [813] = 790,
  [814] = 104,
  [815] = 812,
  [816] = 816,
  [817] = 779,
  [818] = 781,
  [819] = 798,
  [820] = 820,
  [821] = 812,
  [822] = 779,
  [823] = 781,
  [824] = 824,
  [825] = 825,
  [826] = 826,
  [827] = 151,
  [828] = 790,
  [829] = 124,
  [830] = 114,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 834,
  [835] = 123,
  [836] = 148,
  [837] = 837,
  [838] = 131,
  [839] = 109,
  [840] = 99,
  [841] = 125,
  [842] = 150,
  [843] = 117,
  [844] = 134,
  [845] = 845,
  [846] = 145,
  [847] = 127,
  [848] = 848,
  [849] = 849,
  [850] = 831,
  [851] = 851,
  [852] = 118,
  [853] = 112,
  [854] = 115,
  [855] = 834,
  [856] = 116,
  [857] = 848,
  [858] = 120,
  [859] = 121,
  [860] = 129,
  [861] = 861,
  [862] = 130,
  [863] = 851,
  [864] = 831,
  [865] = 851,
  [866] = 132,
  [867] = 119,
  [868] = 133,
  [869] = 848,
  [870] = 849,
  [871] = 833,
  [872] = 834,
  [873] = 136,
  [874] = 845,
  [875] = 135,
  [876] = 138,
  [877] = 845,
  [878] = 834,
  [879] = 879,
  [880] = 140,
  [881] = 141,
  [882] = 122,
  [883] = 142,
  [884] = 849,
  [885] = 111,
  [886] = 845,
  [887] = 137,
  [888] = 139,
  [889] = 146,
  [890] = 143,
  [891] = 147,
  [892] = 834,
  [893] = 113,
  [894] = 848,
  [895] = 832,
  [896] = 849,
  [897] = 845,
  [898] = 139,
  [899] = 899,
  [900] = 900,
  [901] = 901,
  [902] = 899,
  [903] = 123,
  [904] = 131,
  [905] = 134,
  [906] = 137,
  [907] = 143,
  [908] = 106,
  [909] = 147,
  [910] = 148,
  [911] = 911,
  [912] = 912,
  [913] = 913,
  [914] = 914,
  [915] = 915,
  [916] = 916,
  [917] = 917,
  [918] = 918,
  [919] = 919,
  [920] = 920,
  [921] = 107,
  [922] = 899,
  [923] = 899,
  [924] = 924,
  [925] = 925,
  [926] = 926,
  [927] = 927,
  [928] = 924,
  [929] = 929,
  [930] = 930,
  [931] = 931,
  [932] = 932,
  [933] = 933,
  [934] = 934,
  [935] = 935,
  [936] = 936,
  [937] = 937,
  [938] = 924,
  [939] = 924,
  [940] = 924,
  [941] = 941,
  [942] = 942,
  [943] = 943,
  [944] = 944,
  [945] = 945,
  [946] = 136,
  [947] = 947,
  [948] = 948,
  [949] = 127,
  [950] = 950,
  [951] = 951,
  [952] = 122,
  [953] = 953,
  [954] = 125,
  [955] = 150,
  [956] = 129,
  [957] = 80,
  [958] = 130,
  [959] = 138,
  [960] = 140,
  [961] = 82,
  [962] = 962,
  [963] = 963,
  [964] = 964,
  [965] = 965,
  [966] = 966,
  [967] = 967,
  [968] = 968,
  [969] = 969,
  [970] = 970,
  [971] = 971,
  [972] = 972,
  [973] = 971,
  [974] = 974,
  [975] = 975,
  [976] = 976,
  [977] = 976,
  [978] = 978,
  [979] = 979,
  [980] = 978,
  [981] = 981,
  [982] = 982,
  [983] = 983,
  [984] = 984,
  [985] = 985,
  [986] = 986,
  [987] = 987,
  [988] = 988,
  [989] = 989,
  [990] = 985,
  [991] = 991,
  [992] = 986,
  [993] = 993,
  [994] = 994,
  [995] = 995,
  [996] = 996,
  [997] = 997,
  [998] = 998,
  [999] = 999,
  [1000] = 1000,
  [1001] = 1001,
  [1002] = 1002,
  [1003] = 1003,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 1007,
  [1008] = 1008,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1013,
  [1014] = 1011,
  [1015] = 214,
  [1016] = 1016,
  [1017] = 1017,
  [1018] = 1012,
  [1019] = 1019,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 1021,
  [1023] = 1023,
  [1024] = 1024,
  [1025] = 1025,
  [1026] = 1026,
  [1027] = 1027,
  [1028] = 1028,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 1031,
  [1032] = 1032,
  [1033] = 1021,
  [1034] = 1034,
  [1035] = 1035,
  [1036] = 1036,
  [1037] = 1037,
  [1038] = 1038,
  [1039] = 1039,
  [1040] = 1040,
  [1041] = 1041,
  [1042] = 1042,
  [1043] = 1043,
  [1044] = 1044,
  [1045] = 1045,
  [1046] = 1046,
  [1047] = 1042,
  [1048] = 1048,
  [1049] = 1048,
  [1050] = 1050,
  [1051] = 1051,
  [1052] = 1052,
  [1053] = 1053,
  [1054] = 1054,
  [1055] = 1055,
  [1056] = 1056,
  [1057] = 1029,
  [1058] = 1044,
  [1059] = 1042,
  [1060] = 1042,
  [1061] = 1042,
  [1062] = 1043,
  [1063] = 1063,
  [1064] = 1064,
  [1065] = 1065,
  [1066] = 1066,
  [1067] = 1067,
  [1068] = 1068,
  [1069] = 230,
  [1070] = 1070,
  [1071] = 1071,
  [1072] = 1072,
  [1073] = 1073,
  [1074] = 1074,
  [1075] = 1075,
  [1076] = 1076,
  [1077] = 1077,
  [1078] = 1078,
  [1079] = 1079,
  [1080] = 1068,
  [1081] = 1081,
  [1082] = 1082,
  [1083] = 1083,
  [1084] = 1084,
  [1085] = 1083,
  [1086] = 1086,
  [1087] = 1087,
  [1088] = 1088,
  [1089] = 1089,
  [1090] = 1090,
  [1091] = 1082,
  [1092] = 1092,
  [1093] = 1093,
  [1094] = 1094,
  [1095] = 1095,
  [1096] = 1076,
  [1097] = 1074,
  [1098] = 1098,
  [1099] = 1082,
  [1100] = 1100,
  [1101] = 1101,
  [1102] = 1082,
  [1103] = 1103,
  [1104] = 1104,
  [1105] = 1105,
  [1106] = 1106,
  [1107] = 220,
  [1108] = 1108,
  [1109] = 1109,
  [1110] = 1110,
  [1111] = 1106,
  [1112] = 1112,
  [1113] = 1113,
  [1114] = 1114,
  [1115] = 1115,
  [1116] = 1116,
  [1117] = 1117,
  [1118] = 1118,
  [1119] = 1119,
  [1120] = 1120,
  [1121] = 1121,
  [1122] = 1122,
  [1123] = 1123,
  [1124] = 1124,
  [1125] = 1125,
  [1126] = 1126,
  [1127] = 1127,
  [1128] = 1128,
  [1129] = 1129,
  [1130] = 1130,
  [1131] = 1131,
  [1132] = 1132,
  [1133] = 221,
  [1134] = 1134,
  [1135] = 1135,
  [1136] = 1136,
  [1137] = 1137,
  [1138] = 1138,
  [1139] = 1139,
  [1140] = 1140,
  [1141] = 1141,
  [1142] = 1142,
  [1143] = 1112,
  [1144] = 1144,
  [1145] = 226,
  [1146] = 1146,
  [1147] = 224,
  [1148] = 225,
  [1149] = 1149,
  [1150] = 1150,
  [1151] = 1151,
  [1152] = 219,
  [1153] = 217,
  [1154] = 222,
  [1155] = 1155,
  [1156] = 1156,
  [1157] = 1157,
  [1158] = 1126,
  [1159] = 1113,
  [1160] = 1160,
  [1161] = 1161,
  [1162] = 1162,
  [1163] = 1163,
  [1164] = 1164,
  [1165] = 1165,
  [1166] = 1166,
  [1167] = 1167,
  [1168] = 1167,
  [1169] = 1169,
  [1170] = 1170,
  [1171] = 1171,
  [1172] = 1172,
  [1173] = 1167,
  [1174] = 1174,
  [1175] = 1175,
  [1176] = 1176,
  [1177] = 1177,
  [1178] = 1175,
  [1179] = 1179,
  [1180] = 1175,
  [1181] = 1181,
  [1182] = 464,
  [1183] = 1183,
  [1184] = 1165,
  [1185] = 1171,
  [1186] = 1186,
  [1187] = 1187,
  [1188] = 1175,
  [1189] = 1189,
  [1190] = 1190,
  [1191] = 1171,
  [1192] = 1192,
  [1193] = 1190,
  [1194] = 1194,
  [1195] = 1195,
  [1196] = 1196,
  [1197] = 1197,
  [1198] = 1198,
  [1199] = 1199,
  [1200] = 1200,
  [1201] = 1201,
  [1202] = 1202,
  [1203] = 1203,
  [1204] = 1204,
  [1205] = 1205,
  [1206] = 1206,
  [1207] = 1207,
  [1208] = 1208,
  [1209] = 1209,
  [1210] = 1210,
  [1211] = 1196,
  [1212] = 1212,
  [1213] = 1213,
  [1214] = 1196,
  [1215] = 1215,
  [1216] = 1216,
  [1217] = 1217,
  [1218] = 1218,
  [1219] = 1219,
  [1220] = 1220,
  [1221] = 1221,
  [1222] = 1218,
  [1223] = 1223,
  [1224] = 1196,
  [1225] = 1215,
  [1226] = 1226,
  [1227] = 1227,
  [1228] = 1228,
  [1229] = 1229,
  [1230] = 1215,
  [1231] = 1231,
  [1232] = 1232,
  [1233] = 1196,
  [1234] = 1215,
  [1235] = 1235,
  [1236] = 1196,
  [1237] = 1215,
  [1238] = 1215,
  [1239] = 1196,
  [1240] = 1215,
  [1241] = 1241,
  [1242] = 1242,
  [1243] = 1197,
  [1244] = 1244,
  [1245] = 1245,
  [1246] = 1246,
  [1247] = 1247,
  [1248] = 1248,
  [1249] = 1249,
  [1250] = 1250,
  [1251] = 1251,
  [1252] = 1252,
  [1253] = 1197,
  [1254] = 1254,
  [1255] = 1255,
  [1256] = 1256,
  [1257] = 1257,
  [1258] = 1258,
  [1259] = 1259,
  [1260] = 1260,
  [1261] = 1255,
  [1262] = 1262,
  [1263] = 1263,
  [1264] = 1255,
  [1265] = 1265,
  [1266] = 1266,
  [1267] = 1267,
  [1268] = 1268,
  [1269] = 1269,
  [1270] = 1270,
  [1271] = 1271,
  [1272] = 1272,
  [1273] = 1273,
  [1274] = 1274,
  [1275] = 1275,
  [1276] = 1201,
  [1277] = 1277,
  [1278] = 1278,
  [1279] = 1279,
  [1280] = 1280,
  [1281] = 1281,
  [1282] = 1282,
  [1283] = 1283,
  [1284] = 1284,
  [1285] = 1259,
  [1286] = 1255,
  [1287] = 1287,
  [1288] = 1267,
  [1289] = 1289,
  [1290] = 1290,
  [1291] = 1270,
  [1292] = 1292,
  [1293] = 1293,
  [1294] = 1294,
  [1295] = 1295,
  [1296] = 1296,
  [1297] = 1297,
  [1298] = 1298,
  [1299] = 1299,
  [1300] = 1300,
  [1301] = 1256,
  [1302] = 1302,
  [1303] = 1282,
  [1304] = 1304,
  [1305] = 1259,
  [1306] = 1306,
  [1307] = 1282,
  [1308] = 1267,
  [1309] = 1309,
  [1310] = 1310,
  [1311] = 1270,
  [1312] = 1312,
  [1313] = 1313,
  [1314] = 1282,
  [1315] = 1315,
  [1316] = 1259,
  [1317] = 1255,
  [1318] = 1267,
  [1319] = 1319,
  [1320] = 1270,
  [1321] = 1321,
  [1322] = 1259,
  [1323] = 1323,
  [1324] = 1324,
  [1325] = 1325,
  [1326] = 1326,
  [1327] = 1327,
  [1328] = 1328,
  [1329] = 1329,
  [1330] = 1330,
  [1331] = 1267,
  [1332] = 1332,
  [1333] = 1333,
  [1334] = 1270,
  [1335] = 1335,
  [1336] = 1336,
  [1337] = 1337,
  [1338] = 1338,
  [1339] = 1339,
  [1340] = 1340,
  [1341] = 1341,
  [1342] = 1262,
  [1343] = 1343,
  [1344] = 1344,
  [1345] = 1345,
  [1346] = 1282,
  [1347] = 1347,
  [1348] = 1348,
  [1349] = 1349,
  [1350] = 1350,
  [1351] = 1351,
  [1352] = 1352,
  [1353] = 1353,
  [1354] = 1354,
  [1355] = 1355,
  [1356] = 1356,
  [1357] = 1357,
  [1358] = 1358,
  [1359] = 1359,
  [1360] = 1360,
  [1361] = 1361,
  [1362] = 1362,
  [1363] = 1363,
  [1364] = 1364,
  [1365] = 1365,
  [1366] = 1366,
  [1367] = 1367,
  [1368] = 1368,
  [1369] = 1369,
  [1370] = 1370,
  [1371] = 1371,
  [1372] = 1372,
  [1373] = 1373,
  [1374] = 1374,
  [1375] = 1375,
  [1376] = 1376,
  [1377] = 1377,
  [1378] = 1378,
  [1379] = 1379,
  [1380] = 1380,
  [1381] = 1381,
  [1382] = 1382,
  [1383] = 1383,
  [1384] = 1384,
  [1385] = 1385,
  [1386] = 1386,
  [1387] = 1379,
  [1388] = 1231,
  [1389] = 1389,
  [1390] = 1390,
  [1391] = 1391,
  [1392] = 1329,
  [1393] = 1393,
  [1394] = 1394,
  [1395] = 1368,
  [1396] = 1396,
  [1397] = 1397,
  [1398] = 1398,
  [1399] = 1399,
  [1400] = 1370,
  [1401] = 1401,
  [1402] = 1402,
  [1403] = 1403,
  [1404] = 1404,
  [1405] = 1405,
  [1406] = 1406,
  [1407] = 1370,
  [1408] = 1408,
  [1409] = 1409,
  [1410] = 1410,
  [1411] = 1411,
  [1412] = 1412,
  [1413] = 1413,
  [1414] = 1414,
  [1415] = 1415,
  [1416] = 1416,
  [1417] = 1378,
  [1418] = 1418,
  [1419] = 1370,
  [1420] = 1420,
  [1421] = 1421,
  [1422] = 1422,
  [1423] = 1423,
  [1424] = 1424,
  [1425] = 1384,
  [1426] = 1370,
  [1427] = 1427,
  [1428] = 1384,
  [1429] = 1429,
  [1430] = 1430,
  [1431] = 1431,
  [1432] = 1383,
  [1433] = 1433,
  [1434] = 1434,
  [1435] = 1435,
  [1436] = 1436,
  [1437] = 1437,
  [1438] = 1438,
  [1439] = 1383,
  [1440] = 1440,
  [1441] = 1441,
  [1442] = 1442,
  [1443] = 1443,
  [1444] = 1444,
  [1445] = 1445,
  [1446] = 1383,
  [1447] = 1447,
  [1448] = 1448,
  [1449] = 1378,
  [1450] = 1450,
  [1451] = 1383,
  [1452] = 1452,
  [1453] = 1430,
  [1454] = 1430,
  [1455] = 1455,
  [1456] = 1456,
  [1457] = 1457,
  [1458] = 1458,
  [1459] = 1459,
  [1460] = 1460,
  [1461] = 1461,
  [1462] = 1462,
  [1463] = 1463,
  [1464] = 1464,
  [1465] = 1465,
  [1466] = 1466,
  [1467] = 1467,
  [1468] = 1468,
  [1469] = 1469,
  [1470] = 1470,
  [1471] = 1471,
  [1472] = 1457,
  [1473] = 1473,
  [1474] = 1474,
  [1475] = 1475,
  [1476] = 1469,
  [1477] = 1457,
  [1478] = 1478,
  [1479] = 1471,
  [1480] = 1478,
  [1481] = 1481,
  [1482] = 1482,
  [1483] = 1483,
  [1484] = 1484,
  [1485] = 1485,
  [1486] = 1486,
  [1487] = 1487,
  [1488] = 1488,
  [1489] = 1489,
  [1490] = 1463,
  [1491] = 1491,
  [1492] = 1492,
  [1493] = 1232,
  [1494] = 1494,
  [1495] = 1495,
  [1496] = 1496,
  [1497] = 1497,
  [1498] = 1498,
  [1499] = 1499,
  [1500] = 1500,
  [1501] = 1501,
  [1502] = 1502,
  [1503] = 1503,
  [1504] = 1504,
  [1505] = 1505,
  [1506] = 1506,
  [1507] = 1507,
  [1508] = 1508,
  [1509] = 1509,
  [1510] = 1510,
  [1511] = 1511,
  [1512] = 1512,
  [1513] = 1458,
  [1514] = 1463,
  [1515] = 1515,
  [1516] = 1516,
  [1517] = 1501,
  [1518] = 1518,
  [1519] = 1483,
  [1520] = 1520,
  [1521] = 1521,
  [1522] = 1471,
  [1523] = 1523,
  [1524] = 1524,
  [1525] = 1525,
  [1526] = 1469,
  [1527] = 1527,
  [1528] = 1478,
  [1529] = 1529,
  [1530] = 1495,
  [1531] = 1531,
  [1532] = 1483,
  [1533] = 1533,
  [1534] = 1534,
  [1535] = 1535,
  [1536] = 1489,
  [1537] = 1537,
  [1538] = 1491,
  [1539] = 1539,
  [1540] = 1540,
  [1541] = 1495,
  [1542] = 1542,
  [1543] = 1543,
  [1544] = 1463,
  [1545] = 1489,
  [1546] = 1546,
  [1547] = 1547,
  [1548] = 1548,
  [1549] = 1549,
  [1550] = 1550,
  [1551] = 1471,
  [1552] = 1552,
  [1553] = 1553,
  [1554] = 1491,
  [1555] = 1469,
  [1556] = 1457,
  [1557] = 1489,
  [1558] = 1507,
  [1559] = 1559,
  [1560] = 1483,
  [1561] = 1489,
  [1562] = 1491,
  [1563] = 1563,
  [1564] = 1495,
  [1565] = 1565,
  [1566] = 1504,
  [1567] = 1567,
  [1568] = 1568,
  [1569] = 1569,
  [1570] = 1570,
  [1571] = 1510,
  [1572] = 1572,
  [1573] = 1573,
  [1574] = 1491,
  [1575] = 1575,
  [1576] = 1576,
  [1577] = 1495,
  [1578] = 1578,
  [1579] = 1579,
  [1580] = 1580,
  [1581] = 1581,
  [1582] = 1582,
  [1583] = 1523,
  [1584] = 1584,
  [1585] = 1508,
  [1586] = 295,
  [1587] = 1587,
  [1588] = 1588,
  [1589] = 1589,
  [1590] = 1498,
  [1591] = 1591,
  [1592] = 1592,
  [1593] = 1521,
  [1594] = 1594,
  [1595] = 1595,
  [1596] = 1510,
  [1597] = 1597,
  [1598] = 1598,
  [1599] = 1498,
  [1600] = 1511,
  [1601] = 1478,
  [1602] = 1602,
  [1603] = 1464,
  [1604] = 1604,
  [1605] = 1605,
  [1606] = 1606,
  [1607] = 1607,
  [1608] = 1501,
  [1609] = 1609,
  [1610] = 1610,
  [1611] = 1510,
  [1612] = 1612,
  [1613] = 1504,
  [1614] = 1469,
  [1615] = 1615,
  [1616] = 1471,
  [1617] = 1617,
  [1618] = 1587,
  [1619] = 1619,
  [1620] = 1620,
  [1621] = 1510,
  [1622] = 1507,
  [1623] = 1508,
  [1624] = 1461,
  [1625] = 1553,
  [1626] = 1626,
  [1627] = 1627,
  [1628] = 1628,
  [1629] = 1629,
  [1630] = 1582,
  [1631] = 1483,
  [1632] = 1525,
  [1633] = 1461,
  [1634] = 1553,
  [1635] = 1457,
  [1636] = 1494,
  [1637] = 1629,
  [1638] = 1582,
  [1639] = 1639,
  [1640] = 1582,
  [1641] = 1582,
  [1642] = 1627,
  [1643] = 1474,
  [1644] = 1463,
  [1645] = 1645,
  [1646] = 1627,
  [1647] = 1645,
  [1648] = 1645,
  [1649] = 1645,
  [1650] = 1575,
  [1651] = 1651,
  [1652] = 1645,
  [1653] = 1511,
  [1654] = 1527,
  [1655] = 1527,
  [1656] = 1527,
  [1657] = 1527,
  [1658] = 1658,
  [1659] = 1659,
  [1660] = 1660,
  [1661] = 148,
  [1662] = 1662,
  [1663] = 1663,
  [1664] = 1664,
  [1665] = 1665,
  [1666] = 1666,
  [1667] = 1667,
  [1668] = 1668,
  [1669] = 1669,
  [1670] = 147,
  [1671] = 1671,
  [1672] = 1672,
  [1673] = 1673,
};

static TSCharacterRange sym_escape_sequence_character_set_1[] = {
  {'"', '"'}, {'\'', '\''}, {'0', '9'}, {'\\', '\\'}, {'a', 'b'}, {'e', 'f'}, {'n', 'n'}, {'r', 'r'},
  {'t', 't'}, {'x', 'x'},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(135);
      ADVANCE_MAP(
        '!', 139,
        '"', 252,
        '#', 55,
        '%', 157,
        '&', 150,
        '\'', 246,
        '(', 136,
        ')', 137,
        '*', 153,
        '+', 147,
        ',', 183,
        '-', 144,
        '.', 229,
        '/', 155,
        '0', 234,
        ':', 209,
        ';', 226,
        '<', 172,
        '=', 197,
        '>', 167,
        '?', 230,
        '[', 222,
        '\\', 2,
        ']', 223,
        '^', 163,
        'u', 265,
        '{', 220,
        '|', 160,
        '}', 221,
        '~', 141,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(133);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(235);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(23);
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(23);
      if (lookahead == '\r') SKIP(1);
      if (lookahead == 'x') ADVANCE(258);
      if ((set_contains(sym_escape_sequence_character_set_1, 10, lookahead)) &&
          (lookahead < '0' || '9' < lookahead)) ADVANCE(254);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(256);
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(26);
      END_STATE();
    case 4:
      if (lookahead == '\n') SKIP(26);
      if (lookahead == '\r') SKIP(3);
      END_STATE();
    case 5:
      if (lookahead == '\n') SKIP(28);
      END_STATE();
    case 6:
      if (lookahead == '\n') SKIP(28);
      if (lookahead == '\r') SKIP(5);
      END_STATE();
    case 7:
      if (lookahead == '\n') SKIP(27);
      END_STATE();
    case 8:
      if (lookahead == '\n') SKIP(27);
      if (lookahead == '\r') SKIP(7);
      END_STATE();
    case 9:
      if (lookahead == '\n') SKIP(29);
      END_STATE();
    case 10:
      if (lookahead == '\n') SKIP(29);
      if (lookahead == '\r') SKIP(9);
      END_STATE();
    case 11:
      if (lookahead == '\n') SKIP(31);
      END_STATE();
    case 12:
      if (lookahead == '\n') SKIP(31);
      if (lookahead == '\r') SKIP(11);
      END_STATE();
    case 13:
      if (lookahead == '\n') ADVANCE(253);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '\n', 253,
        '\r', 13,
        'x', 258,
        '"', 254,
        '\'', 254,
        '\\', 254,
        'a', 254,
        'b', 254,
        'e', 254,
        'f', 254,
        'n', 254,
        'r', 254,
        't', 254,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(256);
      END_STATE();
    case 15:
      if (lookahead == '\n') SKIP(34);
      END_STATE();
    case 16:
      if (lookahead == '\n') SKIP(34);
      if (lookahead == '\r') SKIP(15);
      if (lookahead == 'x') ADVANCE(258);
      if ((set_contains(sym_escape_sequence_character_set_1, 10, lookahead)) &&
          (lookahead < '0' || '9' < lookahead)) ADVANCE(254);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(256);
      END_STATE();
    case 17:
      if (lookahead == '\n') SKIP(34);
      if (lookahead == '#') ADVANCE(250);
      if (lookahead == '/') ADVANCE(248);
      if (lookahead == '\\') ADVANCE(251);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(249);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(247);
      END_STATE();
    case 18:
      if (lookahead == '\n') SKIP(35);
      END_STATE();
    case 19:
      if (lookahead == '\n') SKIP(35);
      if (lookahead == '\r') SKIP(18);
      END_STATE();
    case 20:
      if (lookahead == '\n') SKIP(24);
      END_STATE();
    case 21:
      if (lookahead == '\n') SKIP(24);
      if (lookahead == '\r') SKIP(20);
      END_STATE();
    case 22:
      ADVANCE_MAP(
        '!', 139,
        '"', 252,
        '#', 55,
        '%', 157,
        '&', 150,
        '\'', 246,
        '(', 136,
        ')', 137,
        '*', 153,
        '+', 147,
        ',', 183,
        '-', 144,
        '.', 229,
        '/', 155,
        '0', 234,
        ':', 209,
        ';', 226,
        '<', 172,
        '=', 197,
        '>', 167,
        '?', 230,
        '[', 222,
      );
      if (lookahead == '\\') SKIP(21);
      if (lookahead == ']') ADVANCE(223);
      if (lookahead == '^') ADVANCE(163);
      if (lookahead == '{') ADVANCE(220);
      if (lookahead == '|') ADVANCE(160);
      if (lookahead == '}') ADVANCE(221);
      if (lookahead == '~') ADVANCE(141);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(24);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(235);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 23:
      ADVANCE_MAP(
        '!', 139,
        '"', 252,
        '#', 55,
        '%', 157,
        '&', 150,
        '\'', 246,
        '(', 136,
        ')', 137,
        '*', 153,
        '+', 147,
        ',', 183,
        '-', 144,
        '.', 229,
        '/', 155,
        '0', 234,
        ':', 225,
        ';', 226,
        '<', 172,
        '=', 197,
        '>', 167,
        '?', 230,
        '[', 222,
        '\\', 2,
        ']', 223,
        '^', 163,
        'u', 265,
        '{', 220,
        '|', 160,
        '}', 221,
        '~', 141,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(23);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(235);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 24:
      ADVANCE_MAP(
        '!', 139,
        '"', 252,
        '#', 55,
        '%', 157,
        '&', 150,
        '\'', 246,
        '(', 136,
        ')', 137,
        '*', 153,
        '+', 147,
        ',', 183,
        '-', 144,
        '.', 229,
        '/', 155,
        '0', 234,
        ':', 43,
        ';', 226,
        '<', 172,
        '=', 197,
        '>', 167,
        '?', 230,
        '[', 222,
      );
      if (lookahead == '\\') SKIP(21);
      if (lookahead == ']') ADVANCE(223);
      if (lookahead == '^') ADVANCE(163);
      if (lookahead == '{') ADVANCE(220);
      if (lookahead == '|') ADVANCE(160);
      if (lookahead == '}') ADVANCE(221);
      if (lookahead == '~') ADVANCE(141);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(24);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(235);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 25:
      ADVANCE_MAP(
        '!', 138,
        '"', 252,
        '#', 55,
        '%', 128,
        '&', 148,
        '\'', 246,
        '(', 136,
        ')', 137,
        '+', 146,
        ',', 183,
        '-', 143,
        '.', 229,
        '/', 36,
        '0', 234,
        ':', 208,
        ';', 226,
        '<', 171,
        '=', 196,
        '>', 166,
        '[', 222,
      );
      if (lookahead == '\\') SKIP(4);
      if (lookahead == ']') ADVANCE(223);
      if (lookahead == '{') ADVANCE(220);
      if (lookahead == '}') ADVANCE(221);
      if (lookahead == '~') ADVANCE(140);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(26);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(235);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 26:
      ADVANCE_MAP(
        '!', 138,
        '"', 252,
        '#', 55,
        '%', 128,
        '&', 148,
        '\'', 246,
        '(', 136,
        ')', 137,
        '+', 146,
        ',', 183,
        '-', 143,
        '.', 229,
        '/', 36,
        '0', 234,
        ';', 226,
        '<', 171,
        '=', 196,
        '>', 166,
        '[', 222,
      );
      if (lookahead == '\\') SKIP(4);
      if (lookahead == ']') ADVANCE(223);
      if (lookahead == '{') ADVANCE(220);
      if (lookahead == '}') ADVANCE(221);
      if (lookahead == '~') ADVANCE(140);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(26);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(235);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 27:
      ADVANCE_MAP(
        '!', 138,
        '"', 252,
        '#', 55,
        '&', 148,
        '\'', 246,
        '(', 136,
        '+', 145,
        '-', 142,
        '.', 39,
        '/', 36,
        '0', 234,
      );
      if (lookahead == '\\') SKIP(8);
      if (lookahead == '{') ADVANCE(220);
      if (lookahead == '}') ADVANCE(221);
      if (lookahead == '~') ADVANCE(140);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(27);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(235);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 28:
      ADVANCE_MAP(
        '!', 44,
        '#', 55,
        '%', 157,
        '&', 150,
        '(', 136,
        ')', 137,
        '*', 153,
        '+', 147,
        ',', 183,
        '-', 144,
        '.', 229,
        '/', 155,
        ':', 224,
        ';', 226,
        '<', 172,
        '=', 197,
        '>', 167,
        '?', 230,
        '[', 222,
      );
      if (lookahead == '\\') SKIP(6);
      if (lookahead == ']') ADVANCE(223);
      if (lookahead == '^') ADVANCE(163);
      if (lookahead == '|') ADVANCE(160);
      if (lookahead == '}') ADVANCE(221);
      if (lookahead == '~') ADVANCE(46);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(28);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        '!', 44,
        '#', 55,
        '%', 156,
        '&', 149,
        ')', 137,
        '*', 152,
        '+', 145,
        ',', 183,
        '-', 142,
        '.', 229,
        '/', 154,
        ':', 225,
        '<', 173,
        '=', 45,
        '>', 168,
        '[', 222,
      );
      if (lookahead == '\\') SKIP(10);
      if (lookahead == '^') ADVANCE(162);
      if (lookahead == '|') ADVANCE(161);
      if (lookahead == '}') ADVANCE(221);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(29);
      END_STATE();
    case 30:
      ADVANCE_MAP(
        '!', 44,
        '#', 55,
        '%', 156,
        '&', 149,
        '*', 152,
        '+', 145,
        ',', 183,
        '-', 142,
        '.', 39,
        '/', 154,
        ':', 208,
        '<', 173,
        '=', 45,
        '>', 168,
      );
      if (lookahead == '\\') SKIP(12);
      if (lookahead == '^') ADVANCE(162);
      if (lookahead == '|') ADVANCE(161);
      if (lookahead == '}') ADVANCE(221);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(31);
      END_STATE();
    case 31:
      ADVANCE_MAP(
        '!', 44,
        '#', 55,
        '%', 156,
        '&', 149,
        '*', 152,
        '+', 145,
        ',', 183,
        '-', 142,
        '.', 39,
        '/', 154,
        '<', 173,
        '=', 45,
        '>', 168,
      );
      if (lookahead == '\\') SKIP(12);
      if (lookahead == '^') ADVANCE(162);
      if (lookahead == '|') ADVANCE(161);
      if (lookahead == '}') ADVANCE(221);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(31);
      END_STATE();
    case 32:
      ADVANCE_MAP(
        '!', 203,
        '#', 55,
        '&', 199,
        '+', 201,
        '-', 202,
        '/', 200,
        '<', 207,
        '=', 47,
        '>', 204,
      );
      if (lookahead == '\\') SKIP(19);
      if (lookahead == '|') ADVANCE(206);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '^') ADVANCE(198);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(35);
      END_STATE();
    case 33:
      if (lookahead == '"') ADVANCE(252);
      if (lookahead == '#') ADVANCE(253);
      if (lookahead == '/') ADVANCE(253);
      if (lookahead == '\\') ADVANCE(14);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(253);
      if (lookahead != 0) ADVANCE(253);
      END_STATE();
    case 34:
      if (lookahead == '#') ADVANCE(55);
      if (lookahead == '/') ADVANCE(36);
      if (lookahead == '\\') ADVANCE(16);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(34);
      END_STATE();
    case 35:
      if (lookahead == '#') ADVANCE(55);
      if (lookahead == '/') ADVANCE(36);
      if (lookahead == '\\') SKIP(19);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(35);
      END_STATE();
    case 36:
      if (lookahead == '*') ADVANCE(38);
      if (lookahead == '/') ADVANCE(268);
      END_STATE();
    case 37:
      if (lookahead == '*') ADVANCE(37);
      if (lookahead == '/') ADVANCE(267);
      if (lookahead != 0) ADVANCE(38);
      END_STATE();
    case 38:
      if (lookahead == '*') ADVANCE(37);
      if (lookahead != 0) ADVANCE(38);
      END_STATE();
    case 39:
      if (lookahead == '.') ADVANCE(41);
      END_STATE();
    case 40:
      if (lookahead == '.') ADVANCE(244);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(235);
      END_STATE();
    case 41:
      if (lookahead == '.') ADVANCE(151);
      END_STATE();
    case 42:
      if (lookahead == '.') ADVANCE(50);
      END_STATE();
    case 43:
      if (lookahead == ':') ADVANCE(231);
      END_STATE();
    case 44:
      if (lookahead == '=') ADVANCE(165);
      END_STATE();
    case 45:
      if (lookahead == '=') ADVANCE(164);
      END_STATE();
    case 46:
      if (lookahead == '=') ADVANCE(217);
      END_STATE();
    case 47:
      if (lookahead == '=') ADVANCE(198);
      END_STATE();
    case 48:
      if (lookahead == '>') ADVANCE(259);
      if (lookahead == '\\') ADVANCE(49);
      if (lookahead != 0) ADVANCE(48);
      END_STATE();
    case 49:
      if (lookahead == '>') ADVANCE(260);
      if (lookahead == '\\') ADVANCE(49);
      if (lookahead != 0) ADVANCE(48);
      END_STATE();
    case 50:
      if (lookahead == 'H') ADVANCE(59);
      END_STATE();
    case 51:
      if (lookahead == '_') ADVANCE(42);
      END_STATE();
    case 52:
      if (lookahead == '_') ADVANCE(54);
      END_STATE();
    case 53:
      if (lookahead == '_') ADVANCE(51);
      END_STATE();
    case 54:
      if (lookahead == '_') ADVANCE(88);
      END_STATE();
    case 55:
      ADVANCE_MAP(
        'a', 112,
        'd', 68,
        'e', 92,
        'i', 76,
        'p', 110,
        't', 105,
        'u', 95,
        'w', 58,
      );
      END_STATE();
    case 56:
      if (lookahead == 'a') ADVANCE(81);
      END_STATE();
    case 57:
      if (lookahead == 'a') ADVANCE(192);
      END_STATE();
    case 58:
      if (lookahead == 'a') ADVANCE(109);
      END_STATE();
    case 59:
      if (lookahead == 'a') ADVANCE(100);
      END_STATE();
    case 60:
      if (lookahead == 'c') ADVANCE(90);
      END_STATE();
    case 61:
      if (lookahead == 'c') ADVANCE(116);
      END_STATE();
    case 62:
      if (lookahead == 'c') ADVANCE(93);
      END_STATE();
    case 63:
      if (lookahead == 'd') ADVANCE(83);
      END_STATE();
    case 64:
      if (lookahead == 'd') ADVANCE(91);
      END_STATE();
    case 65:
      if (lookahead == 'd') ADVANCE(71);
      END_STATE();
    case 66:
      if (lookahead == 'd') ADVANCE(72);
      END_STATE();
    case 67:
      if (lookahead == 'd') ADVANCE(74);
      END_STATE();
    case 68:
      if (lookahead == 'e') ADVANCE(77);
      END_STATE();
    case 69:
      if (lookahead == 'e') ADVANCE(189);
      END_STATE();
    case 70:
      if (lookahead == 'e') ADVANCE(182);
      END_STATE();
    case 71:
      if (lookahead == 'e') ADVANCE(180);
      END_STATE();
    case 72:
      if (lookahead == 'e') ADVANCE(181);
      END_STATE();
    case 73:
      if (lookahead == 'e') ADVANCE(195);
      END_STATE();
    case 74:
      if (lookahead == 'e') ADVANCE(79);
      END_STATE();
    case 75:
      if (lookahead == 'e') ADVANCE(107);
      END_STATE();
    case 76:
      if (lookahead == 'f') ADVANCE(186);
      if (lookahead == 'n') ADVANCE(60);
      END_STATE();
    case 77:
      if (lookahead == 'f') ADVANCE(85);
      END_STATE();
    case 78:
      if (lookahead == 'f') ADVANCE(190);
      if (lookahead == 'n') ADVANCE(104);
      END_STATE();
    case 79:
      if (lookahead == 'f') ADVANCE(185);
      END_STATE();
    case 80:
      if (lookahead == 'f') ADVANCE(187);
      END_STATE();
    case 81:
      if (lookahead == 'g') ADVANCE(94);
      END_STATE();
    case 82:
      if (lookahead == 'g') ADVANCE(194);
      END_STATE();
    case 83:
      if (lookahead == 'i') ADVANCE(78);
      END_STATE();
    case 84:
      if (lookahead == 'i') ADVANCE(61);
      END_STATE();
    case 85:
      if (lookahead == 'i') ADVANCE(99);
      END_STATE();
    case 86:
      if (lookahead == 'i') ADVANCE(102);
      END_STATE();
    case 87:
      if (lookahead == 'i') ADVANCE(96);
      END_STATE();
    case 88:
      if (lookahead == 'i') ADVANCE(98);
      END_STATE();
    case 89:
      if (lookahead == 'i') ADVANCE(97);
      END_STATE();
    case 90:
      if (lookahead == 'l') ADVANCE(121);
      END_STATE();
    case 91:
      if (lookahead == 'l') ADVANCE(73);
      END_STATE();
    case 92:
      if (lookahead == 'l') ADVANCE(114);
      if (lookahead == 'n') ADVANCE(63);
      if (lookahead == 'r') ADVANCE(106);
      END_STATE();
    case 93:
      if (lookahead == 'l') ADVANCE(122);
      END_STATE();
    case 94:
      if (lookahead == 'm') ADVANCE(57);
      END_STATE();
    case 95:
      if (lookahead == 'n') ADVANCE(67);
      END_STATE();
    case 96:
      if (lookahead == 'n') ADVANCE(82);
      END_STATE();
    case 97:
      if (lookahead == 'n') ADVANCE(115);
      END_STATE();
    case 98:
      if (lookahead == 'n') ADVANCE(119);
      END_STATE();
    case 99:
      if (lookahead == 'n') ADVANCE(70);
      END_STATE();
    case 100:
      if (lookahead == 'n') ADVANCE(64);
      END_STATE();
    case 101:
      if (lookahead == 'n') ADVANCE(87);
      END_STATE();
    case 102:
      if (lookahead == 'n') ADVANCE(62);
      END_STATE();
    case 103:
      if (lookahead == 'o') ADVANCE(108);
      END_STATE();
    case 104:
      if (lookahead == 'p') ADVANCE(120);
      END_STATE();
    case 105:
      if (lookahead == 'r') ADVANCE(123);
      END_STATE();
    case 106:
      if (lookahead == 'r') ADVANCE(103);
      END_STATE();
    case 107:
      if (lookahead == 'r') ADVANCE(117);
      END_STATE();
    case 108:
      if (lookahead == 'r') ADVANCE(193);
      END_STATE();
    case 109:
      if (lookahead == 'r') ADVANCE(101);
      END_STATE();
    case 110:
      if (lookahead == 'r') ADVANCE(56);
      END_STATE();
    case 111:
      if (lookahead == 'r') ADVANCE(89);
      END_STATE();
    case 112:
      if (lookahead == 's') ADVANCE(113);
      END_STATE();
    case 113:
      if (lookahead == 's') ADVANCE(75);
      END_STATE();
    case 114:
      if (lookahead == 's') ADVANCE(69);
      END_STATE();
    case 115:
      if (lookahead == 's') ADVANCE(84);
      END_STATE();
    case 116:
      if (lookahead == 's') ADVANCE(53);
      END_STATE();
    case 117:
      if (lookahead == 't') ADVANCE(188);
      END_STATE();
    case 118:
      if (lookahead == 't') ADVANCE(191);
      END_STATE();
    case 119:
      if (lookahead == 't') ADVANCE(111);
      END_STATE();
    case 120:
      if (lookahead == 'u') ADVANCE(118);
      END_STATE();
    case 121:
      if (lookahead == 'u') ADVANCE(65);
      END_STATE();
    case 122:
      if (lookahead == 'u') ADVANCE(66);
      END_STATE();
    case 123:
      if (lookahead == 'y') ADVANCE(86);
      END_STATE();
    case 124:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(127);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(243);
      END_STATE();
    case 125:
      if (('0' <= lookahead && lookahead <= '7') ||
          lookahead == 'o') ADVANCE(237);
      END_STATE();
    case 126:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(236);
      END_STATE();
    case 127:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(243);
      END_STATE();
    case 128:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(184);
      END_STATE();
    case 129:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(239);
      END_STATE();
    case 130:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(240);
      END_STATE();
    case 131:
      if (eof) ADVANCE(135);
      if (lookahead == '\n') SKIP(134);
      END_STATE();
    case 132:
      if (eof) ADVANCE(135);
      if (lookahead == '\n') SKIP(134);
      if (lookahead == '\r') SKIP(131);
      END_STATE();
    case 133:
      if (eof) ADVANCE(135);
      ADVANCE_MAP(
        '!', 139,
        '"', 252,
        '#', 55,
        '%', 157,
        '&', 150,
        '\'', 246,
        '(', 136,
        ')', 137,
        '*', 153,
        '+', 147,
        ',', 183,
        '-', 144,
        '.', 229,
        '/', 155,
        '0', 234,
        ':', 225,
        ';', 226,
        '<', 172,
        '=', 197,
        '>', 167,
        '?', 230,
        '[', 222,
        '\\', 2,
        ']', 223,
        '^', 163,
        'u', 265,
        '{', 220,
        '|', 160,
        '}', 221,
        '~', 141,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(133);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(235);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 134:
      if (eof) ADVANCE(135);
      ADVANCE_MAP(
        '!', 138,
        '"', 252,
        '#', 55,
        '&', 148,
        '\'', 246,
        '(', 136,
        '+', 146,
        ',', 183,
        '-', 143,
        '/', 36,
        '0', 234,
        ':', 224,
        ';', 226,
        '<', 48,
      );
      if (lookahead == '\\') SKIP(132);
      if (lookahead == 'u') ADVANCE(265);
      if (lookahead == '{') ADVANCE(220);
      if (lookahead == '~') ADVANCE(140);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(134);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(235);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(165);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '=') ADVANCE(217);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(232);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(232);
      if (lookahead == '=') ADVANCE(211);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(233);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(233);
      if (lookahead == '=') ADVANCE(210);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(159);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(159);
      if (lookahead == '=') ADVANCE(215);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_DOT);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(212);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(38);
      if (lookahead == '/') ADVANCE(268);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(38);
      if (lookahead == '/') ADVANCE(268);
      if (lookahead == '=') ADVANCE(213);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(228);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(214);
      if (lookahead == '|') ADVANCE(158);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(158);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(216);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(169);
      if (lookahead == '>') ADVANCE(176);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(169);
      if (lookahead == '>') ADVANCE(177);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(175);
      if (lookahead == '=') ADVANCE(170);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(174);
      if (lookahead == '=') ADVANCE(170);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(218);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(219);
      if (lookahead == '>') ADVANCE(179);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '>') ADVANCE(178);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT);
      if (lookahead == '=') ADVANCE(227);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(anon_sym_POUNDinclude);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(anon_sym_POUNDtryinclude);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(anon_sym_POUNDdefine);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(sym_macro_param);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_POUNDundef);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(anon_sym_POUNDif);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_POUNDelseif);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(anon_sym_POUNDassert);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(sym_preproc_else);
      if (lookahead == 'i') ADVANCE(80);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(sym_preproc_endif);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(sym_preproc_endinput);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_POUNDpragma);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_POUNDerror);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(anon_sym_POUNDwarning);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(anon_sym_using__intrinsics__DOTHandle);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(164);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(sym_alias_operator);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(sym_alias_operator);
      if (lookahead == '&') ADVANCE(198);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(sym_alias_operator);
      if (lookahead == '*') ADVANCE(38);
      if (lookahead == '/') ADVANCE(268);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(sym_alias_operator);
      if (lookahead == '+') ADVANCE(198);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(sym_alias_operator);
      if (lookahead == '-') ADVANCE(198);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(sym_alias_operator);
      if (lookahead == '=') ADVANCE(198);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(sym_alias_operator);
      if (lookahead == '=') ADVANCE(198);
      if (lookahead == '>') ADVANCE(205);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(sym_alias_operator);
      if (lookahead == '>') ADVANCE(198);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(sym_alias_operator);
      if (lookahead == '|') ADVANCE(198);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(sym_alias_operator);
      if (lookahead == '<' ||
          lookahead == '=') ADVANCE(198);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(231);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(anon_sym_TILDE_EQ);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(anon_sym_COLON2);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(231);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT_EQ);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(41);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(sym_int_literal);
      ADVANCE_MAP(
        '.', 244,
        '_', 40,
        'b', 126,
        'o', 125,
        'x', 129,
        'E', 241,
        'P', 241,
        'e', 241,
        'p', 241,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(235);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(sym_int_literal);
      if (lookahead == '.') ADVANCE(244);
      if (lookahead == '_') ADVANCE(40);
      if (lookahead == 'E' ||
          lookahead == 'P' ||
          lookahead == 'e' ||
          lookahead == 'p') ADVANCE(241);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(235);
      END_STATE();
    case 236:
      ACCEPT_TOKEN(sym_int_literal);
      if (lookahead == '_') ADVANCE(126);
      if (lookahead == 'E' ||
          lookahead == 'P' ||
          lookahead == 'e' ||
          lookahead == 'p') ADVANCE(241);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(236);
      END_STATE();
    case 237:
      ACCEPT_TOKEN(sym_int_literal);
      if (lookahead == '_') ADVANCE(125);
      if (lookahead == 'E' ||
          lookahead == 'P' ||
          lookahead == 'e' ||
          lookahead == 'p') ADVANCE(241);
      if (('0' <= lookahead && lookahead <= '7') ||
          lookahead == 'o') ADVANCE(237);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(sym_int_literal);
      if (lookahead == '_') ADVANCE(129);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(130);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(238);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(241);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(239);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(sym_int_literal);
      if (lookahead == '_') ADVANCE(129);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(238);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(241);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(239);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(sym_int_literal);
      if (lookahead == '_') ADVANCE(130);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(240);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(sym_int_literal);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(130);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(240);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(sym_float_literal);
      if (lookahead == '_') ADVANCE(244);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(124);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(242);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(sym_float_literal);
      if (lookahead == '_') ADVANCE(245);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(243);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(sym_float_literal);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(124);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(242);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(sym_float_literal);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(243);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == '*') ADVANCE(38);
      if (lookahead == '/') ADVANCE(268);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == '\\') ADVANCE(16);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      ADVANCE_MAP(
        'a', 112,
        'd', 68,
        'e', 92,
        'i', 76,
        'p', 110,
        't', 105,
        'u', 95,
        'w', 58,
      );
      END_STATE();
    case 251:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      ADVANCE_MAP(
        'x', 258,
        '"', 254,
        '\'', 254,
        '\\', 254,
        'a', 254,
        'b', 254,
        'e', 254,
        'f', 254,
        'n', 254,
        'r', 254,
        't', 254,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(256);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (lookahead == ';') ADVANCE(254);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (lookahead == ';') ADVANCE(254);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(256);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (lookahead == ';') ADVANCE(254);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(255);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (lookahead == ';') ADVANCE(254);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(257);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(sym_system_lib_string);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(sym_system_lib_string);
      if (lookahead == '>') ADVANCE(259);
      if (lookahead == '\\') ADVANCE(49);
      if (lookahead != 0) ADVANCE(48);
      END_STATE();
    case 261:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == ' ') ADVANCE(52);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(261);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(264);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(262);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(263);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(266);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(268);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (lookahead == 'F') ADVANCE(1);
      if (lookahead == 'S') ADVANCE(2);
      if (lookahead == '\\') SKIP(3);
      if (lookahead == '_') ADVANCE(4);
      if (lookahead == 'a') ADVANCE(5);
      if (lookahead == 'b') ADVANCE(6);
      if (lookahead == 'c') ADVANCE(7);
      if (lookahead == 'd') ADVANCE(8);
      if (lookahead == 'e') ADVANCE(9);
      if (lookahead == 'f') ADVANCE(10);
      if (lookahead == 'g') ADVANCE(11);
      if (lookahead == 'i') ADVANCE(12);
      if (lookahead == 'm') ADVANCE(13);
      if (lookahead == 'n') ADVANCE(14);
      if (lookahead == 'o') ADVANCE(15);
      if (lookahead == 'p') ADVANCE(16);
      if (lookahead == 'r') ADVANCE(17);
      if (lookahead == 's') ADVANCE(18);
      if (lookahead == 't') ADVANCE(19);
      if (lookahead == 'v') ADVANCE(20);
      if (lookahead == 'w') ADVANCE(21);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'l') ADVANCE(22);
      END_STATE();
    case 2:
      if (lookahead == 't') ADVANCE(23);
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(0);
      if (lookahead == '\r') SKIP(24);
      END_STATE();
    case 4:
      ACCEPT_TOKEN(anon_sym__);
      if (lookahead == '_') ADVANCE(25);
      END_STATE();
    case 5:
      if (lookahead == 'n') ADVANCE(26);
      if (lookahead == 's') ADVANCE(27);
      END_STATE();
    case 6:
      if (lookahead == 'o') ADVANCE(28);
      if (lookahead == 'r') ADVANCE(29);
      END_STATE();
    case 7:
      if (lookahead == 'a') ADVANCE(30);
      if (lookahead == 'h') ADVANCE(31);
      if (lookahead == 'o') ADVANCE(32);
      END_STATE();
    case 8:
      if (lookahead == 'e') ADVANCE(33);
      if (lookahead == 'o') ADVANCE(34);
      END_STATE();
    case 9:
      if (lookahead == 'l') ADVANCE(35);
      if (lookahead == 'n') ADVANCE(36);
      END_STATE();
    case 10:
      if (lookahead == 'a') ADVANCE(37);
      if (lookahead == 'l') ADVANCE(38);
      if (lookahead == 'o') ADVANCE(39);
      if (lookahead == 'u') ADVANCE(40);
      END_STATE();
    case 11:
      if (lookahead == 'e') ADVANCE(41);
      END_STATE();
    case 12:
      if (lookahead == 'f') ADVANCE(42);
      if (lookahead == 'n') ADVANCE(43);
      END_STATE();
    case 13:
      if (lookahead == 'e') ADVANCE(44);
      END_STATE();
    case 14:
      if (lookahead == 'a') ADVANCE(45);
      if (lookahead == 'e') ADVANCE(46);
      if (lookahead == 'u') ADVANCE(47);
      END_STATE();
    case 15:
      if (lookahead == 'p') ADVANCE(48);
      END_STATE();
    case 16:
      if (lookahead == 'r') ADVANCE(49);
      if (lookahead == 'u') ADVANCE(50);
      END_STATE();
    case 17:
      if (lookahead == 'e') ADVANCE(51);
      END_STATE();
    case 18:
      if (lookahead == 'e') ADVANCE(52);
      if (lookahead == 'i') ADVANCE(53);
      if (lookahead == 't') ADVANCE(54);
      if (lookahead == 'w') ADVANCE(55);
      END_STATE();
    case 19:
      if (lookahead == 'h') ADVANCE(56);
      if (lookahead == 'r') ADVANCE(57);
      if (lookahead == 'y') ADVANCE(58);
      END_STATE();
    case 20:
      if (lookahead == 'i') ADVANCE(59);
      if (lookahead == 'o') ADVANCE(60);
      END_STATE();
    case 21:
      if (lookahead == 'h') ADVANCE(61);
      END_STATE();
    case 22:
      if (lookahead == 'o') ADVANCE(62);
      END_STATE();
    case 23:
      if (lookahead == 'r') ADVANCE(63);
      END_STATE();
    case 24:
      if (lookahead == '\n') SKIP(0);
      END_STATE();
    case 25:
      if (lookahead == 'n') ADVANCE(64);
      END_STATE();
    case 26:
      if (lookahead == 'y') ADVANCE(65);
      END_STATE();
    case 27:
      if (lookahead == 's') ADVANCE(66);
      END_STATE();
    case 28:
      if (lookahead == 'o') ADVANCE(67);
      END_STATE();
    case 29:
      if (lookahead == 'e') ADVANCE(68);
      END_STATE();
    case 30:
      if (lookahead == 's') ADVANCE(69);
      END_STATE();
    case 31:
      if (lookahead == 'a') ADVANCE(70);
      END_STATE();
    case 32:
      if (lookahead == 'n') ADVANCE(71);
      END_STATE();
    case 33:
      if (lookahead == 'c') ADVANCE(72);
      if (lookahead == 'f') ADVANCE(73);
      if (lookahead == 'l') ADVANCE(74);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(anon_sym_do);
      END_STATE();
    case 35:
      if (lookahead == 's') ADVANCE(75);
      END_STATE();
    case 36:
      if (lookahead == 'u') ADVANCE(76);
      END_STATE();
    case 37:
      if (lookahead == 'l') ADVANCE(77);
      END_STATE();
    case 38:
      if (lookahead == 'o') ADVANCE(78);
      END_STATE();
    case 39:
      if (lookahead == 'r') ADVANCE(79);
      END_STATE();
    case 40:
      if (lookahead == 'n') ADVANCE(80);
      END_STATE();
    case 41:
      if (lookahead == 't') ADVANCE(81);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 43:
      if (lookahead == 't') ADVANCE(82);
      END_STATE();
    case 44:
      if (lookahead == 't') ADVANCE(83);
      END_STATE();
    case 45:
      if (lookahead == 't') ADVANCE(84);
      END_STATE();
    case 46:
      if (lookahead == 'w') ADVANCE(85);
      END_STATE();
    case 47:
      if (lookahead == 'l') ADVANCE(86);
      END_STATE();
    case 48:
      if (lookahead == 'e') ADVANCE(87);
      END_STATE();
    case 49:
      if (lookahead == 'o') ADVANCE(88);
      END_STATE();
    case 50:
      if (lookahead == 'b') ADVANCE(89);
      END_STATE();
    case 51:
      if (lookahead == 't') ADVANCE(90);
      END_STATE();
    case 52:
      if (lookahead == 't') ADVANCE(91);
      END_STATE();
    case 53:
      if (lookahead == 'z') ADVANCE(92);
      END_STATE();
    case 54:
      if (lookahead == 'a') ADVANCE(93);
      if (lookahead == 'o') ADVANCE(94);
      if (lookahead == 'r') ADVANCE(95);
      END_STATE();
    case 55:
      if (lookahead == 'i') ADVANCE(96);
      END_STATE();
    case 56:
      if (lookahead == 'i') ADVANCE(97);
      END_STATE();
    case 57:
      if (lookahead == 'u') ADVANCE(98);
      END_STATE();
    case 58:
      if (lookahead == 'p') ADVANCE(99);
      END_STATE();
    case 59:
      if (lookahead == 'e') ADVANCE(100);
      END_STATE();
    case 60:
      if (lookahead == 'i') ADVANCE(101);
      END_STATE();
    case 61:
      if (lookahead == 'i') ADVANCE(102);
      END_STATE();
    case 62:
      if (lookahead == 'a') ADVANCE(103);
      END_STATE();
    case 63:
      if (lookahead == 'i') ADVANCE(104);
      END_STATE();
    case 64:
      if (lookahead == 'u') ADVANCE(105);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(sym_any_type);
      END_STATE();
    case 66:
      if (lookahead == 'e') ADVANCE(106);
      END_STATE();
    case 67:
      if (lookahead == 'l') ADVANCE(107);
      END_STATE();
    case 68:
      if (lookahead == 'a') ADVANCE(108);
      END_STATE();
    case 69:
      if (lookahead == 'e') ADVANCE(109);
      END_STATE();
    case 70:
      if (lookahead == 'r') ADVANCE(110);
      END_STATE();
    case 71:
      if (lookahead == 's') ADVANCE(111);
      if (lookahead == 't') ADVANCE(112);
      END_STATE();
    case 72:
      if (lookahead == 'l') ADVANCE(113);
      END_STATE();
    case 73:
      if (lookahead == 'a') ADVANCE(114);
      if (lookahead == 'i') ADVANCE(115);
      END_STATE();
    case 74:
      if (lookahead == 'e') ADVANCE(116);
      END_STATE();
    case 75:
      if (lookahead == 'e') ADVANCE(117);
      END_STATE();
    case 76:
      if (lookahead == 'm') ADVANCE(118);
      END_STATE();
    case 77:
      if (lookahead == 's') ADVANCE(119);
      END_STATE();
    case 78:
      if (lookahead == 'a') ADVANCE(120);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_for);
      if (lookahead == 'w') ADVANCE(121);
      END_STATE();
    case 80:
      if (lookahead == 'c') ADVANCE(122);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_get);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_int);
      END_STATE();
    case 83:
      if (lookahead == 'h') ADVANCE(123);
      END_STATE();
    case 84:
      if (lookahead == 'i') ADVANCE(124);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(anon_sym_new);
      END_STATE();
    case 86:
      if (lookahead == 'l') ADVANCE(125);
      END_STATE();
    case 87:
      if (lookahead == 'r') ADVANCE(126);
      END_STATE();
    case 88:
      if (lookahead == 'p') ADVANCE(127);
      END_STATE();
    case 89:
      if (lookahead == 'l') ADVANCE(128);
      END_STATE();
    case 90:
      if (lookahead == 'u') ADVANCE(129);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(anon_sym_set);
      END_STATE();
    case 92:
      if (lookahead == 'e') ADVANCE(130);
      END_STATE();
    case 93:
      if (lookahead == 't') ADVANCE(131);
      END_STATE();
    case 94:
      if (lookahead == 'c') ADVANCE(132);
      END_STATE();
    case 95:
      if (lookahead == 'u') ADVANCE(133);
      END_STATE();
    case 96:
      if (lookahead == 't') ADVANCE(134);
      END_STATE();
    case 97:
      if (lookahead == 's') ADVANCE(135);
      END_STATE();
    case 98:
      if (lookahead == 'e') ADVANCE(136);
      END_STATE();
    case 99:
      if (lookahead == 'e') ADVANCE(137);
      END_STATE();
    case 100:
      if (lookahead == 'w') ADVANCE(138);
      END_STATE();
    case 101:
      if (lookahead == 'd') ADVANCE(139);
      END_STATE();
    case 102:
      if (lookahead == 'l') ADVANCE(140);
      END_STATE();
    case 103:
      if (lookahead == 't') ADVANCE(141);
      END_STATE();
    case 104:
      if (lookahead == 'n') ADVANCE(142);
      END_STATE();
    case 105:
      if (lookahead == 'l') ADVANCE(143);
      END_STATE();
    case 106:
      if (lookahead == 'r') ADVANCE(144);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_bool);
      END_STATE();
    case 108:
      if (lookahead == 'k') ADVANCE(145);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_char);
      END_STATE();
    case 111:
      if (lookahead == 't') ADVANCE(146);
      END_STATE();
    case 112:
      if (lookahead == 'i') ADVANCE(147);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_decl);
      END_STATE();
    case 114:
      if (lookahead == 'u') ADVANCE(148);
      END_STATE();
    case 115:
      if (lookahead == 'n') ADVANCE(149);
      END_STATE();
    case 116:
      if (lookahead == 't') ADVANCE(150);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 119:
      if (lookahead == 'e') ADVANCE(136);
      END_STATE();
    case 120:
      if (lookahead == 't') ADVANCE(151);
      END_STATE();
    case 121:
      if (lookahead == 'a') ADVANCE(152);
      END_STATE();
    case 122:
      if (lookahead == 'e') ADVANCE(153);
      if (lookahead == 't') ADVANCE(154);
      END_STATE();
    case 123:
      if (lookahead == 'o') ADVANCE(155);
      END_STATE();
    case 124:
      if (lookahead == 'v') ADVANCE(156);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(sym_null);
      END_STATE();
    case 126:
      if (lookahead == 'a') ADVANCE(157);
      END_STATE();
    case 127:
      if (lookahead == 'e') ADVANCE(158);
      END_STATE();
    case 128:
      if (lookahead == 'i') ADVANCE(159);
      END_STATE();
    case 129:
      if (lookahead == 'r') ADVANCE(160);
      END_STATE();
    case 130:
      if (lookahead == 'o') ADVANCE(161);
      END_STATE();
    case 131:
      if (lookahead == 'i') ADVANCE(162);
      END_STATE();
    case 132:
      if (lookahead == 'k') ADVANCE(163);
      END_STATE();
    case 133:
      if (lookahead == 'c') ADVANCE(164);
      END_STATE();
    case 134:
      if (lookahead == 'c') ADVANCE(165);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(sym_this);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(sym_bool_literal);
      END_STATE();
    case 137:
      if (lookahead == 'd') ADVANCE(166);
      if (lookahead == 's') ADVANCE(167);
      END_STATE();
    case 138:
      if (lookahead == '_') ADVANCE(168);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_void);
      END_STATE();
    case 140:
      if (lookahead == 'e') ADVANCE(169);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_Float);
      END_STATE();
    case 142:
      if (lookahead == 'g') ADVANCE(170);
      END_STATE();
    case 143:
      if (lookahead == 'l') ADVANCE(171);
      END_STATE();
    case 144:
      if (lookahead == 't') ADVANCE(172);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_const);
      END_STATE();
    case 147:
      if (lookahead == 'n') ADVANCE(173);
      END_STATE();
    case 148:
      if (lookahead == 'l') ADVANCE(174);
      END_STATE();
    case 149:
      if (lookahead == 'e') ADVANCE(175);
      END_STATE();
    case 150:
      if (lookahead == 'e') ADVANCE(176);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_float);
      END_STATE();
    case 152:
      if (lookahead == 'r') ADVANCE(177);
      END_STATE();
    case 153:
      if (lookahead == 'n') ADVANCE(178);
      END_STATE();
    case 154:
      if (lookahead == 'a') ADVANCE(179);
      if (lookahead == 'i') ADVANCE(180);
      END_STATE();
    case 155:
      if (lookahead == 'd') ADVANCE(181);
      END_STATE();
    case 156:
      if (lookahead == 'e') ADVANCE(182);
      END_STATE();
    case 157:
      if (lookahead == 't') ADVANCE(183);
      END_STATE();
    case 158:
      if (lookahead == 'r') ADVANCE(184);
      END_STATE();
    case 159:
      if (lookahead == 'c') ADVANCE(185);
      END_STATE();
    case 160:
      if (lookahead == 'n') ADVANCE(186);
      END_STATE();
    case 161:
      if (lookahead == 'f') ADVANCE(187);
      END_STATE();
    case 162:
      if (lookahead == 'c') ADVANCE(188);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_stock);
      END_STATE();
    case 164:
      if (lookahead == 't') ADVANCE(189);
      END_STATE();
    case 165:
      if (lookahead == 'h') ADVANCE(190);
      END_STATE();
    case 166:
      if (lookahead == 'e') ADVANCE(191);
      END_STATE();
    case 167:
      if (lookahead == 'e') ADVANCE(192);
      END_STATE();
    case 168:
      if (lookahead == 'a') ADVANCE(193);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_String);
      END_STATE();
    case 171:
      if (lookahead == 'a') ADVANCE(194);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_assert);
      END_STATE();
    case 173:
      if (lookahead == 'u') ADVANCE(195);
      END_STATE();
    case 174:
      if (lookahead == 't') ADVANCE(196);
      END_STATE();
    case 175:
      if (lookahead == 'd') ADVANCE(197);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(anon_sym_delete);
      END_STATE();
    case 177:
      if (lookahead == 'd') ADVANCE(198);
      END_STATE();
    case 178:
      if (lookahead == 'u') ADVANCE(199);
      END_STATE();
    case 179:
      if (lookahead == 'g') ADVANCE(200);
      END_STATE();
    case 180:
      if (lookahead == 'o') ADVANCE(201);
      END_STATE();
    case 181:
      if (lookahead == 'm') ADVANCE(202);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(anon_sym_native);
      END_STATE();
    case 183:
      if (lookahead == 'o') ADVANCE(203);
      END_STATE();
    case 184:
      if (lookahead == 't') ADVANCE(204);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_public);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_sizeof);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(anon_sym_static);
      if (lookahead == '_') ADVANCE(205);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 191:
      if (lookahead == 'f') ADVANCE(206);
      END_STATE();
    case 192:
      if (lookahead == 't') ADVANCE(207);
      END_STATE();
    case 193:
      if (lookahead == 's') ADVANCE(208);
      END_STATE();
    case 194:
      if (lookahead == 'b') ADVANCE(209);
      END_STATE();
    case 195:
      if (lookahead == 'e') ADVANCE(210);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(anon_sym_defined);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(anon_sym_forward);
      END_STATE();
    case 199:
      if (lookahead == 'm') ADVANCE(211);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(anon_sym_functag);
      END_STATE();
    case 201:
      if (lookahead == 'n') ADVANCE(212);
      END_STATE();
    case 202:
      if (lookahead == 'a') ADVANCE(213);
      END_STATE();
    case 203:
      if (lookahead == 'r') ADVANCE(214);
      END_STATE();
    case 204:
      if (lookahead == 'y') ADVANCE(215);
      END_STATE();
    case 205:
      if (lookahead == 'a') ADVANCE(216);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(anon_sym_typedef);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(anon_sym_typeset);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(anon_sym_view_as);
      END_STATE();
    case 209:
      if (lookahead == 'l') ADVANCE(217);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(anon_sym_funcenum);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 213:
      if (lookahead == 'p') ADVANCE(218);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(anon_sym_operator);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(anon_sym_property);
      END_STATE();
    case 216:
      if (lookahead == 's') ADVANCE(219);
      END_STATE();
    case 217:
      if (lookahead == 'e') ADVANCE(220);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(anon_sym_methodmap);
      END_STATE();
    case 219:
      if (lookahead == 's') ADVANCE(221);
      END_STATE();
    case 220:
      if (lookahead == '_') ADVANCE(222);
      END_STATE();
    case 221:
      if (lookahead == 'e') ADVANCE(223);
      END_STATE();
    case 222:
      if (lookahead == '_') ADVANCE(224);
      END_STATE();
    case 223:
      if (lookahead == 'r') ADVANCE(225);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(anon_sym___nullable__);
      END_STATE();
    case 225:
      if (lookahead == 't') ADVANCE(226);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(anon_sym_static_assert);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 0},
  [2] = {.lex_state = 25},
  [3] = {.lex_state = 25},
  [4] = {.lex_state = 22, .external_lex_state = 2},
  [5] = {.lex_state = 25},
  [6] = {.lex_state = 25},
  [7] = {.lex_state = 25},
  [8] = {.lex_state = 25},
  [9] = {.lex_state = 22, .external_lex_state = 2},
  [10] = {.lex_state = 25},
  [11] = {.lex_state = 22, .external_lex_state = 2},
  [12] = {.lex_state = 22, .external_lex_state = 2},
  [13] = {.lex_state = 22, .external_lex_state = 2},
  [14] = {.lex_state = 22, .external_lex_state = 2},
  [15] = {.lex_state = 25},
  [16] = {.lex_state = 25},
  [17] = {.lex_state = 25},
  [18] = {.lex_state = 25},
  [19] = {.lex_state = 25},
  [20] = {.lex_state = 25},
  [21] = {.lex_state = 25},
  [22] = {.lex_state = 25},
  [23] = {.lex_state = 25},
  [24] = {.lex_state = 25},
  [25] = {.lex_state = 25},
  [26] = {.lex_state = 25},
  [27] = {.lex_state = 25},
  [28] = {.lex_state = 25},
  [29] = {.lex_state = 25},
  [30] = {.lex_state = 25},
  [31] = {.lex_state = 25},
  [32] = {.lex_state = 25},
  [33] = {.lex_state = 25},
  [34] = {.lex_state = 25},
  [35] = {.lex_state = 25},
  [36] = {.lex_state = 25},
  [37] = {.lex_state = 25},
  [38] = {.lex_state = 25},
  [39] = {.lex_state = 25},
  [40] = {.lex_state = 25},
  [41] = {.lex_state = 25},
  [42] = {.lex_state = 25},
  [43] = {.lex_state = 25},
  [44] = {.lex_state = 25},
  [45] = {.lex_state = 25},
  [46] = {.lex_state = 25},
  [47] = {.lex_state = 25},
  [48] = {.lex_state = 25},
  [49] = {.lex_state = 25},
  [50] = {.lex_state = 25},
  [51] = {.lex_state = 25},
  [52] = {.lex_state = 25},
  [53] = {.lex_state = 25},
  [54] = {.lex_state = 25},
  [55] = {.lex_state = 25},
  [56] = {.lex_state = 25},
  [57] = {.lex_state = 25},
  [58] = {.lex_state = 25},
  [59] = {.lex_state = 25},
  [60] = {.lex_state = 25},
  [61] = {.lex_state = 25},
  [62] = {.lex_state = 25},
  [63] = {.lex_state = 25},
  [64] = {.lex_state = 22, .external_lex_state = 2},
  [65] = {.lex_state = 25},
  [66] = {.lex_state = 25},
  [67] = {.lex_state = 22, .external_lex_state = 2},
  [68] = {.lex_state = 25},
  [69] = {.lex_state = 25},
  [70] = {.lex_state = 25},
  [71] = {.lex_state = 25},
  [72] = {.lex_state = 25},
  [73] = {.lex_state = 22, .external_lex_state = 2},
  [74] = {.lex_state = 22, .external_lex_state = 2},
  [75] = {.lex_state = 22, .external_lex_state = 2},
  [76] = {.lex_state = 0, .external_lex_state = 2},
  [77] = {.lex_state = 22, .external_lex_state = 2},
  [78] = {.lex_state = 22, .external_lex_state = 2},
  [79] = {.lex_state = 22, .external_lex_state = 2},
  [80] = {.lex_state = 22, .external_lex_state = 2},
  [81] = {.lex_state = 22, .external_lex_state = 2},
  [82] = {.lex_state = 22, .external_lex_state = 2},
  [83] = {.lex_state = 0, .external_lex_state = 2},
  [84] = {.lex_state = 0, .external_lex_state = 2},
  [85] = {.lex_state = 0, .external_lex_state = 2},
  [86] = {.lex_state = 0, .external_lex_state = 2},
  [87] = {.lex_state = 0, .external_lex_state = 2},
  [88] = {.lex_state = 0, .external_lex_state = 2},
  [89] = {.lex_state = 0, .external_lex_state = 2},
  [90] = {.lex_state = 0, .external_lex_state = 2},
  [91] = {.lex_state = 134, .external_lex_state = 2},
  [92] = {.lex_state = 0, .external_lex_state = 2},
  [93] = {.lex_state = 0, .external_lex_state = 2},
  [94] = {.lex_state = 0, .external_lex_state = 2},
  [95] = {.lex_state = 0, .external_lex_state = 2},
  [96] = {.lex_state = 25, .external_lex_state = 2},
  [97] = {.lex_state = 22, .external_lex_state = 2},
  [98] = {.lex_state = 22, .external_lex_state = 2},
  [99] = {.lex_state = 22, .external_lex_state = 2},
  [100] = {.lex_state = 22, .external_lex_state = 2},
  [101] = {.lex_state = 22, .external_lex_state = 2},
  [102] = {.lex_state = 22, .external_lex_state = 2},
  [103] = {.lex_state = 22, .external_lex_state = 2},
  [104] = {.lex_state = 22, .external_lex_state = 2},
  [105] = {.lex_state = 22, .external_lex_state = 2},
  [106] = {.lex_state = 22, .external_lex_state = 2},
  [107] = {.lex_state = 22, .external_lex_state = 2},
  [108] = {.lex_state = 22, .external_lex_state = 2},
  [109] = {.lex_state = 22, .external_lex_state = 2},
  [110] = {.lex_state = 22, .external_lex_state = 2},
  [111] = {.lex_state = 22, .external_lex_state = 2},
  [112] = {.lex_state = 22, .external_lex_state = 2},
  [113] = {.lex_state = 22, .external_lex_state = 2},
  [114] = {.lex_state = 22, .external_lex_state = 2},
  [115] = {.lex_state = 22, .external_lex_state = 2},
  [116] = {.lex_state = 22, .external_lex_state = 2},
  [117] = {.lex_state = 22, .external_lex_state = 2},
  [118] = {.lex_state = 22, .external_lex_state = 2},
  [119] = {.lex_state = 22, .external_lex_state = 2},
  [120] = {.lex_state = 22, .external_lex_state = 2},
  [121] = {.lex_state = 22, .external_lex_state = 2},
  [122] = {.lex_state = 22, .external_lex_state = 2},
  [123] = {.lex_state = 22, .external_lex_state = 2},
  [124] = {.lex_state = 22, .external_lex_state = 2},
  [125] = {.lex_state = 22, .external_lex_state = 2},
  [126] = {.lex_state = 22, .external_lex_state = 2},
  [127] = {.lex_state = 22, .external_lex_state = 2},
  [128] = {.lex_state = 22, .external_lex_state = 2},
  [129] = {.lex_state = 22, .external_lex_state = 2},
  [130] = {.lex_state = 22, .external_lex_state = 2},
  [131] = {.lex_state = 22, .external_lex_state = 2},
  [132] = {.lex_state = 22, .external_lex_state = 2},
  [133] = {.lex_state = 22, .external_lex_state = 2},
  [134] = {.lex_state = 22, .external_lex_state = 2},
  [135] = {.lex_state = 22, .external_lex_state = 2},
  [136] = {.lex_state = 22, .external_lex_state = 2},
  [137] = {.lex_state = 22, .external_lex_state = 2},
  [138] = {.lex_state = 22, .external_lex_state = 2},
  [139] = {.lex_state = 22, .external_lex_state = 2},
  [140] = {.lex_state = 22, .external_lex_state = 2},
  [141] = {.lex_state = 22, .external_lex_state = 2},
  [142] = {.lex_state = 22, .external_lex_state = 2},
  [143] = {.lex_state = 22, .external_lex_state = 2},
  [144] = {.lex_state = 22, .external_lex_state = 2},
  [145] = {.lex_state = 22, .external_lex_state = 2},
  [146] = {.lex_state = 22, .external_lex_state = 2},
  [147] = {.lex_state = 22, .external_lex_state = 2},
  [148] = {.lex_state = 22, .external_lex_state = 2},
  [149] = {.lex_state = 22, .external_lex_state = 2},
  [150] = {.lex_state = 22, .external_lex_state = 2},
  [151] = {.lex_state = 22, .external_lex_state = 2},
  [152] = {.lex_state = 0, .external_lex_state = 2},
  [153] = {.lex_state = 0, .external_lex_state = 2},
  [154] = {.lex_state = 0, .external_lex_state = 2},
  [155] = {.lex_state = 0, .external_lex_state = 2},
  [156] = {.lex_state = 0, .external_lex_state = 2},
  [157] = {.lex_state = 0, .external_lex_state = 2},
  [158] = {.lex_state = 0, .external_lex_state = 2},
  [159] = {.lex_state = 25},
  [160] = {.lex_state = 0, .external_lex_state = 2},
  [161] = {.lex_state = 25},
  [162] = {.lex_state = 25},
  [163] = {.lex_state = 0, .external_lex_state = 2},
  [164] = {.lex_state = 0, .external_lex_state = 2},
  [165] = {.lex_state = 0, .external_lex_state = 2},
  [166] = {.lex_state = 0, .external_lex_state = 2},
  [167] = {.lex_state = 0, .external_lex_state = 2},
  [168] = {.lex_state = 0, .external_lex_state = 2},
  [169] = {.lex_state = 0, .external_lex_state = 2},
  [170] = {.lex_state = 0, .external_lex_state = 2},
  [171] = {.lex_state = 0, .external_lex_state = 2},
  [172] = {.lex_state = 0, .external_lex_state = 2},
  [173] = {.lex_state = 0, .external_lex_state = 2},
  [174] = {.lex_state = 0, .external_lex_state = 2},
  [175] = {.lex_state = 0, .external_lex_state = 2},
  [176] = {.lex_state = 0, .external_lex_state = 2},
  [177] = {.lex_state = 0, .external_lex_state = 2},
  [178] = {.lex_state = 0, .external_lex_state = 2},
  [179] = {.lex_state = 0, .external_lex_state = 2},
  [180] = {.lex_state = 0, .external_lex_state = 2},
  [181] = {.lex_state = 0, .external_lex_state = 2},
  [182] = {.lex_state = 0, .external_lex_state = 2},
  [183] = {.lex_state = 0, .external_lex_state = 2},
  [184] = {.lex_state = 0, .external_lex_state = 2},
  [185] = {.lex_state = 0, .external_lex_state = 2},
  [186] = {.lex_state = 0, .external_lex_state = 2},
  [187] = {.lex_state = 0, .external_lex_state = 2},
  [188] = {.lex_state = 0, .external_lex_state = 2},
  [189] = {.lex_state = 0, .external_lex_state = 2},
  [190] = {.lex_state = 0, .external_lex_state = 2},
  [191] = {.lex_state = 0, .external_lex_state = 2},
  [192] = {.lex_state = 0, .external_lex_state = 2},
  [193] = {.lex_state = 0, .external_lex_state = 2},
  [194] = {.lex_state = 0, .external_lex_state = 2},
  [195] = {.lex_state = 0, .external_lex_state = 2},
  [196] = {.lex_state = 0, .external_lex_state = 2},
  [197] = {.lex_state = 0, .external_lex_state = 2},
  [198] = {.lex_state = 0, .external_lex_state = 2},
  [199] = {.lex_state = 0, .external_lex_state = 2},
  [200] = {.lex_state = 0, .external_lex_state = 2},
  [201] = {.lex_state = 0, .external_lex_state = 2},
  [202] = {.lex_state = 0, .external_lex_state = 2},
  [203] = {.lex_state = 0, .external_lex_state = 2},
  [204] = {.lex_state = 0, .external_lex_state = 2},
  [205] = {.lex_state = 0, .external_lex_state = 2},
  [206] = {.lex_state = 0, .external_lex_state = 2},
  [207] = {.lex_state = 25, .external_lex_state = 2},
  [208] = {.lex_state = 0},
  [209] = {.lex_state = 0},
  [210] = {.lex_state = 25},
  [211] = {.lex_state = 25, .external_lex_state = 2},
  [212] = {.lex_state = 25},
  [213] = {.lex_state = 25, .external_lex_state = 2},
  [214] = {.lex_state = 25, .external_lex_state = 2},
  [215] = {.lex_state = 25},
  [216] = {.lex_state = 25},
  [217] = {.lex_state = 25, .external_lex_state = 2},
  [218] = {.lex_state = 25, .external_lex_state = 2},
  [219] = {.lex_state = 25, .external_lex_state = 2},
  [220] = {.lex_state = 25, .external_lex_state = 2},
  [221] = {.lex_state = 25, .external_lex_state = 2},
  [222] = {.lex_state = 25, .external_lex_state = 2},
  [223] = {.lex_state = 22, .external_lex_state = 2},
  [224] = {.lex_state = 25, .external_lex_state = 2},
  [225] = {.lex_state = 25, .external_lex_state = 2},
  [226] = {.lex_state = 25, .external_lex_state = 2},
  [227] = {.lex_state = 25, .external_lex_state = 2},
  [228] = {.lex_state = 25},
  [229] = {.lex_state = 25},
  [230] = {.lex_state = 25, .external_lex_state = 2},
  [231] = {.lex_state = 25, .external_lex_state = 2},
  [232] = {.lex_state = 25},
  [233] = {.lex_state = 25},
  [234] = {.lex_state = 25, .external_lex_state = 2},
  [235] = {.lex_state = 25},
  [236] = {.lex_state = 25, .external_lex_state = 2},
  [237] = {.lex_state = 25},
  [238] = {.lex_state = 25, .external_lex_state = 2},
  [239] = {.lex_state = 0},
  [240] = {.lex_state = 25, .external_lex_state = 2},
  [241] = {.lex_state = 25, .external_lex_state = 2},
  [242] = {.lex_state = 25, .external_lex_state = 2},
  [243] = {.lex_state = 25},
  [244] = {.lex_state = 25},
  [245] = {.lex_state = 25},
  [246] = {.lex_state = 25},
  [247] = {.lex_state = 25},
  [248] = {.lex_state = 25, .external_lex_state = 2},
  [249] = {.lex_state = 25, .external_lex_state = 2},
  [250] = {.lex_state = 25, .external_lex_state = 2},
  [251] = {.lex_state = 25},
  [252] = {.lex_state = 25},
  [253] = {.lex_state = 25},
  [254] = {.lex_state = 25},
  [255] = {.lex_state = 25},
  [256] = {.lex_state = 25},
  [257] = {.lex_state = 25},
  [258] = {.lex_state = 25},
  [259] = {.lex_state = 25},
  [260] = {.lex_state = 25},
  [261] = {.lex_state = 25, .external_lex_state = 2},
  [262] = {.lex_state = 25},
  [263] = {.lex_state = 25, .external_lex_state = 2},
  [264] = {.lex_state = 25, .external_lex_state = 2},
  [265] = {.lex_state = 25},
  [266] = {.lex_state = 25},
  [267] = {.lex_state = 25},
  [268] = {.lex_state = 25},
  [269] = {.lex_state = 25},
  [270] = {.lex_state = 25},
  [271] = {.lex_state = 25, .external_lex_state = 2},
  [272] = {.lex_state = 25},
  [273] = {.lex_state = 25, .external_lex_state = 2},
  [274] = {.lex_state = 25},
  [275] = {.lex_state = 25},
  [276] = {.lex_state = 25},
  [277] = {.lex_state = 25},
  [278] = {.lex_state = 25},
  [279] = {.lex_state = 25},
  [280] = {.lex_state = 25},
  [281] = {.lex_state = 25},
  [282] = {.lex_state = 25},
  [283] = {.lex_state = 25},
  [284] = {.lex_state = 25},
  [285] = {.lex_state = 25},
  [286] = {.lex_state = 25},
  [287] = {.lex_state = 25},
  [288] = {.lex_state = 25},
  [289] = {.lex_state = 25},
  [290] = {.lex_state = 25},
  [291] = {.lex_state = 25},
  [292] = {.lex_state = 25},
  [293] = {.lex_state = 25},
  [294] = {.lex_state = 25},
  [295] = {.lex_state = 25, .external_lex_state = 2},
  [296] = {.lex_state = 25},
  [297] = {.lex_state = 25},
  [298] = {.lex_state = 25},
  [299] = {.lex_state = 25},
  [300] = {.lex_state = 25},
  [301] = {.lex_state = 25},
  [302] = {.lex_state = 25},
  [303] = {.lex_state = 25},
  [304] = {.lex_state = 0},
  [305] = {.lex_state = 25},
  [306] = {.lex_state = 25},
  [307] = {.lex_state = 25},
  [308] = {.lex_state = 25},
  [309] = {.lex_state = 25},
  [310] = {.lex_state = 25},
  [311] = {.lex_state = 25},
  [312] = {.lex_state = 25},
  [313] = {.lex_state = 25},
  [314] = {.lex_state = 25},
  [315] = {.lex_state = 25},
  [316] = {.lex_state = 25},
  [317] = {.lex_state = 25},
  [318] = {.lex_state = 0},
  [319] = {.lex_state = 25},
  [320] = {.lex_state = 25},
  [321] = {.lex_state = 25},
  [322] = {.lex_state = 25},
  [323] = {.lex_state = 25},
  [324] = {.lex_state = 25},
  [325] = {.lex_state = 25},
  [326] = {.lex_state = 25},
  [327] = {.lex_state = 25},
  [328] = {.lex_state = 25},
  [329] = {.lex_state = 25},
  [330] = {.lex_state = 25},
  [331] = {.lex_state = 25},
  [332] = {.lex_state = 25},
  [333] = {.lex_state = 25},
  [334] = {.lex_state = 25},
  [335] = {.lex_state = 25},
  [336] = {.lex_state = 25},
  [337] = {.lex_state = 25},
  [338] = {.lex_state = 25},
  [339] = {.lex_state = 25},
  [340] = {.lex_state = 25},
  [341] = {.lex_state = 25},
  [342] = {.lex_state = 25},
  [343] = {.lex_state = 25},
  [344] = {.lex_state = 25},
  [345] = {.lex_state = 25},
  [346] = {.lex_state = 25},
  [347] = {.lex_state = 25},
  [348] = {.lex_state = 25},
  [349] = {.lex_state = 25},
  [350] = {.lex_state = 25},
  [351] = {.lex_state = 25},
  [352] = {.lex_state = 25},
  [353] = {.lex_state = 25},
  [354] = {.lex_state = 25},
  [355] = {.lex_state = 25},
  [356] = {.lex_state = 25},
  [357] = {.lex_state = 25},
  [358] = {.lex_state = 25},
  [359] = {.lex_state = 25},
  [360] = {.lex_state = 25},
  [361] = {.lex_state = 25},
  [362] = {.lex_state = 25},
  [363] = {.lex_state = 25},
  [364] = {.lex_state = 25},
  [365] = {.lex_state = 25},
  [366] = {.lex_state = 25},
  [367] = {.lex_state = 25},
  [368] = {.lex_state = 25},
  [369] = {.lex_state = 25},
  [370] = {.lex_state = 25},
  [371] = {.lex_state = 25},
  [372] = {.lex_state = 25},
  [373] = {.lex_state = 25},
  [374] = {.lex_state = 25},
  [375] = {.lex_state = 25},
  [376] = {.lex_state = 25},
  [377] = {.lex_state = 25},
  [378] = {.lex_state = 25},
  [379] = {.lex_state = 25},
  [380] = {.lex_state = 25},
  [381] = {.lex_state = 25},
  [382] = {.lex_state = 25},
  [383] = {.lex_state = 25},
  [384] = {.lex_state = 25},
  [385] = {.lex_state = 0},
  [386] = {.lex_state = 25},
  [387] = {.lex_state = 25},
  [388] = {.lex_state = 25},
  [389] = {.lex_state = 25},
  [390] = {.lex_state = 25},
  [391] = {.lex_state = 25},
  [392] = {.lex_state = 25},
  [393] = {.lex_state = 25},
  [394] = {.lex_state = 25},
  [395] = {.lex_state = 25},
  [396] = {.lex_state = 25},
  [397] = {.lex_state = 25},
  [398] = {.lex_state = 25},
  [399] = {.lex_state = 25},
  [400] = {.lex_state = 25},
  [401] = {.lex_state = 25},
  [402] = {.lex_state = 25},
  [403] = {.lex_state = 25},
  [404] = {.lex_state = 25},
  [405] = {.lex_state = 25},
  [406] = {.lex_state = 25},
  [407] = {.lex_state = 25},
  [408] = {.lex_state = 25},
  [409] = {.lex_state = 25},
  [410] = {.lex_state = 25},
  [411] = {.lex_state = 25},
  [412] = {.lex_state = 25},
  [413] = {.lex_state = 25},
  [414] = {.lex_state = 25},
  [415] = {.lex_state = 25},
  [416] = {.lex_state = 25},
  [417] = {.lex_state = 25},
  [418] = {.lex_state = 25},
  [419] = {.lex_state = 25},
  [420] = {.lex_state = 25},
  [421] = {.lex_state = 25},
  [422] = {.lex_state = 25},
  [423] = {.lex_state = 25},
  [424] = {.lex_state = 25},
  [425] = {.lex_state = 25},
  [426] = {.lex_state = 25},
  [427] = {.lex_state = 25},
  [428] = {.lex_state = 25},
  [429] = {.lex_state = 25},
  [430] = {.lex_state = 25},
  [431] = {.lex_state = 25},
  [432] = {.lex_state = 25},
  [433] = {.lex_state = 25},
  [434] = {.lex_state = 25},
  [435] = {.lex_state = 25},
  [436] = {.lex_state = 25},
  [437] = {.lex_state = 25},
  [438] = {.lex_state = 25},
  [439] = {.lex_state = 25},
  [440] = {.lex_state = 25},
  [441] = {.lex_state = 25},
  [442] = {.lex_state = 25},
  [443] = {.lex_state = 25},
  [444] = {.lex_state = 0},
  [445] = {.lex_state = 0},
  [446] = {.lex_state = 25},
  [447] = {.lex_state = 25},
  [448] = {.lex_state = 25},
  [449] = {.lex_state = 25},
  [450] = {.lex_state = 25},
  [451] = {.lex_state = 25},
  [452] = {.lex_state = 25},
  [453] = {.lex_state = 25},
  [454] = {.lex_state = 0},
  [455] = {.lex_state = 25},
  [456] = {.lex_state = 25},
  [457] = {.lex_state = 25},
  [458] = {.lex_state = 25},
  [459] = {.lex_state = 25},
  [460] = {.lex_state = 25},
  [461] = {.lex_state = 25},
  [462] = {.lex_state = 25},
  [463] = {.lex_state = 25},
  [464] = {.lex_state = 25},
  [465] = {.lex_state = 25},
  [466] = {.lex_state = 25},
  [467] = {.lex_state = 25},
  [468] = {.lex_state = 25},
  [469] = {.lex_state = 25},
  [470] = {.lex_state = 0, .external_lex_state = 3},
  [471] = {.lex_state = 25},
  [472] = {.lex_state = 25},
  [473] = {.lex_state = 25},
  [474] = {.lex_state = 25},
  [475] = {.lex_state = 25},
  [476] = {.lex_state = 25},
  [477] = {.lex_state = 28},
  [478] = {.lex_state = 25},
  [479] = {.lex_state = 25},
  [480] = {.lex_state = 25},
  [481] = {.lex_state = 28},
  [482] = {.lex_state = 0},
  [483] = {.lex_state = 25},
  [484] = {.lex_state = 0, .external_lex_state = 3},
  [485] = {.lex_state = 0},
  [486] = {.lex_state = 22},
  [487] = {.lex_state = 28},
  [488] = {.lex_state = 0},
  [489] = {.lex_state = 0, .external_lex_state = 2},
  [490] = {.lex_state = 0},
  [491] = {.lex_state = 28},
  [492] = {.lex_state = 0, .external_lex_state = 2},
  [493] = {.lex_state = 28},
  [494] = {.lex_state = 0, .external_lex_state = 2},
  [495] = {.lex_state = 0},
  [496] = {.lex_state = 0},
  [497] = {.lex_state = 0},
  [498] = {.lex_state = 0, .external_lex_state = 3},
  [499] = {.lex_state = 0, .external_lex_state = 3},
  [500] = {.lex_state = 0, .external_lex_state = 3},
  [501] = {.lex_state = 0, .external_lex_state = 2},
  [502] = {.lex_state = 0, .external_lex_state = 2},
  [503] = {.lex_state = 0, .external_lex_state = 3},
  [504] = {.lex_state = 0, .external_lex_state = 2},
  [505] = {.lex_state = 0, .external_lex_state = 2},
  [506] = {.lex_state = 0, .external_lex_state = 2},
  [507] = {.lex_state = 0, .external_lex_state = 2},
  [508] = {.lex_state = 0, .external_lex_state = 2},
  [509] = {.lex_state = 0, .external_lex_state = 2},
  [510] = {.lex_state = 28},
  [511] = {.lex_state = 0, .external_lex_state = 2},
  [512] = {.lex_state = 0, .external_lex_state = 3},
  [513] = {.lex_state = 0, .external_lex_state = 3},
  [514] = {.lex_state = 0},
  [515] = {.lex_state = 0, .external_lex_state = 2},
  [516] = {.lex_state = 0, .external_lex_state = 2},
  [517] = {.lex_state = 0, .external_lex_state = 2},
  [518] = {.lex_state = 0, .external_lex_state = 2},
  [519] = {.lex_state = 0},
  [520] = {.lex_state = 0, .external_lex_state = 3},
  [521] = {.lex_state = 0, .external_lex_state = 2},
  [522] = {.lex_state = 0, .external_lex_state = 3},
  [523] = {.lex_state = 0, .external_lex_state = 2},
  [524] = {.lex_state = 0, .external_lex_state = 3},
  [525] = {.lex_state = 0, .external_lex_state = 3},
  [526] = {.lex_state = 0},
  [527] = {.lex_state = 0, .external_lex_state = 2},
  [528] = {.lex_state = 27},
  [529] = {.lex_state = 27},
  [530] = {.lex_state = 0, .external_lex_state = 2},
  [531] = {.lex_state = 0, .external_lex_state = 2},
  [532] = {.lex_state = 27},
  [533] = {.lex_state = 27},
  [534] = {.lex_state = 27},
  [535] = {.lex_state = 27},
  [536] = {.lex_state = 0, .external_lex_state = 2},
  [537] = {.lex_state = 27},
  [538] = {.lex_state = 27},
  [539] = {.lex_state = 27},
  [540] = {.lex_state = 27},
  [541] = {.lex_state = 0, .external_lex_state = 2},
  [542] = {.lex_state = 0, .external_lex_state = 2},
  [543] = {.lex_state = 0, .external_lex_state = 2},
  [544] = {.lex_state = 0, .external_lex_state = 2},
  [545] = {.lex_state = 0},
  [546] = {.lex_state = 0},
  [547] = {.lex_state = 0},
  [548] = {.lex_state = 0},
  [549] = {.lex_state = 0},
  [550] = {.lex_state = 0},
  [551] = {.lex_state = 0},
  [552] = {.lex_state = 0},
  [553] = {.lex_state = 0},
  [554] = {.lex_state = 0},
  [555] = {.lex_state = 0},
  [556] = {.lex_state = 0},
  [557] = {.lex_state = 0},
  [558] = {.lex_state = 0},
  [559] = {.lex_state = 0},
  [560] = {.lex_state = 0},
  [561] = {.lex_state = 0},
  [562] = {.lex_state = 0},
  [563] = {.lex_state = 0},
  [564] = {.lex_state = 0},
  [565] = {.lex_state = 0},
  [566] = {.lex_state = 0},
  [567] = {.lex_state = 0},
  [568] = {.lex_state = 0},
  [569] = {.lex_state = 0},
  [570] = {.lex_state = 0},
  [571] = {.lex_state = 0},
  [572] = {.lex_state = 0},
  [573] = {.lex_state = 0},
  [574] = {.lex_state = 0},
  [575] = {.lex_state = 27},
  [576] = {.lex_state = 0},
  [577] = {.lex_state = 0},
  [578] = {.lex_state = 0},
  [579] = {.lex_state = 0},
  [580] = {.lex_state = 27},
  [581] = {.lex_state = 27},
  [582] = {.lex_state = 27},
  [583] = {.lex_state = 27},
  [584] = {.lex_state = 0},
  [585] = {.lex_state = 27},
  [586] = {.lex_state = 22},
  [587] = {.lex_state = 0, .external_lex_state = 2},
  [588] = {.lex_state = 0, .external_lex_state = 2},
  [589] = {.lex_state = 22},
  [590] = {.lex_state = 0, .external_lex_state = 2},
  [591] = {.lex_state = 22},
  [592] = {.lex_state = 0, .external_lex_state = 2},
  [593] = {.lex_state = 0, .external_lex_state = 2},
  [594] = {.lex_state = 0, .external_lex_state = 2},
  [595] = {.lex_state = 0, .external_lex_state = 2},
  [596] = {.lex_state = 0, .external_lex_state = 2},
  [597] = {.lex_state = 0, .external_lex_state = 2},
  [598] = {.lex_state = 0, .external_lex_state = 2},
  [599] = {.lex_state = 0, .external_lex_state = 2},
  [600] = {.lex_state = 0, .external_lex_state = 2},
  [601] = {.lex_state = 0, .external_lex_state = 2},
  [602] = {.lex_state = 0, .external_lex_state = 2},
  [603] = {.lex_state = 0, .external_lex_state = 2},
  [604] = {.lex_state = 0, .external_lex_state = 2},
  [605] = {.lex_state = 0, .external_lex_state = 2},
  [606] = {.lex_state = 0, .external_lex_state = 2},
  [607] = {.lex_state = 0, .external_lex_state = 2},
  [608] = {.lex_state = 0, .external_lex_state = 2},
  [609] = {.lex_state = 0, .external_lex_state = 2},
  [610] = {.lex_state = 0, .external_lex_state = 2},
  [611] = {.lex_state = 0},
  [612] = {.lex_state = 0},
  [613] = {.lex_state = 0},
  [614] = {.lex_state = 0},
  [615] = {.lex_state = 0, .external_lex_state = 2},
  [616] = {.lex_state = 0, .external_lex_state = 2},
  [617] = {.lex_state = 0, .external_lex_state = 2},
  [618] = {.lex_state = 0, .external_lex_state = 2},
  [619] = {.lex_state = 0, .external_lex_state = 2},
  [620] = {.lex_state = 0, .external_lex_state = 2},
  [621] = {.lex_state = 22},
  [622] = {.lex_state = 0, .external_lex_state = 2},
  [623] = {.lex_state = 0, .external_lex_state = 2},
  [624] = {.lex_state = 28},
  [625] = {.lex_state = 28},
  [626] = {.lex_state = 28},
  [627] = {.lex_state = 28},
  [628] = {.lex_state = 28},
  [629] = {.lex_state = 28},
  [630] = {.lex_state = 0},
  [631] = {.lex_state = 28},
  [632] = {.lex_state = 28},
  [633] = {.lex_state = 28},
  [634] = {.lex_state = 28},
  [635] = {.lex_state = 0},
  [636] = {.lex_state = 28},
  [637] = {.lex_state = 28},
  [638] = {.lex_state = 28},
  [639] = {.lex_state = 0},
  [640] = {.lex_state = 27},
  [641] = {.lex_state = 27},
  [642] = {.lex_state = 27},
  [643] = {.lex_state = 0},
  [644] = {.lex_state = 0},
  [645] = {.lex_state = 0},
  [646] = {.lex_state = 0},
  [647] = {.lex_state = 0},
  [648] = {.lex_state = 0},
  [649] = {.lex_state = 0},
  [650] = {.lex_state = 0},
  [651] = {.lex_state = 0},
  [652] = {.lex_state = 0},
  [653] = {.lex_state = 0},
  [654] = {.lex_state = 0},
  [655] = {.lex_state = 0},
  [656] = {.lex_state = 0},
  [657] = {.lex_state = 0},
  [658] = {.lex_state = 0},
  [659] = {.lex_state = 0},
  [660] = {.lex_state = 0},
  [661] = {.lex_state = 0},
  [662] = {.lex_state = 0},
  [663] = {.lex_state = 0},
  [664] = {.lex_state = 0},
  [665] = {.lex_state = 0},
  [666] = {.lex_state = 0},
  [667] = {.lex_state = 0},
  [668] = {.lex_state = 0},
  [669] = {.lex_state = 0},
  [670] = {.lex_state = 0},
  [671] = {.lex_state = 0},
  [672] = {.lex_state = 0},
  [673] = {.lex_state = 0},
  [674] = {.lex_state = 0},
  [675] = {.lex_state = 0},
  [676] = {.lex_state = 0},
  [677] = {.lex_state = 0},
  [678] = {.lex_state = 0},
  [679] = {.lex_state = 0},
  [680] = {.lex_state = 0},
  [681] = {.lex_state = 0},
  [682] = {.lex_state = 0},
  [683] = {.lex_state = 0},
  [684] = {.lex_state = 0},
  [685] = {.lex_state = 0},
  [686] = {.lex_state = 0},
  [687] = {.lex_state = 0},
  [688] = {.lex_state = 0},
  [689] = {.lex_state = 0},
  [690] = {.lex_state = 0},
  [691] = {.lex_state = 0},
  [692] = {.lex_state = 27},
  [693] = {.lex_state = 0},
  [694] = {.lex_state = 0},
  [695] = {.lex_state = 0},
  [696] = {.lex_state = 0},
  [697] = {.lex_state = 0},
  [698] = {.lex_state = 0},
  [699] = {.lex_state = 0},
  [700] = {.lex_state = 0},
  [701] = {.lex_state = 0},
  [702] = {.lex_state = 0},
  [703] = {.lex_state = 0},
  [704] = {.lex_state = 0},
  [705] = {.lex_state = 0},
  [706] = {.lex_state = 0},
  [707] = {.lex_state = 0},
  [708] = {.lex_state = 0},
  [709] = {.lex_state = 0},
  [710] = {.lex_state = 0},
  [711] = {.lex_state = 0},
  [712] = {.lex_state = 0},
  [713] = {.lex_state = 0},
  [714] = {.lex_state = 0},
  [715] = {.lex_state = 0},
  [716] = {.lex_state = 0},
  [717] = {.lex_state = 0},
  [718] = {.lex_state = 0},
  [719] = {.lex_state = 0},
  [720] = {.lex_state = 0},
  [721] = {.lex_state = 0},
  [722] = {.lex_state = 0},
  [723] = {.lex_state = 27},
  [724] = {.lex_state = 0},
  [725] = {.lex_state = 0},
  [726] = {.lex_state = 0},
  [727] = {.lex_state = 0},
  [728] = {.lex_state = 0},
  [729] = {.lex_state = 0},
  [730] = {.lex_state = 0},
  [731] = {.lex_state = 0},
  [732] = {.lex_state = 27},
  [733] = {.lex_state = 0},
  [734] = {.lex_state = 27},
  [735] = {.lex_state = 27},
  [736] = {.lex_state = 0},
  [737] = {.lex_state = 27},
  [738] = {.lex_state = 27},
  [739] = {.lex_state = 27},
  [740] = {.lex_state = 27},
  [741] = {.lex_state = 27},
  [742] = {.lex_state = 25},
  [743] = {.lex_state = 0, .external_lex_state = 3},
  [744] = {.lex_state = 0},
  [745] = {.lex_state = 0, .external_lex_state = 3},
  [746] = {.lex_state = 0, .external_lex_state = 3},
  [747] = {.lex_state = 0},
  [748] = {.lex_state = 0},
  [749] = {.lex_state = 0, .external_lex_state = 3},
  [750] = {.lex_state = 0, .external_lex_state = 3},
  [751] = {.lex_state = 0},
  [752] = {.lex_state = 0, .external_lex_state = 2},
  [753] = {.lex_state = 0},
  [754] = {.lex_state = 0, .external_lex_state = 2},
  [755] = {.lex_state = 0},
  [756] = {.lex_state = 0, .external_lex_state = 2},
  [757] = {.lex_state = 0},
  [758] = {.lex_state = 0, .external_lex_state = 2},
  [759] = {.lex_state = 0},
  [760] = {.lex_state = 0},
  [761] = {.lex_state = 0},
  [762] = {.lex_state = 0},
  [763] = {.lex_state = 29},
  [764] = {.lex_state = 0},
  [765] = {.lex_state = 0},
  [766] = {.lex_state = 0},
  [767] = {.lex_state = 0},
  [768] = {.lex_state = 0},
  [769] = {.lex_state = 29},
  [770] = {.lex_state = 0},
  [771] = {.lex_state = 0},
  [772] = {.lex_state = 0},
  [773] = {.lex_state = 28},
  [774] = {.lex_state = 0},
  [775] = {.lex_state = 0},
  [776] = {.lex_state = 0},
  [777] = {.lex_state = 0},
  [778] = {.lex_state = 0},
  [779] = {.lex_state = 0},
  [780] = {.lex_state = 0},
  [781] = {.lex_state = 0},
  [782] = {.lex_state = 0},
  [783] = {.lex_state = 0},
  [784] = {.lex_state = 0},
  [785] = {.lex_state = 0},
  [786] = {.lex_state = 0},
  [787] = {.lex_state = 0, .external_lex_state = 3},
  [788] = {.lex_state = 0},
  [789] = {.lex_state = 0},
  [790] = {.lex_state = 0},
  [791] = {.lex_state = 0, .external_lex_state = 3},
  [792] = {.lex_state = 0},
  [793] = {.lex_state = 0},
  [794] = {.lex_state = 0},
  [795] = {.lex_state = 0},
  [796] = {.lex_state = 0},
  [797] = {.lex_state = 0},
  [798] = {.lex_state = 0},
  [799] = {.lex_state = 0},
  [800] = {.lex_state = 0},
  [801] = {.lex_state = 0},
  [802] = {.lex_state = 0, .external_lex_state = 3},
  [803] = {.lex_state = 0},
  [804] = {.lex_state = 0},
  [805] = {.lex_state = 0},
  [806] = {.lex_state = 0},
  [807] = {.lex_state = 0},
  [808] = {.lex_state = 0},
  [809] = {.lex_state = 0},
  [810] = {.lex_state = 0},
  [811] = {.lex_state = 0},
  [812] = {.lex_state = 0},
  [813] = {.lex_state = 0},
  [814] = {.lex_state = 0, .external_lex_state = 3},
  [815] = {.lex_state = 0},
  [816] = {.lex_state = 0},
  [817] = {.lex_state = 0},
  [818] = {.lex_state = 0},
  [819] = {.lex_state = 0},
  [820] = {.lex_state = 0},
  [821] = {.lex_state = 0},
  [822] = {.lex_state = 0},
  [823] = {.lex_state = 0},
  [824] = {.lex_state = 0},
  [825] = {.lex_state = 0},
  [826] = {.lex_state = 0},
  [827] = {.lex_state = 0},
  [828] = {.lex_state = 0},
  [829] = {.lex_state = 0, .external_lex_state = 3},
  [830] = {.lex_state = 0, .external_lex_state = 3},
  [831] = {.lex_state = 0},
  [832] = {.lex_state = 0},
  [833] = {.lex_state = 0},
  [834] = {.lex_state = 0},
  [835] = {.lex_state = 0, .external_lex_state = 3},
  [836] = {.lex_state = 0, .external_lex_state = 3},
  [837] = {.lex_state = 0},
  [838] = {.lex_state = 0, .external_lex_state = 3},
  [839] = {.lex_state = 0, .external_lex_state = 3},
  [840] = {.lex_state = 29},
  [841] = {.lex_state = 0, .external_lex_state = 3},
  [842] = {.lex_state = 0, .external_lex_state = 3},
  [843] = {.lex_state = 0, .external_lex_state = 3},
  [844] = {.lex_state = 0, .external_lex_state = 3},
  [845] = {.lex_state = 0},
  [846] = {.lex_state = 0, .external_lex_state = 3},
  [847] = {.lex_state = 0, .external_lex_state = 3},
  [848] = {.lex_state = 0},
  [849] = {.lex_state = 0, .external_lex_state = 3},
  [850] = {.lex_state = 0},
  [851] = {.lex_state = 0},
  [852] = {.lex_state = 0, .external_lex_state = 3},
  [853] = {.lex_state = 0, .external_lex_state = 3},
  [854] = {.lex_state = 0, .external_lex_state = 3},
  [855] = {.lex_state = 0},
  [856] = {.lex_state = 0, .external_lex_state = 3},
  [857] = {.lex_state = 0},
  [858] = {.lex_state = 0, .external_lex_state = 3},
  [859] = {.lex_state = 0, .external_lex_state = 3},
  [860] = {.lex_state = 0, .external_lex_state = 3},
  [861] = {.lex_state = 0},
  [862] = {.lex_state = 0, .external_lex_state = 3},
  [863] = {.lex_state = 0},
  [864] = {.lex_state = 0},
  [865] = {.lex_state = 0},
  [866] = {.lex_state = 0, .external_lex_state = 3},
  [867] = {.lex_state = 0, .external_lex_state = 3},
  [868] = {.lex_state = 0, .external_lex_state = 3},
  [869] = {.lex_state = 0},
  [870] = {.lex_state = 0, .external_lex_state = 3},
  [871] = {.lex_state = 0},
  [872] = {.lex_state = 0},
  [873] = {.lex_state = 0, .external_lex_state = 3},
  [874] = {.lex_state = 0},
  [875] = {.lex_state = 0, .external_lex_state = 3},
  [876] = {.lex_state = 0, .external_lex_state = 3},
  [877] = {.lex_state = 0},
  [878] = {.lex_state = 0},
  [879] = {.lex_state = 0},
  [880] = {.lex_state = 0, .external_lex_state = 3},
  [881] = {.lex_state = 0, .external_lex_state = 3},
  [882] = {.lex_state = 0, .external_lex_state = 3},
  [883] = {.lex_state = 0, .external_lex_state = 3},
  [884] = {.lex_state = 0, .external_lex_state = 3},
  [885] = {.lex_state = 0, .external_lex_state = 3},
  [886] = {.lex_state = 0},
  [887] = {.lex_state = 0, .external_lex_state = 3},
  [888] = {.lex_state = 0, .external_lex_state = 3},
  [889] = {.lex_state = 0, .external_lex_state = 3},
  [890] = {.lex_state = 0, .external_lex_state = 3},
  [891] = {.lex_state = 0, .external_lex_state = 3},
  [892] = {.lex_state = 0},
  [893] = {.lex_state = 0, .external_lex_state = 3},
  [894] = {.lex_state = 0},
  [895] = {.lex_state = 0},
  [896] = {.lex_state = 0, .external_lex_state = 3},
  [897] = {.lex_state = 0},
  [898] = {.lex_state = 29},
  [899] = {.lex_state = 0},
  [900] = {.lex_state = 27},
  [901] = {.lex_state = 27},
  [902] = {.lex_state = 0},
  [903] = {.lex_state = 29},
  [904] = {.lex_state = 29},
  [905] = {.lex_state = 29},
  [906] = {.lex_state = 29},
  [907] = {.lex_state = 29},
  [908] = {.lex_state = 29},
  [909] = {.lex_state = 29},
  [910] = {.lex_state = 29},
  [911] = {.lex_state = 27},
  [912] = {.lex_state = 27},
  [913] = {.lex_state = 27},
  [914] = {.lex_state = 27},
  [915] = {.lex_state = 27},
  [916] = {.lex_state = 27},
  [917] = {.lex_state = 27},
  [918] = {.lex_state = 27},
  [919] = {.lex_state = 27},
  [920] = {.lex_state = 27},
  [921] = {.lex_state = 29},
  [922] = {.lex_state = 0},
  [923] = {.lex_state = 0},
  [924] = {.lex_state = 29},
  [925] = {.lex_state = 29},
  [926] = {.lex_state = 29},
  [927] = {.lex_state = 30},
  [928] = {.lex_state = 29},
  [929] = {.lex_state = 29},
  [930] = {.lex_state = 29},
  [931] = {.lex_state = 29},
  [932] = {.lex_state = 29},
  [933] = {.lex_state = 29},
  [934] = {.lex_state = 29},
  [935] = {.lex_state = 29},
  [936] = {.lex_state = 29},
  [937] = {.lex_state = 29},
  [938] = {.lex_state = 29},
  [939] = {.lex_state = 29},
  [940] = {.lex_state = 29},
  [941] = {.lex_state = 29},
  [942] = {.lex_state = 29},
  [943] = {.lex_state = 29},
  [944] = {.lex_state = 29},
  [945] = {.lex_state = 29},
  [946] = {.lex_state = 29},
  [947] = {.lex_state = 29},
  [948] = {.lex_state = 29},
  [949] = {.lex_state = 29},
  [950] = {.lex_state = 29},
  [951] = {.lex_state = 29},
  [952] = {.lex_state = 29},
  [953] = {.lex_state = 29},
  [954] = {.lex_state = 29},
  [955] = {.lex_state = 29},
  [956] = {.lex_state = 29},
  [957] = {.lex_state = 29},
  [958] = {.lex_state = 29},
  [959] = {.lex_state = 29},
  [960] = {.lex_state = 29},
  [961] = {.lex_state = 29},
  [962] = {.lex_state = 29},
  [963] = {.lex_state = 29},
  [964] = {.lex_state = 29},
  [965] = {.lex_state = 29},
  [966] = {.lex_state = 29},
  [967] = {.lex_state = 29},
  [968] = {.lex_state = 29},
  [969] = {.lex_state = 29},
  [970] = {.lex_state = 29},
  [971] = {.lex_state = 25},
  [972] = {.lex_state = 29},
  [973] = {.lex_state = 25},
  [974] = {.lex_state = 25},
  [975] = {.lex_state = 25},
  [976] = {.lex_state = 25},
  [977] = {.lex_state = 25},
  [978] = {.lex_state = 25},
  [979] = {.lex_state = 25},
  [980] = {.lex_state = 25},
  [981] = {.lex_state = 25},
  [982] = {.lex_state = 25},
  [983] = {.lex_state = 25},
  [984] = {.lex_state = 25},
  [985] = {.lex_state = 25},
  [986] = {.lex_state = 25},
  [987] = {.lex_state = 25},
  [988] = {.lex_state = 25},
  [989] = {.lex_state = 25},
  [990] = {.lex_state = 25},
  [991] = {.lex_state = 25},
  [992] = {.lex_state = 25},
  [993] = {.lex_state = 25, .external_lex_state = 2},
  [994] = {.lex_state = 25},
  [995] = {.lex_state = 25},
  [996] = {.lex_state = 25},
  [997] = {.lex_state = 25},
  [998] = {.lex_state = 25, .external_lex_state = 2},
  [999] = {.lex_state = 25},
  [1000] = {.lex_state = 25},
  [1001] = {.lex_state = 25},
  [1002] = {.lex_state = 25},
  [1003] = {.lex_state = 25},
  [1004] = {.lex_state = 25},
  [1005] = {.lex_state = 25},
  [1006] = {.lex_state = 25},
  [1007] = {.lex_state = 25},
  [1008] = {.lex_state = 25},
  [1009] = {.lex_state = 25},
  [1010] = {.lex_state = 25},
  [1011] = {.lex_state = 25},
  [1012] = {.lex_state = 25},
  [1013] = {.lex_state = 25},
  [1014] = {.lex_state = 25},
  [1015] = {.lex_state = 25},
  [1016] = {.lex_state = 0},
  [1017] = {.lex_state = 25},
  [1018] = {.lex_state = 25},
  [1019] = {.lex_state = 25},
  [1020] = {.lex_state = 0},
  [1021] = {.lex_state = 0, .external_lex_state = 2},
  [1022] = {.lex_state = 0, .external_lex_state = 2},
  [1023] = {.lex_state = 25},
  [1024] = {.lex_state = 25},
  [1025] = {.lex_state = 25},
  [1026] = {.lex_state = 25},
  [1027] = {.lex_state = 0},
  [1028] = {.lex_state = 25},
  [1029] = {.lex_state = 25, .external_lex_state = 2},
  [1030] = {.lex_state = 25},
  [1031] = {.lex_state = 25},
  [1032] = {.lex_state = 0, .external_lex_state = 2},
  [1033] = {.lex_state = 0},
  [1034] = {.lex_state = 25},
  [1035] = {.lex_state = 25},
  [1036] = {.lex_state = 25},
  [1037] = {.lex_state = 0, .external_lex_state = 2},
  [1038] = {.lex_state = 0, .external_lex_state = 2},
  [1039] = {.lex_state = 0, .external_lex_state = 2},
  [1040] = {.lex_state = 25},
  [1041] = {.lex_state = 25},
  [1042] = {.lex_state = 25},
  [1043] = {.lex_state = 0, .external_lex_state = 2},
  [1044] = {.lex_state = 25},
  [1045] = {.lex_state = 25},
  [1046] = {.lex_state = 25},
  [1047] = {.lex_state = 25},
  [1048] = {.lex_state = 25},
  [1049] = {.lex_state = 25},
  [1050] = {.lex_state = 25},
  [1051] = {.lex_state = 25},
  [1052] = {.lex_state = 25},
  [1053] = {.lex_state = 25},
  [1054] = {.lex_state = 25},
  [1055] = {.lex_state = 25},
  [1056] = {.lex_state = 25},
  [1057] = {.lex_state = 25},
  [1058] = {.lex_state = 25},
  [1059] = {.lex_state = 25},
  [1060] = {.lex_state = 25},
  [1061] = {.lex_state = 25},
  [1062] = {.lex_state = 0},
  [1063] = {.lex_state = 25},
  [1064] = {.lex_state = 25},
  [1065] = {.lex_state = 25},
  [1066] = {.lex_state = 25},
  [1067] = {.lex_state = 25},
  [1068] = {.lex_state = 0, .external_lex_state = 2},
  [1069] = {.lex_state = 25},
  [1070] = {.lex_state = 25},
  [1071] = {.lex_state = 25},
  [1072] = {.lex_state = 25},
  [1073] = {.lex_state = 0, .external_lex_state = 2},
  [1074] = {.lex_state = 0, .external_lex_state = 2},
  [1075] = {.lex_state = 25},
  [1076] = {.lex_state = 0, .external_lex_state = 2},
  [1077] = {.lex_state = 25},
  [1078] = {.lex_state = 0},
  [1079] = {.lex_state = 25, .external_lex_state = 2},
  [1080] = {.lex_state = 0},
  [1081] = {.lex_state = 25, .external_lex_state = 2},
  [1082] = {.lex_state = 25},
  [1083] = {.lex_state = 25},
  [1084] = {.lex_state = 0},
  [1085] = {.lex_state = 25},
  [1086] = {.lex_state = 0},
  [1087] = {.lex_state = 25},
  [1088] = {.lex_state = 25, .external_lex_state = 2},
  [1089] = {.lex_state = 25, .external_lex_state = 2},
  [1090] = {.lex_state = 25, .external_lex_state = 2},
  [1091] = {.lex_state = 25},
  [1092] = {.lex_state = 0},
  [1093] = {.lex_state = 0},
  [1094] = {.lex_state = 25},
  [1095] = {.lex_state = 0},
  [1096] = {.lex_state = 0},
  [1097] = {.lex_state = 0},
  [1098] = {.lex_state = 25, .external_lex_state = 2},
  [1099] = {.lex_state = 25},
  [1100] = {.lex_state = 25, .external_lex_state = 2},
  [1101] = {.lex_state = 25, .external_lex_state = 2},
  [1102] = {.lex_state = 25},
  [1103] = {.lex_state = 25},
  [1104] = {.lex_state = 25, .external_lex_state = 2},
  [1105] = {.lex_state = 25, .external_lex_state = 2},
  [1106] = {.lex_state = 0, .external_lex_state = 2},
  [1107] = {.lex_state = 0, .external_lex_state = 2},
  [1108] = {.lex_state = 25},
  [1109] = {.lex_state = 25},
  [1110] = {.lex_state = 25},
  [1111] = {.lex_state = 0, .external_lex_state = 2},
  [1112] = {.lex_state = 0, .external_lex_state = 2},
  [1113] = {.lex_state = 0, .external_lex_state = 2},
  [1114] = {.lex_state = 25, .external_lex_state = 2},
  [1115] = {.lex_state = 0, .external_lex_state = 2},
  [1116] = {.lex_state = 0, .external_lex_state = 2},
  [1117] = {.lex_state = 0, .external_lex_state = 2},
  [1118] = {.lex_state = 0, .external_lex_state = 2},
  [1119] = {.lex_state = 0, .external_lex_state = 2},
  [1120] = {.lex_state = 0, .external_lex_state = 2},
  [1121] = {.lex_state = 25, .external_lex_state = 2},
  [1122] = {.lex_state = 0},
  [1123] = {.lex_state = 0, .external_lex_state = 2},
  [1124] = {.lex_state = 0, .external_lex_state = 2},
  [1125] = {.lex_state = 0, .external_lex_state = 2},
  [1126] = {.lex_state = 0, .external_lex_state = 2},
  [1127] = {.lex_state = 0},
  [1128] = {.lex_state = 25},
  [1129] = {.lex_state = 0, .external_lex_state = 2},
  [1130] = {.lex_state = 25},
  [1131] = {.lex_state = 0},
  [1132] = {.lex_state = 25, .external_lex_state = 2},
  [1133] = {.lex_state = 0, .external_lex_state = 2},
  [1134] = {.lex_state = 25},
  [1135] = {.lex_state = 0},
  [1136] = {.lex_state = 25},
  [1137] = {.lex_state = 25},
  [1138] = {.lex_state = 25, .external_lex_state = 2},
  [1139] = {.lex_state = 0, .external_lex_state = 2},
  [1140] = {.lex_state = 25, .external_lex_state = 2},
  [1141] = {.lex_state = 0, .external_lex_state = 2},
  [1142] = {.lex_state = 25},
  [1143] = {.lex_state = 0, .external_lex_state = 2},
  [1144] = {.lex_state = 0, .external_lex_state = 2},
  [1145] = {.lex_state = 0, .external_lex_state = 2},
  [1146] = {.lex_state = 25, .external_lex_state = 2},
  [1147] = {.lex_state = 0, .external_lex_state = 2},
  [1148] = {.lex_state = 0, .external_lex_state = 2},
  [1149] = {.lex_state = 25},
  [1150] = {.lex_state = 0, .external_lex_state = 2},
  [1151] = {.lex_state = 0},
  [1152] = {.lex_state = 0, .external_lex_state = 2},
  [1153] = {.lex_state = 0, .external_lex_state = 2},
  [1154] = {.lex_state = 0, .external_lex_state = 2},
  [1155] = {.lex_state = 0, .external_lex_state = 2},
  [1156] = {.lex_state = 0, .external_lex_state = 2},
  [1157] = {.lex_state = 0, .external_lex_state = 2},
  [1158] = {.lex_state = 0, .external_lex_state = 2},
  [1159] = {.lex_state = 0, .external_lex_state = 2},
  [1160] = {.lex_state = 0, .external_lex_state = 2},
  [1161] = {.lex_state = 0, .external_lex_state = 2},
  [1162] = {.lex_state = 0, .external_lex_state = 2},
  [1163] = {.lex_state = 25, .external_lex_state = 2},
  [1164] = {.lex_state = 25},
  [1165] = {.lex_state = 25},
  [1166] = {.lex_state = 25},
  [1167] = {.lex_state = 25},
  [1168] = {.lex_state = 25},
  [1169] = {.lex_state = 25},
  [1170] = {.lex_state = 0, .external_lex_state = 2},
  [1171] = {.lex_state = 25},
  [1172] = {.lex_state = 25},
  [1173] = {.lex_state = 25},
  [1174] = {.lex_state = 25, .external_lex_state = 2},
  [1175] = {.lex_state = 0},
  [1176] = {.lex_state = 25},
  [1177] = {.lex_state = 25},
  [1178] = {.lex_state = 0},
  [1179] = {.lex_state = 25},
  [1180] = {.lex_state = 0},
  [1181] = {.lex_state = 0},
  [1182] = {.lex_state = 25},
  [1183] = {.lex_state = 25, .external_lex_state = 2},
  [1184] = {.lex_state = 25},
  [1185] = {.lex_state = 25},
  [1186] = {.lex_state = 25, .external_lex_state = 2},
  [1187] = {.lex_state = 25},
  [1188] = {.lex_state = 0},
  [1189] = {.lex_state = 0, .external_lex_state = 2},
  [1190] = {.lex_state = 25},
  [1191] = {.lex_state = 25},
  [1192] = {.lex_state = 0, .external_lex_state = 2},
  [1193] = {.lex_state = 25},
  [1194] = {.lex_state = 25},
  [1195] = {.lex_state = 25},
  [1196] = {.lex_state = 33},
  [1197] = {.lex_state = 0},
  [1198] = {.lex_state = 0, .external_lex_state = 2},
  [1199] = {.lex_state = 0},
  [1200] = {.lex_state = 25},
  [1201] = {.lex_state = 0, .external_lex_state = 2},
  [1202] = {.lex_state = 0, .external_lex_state = 2},
  [1203] = {.lex_state = 25},
  [1204] = {.lex_state = 33},
  [1205] = {.lex_state = 0, .external_lex_state = 2},
  [1206] = {.lex_state = 25},
  [1207] = {.lex_state = 0, .external_lex_state = 2},
  [1208] = {.lex_state = 0, .external_lex_state = 2},
  [1209] = {.lex_state = 25},
  [1210] = {.lex_state = 0, .external_lex_state = 2},
  [1211] = {.lex_state = 33},
  [1212] = {.lex_state = 0, .external_lex_state = 2},
  [1213] = {.lex_state = 25},
  [1214] = {.lex_state = 33},
  [1215] = {.lex_state = 33},
  [1216] = {.lex_state = 25},
  [1217] = {.lex_state = 0, .external_lex_state = 2},
  [1218] = {.lex_state = 25},
  [1219] = {.lex_state = 25},
  [1220] = {.lex_state = 25},
  [1221] = {.lex_state = 25},
  [1222] = {.lex_state = 25},
  [1223] = {.lex_state = 25},
  [1224] = {.lex_state = 33},
  [1225] = {.lex_state = 33},
  [1226] = {.lex_state = 25},
  [1227] = {.lex_state = 0, .external_lex_state = 2},
  [1228] = {.lex_state = 25},
  [1229] = {.lex_state = 0, .external_lex_state = 2},
  [1230] = {.lex_state = 33},
  [1231] = {.lex_state = 25, .external_lex_state = 2},
  [1232] = {.lex_state = 25, .external_lex_state = 2},
  [1233] = {.lex_state = 33},
  [1234] = {.lex_state = 33},
  [1235] = {.lex_state = 25},
  [1236] = {.lex_state = 33},
  [1237] = {.lex_state = 33},
  [1238] = {.lex_state = 33},
  [1239] = {.lex_state = 33},
  [1240] = {.lex_state = 33},
  [1241] = {.lex_state = 25},
  [1242] = {.lex_state = 25},
  [1243] = {.lex_state = 0},
  [1244] = {.lex_state = 0},
  [1245] = {.lex_state = 0, .external_lex_state = 2},
  [1246] = {.lex_state = 25},
  [1247] = {.lex_state = 0, .external_lex_state = 2},
  [1248] = {.lex_state = 0},
  [1249] = {.lex_state = 25},
  [1250] = {.lex_state = 25},
  [1251] = {.lex_state = 25},
  [1252] = {.lex_state = 25},
  [1253] = {.lex_state = 0},
  [1254] = {.lex_state = 25},
  [1255] = {.lex_state = 0},
  [1256] = {.lex_state = 0},
  [1257] = {.lex_state = 25},
  [1258] = {.lex_state = 25},
  [1259] = {.lex_state = 0},
  [1260] = {.lex_state = 0},
  [1261] = {.lex_state = 0},
  [1262] = {.lex_state = 0},
  [1263] = {.lex_state = 0},
  [1264] = {.lex_state = 0},
  [1265] = {.lex_state = 0},
  [1266] = {.lex_state = 25},
  [1267] = {.lex_state = 0},
  [1268] = {.lex_state = 0},
  [1269] = {.lex_state = 25},
  [1270] = {.lex_state = 0},
  [1271] = {.lex_state = 0},
  [1272] = {.lex_state = 0},
  [1273] = {.lex_state = 0},
  [1274] = {.lex_state = 0},
  [1275] = {.lex_state = 0},
  [1276] = {.lex_state = 0},
  [1277] = {.lex_state = 25},
  [1278] = {.lex_state = 25},
  [1279] = {.lex_state = 25},
  [1280] = {.lex_state = 25},
  [1281] = {.lex_state = 25},
  [1282] = {.lex_state = 0},
  [1283] = {.lex_state = 0},
  [1284] = {.lex_state = 25},
  [1285] = {.lex_state = 0},
  [1286] = {.lex_state = 0},
  [1287] = {.lex_state = 0},
  [1288] = {.lex_state = 0},
  [1289] = {.lex_state = 25},
  [1290] = {.lex_state = 0},
  [1291] = {.lex_state = 0},
  [1292] = {.lex_state = 25},
  [1293] = {.lex_state = 25},
  [1294] = {.lex_state = 0},
  [1295] = {.lex_state = 25},
  [1296] = {.lex_state = 0},
  [1297] = {.lex_state = 25},
  [1298] = {.lex_state = 25},
  [1299] = {.lex_state = 25},
  [1300] = {.lex_state = 0},
  [1301] = {.lex_state = 0},
  [1302] = {.lex_state = 25},
  [1303] = {.lex_state = 0},
  [1304] = {.lex_state = 25},
  [1305] = {.lex_state = 0},
  [1306] = {.lex_state = 0},
  [1307] = {.lex_state = 0},
  [1308] = {.lex_state = 0},
  [1309] = {.lex_state = 25},
  [1310] = {.lex_state = 0},
  [1311] = {.lex_state = 0},
  [1312] = {.lex_state = 0},
  [1313] = {.lex_state = 25},
  [1314] = {.lex_state = 0},
  [1315] = {.lex_state = 0},
  [1316] = {.lex_state = 0},
  [1317] = {.lex_state = 0},
  [1318] = {.lex_state = 0},
  [1319] = {.lex_state = 0},
  [1320] = {.lex_state = 0},
  [1321] = {.lex_state = 0},
  [1322] = {.lex_state = 0},
  [1323] = {.lex_state = 0},
  [1324] = {.lex_state = 134},
  [1325] = {.lex_state = 134},
  [1326] = {.lex_state = 0},
  [1327] = {.lex_state = 0},
  [1328] = {.lex_state = 25},
  [1329] = {.lex_state = 0, .external_lex_state = 2},
  [1330] = {.lex_state = 0},
  [1331] = {.lex_state = 0},
  [1332] = {.lex_state = 0},
  [1333] = {.lex_state = 25},
  [1334] = {.lex_state = 0},
  [1335] = {.lex_state = 0},
  [1336] = {.lex_state = 33},
  [1337] = {.lex_state = 25},
  [1338] = {.lex_state = 25},
  [1339] = {.lex_state = 0},
  [1340] = {.lex_state = 134},
  [1341] = {.lex_state = 0},
  [1342] = {.lex_state = 0},
  [1343] = {.lex_state = 25},
  [1344] = {.lex_state = 0},
  [1345] = {.lex_state = 25},
  [1346] = {.lex_state = 0},
  [1347] = {.lex_state = 25},
  [1348] = {.lex_state = 0},
  [1349] = {.lex_state = 25},
  [1350] = {.lex_state = 25},
  [1351] = {.lex_state = 134},
  [1352] = {.lex_state = 0},
  [1353] = {.lex_state = 0},
  [1354] = {.lex_state = 0},
  [1355] = {.lex_state = 0},
  [1356] = {.lex_state = 25},
  [1357] = {.lex_state = 0},
  [1358] = {.lex_state = 0},
  [1359] = {.lex_state = 0},
  [1360] = {.lex_state = 0},
  [1361] = {.lex_state = 0},
  [1362] = {.lex_state = 0},
  [1363] = {.lex_state = 25},
  [1364] = {.lex_state = 0},
  [1365] = {.lex_state = 0},
  [1366] = {.lex_state = 0},
  [1367] = {.lex_state = 0},
  [1368] = {.lex_state = 25},
  [1369] = {.lex_state = 25},
  [1370] = {.lex_state = 0},
  [1371] = {.lex_state = 25},
  [1372] = {.lex_state = 0},
  [1373] = {.lex_state = 0},
  [1374] = {.lex_state = 0},
  [1375] = {.lex_state = 0},
  [1376] = {.lex_state = 0},
  [1377] = {.lex_state = 0},
  [1378] = {.lex_state = 25},
  [1379] = {.lex_state = 25},
  [1380] = {.lex_state = 0},
  [1381] = {.lex_state = 25},
  [1382] = {.lex_state = 0},
  [1383] = {.lex_state = 17},
  [1384] = {.lex_state = 25},
  [1385] = {.lex_state = 25},
  [1386] = {.lex_state = 25},
  [1387] = {.lex_state = 25},
  [1388] = {.lex_state = 0},
  [1389] = {.lex_state = 0},
  [1390] = {.lex_state = 0},
  [1391] = {.lex_state = 0},
  [1392] = {.lex_state = 0},
  [1393] = {.lex_state = 0},
  [1394] = {.lex_state = 0},
  [1395] = {.lex_state = 25},
  [1396] = {.lex_state = 0},
  [1397] = {.lex_state = 0},
  [1398] = {.lex_state = 0},
  [1399] = {.lex_state = 25},
  [1400] = {.lex_state = 0},
  [1401] = {.lex_state = 25},
  [1402] = {.lex_state = 25},
  [1403] = {.lex_state = 25},
  [1404] = {.lex_state = 25},
  [1405] = {.lex_state = 0},
  [1406] = {.lex_state = 0},
  [1407] = {.lex_state = 0},
  [1408] = {.lex_state = 0},
  [1409] = {.lex_state = 25},
  [1410] = {.lex_state = 25},
  [1411] = {.lex_state = 0},
  [1412] = {.lex_state = 0},
  [1413] = {.lex_state = 0},
  [1414] = {.lex_state = 0},
  [1415] = {.lex_state = 0},
  [1416] = {.lex_state = 0},
  [1417] = {.lex_state = 25},
  [1418] = {.lex_state = 0},
  [1419] = {.lex_state = 0},
  [1420] = {.lex_state = 0},
  [1421] = {.lex_state = 25},
  [1422] = {.lex_state = 0},
  [1423] = {.lex_state = 0},
  [1424] = {.lex_state = 0},
  [1425] = {.lex_state = 25},
  [1426] = {.lex_state = 0},
  [1427] = {.lex_state = 0},
  [1428] = {.lex_state = 25},
  [1429] = {.lex_state = 25},
  [1430] = {.lex_state = 0},
  [1431] = {.lex_state = 0},
  [1432] = {.lex_state = 17},
  [1433] = {.lex_state = 0},
  [1434] = {.lex_state = 25},
  [1435] = {.lex_state = 0},
  [1436] = {.lex_state = 25},
  [1437] = {.lex_state = 0},
  [1438] = {.lex_state = 0},
  [1439] = {.lex_state = 17},
  [1440] = {.lex_state = 25},
  [1441] = {.lex_state = 0},
  [1442] = {.lex_state = 0},
  [1443] = {.lex_state = 0},
  [1444] = {.lex_state = 0},
  [1445] = {.lex_state = 25},
  [1446] = {.lex_state = 17},
  [1447] = {.lex_state = 0, .external_lex_state = 4},
  [1448] = {.lex_state = 0},
  [1449] = {.lex_state = 25},
  [1450] = {.lex_state = 25},
  [1451] = {.lex_state = 17},
  [1452] = {.lex_state = 25},
  [1453] = {.lex_state = 0},
  [1454] = {.lex_state = 0},
  [1455] = {.lex_state = 0},
  [1456] = {.lex_state = 25},
  [1457] = {.lex_state = 25},
  [1458] = {.lex_state = 0},
  [1459] = {.lex_state = 0},
  [1460] = {.lex_state = 0},
  [1461] = {.lex_state = 0},
  [1462] = {.lex_state = 0, .external_lex_state = 4},
  [1463] = {.lex_state = 0},
  [1464] = {.lex_state = 25},
  [1465] = {.lex_state = 0},
  [1466] = {.lex_state = 0, .external_lex_state = 4},
  [1467] = {.lex_state = 25},
  [1468] = {.lex_state = 0},
  [1469] = {.lex_state = 0},
  [1470] = {.lex_state = 32},
  [1471] = {.lex_state = 0},
  [1472] = {.lex_state = 25},
  [1473] = {.lex_state = 25},
  [1474] = {.lex_state = 25},
  [1475] = {.lex_state = 25},
  [1476] = {.lex_state = 0},
  [1477] = {.lex_state = 25},
  [1478] = {.lex_state = 25},
  [1479] = {.lex_state = 0},
  [1480] = {.lex_state = 25},
  [1481] = {.lex_state = 25},
  [1482] = {.lex_state = 25},
  [1483] = {.lex_state = 0},
  [1484] = {.lex_state = 32},
  [1485] = {.lex_state = 32},
  [1486] = {.lex_state = 0, .external_lex_state = 4},
  [1487] = {.lex_state = 0, .external_lex_state = 4},
  [1488] = {.lex_state = 25},
  [1489] = {.lex_state = 0},
  [1490] = {.lex_state = 0},
  [1491] = {.lex_state = 25},
  [1492] = {.lex_state = 0},
  [1493] = {.lex_state = 0},
  [1494] = {.lex_state = 0},
  [1495] = {.lex_state = 0},
  [1496] = {.lex_state = 25},
  [1497] = {.lex_state = 0},
  [1498] = {.lex_state = 0},
  [1499] = {.lex_state = 0},
  [1500] = {.lex_state = 25},
  [1501] = {.lex_state = 0},
  [1502] = {.lex_state = 0, .external_lex_state = 4},
  [1503] = {.lex_state = 25},
  [1504] = {.lex_state = 0},
  [1505] = {.lex_state = 25},
  [1506] = {.lex_state = 25},
  [1507] = {.lex_state = 0},
  [1508] = {.lex_state = 0},
  [1509] = {.lex_state = 0},
  [1510] = {.lex_state = 25},
  [1511] = {.lex_state = 0},
  [1512] = {.lex_state = 25},
  [1513] = {.lex_state = 0},
  [1514] = {.lex_state = 0},
  [1515] = {.lex_state = 32},
  [1516] = {.lex_state = 0},
  [1517] = {.lex_state = 0},
  [1518] = {.lex_state = 0},
  [1519] = {.lex_state = 0},
  [1520] = {.lex_state = 25},
  [1521] = {.lex_state = 0},
  [1522] = {.lex_state = 0},
  [1523] = {.lex_state = 0},
  [1524] = {.lex_state = 25},
  [1525] = {.lex_state = 0},
  [1526] = {.lex_state = 0},
  [1527] = {.lex_state = 0},
  [1528] = {.lex_state = 25},
  [1529] = {.lex_state = 0},
  [1530] = {.lex_state = 0},
  [1531] = {.lex_state = 0},
  [1532] = {.lex_state = 0},
  [1533] = {.lex_state = 25},
  [1534] = {.lex_state = 25},
  [1535] = {.lex_state = 25},
  [1536] = {.lex_state = 0},
  [1537] = {.lex_state = 0},
  [1538] = {.lex_state = 25},
  [1539] = {.lex_state = 25},
  [1540] = {.lex_state = 0},
  [1541] = {.lex_state = 0},
  [1542] = {.lex_state = 25},
  [1543] = {.lex_state = 25},
  [1544] = {.lex_state = 0},
  [1545] = {.lex_state = 0},
  [1546] = {.lex_state = 0},
  [1547] = {.lex_state = 0},
  [1548] = {.lex_state = 25},
  [1549] = {.lex_state = 0},
  [1550] = {.lex_state = 0},
  [1551] = {.lex_state = 0},
  [1552] = {.lex_state = 25},
  [1553] = {.lex_state = 0},
  [1554] = {.lex_state = 25},
  [1555] = {.lex_state = 0},
  [1556] = {.lex_state = 25},
  [1557] = {.lex_state = 0},
  [1558] = {.lex_state = 0},
  [1559] = {.lex_state = 25},
  [1560] = {.lex_state = 0},
  [1561] = {.lex_state = 0},
  [1562] = {.lex_state = 25},
  [1563] = {.lex_state = 0, .external_lex_state = 4},
  [1564] = {.lex_state = 0},
  [1565] = {.lex_state = 25},
  [1566] = {.lex_state = 0},
  [1567] = {.lex_state = 0},
  [1568] = {.lex_state = 25},
  [1569] = {.lex_state = 0},
  [1570] = {.lex_state = 0},
  [1571] = {.lex_state = 25},
  [1572] = {.lex_state = 0},
  [1573] = {.lex_state = 25},
  [1574] = {.lex_state = 25},
  [1575] = {.lex_state = 0},
  [1576] = {.lex_state = 0},
  [1577] = {.lex_state = 0},
  [1578] = {.lex_state = 25},
  [1579] = {.lex_state = 0},
  [1580] = {.lex_state = 25},
  [1581] = {.lex_state = 0},
  [1582] = {.lex_state = 0},
  [1583] = {.lex_state = 0},
  [1584] = {.lex_state = 0},
  [1585] = {.lex_state = 0},
  [1586] = {.lex_state = 0},
  [1587] = {.lex_state = 0},
  [1588] = {.lex_state = 0, .external_lex_state = 4},
  [1589] = {.lex_state = 0},
  [1590] = {.lex_state = 0},
  [1591] = {.lex_state = 25},
  [1592] = {.lex_state = 25},
  [1593] = {.lex_state = 0},
  [1594] = {.lex_state = 25},
  [1595] = {.lex_state = 32},
  [1596] = {.lex_state = 25},
  [1597] = {.lex_state = 25},
  [1598] = {.lex_state = 0, .external_lex_state = 4},
  [1599] = {.lex_state = 0},
  [1600] = {.lex_state = 0},
  [1601] = {.lex_state = 25},
  [1602] = {.lex_state = 25},
  [1603] = {.lex_state = 25},
  [1604] = {.lex_state = 25},
  [1605] = {.lex_state = 25},
  [1606] = {.lex_state = 25},
  [1607] = {.lex_state = 0, .external_lex_state = 4},
  [1608] = {.lex_state = 0},
  [1609] = {.lex_state = 0},
  [1610] = {.lex_state = 0},
  [1611] = {.lex_state = 25},
  [1612] = {.lex_state = 25},
  [1613] = {.lex_state = 0},
  [1614] = {.lex_state = 0},
  [1615] = {.lex_state = 32},
  [1616] = {.lex_state = 0},
  [1617] = {.lex_state = 0},
  [1618] = {.lex_state = 0},
  [1619] = {.lex_state = 134},
  [1620] = {.lex_state = 25},
  [1621] = {.lex_state = 25},
  [1622] = {.lex_state = 0},
  [1623] = {.lex_state = 0},
  [1624] = {.lex_state = 0},
  [1625] = {.lex_state = 0},
  [1626] = {.lex_state = 32},
  [1627] = {.lex_state = 0},
  [1628] = {.lex_state = 25},
  [1629] = {.lex_state = 0},
  [1630] = {.lex_state = 0},
  [1631] = {.lex_state = 0},
  [1632] = {.lex_state = 0},
  [1633] = {.lex_state = 0},
  [1634] = {.lex_state = 0},
  [1635] = {.lex_state = 25},
  [1636] = {.lex_state = 0},
  [1637] = {.lex_state = 0},
  [1638] = {.lex_state = 0},
  [1639] = {.lex_state = 25},
  [1640] = {.lex_state = 0},
  [1641] = {.lex_state = 0},
  [1642] = {.lex_state = 0},
  [1643] = {.lex_state = 25},
  [1644] = {.lex_state = 0},
  [1645] = {.lex_state = 0},
  [1646] = {.lex_state = 0},
  [1647] = {.lex_state = 0},
  [1648] = {.lex_state = 0},
  [1649] = {.lex_state = 0},
  [1650] = {.lex_state = 0},
  [1651] = {.lex_state = 0},
  [1652] = {.lex_state = 0},
  [1653] = {.lex_state = 0},
  [1654] = {.lex_state = 0},
  [1655] = {.lex_state = 0},
  [1656] = {.lex_state = 0},
  [1657] = {.lex_state = 0},
  [1658] = {.lex_state = 25},
  [1659] = {(TSStateId)(-1)},
  [1660] = {(TSStateId)(-1)},
  [1661] = {(TSStateId)(-1)},
  [1662] = {(TSStateId)(-1)},
  [1663] = {(TSStateId)(-1)},
  [1664] = {(TSStateId)(-1)},
  [1665] = {(TSStateId)(-1)},
  [1666] = {(TSStateId)(-1)},
  [1667] = {(TSStateId)(-1)},
  [1668] = {(TSStateId)(-1)},
  [1669] = {(TSStateId)(-1)},
  [1670] = {(TSStateId)(-1)},
  [1671] = {(TSStateId)(-1)},
  [1672] = {(TSStateId)(-1)},
  [1673] = {(TSStateId)(-1)},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [sym_preproc_include] = STATE(0),
    [sym_preproc_tryinclude] = STATE(0),
    [sym_preproc_macro] = STATE(0),
    [sym_preproc_define] = STATE(0),
    [sym_preproc_undefine] = STATE(0),
    [sym_preproc_if] = STATE(0),
    [sym_preproc_elseif] = STATE(0),
    [sym_preproc_assert] = STATE(0),
    [sym_preproc_pragma] = STATE(0),
    [sym_preproc_error] = STATE(0),
    [sym_preproc_warning] = STATE(0),
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_GT_GT_GT] = ACTIONS(1),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [anon_sym_defined] = ACTIONS(1),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(1),
    [anon_sym_assert] = ACTIONS(1),
    [anon_sym_static_assert] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_forward] = ACTIONS(1),
    [anon_sym_native] = ACTIONS(1),
    [anon_sym_operator] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_public] = ACTIONS(1),
    [anon_sym_stock] = ACTIONS(1),
    [anon_sym_static] = ACTIONS(1),
    [anon_sym_new] = ACTIONS(1),
    [anon_sym_decl] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_TILDE_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_typedef] = ACTIONS(1),
    [anon_sym_typeset] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_funcenum] = ACTIONS(1),
    [anon_sym_functag] = ACTIONS(1),
    [anon_sym_methodmap] = ACTIONS(1),
    [anon_sym___nullable__] = ACTIONS(1),
    [anon_sym_property] = ACTIONS(1),
    [anon_sym_get] = ACTIONS(1),
    [anon_sym_set] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_void] = ACTIONS(1),
    [anon_sym_bool] = ACTIONS(1),
    [anon_sym_int] = ACTIONS(1),
    [anon_sym_float] = ACTIONS(1),
    [anon_sym_char] = ACTIONS(1),
    [anon_sym__] = ACTIONS(1),
    [anon_sym_Float] = ACTIONS(1),
    [anon_sym_String] = ACTIONS(1),
    [sym_any_type] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_COLON2] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_delete] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_sizeof] = ACTIONS(1),
    [anon_sym_view_as] = ACTIONS(1),
    [sym_int_literal] = ACTIONS(1),
    [sym_float_literal] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [sym_bool_literal] = ACTIONS(1),
    [sym_null] = ACTIONS(1),
    [sym_this] = ACTIONS(1),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(1),
    [sym__ternary_colon] = ACTIONS(1),
    [sym_preproc_arg] = ACTIONS(1),
  },
  [1] = {
    [sym_source_file] = STATE(1651),
    [sym_preproc_include] = STATE(1),
    [sym_preproc_tryinclude] = STATE(1),
    [sym_preproc_macro] = STATE(1),
    [sym_preproc_define] = STATE(1),
    [sym_preproc_undefine] = STATE(1),
    [sym_preproc_if] = STATE(1),
    [sym_preproc_elseif] = STATE(1),
    [sym_preproc_assert] = STATE(1),
    [sym_preproc_pragma] = STATE(1),
    [sym_preproc_error] = STATE(1),
    [sym_preproc_warning] = STATE(1),
    [sym_hardcoded_symbol] = STATE(653),
    [sym_assertion] = STATE(653),
    [sym_function_definition] = STATE(653),
    [sym_function_declaration] = STATE(653),
    [sym_function_declaration_kind] = STATE(991),
    [sym_alias_declaration] = STATE(653),
    [sym_alias_assignment] = STATE(653),
    [sym_global_variable_declaration] = STATE(653),
    [sym_variable_storage_class] = STATE(984),
    [sym_visibility] = STATE(979),
    [sym_old_global_variable_declaration] = STATE(653),
    [sym_old_variable_declaration] = STATE(1144),
    [sym_enum] = STATE(653),
    [sym_enum_struct] = STATE(653),
    [sym_typedef] = STATE(653),
    [sym_typeset] = STATE(653),
    [sym_funcenum] = STATE(653),
    [sym_functag] = STATE(653),
    [sym_methodmap] = STATE(653),
    [sym_struct] = STATE(653),
    [sym_struct_declaration] = STATE(653),
    [sym_type] = STATE(1149),
    [sym_old_type] = STATE(1386),
    [sym_builtin_type] = STATE(1269),
    [sym_old_builtin_type] = STATE(1579),
    [aux_sym_source_file_repeat1] = STATE(208),
    [ts_builtin_sym_end] = ACTIONS(27),
    [sym_identifier] = ACTIONS(29),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(31),
    [anon_sym_assert] = ACTIONS(33),
    [anon_sym_static_assert] = ACTIONS(33),
    [anon_sym_forward] = ACTIONS(35),
    [anon_sym_native] = ACTIONS(35),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(39),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_decl] = ACTIONS(45),
    [anon_sym_enum] = ACTIONS(47),
    [anon_sym_struct] = ACTIONS(49),
    [anon_sym_typedef] = ACTIONS(51),
    [anon_sym_typeset] = ACTIONS(53),
    [anon_sym_funcenum] = ACTIONS(55),
    [anon_sym_functag] = ACTIONS(57),
    [anon_sym_methodmap] = ACTIONS(59),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [sym_comment] = ACTIONS(19),
  },
  [2] = {
    [sym__preproc_expression] = STATE(938),
    [sym_preproc_parenthesized_expression] = STATE(929),
    [sym_preproc_unary_expression] = STATE(929),
    [sym_preproc_binary_expression] = STATE(929),
    [sym_preproc_include] = STATE(2),
    [sym_preproc_tryinclude] = STATE(2),
    [sym_preproc_macro] = STATE(2),
    [sym_preproc_define] = STATE(2),
    [sym_preproc_undefine] = STATE(2),
    [sym_preproc_if] = STATE(2),
    [sym_preproc_elseif] = STATE(2),
    [sym_preproc_assert] = STATE(2),
    [sym_preproc_defined_condition] = STATE(929),
    [sym_preproc_pragma] = STATE(2),
    [sym_preproc_error] = STATE(2),
    [sym_preproc_warning] = STATE(2),
    [sym_variable_declaration_statement] = STATE(483),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(483),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(483),
    [sym_for_statement] = STATE(483),
    [sym_while_statement] = STATE(483),
    [sym_do_while_statement] = STATE(483),
    [sym_break_statement] = STATE(483),
    [sym_continue_statement] = STATE(483),
    [sym_condition_statement] = STATE(483),
    [sym_switch_statement] = STATE(483),
    [sym_expression_statement] = STATE(483),
    [sym_return_statement] = STATE(483),
    [sym_delete_statement] = STATE(483),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(78),
    [sym_old_type_cast] = STATE(128),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(151),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [aux_sym_block_repeat1] = STATE(5),
    [sym_identifier] = ACTIONS(69),
    [anon_sym_LPAREN] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [anon_sym_defined] = ACTIONS(77),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_RBRACE] = ACTIONS(85),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [3] = {
    [sym__preproc_expression] = STATE(939),
    [sym_preproc_parenthesized_expression] = STATE(929),
    [sym_preproc_unary_expression] = STATE(929),
    [sym_preproc_binary_expression] = STATE(929),
    [sym_preproc_include] = STATE(3),
    [sym_preproc_tryinclude] = STATE(3),
    [sym_preproc_macro] = STATE(3),
    [sym_preproc_define] = STATE(3),
    [sym_preproc_undefine] = STATE(3),
    [sym_preproc_if] = STATE(3),
    [sym_preproc_elseif] = STATE(3),
    [sym_preproc_assert] = STATE(3),
    [sym_preproc_defined_condition] = STATE(929),
    [sym_preproc_pragma] = STATE(3),
    [sym_preproc_error] = STATE(3),
    [sym_preproc_warning] = STATE(3),
    [sym_variable_declaration_statement] = STATE(483),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(483),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(483),
    [sym_for_statement] = STATE(483),
    [sym_while_statement] = STATE(483),
    [sym_do_while_statement] = STATE(483),
    [sym_break_statement] = STATE(483),
    [sym_continue_statement] = STATE(483),
    [sym_condition_statement] = STATE(483),
    [sym_switch_statement] = STATE(483),
    [sym_expression_statement] = STATE(483),
    [sym_return_statement] = STATE(483),
    [sym_delete_statement] = STATE(483),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(79),
    [sym_old_type_cast] = STATE(149),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(151),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [aux_sym_block_repeat1] = STATE(10),
    [sym_identifier] = ACTIONS(69),
    [anon_sym_LPAREN] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [anon_sym_defined] = ACTIONS(77),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_RBRACE] = ACTIONS(121),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [4] = {
    [sym_preproc_include] = STATE(4),
    [sym_preproc_tryinclude] = STATE(4),
    [sym_preproc_macro] = STATE(4),
    [sym_preproc_define] = STATE(4),
    [sym_preproc_undefine] = STATE(4),
    [sym_preproc_if] = STATE(4),
    [sym_preproc_elseif] = STATE(4),
    [sym_preproc_assert] = STATE(4),
    [sym_preproc_pragma] = STATE(4),
    [sym_preproc_error] = STATE(4),
    [sym_preproc_warning] = STATE(4),
    [sym_dimension] = STATE(106),
    [sym_call_arguments] = STATE(117),
    [aux_sym_function_definition_repeat1] = STATE(100),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_LPAREN] = ACTIONS(125),
    [anon_sym_BANG] = ACTIONS(123),
    [anon_sym_TILDE] = ACTIONS(123),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_const] = ACTIONS(123),
    [anon_sym_public] = ACTIONS(123),
    [anon_sym_stock] = ACTIONS(123),
    [anon_sym_static] = ACTIONS(123),
    [anon_sym_new] = ACTIONS(123),
    [anon_sym_decl] = ACTIONS(123),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_void] = ACTIONS(123),
    [anon_sym_bool] = ACTIONS(123),
    [anon_sym_int] = ACTIONS(123),
    [anon_sym_float] = ACTIONS(123),
    [anon_sym_char] = ACTIONS(123),
    [anon_sym__] = ACTIONS(123),
    [anon_sym_Float] = ACTIONS(123),
    [anon_sym_String] = ACTIONS(123),
    [sym_any_type] = ACTIONS(123),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_while] = ACTIONS(123),
    [anon_sym_do] = ACTIONS(123),
    [anon_sym_break] = ACTIONS(123),
    [anon_sym_continue] = ACTIONS(123),
    [anon_sym_if] = ACTIONS(123),
    [anon_sym_else] = ACTIONS(123),
    [anon_sym_switch] = ACTIONS(123),
    [anon_sym_return] = ACTIONS(123),
    [anon_sym_delete] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_COLON_COLON] = ACTIONS(137),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(123),
    [anon_sym_view_as] = ACTIONS(123),
    [sym_int_literal] = ACTIONS(123),
    [sym_float_literal] = ACTIONS(127),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DQUOTE] = ACTIONS(127),
    [sym_bool_literal] = ACTIONS(123),
    [sym_null] = ACTIONS(123),
    [sym_this] = ACTIONS(123),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(127),
  },
  [5] = {
    [sym_preproc_include] = STATE(5),
    [sym_preproc_tryinclude] = STATE(5),
    [sym_preproc_macro] = STATE(5),
    [sym_preproc_define] = STATE(5),
    [sym_preproc_undefine] = STATE(5),
    [sym_preproc_if] = STATE(5),
    [sym_preproc_elseif] = STATE(5),
    [sym_preproc_assert] = STATE(5),
    [sym_preproc_pragma] = STATE(5),
    [sym_preproc_error] = STATE(5),
    [sym_preproc_warning] = STATE(5),
    [sym_variable_declaration_statement] = STATE(483),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(483),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(483),
    [sym_for_statement] = STATE(483),
    [sym_while_statement] = STATE(483),
    [sym_do_while_statement] = STATE(483),
    [sym_break_statement] = STATE(483),
    [sym_continue_statement] = STATE(483),
    [sym_condition_statement] = STATE(483),
    [sym_switch_statement] = STATE(483),
    [sym_expression_statement] = STATE(483),
    [sym_return_statement] = STATE(483),
    [sym_delete_statement] = STATE(483),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [aux_sym_block_repeat1] = STATE(6),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_RBRACE] = ACTIONS(147),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [6] = {
    [sym_preproc_include] = STATE(6),
    [sym_preproc_tryinclude] = STATE(6),
    [sym_preproc_macro] = STATE(6),
    [sym_preproc_define] = STATE(6),
    [sym_preproc_undefine] = STATE(6),
    [sym_preproc_if] = STATE(6),
    [sym_preproc_elseif] = STATE(6),
    [sym_preproc_assert] = STATE(6),
    [sym_preproc_pragma] = STATE(6),
    [sym_preproc_error] = STATE(6),
    [sym_preproc_warning] = STATE(6),
    [sym_variable_declaration_statement] = STATE(483),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(483),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(483),
    [sym_for_statement] = STATE(483),
    [sym_while_statement] = STATE(483),
    [sym_do_while_statement] = STATE(483),
    [sym_break_statement] = STATE(483),
    [sym_continue_statement] = STATE(483),
    [sym_condition_statement] = STATE(483),
    [sym_switch_statement] = STATE(483),
    [sym_expression_statement] = STATE(483),
    [sym_return_statement] = STATE(483),
    [sym_delete_statement] = STATE(483),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [aux_sym_block_repeat1] = STATE(6),
    [sym_identifier] = ACTIONS(149),
    [anon_sym_LPAREN] = ACTIONS(152),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(155),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(161),
    [anon_sym_public] = ACTIONS(164),
    [anon_sym_stock] = ACTIONS(164),
    [anon_sym_static] = ACTIONS(167),
    [anon_sym_new] = ACTIONS(170),
    [anon_sym_decl] = ACTIONS(173),
    [anon_sym_LBRACE] = ACTIONS(176),
    [anon_sym_RBRACE] = ACTIONS(179),
    [anon_sym_void] = ACTIONS(181),
    [anon_sym_bool] = ACTIONS(184),
    [anon_sym_int] = ACTIONS(181),
    [anon_sym_float] = ACTIONS(181),
    [anon_sym_char] = ACTIONS(181),
    [anon_sym__] = ACTIONS(187),
    [anon_sym_Float] = ACTIONS(187),
    [anon_sym_String] = ACTIONS(187),
    [sym_any_type] = ACTIONS(190),
    [anon_sym_for] = ACTIONS(193),
    [anon_sym_while] = ACTIONS(196),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_break] = ACTIONS(202),
    [anon_sym_continue] = ACTIONS(205),
    [anon_sym_if] = ACTIONS(208),
    [anon_sym_switch] = ACTIONS(211),
    [anon_sym_return] = ACTIONS(214),
    [anon_sym_delete] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(220),
    [anon_sym_PLUS_PLUS] = ACTIONS(220),
    [anon_sym_sizeof] = ACTIONS(223),
    [anon_sym_view_as] = ACTIONS(226),
    [sym_int_literal] = ACTIONS(229),
    [sym_float_literal] = ACTIONS(232),
    [anon_sym_SQUOTE] = ACTIONS(235),
    [anon_sym_DQUOTE] = ACTIONS(238),
    [sym_bool_literal] = ACTIONS(229),
    [sym_null] = ACTIONS(229),
    [sym_this] = ACTIONS(241),
    [sym_comment] = ACTIONS(19),
  },
  [7] = {
    [sym_preproc_include] = STATE(7),
    [sym_preproc_tryinclude] = STATE(7),
    [sym_preproc_macro] = STATE(7),
    [sym_preproc_define] = STATE(7),
    [sym_preproc_undefine] = STATE(7),
    [sym_preproc_if] = STATE(7),
    [sym_preproc_elseif] = STATE(7),
    [sym_preproc_assert] = STATE(7),
    [sym_preproc_pragma] = STATE(7),
    [sym_preproc_error] = STATE(7),
    [sym_preproc_warning] = STATE(7),
    [sym_variable_declaration_statement] = STATE(483),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(483),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(483),
    [sym_for_statement] = STATE(483),
    [sym_while_statement] = STATE(483),
    [sym_do_while_statement] = STATE(483),
    [sym_break_statement] = STATE(483),
    [sym_continue_statement] = STATE(483),
    [sym_condition_statement] = STATE(483),
    [sym_switch_statement] = STATE(483),
    [sym_expression_statement] = STATE(483),
    [sym_return_statement] = STATE(483),
    [sym_delete_statement] = STATE(483),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [aux_sym_block_repeat1] = STATE(10),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_RBRACE] = ACTIONS(121),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [8] = {
    [sym_preproc_include] = STATE(8),
    [sym_preproc_tryinclude] = STATE(8),
    [sym_preproc_macro] = STATE(8),
    [sym_preproc_define] = STATE(8),
    [sym_preproc_undefine] = STATE(8),
    [sym_preproc_if] = STATE(8),
    [sym_preproc_elseif] = STATE(8),
    [sym_preproc_assert] = STATE(8),
    [sym_preproc_pragma] = STATE(8),
    [sym_preproc_error] = STATE(8),
    [sym_preproc_warning] = STATE(8),
    [sym_variable_declaration_statement] = STATE(483),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(483),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(483),
    [sym_for_statement] = STATE(483),
    [sym_while_statement] = STATE(483),
    [sym_do_while_statement] = STATE(483),
    [sym_break_statement] = STATE(483),
    [sym_continue_statement] = STATE(483),
    [sym_condition_statement] = STATE(483),
    [sym_switch_statement] = STATE(483),
    [sym_expression_statement] = STATE(483),
    [sym_return_statement] = STATE(483),
    [sym_delete_statement] = STATE(483),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [aux_sym_block_repeat1] = STATE(5),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_RBRACE] = ACTIONS(85),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [9] = {
    [sym_preproc_include] = STATE(9),
    [sym_preproc_tryinclude] = STATE(9),
    [sym_preproc_macro] = STATE(9),
    [sym_preproc_define] = STATE(9),
    [sym_preproc_undefine] = STATE(9),
    [sym_preproc_if] = STATE(9),
    [sym_preproc_elseif] = STATE(9),
    [sym_preproc_assert] = STATE(9),
    [sym_preproc_pragma] = STATE(9),
    [sym_preproc_error] = STATE(9),
    [sym_preproc_warning] = STATE(9),
    [sym_call_arguments] = STATE(117),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(125),
    [anon_sym_BANG] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(248),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(250),
    [anon_sym_DASH_EQ] = ACTIONS(250),
    [anon_sym_STAR_EQ] = ACTIONS(250),
    [anon_sym_SLASH_EQ] = ACTIONS(250),
    [anon_sym_PIPE_EQ] = ACTIONS(250),
    [anon_sym_AMP_EQ] = ACTIONS(250),
    [anon_sym_CARET_EQ] = ACTIONS(250),
    [anon_sym_TILDE_EQ] = ACTIONS(250),
    [anon_sym_LT_LT_EQ] = ACTIONS(250),
    [anon_sym_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_LBRACK] = ACTIONS(252),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_do] = ACTIONS(244),
    [anon_sym_break] = ACTIONS(244),
    [anon_sym_continue] = ACTIONS(244),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_else] = ACTIONS(244),
    [anon_sym_switch] = ACTIONS(244),
    [anon_sym_return] = ACTIONS(244),
    [anon_sym_delete] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_PERCENT_EQ] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_COLON_COLON] = ACTIONS(137),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [anon_sym_sizeof] = ACTIONS(244),
    [anon_sym_view_as] = ACTIONS(244),
    [sym_int_literal] = ACTIONS(244),
    [sym_float_literal] = ACTIONS(246),
    [anon_sym_SQUOTE] = ACTIONS(246),
    [anon_sym_DQUOTE] = ACTIONS(246),
    [sym_bool_literal] = ACTIONS(244),
    [sym_null] = ACTIONS(244),
    [sym_this] = ACTIONS(244),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [10] = {
    [sym_preproc_include] = STATE(10),
    [sym_preproc_tryinclude] = STATE(10),
    [sym_preproc_macro] = STATE(10),
    [sym_preproc_define] = STATE(10),
    [sym_preproc_undefine] = STATE(10),
    [sym_preproc_if] = STATE(10),
    [sym_preproc_elseif] = STATE(10),
    [sym_preproc_assert] = STATE(10),
    [sym_preproc_pragma] = STATE(10),
    [sym_preproc_error] = STATE(10),
    [sym_preproc_warning] = STATE(10),
    [sym_variable_declaration_statement] = STATE(483),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(483),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(483),
    [sym_for_statement] = STATE(483),
    [sym_while_statement] = STATE(483),
    [sym_do_while_statement] = STATE(483),
    [sym_break_statement] = STATE(483),
    [sym_continue_statement] = STATE(483),
    [sym_condition_statement] = STATE(483),
    [sym_switch_statement] = STATE(483),
    [sym_expression_statement] = STATE(483),
    [sym_return_statement] = STATE(483),
    [sym_delete_statement] = STATE(483),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [aux_sym_block_repeat1] = STATE(6),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_RBRACE] = ACTIONS(254),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [11] = {
    [sym_preproc_include] = STATE(11),
    [sym_preproc_tryinclude] = STATE(11),
    [sym_preproc_macro] = STATE(11),
    [sym_preproc_define] = STATE(11),
    [sym_preproc_undefine] = STATE(11),
    [sym_preproc_if] = STATE(11),
    [sym_preproc_elseif] = STATE(11),
    [sym_preproc_assert] = STATE(11),
    [sym_preproc_pragma] = STATE(11),
    [sym_preproc_error] = STATE(11),
    [sym_preproc_warning] = STATE(11),
    [sym_call_arguments] = STATE(117),
    [sym_identifier] = ACTIONS(256),
    [anon_sym_LPAREN] = ACTIONS(125),
    [anon_sym_BANG] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(248),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(250),
    [anon_sym_DASH_EQ] = ACTIONS(250),
    [anon_sym_STAR_EQ] = ACTIONS(250),
    [anon_sym_SLASH_EQ] = ACTIONS(250),
    [anon_sym_PIPE_EQ] = ACTIONS(250),
    [anon_sym_AMP_EQ] = ACTIONS(250),
    [anon_sym_CARET_EQ] = ACTIONS(250),
    [anon_sym_TILDE_EQ] = ACTIONS(250),
    [anon_sym_LT_LT_EQ] = ACTIONS(250),
    [anon_sym_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_LBRACK] = ACTIONS(258),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_do] = ACTIONS(244),
    [anon_sym_break] = ACTIONS(244),
    [anon_sym_continue] = ACTIONS(244),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_else] = ACTIONS(244),
    [anon_sym_switch] = ACTIONS(244),
    [anon_sym_return] = ACTIONS(244),
    [anon_sym_delete] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_PERCENT_EQ] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_COLON_COLON] = ACTIONS(137),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [anon_sym_sizeof] = ACTIONS(244),
    [anon_sym_view_as] = ACTIONS(244),
    [sym_int_literal] = ACTIONS(244),
    [sym_float_literal] = ACTIONS(246),
    [anon_sym_SQUOTE] = ACTIONS(246),
    [anon_sym_DQUOTE] = ACTIONS(246),
    [sym_bool_literal] = ACTIONS(244),
    [sym_null] = ACTIONS(244),
    [sym_this] = ACTIONS(244),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [12] = {
    [sym_preproc_include] = STATE(12),
    [sym_preproc_tryinclude] = STATE(12),
    [sym_preproc_macro] = STATE(12),
    [sym_preproc_define] = STATE(12),
    [sym_preproc_undefine] = STATE(12),
    [sym_preproc_if] = STATE(12),
    [sym_preproc_elseif] = STATE(12),
    [sym_preproc_assert] = STATE(12),
    [sym_preproc_pragma] = STATE(12),
    [sym_preproc_error] = STATE(12),
    [sym_preproc_warning] = STATE(12),
    [sym_dimension] = STATE(106),
    [aux_sym_function_definition_repeat1] = STATE(99),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_BANG] = ACTIONS(123),
    [anon_sym_TILDE] = ACTIONS(123),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_const] = ACTIONS(123),
    [anon_sym_public] = ACTIONS(123),
    [anon_sym_stock] = ACTIONS(123),
    [anon_sym_static] = ACTIONS(123),
    [anon_sym_new] = ACTIONS(123),
    [anon_sym_decl] = ACTIONS(123),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_void] = ACTIONS(123),
    [anon_sym_bool] = ACTIONS(123),
    [anon_sym_int] = ACTIONS(123),
    [anon_sym_float] = ACTIONS(123),
    [anon_sym_char] = ACTIONS(123),
    [anon_sym__] = ACTIONS(123),
    [anon_sym_Float] = ACTIONS(123),
    [anon_sym_String] = ACTIONS(123),
    [sym_any_type] = ACTIONS(123),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_while] = ACTIONS(123),
    [anon_sym_do] = ACTIONS(123),
    [anon_sym_break] = ACTIONS(123),
    [anon_sym_continue] = ACTIONS(123),
    [anon_sym_if] = ACTIONS(123),
    [anon_sym_else] = ACTIONS(123),
    [anon_sym_switch] = ACTIONS(123),
    [anon_sym_return] = ACTIONS(123),
    [anon_sym_delete] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(123),
    [anon_sym_view_as] = ACTIONS(123),
    [sym_int_literal] = ACTIONS(123),
    [sym_float_literal] = ACTIONS(127),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DQUOTE] = ACTIONS(127),
    [sym_bool_literal] = ACTIONS(123),
    [sym_null] = ACTIONS(123),
    [sym_this] = ACTIONS(123),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(127),
  },
  [13] = {
    [sym_preproc_include] = STATE(13),
    [sym_preproc_tryinclude] = STATE(13),
    [sym_preproc_macro] = STATE(13),
    [sym_preproc_define] = STATE(13),
    [sym_preproc_undefine] = STATE(13),
    [sym_preproc_if] = STATE(13),
    [sym_preproc_elseif] = STATE(13),
    [sym_preproc_assert] = STATE(13),
    [sym_preproc_pragma] = STATE(13),
    [sym_preproc_error] = STATE(13),
    [sym_preproc_warning] = STATE(13),
    [sym_call_arguments] = STATE(117),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(125),
    [anon_sym_BANG] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_PLUS] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(261),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(261),
    [anon_sym_SLASH] = ACTIONS(261),
    [anon_sym_PERCENT] = ACTIONS(261),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_CARET] = ACTIONS(261),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_GT] = ACTIONS(261),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(261),
    [anon_sym_LT_LT] = ACTIONS(261),
    [anon_sym_GT_GT] = ACTIONS(261),
    [anon_sym_GT_GT_GT] = ACTIONS(261),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(248),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(250),
    [anon_sym_DASH_EQ] = ACTIONS(250),
    [anon_sym_STAR_EQ] = ACTIONS(250),
    [anon_sym_SLASH_EQ] = ACTIONS(250),
    [anon_sym_PIPE_EQ] = ACTIONS(250),
    [anon_sym_AMP_EQ] = ACTIONS(250),
    [anon_sym_CARET_EQ] = ACTIONS(250),
    [anon_sym_TILDE_EQ] = ACTIONS(250),
    [anon_sym_LT_LT_EQ] = ACTIONS(250),
    [anon_sym_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_RBRACE] = ACTIONS(264),
    [anon_sym_LBRACK] = ACTIONS(252),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_do] = ACTIONS(244),
    [anon_sym_break] = ACTIONS(244),
    [anon_sym_continue] = ACTIONS(244),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_switch] = ACTIONS(244),
    [anon_sym_return] = ACTIONS(244),
    [anon_sym_delete] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_PERCENT_EQ] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_COLON_COLON] = ACTIONS(137),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [anon_sym_sizeof] = ACTIONS(244),
    [anon_sym_view_as] = ACTIONS(244),
    [sym_int_literal] = ACTIONS(244),
    [sym_float_literal] = ACTIONS(246),
    [anon_sym_SQUOTE] = ACTIONS(246),
    [anon_sym_DQUOTE] = ACTIONS(246),
    [sym_bool_literal] = ACTIONS(244),
    [sym_null] = ACTIONS(244),
    [sym_this] = ACTIONS(244),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [14] = {
    [sym_preproc_include] = STATE(14),
    [sym_preproc_tryinclude] = STATE(14),
    [sym_preproc_macro] = STATE(14),
    [sym_preproc_define] = STATE(14),
    [sym_preproc_undefine] = STATE(14),
    [sym_preproc_if] = STATE(14),
    [sym_preproc_elseif] = STATE(14),
    [sym_preproc_assert] = STATE(14),
    [sym_preproc_pragma] = STATE(14),
    [sym_preproc_error] = STATE(14),
    [sym_preproc_warning] = STATE(14),
    [sym_call_arguments] = STATE(117),
    [sym_identifier] = ACTIONS(256),
    [anon_sym_LPAREN] = ACTIONS(125),
    [anon_sym_BANG] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_PLUS] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(261),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(261),
    [anon_sym_SLASH] = ACTIONS(261),
    [anon_sym_PERCENT] = ACTIONS(261),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_CARET] = ACTIONS(261),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_GT] = ACTIONS(261),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(261),
    [anon_sym_LT_LT] = ACTIONS(261),
    [anon_sym_GT_GT] = ACTIONS(261),
    [anon_sym_GT_GT_GT] = ACTIONS(261),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(248),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(250),
    [anon_sym_DASH_EQ] = ACTIONS(250),
    [anon_sym_STAR_EQ] = ACTIONS(250),
    [anon_sym_SLASH_EQ] = ACTIONS(250),
    [anon_sym_PIPE_EQ] = ACTIONS(250),
    [anon_sym_AMP_EQ] = ACTIONS(250),
    [anon_sym_CARET_EQ] = ACTIONS(250),
    [anon_sym_TILDE_EQ] = ACTIONS(250),
    [anon_sym_LT_LT_EQ] = ACTIONS(250),
    [anon_sym_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_RBRACE] = ACTIONS(264),
    [anon_sym_LBRACK] = ACTIONS(258),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_do] = ACTIONS(244),
    [anon_sym_break] = ACTIONS(244),
    [anon_sym_continue] = ACTIONS(244),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_switch] = ACTIONS(244),
    [anon_sym_return] = ACTIONS(244),
    [anon_sym_delete] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_PERCENT_EQ] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_COLON_COLON] = ACTIONS(137),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [anon_sym_sizeof] = ACTIONS(244),
    [anon_sym_view_as] = ACTIONS(244),
    [sym_int_literal] = ACTIONS(244),
    [sym_float_literal] = ACTIONS(246),
    [anon_sym_SQUOTE] = ACTIONS(246),
    [anon_sym_DQUOTE] = ACTIONS(246),
    [sym_bool_literal] = ACTIONS(244),
    [sym_null] = ACTIONS(244),
    [sym_this] = ACTIONS(244),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [15] = {
    [sym_preproc_include] = STATE(15),
    [sym_preproc_tryinclude] = STATE(15),
    [sym_preproc_macro] = STATE(15),
    [sym_preproc_define] = STATE(15),
    [sym_preproc_undefine] = STATE(15),
    [sym_preproc_if] = STATE(15),
    [sym_preproc_elseif] = STATE(15),
    [sym_preproc_assert] = STATE(15),
    [sym_preproc_pragma] = STATE(15),
    [sym_preproc_error] = STATE(15),
    [sym_preproc_warning] = STATE(15),
    [sym_variable_declaration_statement] = STATE(651),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(651),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(651),
    [sym_for_statement] = STATE(651),
    [sym_while_statement] = STATE(651),
    [sym_do_while_statement] = STATE(651),
    [sym_break_statement] = STATE(651),
    [sym_continue_statement] = STATE(651),
    [sym_condition_statement] = STATE(651),
    [sym_switch_statement] = STATE(651),
    [sym_expression_statement] = STATE(651),
    [sym_return_statement] = STATE(651),
    [sym_delete_statement] = STATE(651),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [16] = {
    [sym_preproc_include] = STATE(16),
    [sym_preproc_tryinclude] = STATE(16),
    [sym_preproc_macro] = STATE(16),
    [sym_preproc_define] = STATE(16),
    [sym_preproc_undefine] = STATE(16),
    [sym_preproc_if] = STATE(16),
    [sym_preproc_elseif] = STATE(16),
    [sym_preproc_assert] = STATE(16),
    [sym_preproc_pragma] = STATE(16),
    [sym_preproc_error] = STATE(16),
    [sym_preproc_warning] = STATE(16),
    [sym_variable_declaration_statement] = STATE(557),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(557),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(557),
    [sym_for_statement] = STATE(557),
    [sym_while_statement] = STATE(557),
    [sym_do_while_statement] = STATE(557),
    [sym_break_statement] = STATE(557),
    [sym_continue_statement] = STATE(557),
    [sym_condition_statement] = STATE(557),
    [sym_switch_statement] = STATE(557),
    [sym_expression_statement] = STATE(557),
    [sym_return_statement] = STATE(557),
    [sym_delete_statement] = STATE(557),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [17] = {
    [sym_preproc_include] = STATE(17),
    [sym_preproc_tryinclude] = STATE(17),
    [sym_preproc_macro] = STATE(17),
    [sym_preproc_define] = STATE(17),
    [sym_preproc_undefine] = STATE(17),
    [sym_preproc_if] = STATE(17),
    [sym_preproc_elseif] = STATE(17),
    [sym_preproc_assert] = STATE(17),
    [sym_preproc_pragma] = STATE(17),
    [sym_preproc_error] = STATE(17),
    [sym_preproc_warning] = STATE(17),
    [sym_variable_declaration_statement] = STATE(559),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(559),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(559),
    [sym_for_statement] = STATE(559),
    [sym_while_statement] = STATE(559),
    [sym_do_while_statement] = STATE(559),
    [sym_break_statement] = STATE(559),
    [sym_continue_statement] = STATE(559),
    [sym_condition_statement] = STATE(559),
    [sym_switch_statement] = STATE(559),
    [sym_expression_statement] = STATE(559),
    [sym_return_statement] = STATE(559),
    [sym_delete_statement] = STATE(559),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [18] = {
    [sym_preproc_include] = STATE(18),
    [sym_preproc_tryinclude] = STATE(18),
    [sym_preproc_macro] = STATE(18),
    [sym_preproc_define] = STATE(18),
    [sym_preproc_undefine] = STATE(18),
    [sym_preproc_if] = STATE(18),
    [sym_preproc_elseif] = STATE(18),
    [sym_preproc_assert] = STATE(18),
    [sym_preproc_pragma] = STATE(18),
    [sym_preproc_error] = STATE(18),
    [sym_preproc_warning] = STATE(18),
    [sym_variable_declaration_statement] = STATE(560),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(560),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(560),
    [sym_for_statement] = STATE(560),
    [sym_while_statement] = STATE(560),
    [sym_do_while_statement] = STATE(560),
    [sym_break_statement] = STATE(560),
    [sym_continue_statement] = STATE(560),
    [sym_condition_statement] = STATE(560),
    [sym_switch_statement] = STATE(560),
    [sym_expression_statement] = STATE(560),
    [sym_return_statement] = STATE(560),
    [sym_delete_statement] = STATE(560),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [19] = {
    [sym_preproc_include] = STATE(19),
    [sym_preproc_tryinclude] = STATE(19),
    [sym_preproc_macro] = STATE(19),
    [sym_preproc_define] = STATE(19),
    [sym_preproc_undefine] = STATE(19),
    [sym_preproc_if] = STATE(19),
    [sym_preproc_elseif] = STATE(19),
    [sym_preproc_assert] = STATE(19),
    [sym_preproc_pragma] = STATE(19),
    [sym_preproc_error] = STATE(19),
    [sym_preproc_warning] = STATE(19),
    [sym_variable_declaration_statement] = STATE(635),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(635),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(635),
    [sym_for_statement] = STATE(635),
    [sym_while_statement] = STATE(635),
    [sym_do_while_statement] = STATE(635),
    [sym_break_statement] = STATE(635),
    [sym_continue_statement] = STATE(635),
    [sym_condition_statement] = STATE(635),
    [sym_switch_statement] = STATE(635),
    [sym_expression_statement] = STATE(635),
    [sym_return_statement] = STATE(635),
    [sym_delete_statement] = STATE(635),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [20] = {
    [sym_preproc_include] = STATE(20),
    [sym_preproc_tryinclude] = STATE(20),
    [sym_preproc_macro] = STATE(20),
    [sym_preproc_define] = STATE(20),
    [sym_preproc_undefine] = STATE(20),
    [sym_preproc_if] = STATE(20),
    [sym_preproc_elseif] = STATE(20),
    [sym_preproc_assert] = STATE(20),
    [sym_preproc_pragma] = STATE(20),
    [sym_preproc_error] = STATE(20),
    [sym_preproc_warning] = STATE(20),
    [sym_variable_declaration_statement] = STATE(563),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(563),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(563),
    [sym_for_statement] = STATE(563),
    [sym_while_statement] = STATE(563),
    [sym_do_while_statement] = STATE(563),
    [sym_break_statement] = STATE(563),
    [sym_continue_statement] = STATE(563),
    [sym_condition_statement] = STATE(563),
    [sym_switch_statement] = STATE(563),
    [sym_expression_statement] = STATE(563),
    [sym_return_statement] = STATE(563),
    [sym_delete_statement] = STATE(563),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [21] = {
    [sym_preproc_include] = STATE(21),
    [sym_preproc_tryinclude] = STATE(21),
    [sym_preproc_macro] = STATE(21),
    [sym_preproc_define] = STATE(21),
    [sym_preproc_undefine] = STATE(21),
    [sym_preproc_if] = STATE(21),
    [sym_preproc_elseif] = STATE(21),
    [sym_preproc_assert] = STATE(21),
    [sym_preproc_pragma] = STATE(21),
    [sym_preproc_error] = STATE(21),
    [sym_preproc_warning] = STATE(21),
    [sym_variable_declaration_statement] = STATE(565),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(565),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(565),
    [sym_for_statement] = STATE(565),
    [sym_while_statement] = STATE(565),
    [sym_do_while_statement] = STATE(565),
    [sym_break_statement] = STATE(565),
    [sym_continue_statement] = STATE(565),
    [sym_condition_statement] = STATE(565),
    [sym_switch_statement] = STATE(565),
    [sym_expression_statement] = STATE(565),
    [sym_return_statement] = STATE(565),
    [sym_delete_statement] = STATE(565),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [22] = {
    [sym_preproc_include] = STATE(22),
    [sym_preproc_tryinclude] = STATE(22),
    [sym_preproc_macro] = STATE(22),
    [sym_preproc_define] = STATE(22),
    [sym_preproc_undefine] = STATE(22),
    [sym_preproc_if] = STATE(22),
    [sym_preproc_elseif] = STATE(22),
    [sym_preproc_assert] = STATE(22),
    [sym_preproc_pragma] = STATE(22),
    [sym_preproc_error] = STATE(22),
    [sym_preproc_warning] = STATE(22),
    [sym_variable_declaration_statement] = STATE(566),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(566),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(566),
    [sym_for_statement] = STATE(566),
    [sym_while_statement] = STATE(566),
    [sym_do_while_statement] = STATE(566),
    [sym_break_statement] = STATE(566),
    [sym_continue_statement] = STATE(566),
    [sym_condition_statement] = STATE(566),
    [sym_switch_statement] = STATE(566),
    [sym_expression_statement] = STATE(566),
    [sym_return_statement] = STATE(566),
    [sym_delete_statement] = STATE(566),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [23] = {
    [sym_preproc_include] = STATE(23),
    [sym_preproc_tryinclude] = STATE(23),
    [sym_preproc_macro] = STATE(23),
    [sym_preproc_define] = STATE(23),
    [sym_preproc_undefine] = STATE(23),
    [sym_preproc_if] = STATE(23),
    [sym_preproc_elseif] = STATE(23),
    [sym_preproc_assert] = STATE(23),
    [sym_preproc_pragma] = STATE(23),
    [sym_preproc_error] = STATE(23),
    [sym_preproc_warning] = STATE(23),
    [sym_variable_declaration_statement] = STATE(567),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(567),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(567),
    [sym_for_statement] = STATE(567),
    [sym_while_statement] = STATE(567),
    [sym_do_while_statement] = STATE(567),
    [sym_break_statement] = STATE(567),
    [sym_continue_statement] = STATE(567),
    [sym_condition_statement] = STATE(567),
    [sym_switch_statement] = STATE(567),
    [sym_expression_statement] = STATE(567),
    [sym_return_statement] = STATE(567),
    [sym_delete_statement] = STATE(567),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [24] = {
    [sym_preproc_include] = STATE(24),
    [sym_preproc_tryinclude] = STATE(24),
    [sym_preproc_macro] = STATE(24),
    [sym_preproc_define] = STATE(24),
    [sym_preproc_undefine] = STATE(24),
    [sym_preproc_if] = STATE(24),
    [sym_preproc_elseif] = STATE(24),
    [sym_preproc_assert] = STATE(24),
    [sym_preproc_pragma] = STATE(24),
    [sym_preproc_error] = STATE(24),
    [sym_preproc_warning] = STATE(24),
    [sym_variable_declaration_statement] = STATE(568),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(568),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(568),
    [sym_for_statement] = STATE(568),
    [sym_while_statement] = STATE(568),
    [sym_do_while_statement] = STATE(568),
    [sym_break_statement] = STATE(568),
    [sym_continue_statement] = STATE(568),
    [sym_condition_statement] = STATE(568),
    [sym_switch_statement] = STATE(568),
    [sym_expression_statement] = STATE(568),
    [sym_return_statement] = STATE(568),
    [sym_delete_statement] = STATE(568),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [25] = {
    [sym_preproc_include] = STATE(25),
    [sym_preproc_tryinclude] = STATE(25),
    [sym_preproc_macro] = STATE(25),
    [sym_preproc_define] = STATE(25),
    [sym_preproc_undefine] = STATE(25),
    [sym_preproc_if] = STATE(25),
    [sym_preproc_elseif] = STATE(25),
    [sym_preproc_assert] = STATE(25),
    [sym_preproc_pragma] = STATE(25),
    [sym_preproc_error] = STATE(25),
    [sym_preproc_warning] = STATE(25),
    [sym_variable_declaration_statement] = STATE(1257),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(1257),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(1257),
    [sym_for_statement] = STATE(1257),
    [sym_while_statement] = STATE(1257),
    [sym_do_while_statement] = STATE(1257),
    [sym_break_statement] = STATE(1257),
    [sym_continue_statement] = STATE(1257),
    [sym_condition_statement] = STATE(1257),
    [sym_switch_statement] = STATE(1257),
    [sym_expression_statement] = STATE(1257),
    [sym_return_statement] = STATE(1257),
    [sym_delete_statement] = STATE(1257),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [26] = {
    [sym_preproc_include] = STATE(26),
    [sym_preproc_tryinclude] = STATE(26),
    [sym_preproc_macro] = STATE(26),
    [sym_preproc_define] = STATE(26),
    [sym_preproc_undefine] = STATE(26),
    [sym_preproc_if] = STATE(26),
    [sym_preproc_elseif] = STATE(26),
    [sym_preproc_assert] = STATE(26),
    [sym_preproc_pragma] = STATE(26),
    [sym_preproc_error] = STATE(26),
    [sym_preproc_warning] = STATE(26),
    [sym_variable_declaration_statement] = STATE(569),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(569),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(569),
    [sym_for_statement] = STATE(569),
    [sym_while_statement] = STATE(569),
    [sym_do_while_statement] = STATE(569),
    [sym_break_statement] = STATE(569),
    [sym_continue_statement] = STATE(569),
    [sym_condition_statement] = STATE(569),
    [sym_switch_statement] = STATE(569),
    [sym_expression_statement] = STATE(569),
    [sym_return_statement] = STATE(569),
    [sym_delete_statement] = STATE(569),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [27] = {
    [sym_preproc_include] = STATE(27),
    [sym_preproc_tryinclude] = STATE(27),
    [sym_preproc_macro] = STATE(27),
    [sym_preproc_define] = STATE(27),
    [sym_preproc_undefine] = STATE(27),
    [sym_preproc_if] = STATE(27),
    [sym_preproc_elseif] = STATE(27),
    [sym_preproc_assert] = STATE(27),
    [sym_preproc_pragma] = STATE(27),
    [sym_preproc_error] = STATE(27),
    [sym_preproc_warning] = STATE(27),
    [sym_variable_declaration_statement] = STATE(570),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(570),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(570),
    [sym_for_statement] = STATE(570),
    [sym_while_statement] = STATE(570),
    [sym_do_while_statement] = STATE(570),
    [sym_break_statement] = STATE(570),
    [sym_continue_statement] = STATE(570),
    [sym_condition_statement] = STATE(570),
    [sym_switch_statement] = STATE(570),
    [sym_expression_statement] = STATE(570),
    [sym_return_statement] = STATE(570),
    [sym_delete_statement] = STATE(570),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [28] = {
    [sym_preproc_include] = STATE(28),
    [sym_preproc_tryinclude] = STATE(28),
    [sym_preproc_macro] = STATE(28),
    [sym_preproc_define] = STATE(28),
    [sym_preproc_undefine] = STATE(28),
    [sym_preproc_if] = STATE(28),
    [sym_preproc_elseif] = STATE(28),
    [sym_preproc_assert] = STATE(28),
    [sym_preproc_pragma] = STATE(28),
    [sym_preproc_error] = STATE(28),
    [sym_preproc_warning] = STATE(28),
    [sym_variable_declaration_statement] = STATE(571),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(571),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(571),
    [sym_for_statement] = STATE(571),
    [sym_while_statement] = STATE(571),
    [sym_do_while_statement] = STATE(571),
    [sym_break_statement] = STATE(571),
    [sym_continue_statement] = STATE(571),
    [sym_condition_statement] = STATE(571),
    [sym_switch_statement] = STATE(571),
    [sym_expression_statement] = STATE(571),
    [sym_return_statement] = STATE(571),
    [sym_delete_statement] = STATE(571),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [29] = {
    [sym_preproc_include] = STATE(29),
    [sym_preproc_tryinclude] = STATE(29),
    [sym_preproc_macro] = STATE(29),
    [sym_preproc_define] = STATE(29),
    [sym_preproc_undefine] = STATE(29),
    [sym_preproc_if] = STATE(29),
    [sym_preproc_elseif] = STATE(29),
    [sym_preproc_assert] = STATE(29),
    [sym_preproc_pragma] = STATE(29),
    [sym_preproc_error] = STATE(29),
    [sym_preproc_warning] = STATE(29),
    [sym_variable_declaration_statement] = STATE(1299),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(1299),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(1299),
    [sym_for_statement] = STATE(1299),
    [sym_while_statement] = STATE(1299),
    [sym_do_while_statement] = STATE(1299),
    [sym_break_statement] = STATE(1299),
    [sym_continue_statement] = STATE(1299),
    [sym_condition_statement] = STATE(1299),
    [sym_switch_statement] = STATE(1299),
    [sym_expression_statement] = STATE(1299),
    [sym_return_statement] = STATE(1299),
    [sym_delete_statement] = STATE(1299),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [30] = {
    [sym_preproc_include] = STATE(30),
    [sym_preproc_tryinclude] = STATE(30),
    [sym_preproc_macro] = STATE(30),
    [sym_preproc_define] = STATE(30),
    [sym_preproc_undefine] = STATE(30),
    [sym_preproc_if] = STATE(30),
    [sym_preproc_elseif] = STATE(30),
    [sym_preproc_assert] = STATE(30),
    [sym_preproc_pragma] = STATE(30),
    [sym_preproc_error] = STATE(30),
    [sym_preproc_warning] = STATE(30),
    [sym_variable_declaration_statement] = STATE(572),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(572),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(572),
    [sym_for_statement] = STATE(572),
    [sym_while_statement] = STATE(572),
    [sym_do_while_statement] = STATE(572),
    [sym_break_statement] = STATE(572),
    [sym_continue_statement] = STATE(572),
    [sym_condition_statement] = STATE(572),
    [sym_switch_statement] = STATE(572),
    [sym_expression_statement] = STATE(572),
    [sym_return_statement] = STATE(572),
    [sym_delete_statement] = STATE(572),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [31] = {
    [sym_preproc_include] = STATE(31),
    [sym_preproc_tryinclude] = STATE(31),
    [sym_preproc_macro] = STATE(31),
    [sym_preproc_define] = STATE(31),
    [sym_preproc_undefine] = STATE(31),
    [sym_preproc_if] = STATE(31),
    [sym_preproc_elseif] = STATE(31),
    [sym_preproc_assert] = STATE(31),
    [sym_preproc_pragma] = STATE(31),
    [sym_preproc_error] = STATE(31),
    [sym_preproc_warning] = STATE(31),
    [sym_variable_declaration_statement] = STATE(1289),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(1289),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(1289),
    [sym_for_statement] = STATE(1289),
    [sym_while_statement] = STATE(1289),
    [sym_do_while_statement] = STATE(1289),
    [sym_break_statement] = STATE(1289),
    [sym_continue_statement] = STATE(1289),
    [sym_condition_statement] = STATE(1289),
    [sym_switch_statement] = STATE(1289),
    [sym_expression_statement] = STATE(1289),
    [sym_return_statement] = STATE(1289),
    [sym_delete_statement] = STATE(1289),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [32] = {
    [sym_preproc_include] = STATE(32),
    [sym_preproc_tryinclude] = STATE(32),
    [sym_preproc_macro] = STATE(32),
    [sym_preproc_define] = STATE(32),
    [sym_preproc_undefine] = STATE(32),
    [sym_preproc_if] = STATE(32),
    [sym_preproc_elseif] = STATE(32),
    [sym_preproc_assert] = STATE(32),
    [sym_preproc_pragma] = STATE(32),
    [sym_preproc_error] = STATE(32),
    [sym_preproc_warning] = STATE(32),
    [sym_variable_declaration_statement] = STATE(691),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(691),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(691),
    [sym_for_statement] = STATE(691),
    [sym_while_statement] = STATE(691),
    [sym_do_while_statement] = STATE(691),
    [sym_break_statement] = STATE(691),
    [sym_continue_statement] = STATE(691),
    [sym_condition_statement] = STATE(691),
    [sym_switch_statement] = STATE(691),
    [sym_expression_statement] = STATE(691),
    [sym_return_statement] = STATE(691),
    [sym_delete_statement] = STATE(691),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [33] = {
    [sym_preproc_include] = STATE(33),
    [sym_preproc_tryinclude] = STATE(33),
    [sym_preproc_macro] = STATE(33),
    [sym_preproc_define] = STATE(33),
    [sym_preproc_undefine] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_elseif] = STATE(33),
    [sym_preproc_assert] = STATE(33),
    [sym_preproc_pragma] = STATE(33),
    [sym_preproc_error] = STATE(33),
    [sym_preproc_warning] = STATE(33),
    [sym_variable_declaration_statement] = STATE(1474),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(1474),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(1474),
    [sym_for_statement] = STATE(1474),
    [sym_while_statement] = STATE(1474),
    [sym_do_while_statement] = STATE(1474),
    [sym_break_statement] = STATE(1474),
    [sym_continue_statement] = STATE(1474),
    [sym_condition_statement] = STATE(1474),
    [sym_switch_statement] = STATE(1474),
    [sym_expression_statement] = STATE(1474),
    [sym_return_statement] = STATE(1474),
    [sym_delete_statement] = STATE(1474),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [34] = {
    [sym_preproc_include] = STATE(34),
    [sym_preproc_tryinclude] = STATE(34),
    [sym_preproc_macro] = STATE(34),
    [sym_preproc_define] = STATE(34),
    [sym_preproc_undefine] = STATE(34),
    [sym_preproc_if] = STATE(34),
    [sym_preproc_elseif] = STATE(34),
    [sym_preproc_assert] = STATE(34),
    [sym_preproc_pragma] = STATE(34),
    [sym_preproc_error] = STATE(34),
    [sym_preproc_warning] = STATE(34),
    [sym_variable_declaration_statement] = STATE(463),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(463),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(463),
    [sym_for_statement] = STATE(463),
    [sym_while_statement] = STATE(463),
    [sym_do_while_statement] = STATE(463),
    [sym_break_statement] = STATE(463),
    [sym_continue_statement] = STATE(463),
    [sym_condition_statement] = STATE(463),
    [sym_switch_statement] = STATE(463),
    [sym_expression_statement] = STATE(463),
    [sym_return_statement] = STATE(463),
    [sym_delete_statement] = STATE(463),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [35] = {
    [sym_preproc_include] = STATE(35),
    [sym_preproc_tryinclude] = STATE(35),
    [sym_preproc_macro] = STATE(35),
    [sym_preproc_define] = STATE(35),
    [sym_preproc_undefine] = STATE(35),
    [sym_preproc_if] = STATE(35),
    [sym_preproc_elseif] = STATE(35),
    [sym_preproc_assert] = STATE(35),
    [sym_preproc_pragma] = STATE(35),
    [sym_preproc_error] = STATE(35),
    [sym_preproc_warning] = STATE(35),
    [sym_variable_declaration_statement] = STATE(464),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(464),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(464),
    [sym_for_statement] = STATE(464),
    [sym_while_statement] = STATE(464),
    [sym_do_while_statement] = STATE(464),
    [sym_break_statement] = STATE(464),
    [sym_continue_statement] = STATE(464),
    [sym_condition_statement] = STATE(464),
    [sym_switch_statement] = STATE(464),
    [sym_expression_statement] = STATE(464),
    [sym_return_statement] = STATE(464),
    [sym_delete_statement] = STATE(464),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [36] = {
    [sym_preproc_include] = STATE(36),
    [sym_preproc_tryinclude] = STATE(36),
    [sym_preproc_macro] = STATE(36),
    [sym_preproc_define] = STATE(36),
    [sym_preproc_undefine] = STATE(36),
    [sym_preproc_if] = STATE(36),
    [sym_preproc_elseif] = STATE(36),
    [sym_preproc_assert] = STATE(36),
    [sym_preproc_pragma] = STATE(36),
    [sym_preproc_error] = STATE(36),
    [sym_preproc_warning] = STATE(36),
    [sym_variable_declaration_statement] = STATE(475),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(475),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(475),
    [sym_for_statement] = STATE(475),
    [sym_while_statement] = STATE(475),
    [sym_do_while_statement] = STATE(475),
    [sym_break_statement] = STATE(475),
    [sym_continue_statement] = STATE(475),
    [sym_condition_statement] = STATE(475),
    [sym_switch_statement] = STATE(475),
    [sym_expression_statement] = STATE(475),
    [sym_return_statement] = STATE(475),
    [sym_delete_statement] = STATE(475),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [37] = {
    [sym_preproc_include] = STATE(37),
    [sym_preproc_tryinclude] = STATE(37),
    [sym_preproc_macro] = STATE(37),
    [sym_preproc_define] = STATE(37),
    [sym_preproc_undefine] = STATE(37),
    [sym_preproc_if] = STATE(37),
    [sym_preproc_elseif] = STATE(37),
    [sym_preproc_assert] = STATE(37),
    [sym_preproc_pragma] = STATE(37),
    [sym_preproc_error] = STATE(37),
    [sym_preproc_warning] = STATE(37),
    [sym_variable_declaration_statement] = STATE(443),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(443),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(443),
    [sym_for_statement] = STATE(443),
    [sym_while_statement] = STATE(443),
    [sym_do_while_statement] = STATE(443),
    [sym_break_statement] = STATE(443),
    [sym_continue_statement] = STATE(443),
    [sym_condition_statement] = STATE(443),
    [sym_switch_statement] = STATE(443),
    [sym_expression_statement] = STATE(443),
    [sym_return_statement] = STATE(443),
    [sym_delete_statement] = STATE(443),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [38] = {
    [sym_preproc_include] = STATE(38),
    [sym_preproc_tryinclude] = STATE(38),
    [sym_preproc_macro] = STATE(38),
    [sym_preproc_define] = STATE(38),
    [sym_preproc_undefine] = STATE(38),
    [sym_preproc_if] = STATE(38),
    [sym_preproc_elseif] = STATE(38),
    [sym_preproc_assert] = STATE(38),
    [sym_preproc_pragma] = STATE(38),
    [sym_preproc_error] = STATE(38),
    [sym_preproc_warning] = STATE(38),
    [sym_variable_declaration_statement] = STATE(476),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(476),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(476),
    [sym_for_statement] = STATE(476),
    [sym_while_statement] = STATE(476),
    [sym_do_while_statement] = STATE(476),
    [sym_break_statement] = STATE(476),
    [sym_continue_statement] = STATE(476),
    [sym_condition_statement] = STATE(476),
    [sym_switch_statement] = STATE(476),
    [sym_expression_statement] = STATE(476),
    [sym_return_statement] = STATE(476),
    [sym_delete_statement] = STATE(476),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [39] = {
    [sym_preproc_include] = STATE(39),
    [sym_preproc_tryinclude] = STATE(39),
    [sym_preproc_macro] = STATE(39),
    [sym_preproc_define] = STATE(39),
    [sym_preproc_undefine] = STATE(39),
    [sym_preproc_if] = STATE(39),
    [sym_preproc_elseif] = STATE(39),
    [sym_preproc_assert] = STATE(39),
    [sym_preproc_pragma] = STATE(39),
    [sym_preproc_error] = STATE(39),
    [sym_preproc_warning] = STATE(39),
    [sym_variable_declaration_statement] = STATE(456),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(456),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(456),
    [sym_for_statement] = STATE(456),
    [sym_while_statement] = STATE(456),
    [sym_do_while_statement] = STATE(456),
    [sym_break_statement] = STATE(456),
    [sym_continue_statement] = STATE(456),
    [sym_condition_statement] = STATE(456),
    [sym_switch_statement] = STATE(456),
    [sym_expression_statement] = STATE(456),
    [sym_return_statement] = STATE(456),
    [sym_delete_statement] = STATE(456),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [40] = {
    [sym_preproc_include] = STATE(40),
    [sym_preproc_tryinclude] = STATE(40),
    [sym_preproc_macro] = STATE(40),
    [sym_preproc_define] = STATE(40),
    [sym_preproc_undefine] = STATE(40),
    [sym_preproc_if] = STATE(40),
    [sym_preproc_elseif] = STATE(40),
    [sym_preproc_assert] = STATE(40),
    [sym_preproc_pragma] = STATE(40),
    [sym_preproc_error] = STATE(40),
    [sym_preproc_warning] = STATE(40),
    [sym_variable_declaration_statement] = STATE(480),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(480),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(480),
    [sym_for_statement] = STATE(480),
    [sym_while_statement] = STATE(480),
    [sym_do_while_statement] = STATE(480),
    [sym_break_statement] = STATE(480),
    [sym_continue_statement] = STATE(480),
    [sym_condition_statement] = STATE(480),
    [sym_switch_statement] = STATE(480),
    [sym_expression_statement] = STATE(480),
    [sym_return_statement] = STATE(480),
    [sym_delete_statement] = STATE(480),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [41] = {
    [sym_preproc_include] = STATE(41),
    [sym_preproc_tryinclude] = STATE(41),
    [sym_preproc_macro] = STATE(41),
    [sym_preproc_define] = STATE(41),
    [sym_preproc_undefine] = STATE(41),
    [sym_preproc_if] = STATE(41),
    [sym_preproc_elseif] = STATE(41),
    [sym_preproc_assert] = STATE(41),
    [sym_preproc_pragma] = STATE(41),
    [sym_preproc_error] = STATE(41),
    [sym_preproc_warning] = STATE(41),
    [sym_variable_declaration_statement] = STATE(462),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(462),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(462),
    [sym_for_statement] = STATE(462),
    [sym_while_statement] = STATE(462),
    [sym_do_while_statement] = STATE(462),
    [sym_break_statement] = STATE(462),
    [sym_continue_statement] = STATE(462),
    [sym_condition_statement] = STATE(462),
    [sym_switch_statement] = STATE(462),
    [sym_expression_statement] = STATE(462),
    [sym_return_statement] = STATE(462),
    [sym_delete_statement] = STATE(462),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [42] = {
    [sym_preproc_include] = STATE(42),
    [sym_preproc_tryinclude] = STATE(42),
    [sym_preproc_macro] = STATE(42),
    [sym_preproc_define] = STATE(42),
    [sym_preproc_undefine] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_elseif] = STATE(42),
    [sym_preproc_assert] = STATE(42),
    [sym_preproc_pragma] = STATE(42),
    [sym_preproc_error] = STATE(42),
    [sym_preproc_warning] = STATE(42),
    [sym_variable_declaration_statement] = STATE(467),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(467),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(467),
    [sym_for_statement] = STATE(467),
    [sym_while_statement] = STATE(467),
    [sym_do_while_statement] = STATE(467),
    [sym_break_statement] = STATE(467),
    [sym_continue_statement] = STATE(467),
    [sym_condition_statement] = STATE(467),
    [sym_switch_statement] = STATE(467),
    [sym_expression_statement] = STATE(467),
    [sym_return_statement] = STATE(467),
    [sym_delete_statement] = STATE(467),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [43] = {
    [sym_preproc_include] = STATE(43),
    [sym_preproc_tryinclude] = STATE(43),
    [sym_preproc_macro] = STATE(43),
    [sym_preproc_define] = STATE(43),
    [sym_preproc_undefine] = STATE(43),
    [sym_preproc_if] = STATE(43),
    [sym_preproc_elseif] = STATE(43),
    [sym_preproc_assert] = STATE(43),
    [sym_preproc_pragma] = STATE(43),
    [sym_preproc_error] = STATE(43),
    [sym_preproc_warning] = STATE(43),
    [sym_variable_declaration_statement] = STATE(473),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(473),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(473),
    [sym_for_statement] = STATE(473),
    [sym_while_statement] = STATE(473),
    [sym_do_while_statement] = STATE(473),
    [sym_break_statement] = STATE(473),
    [sym_continue_statement] = STATE(473),
    [sym_condition_statement] = STATE(473),
    [sym_switch_statement] = STATE(473),
    [sym_expression_statement] = STATE(473),
    [sym_return_statement] = STATE(473),
    [sym_delete_statement] = STATE(473),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [44] = {
    [sym_preproc_include] = STATE(44),
    [sym_preproc_tryinclude] = STATE(44),
    [sym_preproc_macro] = STATE(44),
    [sym_preproc_define] = STATE(44),
    [sym_preproc_undefine] = STATE(44),
    [sym_preproc_if] = STATE(44),
    [sym_preproc_elseif] = STATE(44),
    [sym_preproc_assert] = STATE(44),
    [sym_preproc_pragma] = STATE(44),
    [sym_preproc_error] = STATE(44),
    [sym_preproc_warning] = STATE(44),
    [sym_variable_declaration_statement] = STATE(474),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(474),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(474),
    [sym_for_statement] = STATE(474),
    [sym_while_statement] = STATE(474),
    [sym_do_while_statement] = STATE(474),
    [sym_break_statement] = STATE(474),
    [sym_continue_statement] = STATE(474),
    [sym_condition_statement] = STATE(474),
    [sym_switch_statement] = STATE(474),
    [sym_expression_statement] = STATE(474),
    [sym_return_statement] = STATE(474),
    [sym_delete_statement] = STATE(474),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [45] = {
    [sym_preproc_include] = STATE(45),
    [sym_preproc_tryinclude] = STATE(45),
    [sym_preproc_macro] = STATE(45),
    [sym_preproc_define] = STATE(45),
    [sym_preproc_undefine] = STATE(45),
    [sym_preproc_if] = STATE(45),
    [sym_preproc_elseif] = STATE(45),
    [sym_preproc_assert] = STATE(45),
    [sym_preproc_pragma] = STATE(45),
    [sym_preproc_error] = STATE(45),
    [sym_preproc_warning] = STATE(45),
    [sym_variable_declaration_statement] = STATE(447),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(447),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(447),
    [sym_for_statement] = STATE(447),
    [sym_while_statement] = STATE(447),
    [sym_do_while_statement] = STATE(447),
    [sym_break_statement] = STATE(447),
    [sym_continue_statement] = STATE(447),
    [sym_condition_statement] = STATE(447),
    [sym_switch_statement] = STATE(447),
    [sym_expression_statement] = STATE(447),
    [sym_return_statement] = STATE(447),
    [sym_delete_statement] = STATE(447),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [46] = {
    [sym_preproc_include] = STATE(46),
    [sym_preproc_tryinclude] = STATE(46),
    [sym_preproc_macro] = STATE(46),
    [sym_preproc_define] = STATE(46),
    [sym_preproc_undefine] = STATE(46),
    [sym_preproc_if] = STATE(46),
    [sym_preproc_elseif] = STATE(46),
    [sym_preproc_assert] = STATE(46),
    [sym_preproc_pragma] = STATE(46),
    [sym_preproc_error] = STATE(46),
    [sym_preproc_warning] = STATE(46),
    [sym_variable_declaration_statement] = STATE(455),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(455),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(455),
    [sym_for_statement] = STATE(455),
    [sym_while_statement] = STATE(455),
    [sym_do_while_statement] = STATE(455),
    [sym_break_statement] = STATE(455),
    [sym_continue_statement] = STATE(455),
    [sym_condition_statement] = STATE(455),
    [sym_switch_statement] = STATE(455),
    [sym_expression_statement] = STATE(455),
    [sym_return_statement] = STATE(455),
    [sym_delete_statement] = STATE(455),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [47] = {
    [sym_preproc_include] = STATE(47),
    [sym_preproc_tryinclude] = STATE(47),
    [sym_preproc_macro] = STATE(47),
    [sym_preproc_define] = STATE(47),
    [sym_preproc_undefine] = STATE(47),
    [sym_preproc_if] = STATE(47),
    [sym_preproc_elseif] = STATE(47),
    [sym_preproc_assert] = STATE(47),
    [sym_preproc_pragma] = STATE(47),
    [sym_preproc_error] = STATE(47),
    [sym_preproc_warning] = STATE(47),
    [sym_variable_declaration_statement] = STATE(439),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(439),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(439),
    [sym_for_statement] = STATE(439),
    [sym_while_statement] = STATE(439),
    [sym_do_while_statement] = STATE(439),
    [sym_break_statement] = STATE(439),
    [sym_continue_statement] = STATE(439),
    [sym_condition_statement] = STATE(439),
    [sym_switch_statement] = STATE(439),
    [sym_expression_statement] = STATE(439),
    [sym_return_statement] = STATE(439),
    [sym_delete_statement] = STATE(439),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [48] = {
    [sym_preproc_include] = STATE(48),
    [sym_preproc_tryinclude] = STATE(48),
    [sym_preproc_macro] = STATE(48),
    [sym_preproc_define] = STATE(48),
    [sym_preproc_undefine] = STATE(48),
    [sym_preproc_if] = STATE(48),
    [sym_preproc_elseif] = STATE(48),
    [sym_preproc_assert] = STATE(48),
    [sym_preproc_pragma] = STATE(48),
    [sym_preproc_error] = STATE(48),
    [sym_preproc_warning] = STATE(48),
    [sym_variable_declaration_statement] = STATE(469),
    [sym_variable_storage_class] = STATE(986),
    [sym_visibility] = STATE(980),
    [sym_new_expression] = STATE(111),
    [sym_old_variable_declaration_statement] = STATE(469),
    [sym_type] = STATE(1168),
    [sym_old_type] = STATE(316),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(469),
    [sym_for_statement] = STATE(469),
    [sym_while_statement] = STATE(469),
    [sym_do_while_statement] = STATE(469),
    [sym_break_statement] = STATE(469),
    [sym_continue_statement] = STATE(469),
    [sym_condition_statement] = STATE(469),
    [sym_switch_statement] = STATE(469),
    [sym_expression_statement] = STATE(469),
    [sym_return_statement] = STATE(469),
    [sym_delete_statement] = STATE(469),
    [sym__expression] = STATE(103),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(242),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(79),
    [anon_sym_decl] = ACTIONS(81),
    [anon_sym_LBRACE] = ACTIONS(83),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_do] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_return] = ACTIONS(101),
    [anon_sym_delete] = ACTIONS(103),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [49] = {
    [sym_preproc_include] = STATE(49),
    [sym_preproc_tryinclude] = STATE(49),
    [sym_preproc_macro] = STATE(49),
    [sym_preproc_define] = STATE(49),
    [sym_preproc_undefine] = STATE(49),
    [sym_preproc_if] = STATE(49),
    [sym_preproc_elseif] = STATE(49),
    [sym_preproc_assert] = STATE(49),
    [sym_preproc_pragma] = STATE(49),
    [sym_preproc_error] = STATE(49),
    [sym_preproc_warning] = STATE(49),
    [sym_variable_declaration_statement] = STATE(556),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(556),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(556),
    [sym_for_statement] = STATE(556),
    [sym_while_statement] = STATE(556),
    [sym_do_while_statement] = STATE(556),
    [sym_break_statement] = STATE(556),
    [sym_continue_statement] = STATE(556),
    [sym_condition_statement] = STATE(556),
    [sym_switch_statement] = STATE(556),
    [sym_expression_statement] = STATE(556),
    [sym_return_statement] = STATE(556),
    [sym_delete_statement] = STATE(556),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [50] = {
    [sym_preproc_include] = STATE(50),
    [sym_preproc_tryinclude] = STATE(50),
    [sym_preproc_macro] = STATE(50),
    [sym_preproc_define] = STATE(50),
    [sym_preproc_undefine] = STATE(50),
    [sym_preproc_if] = STATE(50),
    [sym_preproc_elseif] = STATE(50),
    [sym_preproc_assert] = STATE(50),
    [sym_preproc_pragma] = STATE(50),
    [sym_preproc_error] = STATE(50),
    [sym_preproc_warning] = STATE(50),
    [sym_variable_declaration_statement] = STATE(1182),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(1182),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(1182),
    [sym_for_statement] = STATE(1182),
    [sym_while_statement] = STATE(1182),
    [sym_do_while_statement] = STATE(1182),
    [sym_break_statement] = STATE(1182),
    [sym_continue_statement] = STATE(1182),
    [sym_condition_statement] = STATE(1182),
    [sym_switch_statement] = STATE(1182),
    [sym_expression_statement] = STATE(1182),
    [sym_return_statement] = STATE(1182),
    [sym_delete_statement] = STATE(1182),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [51] = {
    [sym_preproc_include] = STATE(51),
    [sym_preproc_tryinclude] = STATE(51),
    [sym_preproc_macro] = STATE(51),
    [sym_preproc_define] = STATE(51),
    [sym_preproc_undefine] = STATE(51),
    [sym_preproc_if] = STATE(51),
    [sym_preproc_elseif] = STATE(51),
    [sym_preproc_assert] = STATE(51),
    [sym_preproc_pragma] = STATE(51),
    [sym_preproc_error] = STATE(51),
    [sym_preproc_warning] = STATE(51),
    [sym_variable_declaration_statement] = STATE(557),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(557),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(557),
    [sym_for_statement] = STATE(557),
    [sym_while_statement] = STATE(557),
    [sym_do_while_statement] = STATE(557),
    [sym_break_statement] = STATE(557),
    [sym_continue_statement] = STATE(557),
    [sym_condition_statement] = STATE(557),
    [sym_switch_statement] = STATE(557),
    [sym_expression_statement] = STATE(557),
    [sym_return_statement] = STATE(557),
    [sym_delete_statement] = STATE(557),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [52] = {
    [sym_preproc_include] = STATE(52),
    [sym_preproc_tryinclude] = STATE(52),
    [sym_preproc_macro] = STATE(52),
    [sym_preproc_define] = STATE(52),
    [sym_preproc_undefine] = STATE(52),
    [sym_preproc_if] = STATE(52),
    [sym_preproc_elseif] = STATE(52),
    [sym_preproc_assert] = STATE(52),
    [sym_preproc_pragma] = STATE(52),
    [sym_preproc_error] = STATE(52),
    [sym_preproc_warning] = STATE(52),
    [sym_variable_declaration_statement] = STATE(559),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(559),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(559),
    [sym_for_statement] = STATE(559),
    [sym_while_statement] = STATE(559),
    [sym_do_while_statement] = STATE(559),
    [sym_break_statement] = STATE(559),
    [sym_continue_statement] = STATE(559),
    [sym_condition_statement] = STATE(559),
    [sym_switch_statement] = STATE(559),
    [sym_expression_statement] = STATE(559),
    [sym_return_statement] = STATE(559),
    [sym_delete_statement] = STATE(559),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [53] = {
    [sym_preproc_include] = STATE(53),
    [sym_preproc_tryinclude] = STATE(53),
    [sym_preproc_macro] = STATE(53),
    [sym_preproc_define] = STATE(53),
    [sym_preproc_undefine] = STATE(53),
    [sym_preproc_if] = STATE(53),
    [sym_preproc_elseif] = STATE(53),
    [sym_preproc_assert] = STATE(53),
    [sym_preproc_pragma] = STATE(53),
    [sym_preproc_error] = STATE(53),
    [sym_preproc_warning] = STATE(53),
    [sym_variable_declaration_statement] = STATE(560),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(560),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(560),
    [sym_for_statement] = STATE(560),
    [sym_while_statement] = STATE(560),
    [sym_do_while_statement] = STATE(560),
    [sym_break_statement] = STATE(560),
    [sym_continue_statement] = STATE(560),
    [sym_condition_statement] = STATE(560),
    [sym_switch_statement] = STATE(560),
    [sym_expression_statement] = STATE(560),
    [sym_return_statement] = STATE(560),
    [sym_delete_statement] = STATE(560),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [54] = {
    [sym_preproc_include] = STATE(54),
    [sym_preproc_tryinclude] = STATE(54),
    [sym_preproc_macro] = STATE(54),
    [sym_preproc_define] = STATE(54),
    [sym_preproc_undefine] = STATE(54),
    [sym_preproc_if] = STATE(54),
    [sym_preproc_elseif] = STATE(54),
    [sym_preproc_assert] = STATE(54),
    [sym_preproc_pragma] = STATE(54),
    [sym_preproc_error] = STATE(54),
    [sym_preproc_warning] = STATE(54),
    [sym_variable_declaration_statement] = STATE(561),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(561),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(561),
    [sym_for_statement] = STATE(561),
    [sym_while_statement] = STATE(561),
    [sym_do_while_statement] = STATE(561),
    [sym_break_statement] = STATE(561),
    [sym_continue_statement] = STATE(561),
    [sym_condition_statement] = STATE(561),
    [sym_switch_statement] = STATE(561),
    [sym_expression_statement] = STATE(561),
    [sym_return_statement] = STATE(561),
    [sym_delete_statement] = STATE(561),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [55] = {
    [sym_preproc_include] = STATE(55),
    [sym_preproc_tryinclude] = STATE(55),
    [sym_preproc_macro] = STATE(55),
    [sym_preproc_define] = STATE(55),
    [sym_preproc_undefine] = STATE(55),
    [sym_preproc_if] = STATE(55),
    [sym_preproc_elseif] = STATE(55),
    [sym_preproc_assert] = STATE(55),
    [sym_preproc_pragma] = STATE(55),
    [sym_preproc_error] = STATE(55),
    [sym_preproc_warning] = STATE(55),
    [sym_variable_declaration_statement] = STATE(563),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(563),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(563),
    [sym_for_statement] = STATE(563),
    [sym_while_statement] = STATE(563),
    [sym_do_while_statement] = STATE(563),
    [sym_break_statement] = STATE(563),
    [sym_continue_statement] = STATE(563),
    [sym_condition_statement] = STATE(563),
    [sym_switch_statement] = STATE(563),
    [sym_expression_statement] = STATE(563),
    [sym_return_statement] = STATE(563),
    [sym_delete_statement] = STATE(563),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [56] = {
    [sym_preproc_include] = STATE(56),
    [sym_preproc_tryinclude] = STATE(56),
    [sym_preproc_macro] = STATE(56),
    [sym_preproc_define] = STATE(56),
    [sym_preproc_undefine] = STATE(56),
    [sym_preproc_if] = STATE(56),
    [sym_preproc_elseif] = STATE(56),
    [sym_preproc_assert] = STATE(56),
    [sym_preproc_pragma] = STATE(56),
    [sym_preproc_error] = STATE(56),
    [sym_preproc_warning] = STATE(56),
    [sym_variable_declaration_statement] = STATE(565),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(565),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(565),
    [sym_for_statement] = STATE(565),
    [sym_while_statement] = STATE(565),
    [sym_do_while_statement] = STATE(565),
    [sym_break_statement] = STATE(565),
    [sym_continue_statement] = STATE(565),
    [sym_condition_statement] = STATE(565),
    [sym_switch_statement] = STATE(565),
    [sym_expression_statement] = STATE(565),
    [sym_return_statement] = STATE(565),
    [sym_delete_statement] = STATE(565),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [57] = {
    [sym_preproc_include] = STATE(57),
    [sym_preproc_tryinclude] = STATE(57),
    [sym_preproc_macro] = STATE(57),
    [sym_preproc_define] = STATE(57),
    [sym_preproc_undefine] = STATE(57),
    [sym_preproc_if] = STATE(57),
    [sym_preproc_elseif] = STATE(57),
    [sym_preproc_assert] = STATE(57),
    [sym_preproc_pragma] = STATE(57),
    [sym_preproc_error] = STATE(57),
    [sym_preproc_warning] = STATE(57),
    [sym_variable_declaration_statement] = STATE(566),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(566),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(566),
    [sym_for_statement] = STATE(566),
    [sym_while_statement] = STATE(566),
    [sym_do_while_statement] = STATE(566),
    [sym_break_statement] = STATE(566),
    [sym_continue_statement] = STATE(566),
    [sym_condition_statement] = STATE(566),
    [sym_switch_statement] = STATE(566),
    [sym_expression_statement] = STATE(566),
    [sym_return_statement] = STATE(566),
    [sym_delete_statement] = STATE(566),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [58] = {
    [sym_preproc_include] = STATE(58),
    [sym_preproc_tryinclude] = STATE(58),
    [sym_preproc_macro] = STATE(58),
    [sym_preproc_define] = STATE(58),
    [sym_preproc_undefine] = STATE(58),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_elseif] = STATE(58),
    [sym_preproc_assert] = STATE(58),
    [sym_preproc_pragma] = STATE(58),
    [sym_preproc_error] = STATE(58),
    [sym_preproc_warning] = STATE(58),
    [sym_variable_declaration_statement] = STATE(567),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(567),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(567),
    [sym_for_statement] = STATE(567),
    [sym_while_statement] = STATE(567),
    [sym_do_while_statement] = STATE(567),
    [sym_break_statement] = STATE(567),
    [sym_continue_statement] = STATE(567),
    [sym_condition_statement] = STATE(567),
    [sym_switch_statement] = STATE(567),
    [sym_expression_statement] = STATE(567),
    [sym_return_statement] = STATE(567),
    [sym_delete_statement] = STATE(567),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [59] = {
    [sym_preproc_include] = STATE(59),
    [sym_preproc_tryinclude] = STATE(59),
    [sym_preproc_macro] = STATE(59),
    [sym_preproc_define] = STATE(59),
    [sym_preproc_undefine] = STATE(59),
    [sym_preproc_if] = STATE(59),
    [sym_preproc_elseif] = STATE(59),
    [sym_preproc_assert] = STATE(59),
    [sym_preproc_pragma] = STATE(59),
    [sym_preproc_error] = STATE(59),
    [sym_preproc_warning] = STATE(59),
    [sym_variable_declaration_statement] = STATE(568),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(568),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(568),
    [sym_for_statement] = STATE(568),
    [sym_while_statement] = STATE(568),
    [sym_do_while_statement] = STATE(568),
    [sym_break_statement] = STATE(568),
    [sym_continue_statement] = STATE(568),
    [sym_condition_statement] = STATE(568),
    [sym_switch_statement] = STATE(568),
    [sym_expression_statement] = STATE(568),
    [sym_return_statement] = STATE(568),
    [sym_delete_statement] = STATE(568),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [60] = {
    [sym_preproc_include] = STATE(60),
    [sym_preproc_tryinclude] = STATE(60),
    [sym_preproc_macro] = STATE(60),
    [sym_preproc_define] = STATE(60),
    [sym_preproc_undefine] = STATE(60),
    [sym_preproc_if] = STATE(60),
    [sym_preproc_elseif] = STATE(60),
    [sym_preproc_assert] = STATE(60),
    [sym_preproc_pragma] = STATE(60),
    [sym_preproc_error] = STATE(60),
    [sym_preproc_warning] = STATE(60),
    [sym_variable_declaration_statement] = STATE(569),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(569),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(569),
    [sym_for_statement] = STATE(569),
    [sym_while_statement] = STATE(569),
    [sym_do_while_statement] = STATE(569),
    [sym_break_statement] = STATE(569),
    [sym_continue_statement] = STATE(569),
    [sym_condition_statement] = STATE(569),
    [sym_switch_statement] = STATE(569),
    [sym_expression_statement] = STATE(569),
    [sym_return_statement] = STATE(569),
    [sym_delete_statement] = STATE(569),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [61] = {
    [sym_preproc_include] = STATE(61),
    [sym_preproc_tryinclude] = STATE(61),
    [sym_preproc_macro] = STATE(61),
    [sym_preproc_define] = STATE(61),
    [sym_preproc_undefine] = STATE(61),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_elseif] = STATE(61),
    [sym_preproc_assert] = STATE(61),
    [sym_preproc_pragma] = STATE(61),
    [sym_preproc_error] = STATE(61),
    [sym_preproc_warning] = STATE(61),
    [sym_variable_declaration_statement] = STATE(570),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(570),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(570),
    [sym_for_statement] = STATE(570),
    [sym_while_statement] = STATE(570),
    [sym_do_while_statement] = STATE(570),
    [sym_break_statement] = STATE(570),
    [sym_continue_statement] = STATE(570),
    [sym_condition_statement] = STATE(570),
    [sym_switch_statement] = STATE(570),
    [sym_expression_statement] = STATE(570),
    [sym_return_statement] = STATE(570),
    [sym_delete_statement] = STATE(570),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [62] = {
    [sym_preproc_include] = STATE(62),
    [sym_preproc_tryinclude] = STATE(62),
    [sym_preproc_macro] = STATE(62),
    [sym_preproc_define] = STATE(62),
    [sym_preproc_undefine] = STATE(62),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_elseif] = STATE(62),
    [sym_preproc_assert] = STATE(62),
    [sym_preproc_pragma] = STATE(62),
    [sym_preproc_error] = STATE(62),
    [sym_preproc_warning] = STATE(62),
    [sym_variable_declaration_statement] = STATE(571),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(571),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(571),
    [sym_for_statement] = STATE(571),
    [sym_while_statement] = STATE(571),
    [sym_do_while_statement] = STATE(571),
    [sym_break_statement] = STATE(571),
    [sym_continue_statement] = STATE(571),
    [sym_condition_statement] = STATE(571),
    [sym_switch_statement] = STATE(571),
    [sym_expression_statement] = STATE(571),
    [sym_return_statement] = STATE(571),
    [sym_delete_statement] = STATE(571),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [63] = {
    [sym_preproc_include] = STATE(63),
    [sym_preproc_tryinclude] = STATE(63),
    [sym_preproc_macro] = STATE(63),
    [sym_preproc_define] = STATE(63),
    [sym_preproc_undefine] = STATE(63),
    [sym_preproc_if] = STATE(63),
    [sym_preproc_elseif] = STATE(63),
    [sym_preproc_assert] = STATE(63),
    [sym_preproc_pragma] = STATE(63),
    [sym_preproc_error] = STATE(63),
    [sym_preproc_warning] = STATE(63),
    [sym_variable_declaration_statement] = STATE(572),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(572),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(572),
    [sym_for_statement] = STATE(572),
    [sym_while_statement] = STATE(572),
    [sym_do_while_statement] = STATE(572),
    [sym_break_statement] = STATE(572),
    [sym_continue_statement] = STATE(572),
    [sym_condition_statement] = STATE(572),
    [sym_switch_statement] = STATE(572),
    [sym_expression_statement] = STATE(572),
    [sym_return_statement] = STATE(572),
    [sym_delete_statement] = STATE(572),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [64] = {
    [sym_preproc_include] = STATE(64),
    [sym_preproc_tryinclude] = STATE(64),
    [sym_preproc_macro] = STATE(64),
    [sym_preproc_define] = STATE(64),
    [sym_preproc_undefine] = STATE(64),
    [sym_preproc_if] = STATE(64),
    [sym_preproc_elseif] = STATE(64),
    [sym_preproc_assert] = STATE(64),
    [sym_preproc_pragma] = STATE(64),
    [sym_preproc_error] = STATE(64),
    [sym_preproc_warning] = STATE(64),
    [sym_call_arguments] = STATE(117),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(125),
    [anon_sym_BANG] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(248),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(250),
    [anon_sym_DASH_EQ] = ACTIONS(250),
    [anon_sym_STAR_EQ] = ACTIONS(250),
    [anon_sym_SLASH_EQ] = ACTIONS(250),
    [anon_sym_PIPE_EQ] = ACTIONS(250),
    [anon_sym_AMP_EQ] = ACTIONS(250),
    [anon_sym_CARET_EQ] = ACTIONS(250),
    [anon_sym_TILDE_EQ] = ACTIONS(250),
    [anon_sym_LT_LT_EQ] = ACTIONS(250),
    [anon_sym_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_LBRACK] = ACTIONS(252),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_do] = ACTIONS(244),
    [anon_sym_break] = ACTIONS(244),
    [anon_sym_continue] = ACTIONS(244),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_else] = ACTIONS(244),
    [anon_sym_switch] = ACTIONS(244),
    [anon_sym_return] = ACTIONS(244),
    [anon_sym_delete] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_PERCENT_EQ] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [anon_sym_sizeof] = ACTIONS(244),
    [anon_sym_view_as] = ACTIONS(244),
    [sym_int_literal] = ACTIONS(244),
    [sym_float_literal] = ACTIONS(246),
    [anon_sym_SQUOTE] = ACTIONS(246),
    [anon_sym_DQUOTE] = ACTIONS(246),
    [sym_bool_literal] = ACTIONS(244),
    [sym_null] = ACTIONS(244),
    [sym_this] = ACTIONS(244),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [65] = {
    [sym_preproc_include] = STATE(65),
    [sym_preproc_tryinclude] = STATE(65),
    [sym_preproc_macro] = STATE(65),
    [sym_preproc_define] = STATE(65),
    [sym_preproc_undefine] = STATE(65),
    [sym_preproc_if] = STATE(65),
    [sym_preproc_elseif] = STATE(65),
    [sym_preproc_assert] = STATE(65),
    [sym_preproc_pragma] = STATE(65),
    [sym_preproc_error] = STATE(65),
    [sym_preproc_warning] = STATE(65),
    [sym_variable_declaration_statement] = STATE(717),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(717),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(717),
    [sym_for_statement] = STATE(717),
    [sym_while_statement] = STATE(717),
    [sym_do_while_statement] = STATE(717),
    [sym_break_statement] = STATE(717),
    [sym_continue_statement] = STATE(717),
    [sym_condition_statement] = STATE(717),
    [sym_switch_statement] = STATE(717),
    [sym_expression_statement] = STATE(717),
    [sym_return_statement] = STATE(717),
    [sym_delete_statement] = STATE(717),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [66] = {
    [sym_preproc_include] = STATE(66),
    [sym_preproc_tryinclude] = STATE(66),
    [sym_preproc_macro] = STATE(66),
    [sym_preproc_define] = STATE(66),
    [sym_preproc_undefine] = STATE(66),
    [sym_preproc_if] = STATE(66),
    [sym_preproc_elseif] = STATE(66),
    [sym_preproc_assert] = STATE(66),
    [sym_preproc_pragma] = STATE(66),
    [sym_preproc_error] = STATE(66),
    [sym_preproc_warning] = STATE(66),
    [sym_variable_declaration_statement] = STATE(1643),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(1643),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(1643),
    [sym_for_statement] = STATE(1643),
    [sym_while_statement] = STATE(1643),
    [sym_do_while_statement] = STATE(1643),
    [sym_break_statement] = STATE(1643),
    [sym_continue_statement] = STATE(1643),
    [sym_condition_statement] = STATE(1643),
    [sym_switch_statement] = STATE(1643),
    [sym_expression_statement] = STATE(1643),
    [sym_return_statement] = STATE(1643),
    [sym_delete_statement] = STATE(1643),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(315),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(317),
    [anon_sym_while] = ACTIONS(319),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(321),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(323),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [67] = {
    [sym_preproc_include] = STATE(67),
    [sym_preproc_tryinclude] = STATE(67),
    [sym_preproc_macro] = STATE(67),
    [sym_preproc_define] = STATE(67),
    [sym_preproc_undefine] = STATE(67),
    [sym_preproc_if] = STATE(67),
    [sym_preproc_elseif] = STATE(67),
    [sym_preproc_assert] = STATE(67),
    [sym_preproc_pragma] = STATE(67),
    [sym_preproc_error] = STATE(67),
    [sym_preproc_warning] = STATE(67),
    [sym_call_arguments] = STATE(117),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_LPAREN] = ACTIONS(125),
    [anon_sym_BANG] = ACTIONS(123),
    [anon_sym_TILDE] = ACTIONS(123),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_const] = ACTIONS(123),
    [anon_sym_public] = ACTIONS(123),
    [anon_sym_stock] = ACTIONS(123),
    [anon_sym_static] = ACTIONS(123),
    [anon_sym_new] = ACTIONS(123),
    [anon_sym_decl] = ACTIONS(123),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(252),
    [anon_sym_void] = ACTIONS(123),
    [anon_sym_bool] = ACTIONS(123),
    [anon_sym_int] = ACTIONS(123),
    [anon_sym_float] = ACTIONS(123),
    [anon_sym_char] = ACTIONS(123),
    [anon_sym__] = ACTIONS(123),
    [anon_sym_Float] = ACTIONS(123),
    [anon_sym_String] = ACTIONS(123),
    [sym_any_type] = ACTIONS(123),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_while] = ACTIONS(123),
    [anon_sym_do] = ACTIONS(123),
    [anon_sym_break] = ACTIONS(123),
    [anon_sym_continue] = ACTIONS(123),
    [anon_sym_if] = ACTIONS(123),
    [anon_sym_else] = ACTIONS(123),
    [anon_sym_switch] = ACTIONS(123),
    [anon_sym_return] = ACTIONS(123),
    [anon_sym_delete] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(123),
    [anon_sym_view_as] = ACTIONS(123),
    [sym_int_literal] = ACTIONS(123),
    [sym_float_literal] = ACTIONS(127),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DQUOTE] = ACTIONS(127),
    [sym_bool_literal] = ACTIONS(123),
    [sym_null] = ACTIONS(123),
    [sym_this] = ACTIONS(123),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(127),
  },
  [68] = {
    [sym_preproc_include] = STATE(68),
    [sym_preproc_tryinclude] = STATE(68),
    [sym_preproc_macro] = STATE(68),
    [sym_preproc_define] = STATE(68),
    [sym_preproc_undefine] = STATE(68),
    [sym_preproc_if] = STATE(68),
    [sym_preproc_elseif] = STATE(68),
    [sym_preproc_assert] = STATE(68),
    [sym_preproc_pragma] = STATE(68),
    [sym_preproc_error] = STATE(68),
    [sym_preproc_warning] = STATE(68),
    [sym_variable_declaration_statement] = STATE(652),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(652),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(652),
    [sym_for_statement] = STATE(652),
    [sym_while_statement] = STATE(652),
    [sym_do_while_statement] = STATE(652),
    [sym_break_statement] = STATE(652),
    [sym_continue_statement] = STATE(652),
    [sym_condition_statement] = STATE(652),
    [sym_switch_statement] = STATE(652),
    [sym_expression_statement] = STATE(652),
    [sym_return_statement] = STATE(652),
    [sym_delete_statement] = STATE(652),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [69] = {
    [sym_preproc_include] = STATE(69),
    [sym_preproc_tryinclude] = STATE(69),
    [sym_preproc_macro] = STATE(69),
    [sym_preproc_define] = STATE(69),
    [sym_preproc_undefine] = STATE(69),
    [sym_preproc_if] = STATE(69),
    [sym_preproc_elseif] = STATE(69),
    [sym_preproc_assert] = STATE(69),
    [sym_preproc_pragma] = STATE(69),
    [sym_preproc_error] = STATE(69),
    [sym_preproc_warning] = STATE(69),
    [sym_variable_declaration_statement] = STATE(687),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(687),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(687),
    [sym_for_statement] = STATE(687),
    [sym_while_statement] = STATE(687),
    [sym_do_while_statement] = STATE(687),
    [sym_break_statement] = STATE(687),
    [sym_continue_statement] = STATE(687),
    [sym_condition_statement] = STATE(687),
    [sym_switch_statement] = STATE(687),
    [sym_expression_statement] = STATE(687),
    [sym_return_statement] = STATE(687),
    [sym_delete_statement] = STATE(687),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [70] = {
    [sym_preproc_include] = STATE(70),
    [sym_preproc_tryinclude] = STATE(70),
    [sym_preproc_macro] = STATE(70),
    [sym_preproc_define] = STATE(70),
    [sym_preproc_undefine] = STATE(70),
    [sym_preproc_if] = STATE(70),
    [sym_preproc_elseif] = STATE(70),
    [sym_preproc_assert] = STATE(70),
    [sym_preproc_pragma] = STATE(70),
    [sym_preproc_error] = STATE(70),
    [sym_preproc_warning] = STATE(70),
    [sym_variable_declaration_statement] = STATE(683),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(683),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(683),
    [sym_for_statement] = STATE(683),
    [sym_while_statement] = STATE(683),
    [sym_do_while_statement] = STATE(683),
    [sym_break_statement] = STATE(683),
    [sym_continue_statement] = STATE(683),
    [sym_condition_statement] = STATE(683),
    [sym_switch_statement] = STATE(683),
    [sym_expression_statement] = STATE(683),
    [sym_return_statement] = STATE(683),
    [sym_delete_statement] = STATE(683),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [71] = {
    [sym_preproc_include] = STATE(71),
    [sym_preproc_tryinclude] = STATE(71),
    [sym_preproc_macro] = STATE(71),
    [sym_preproc_define] = STATE(71),
    [sym_preproc_undefine] = STATE(71),
    [sym_preproc_if] = STATE(71),
    [sym_preproc_elseif] = STATE(71),
    [sym_preproc_assert] = STATE(71),
    [sym_preproc_pragma] = STATE(71),
    [sym_preproc_error] = STATE(71),
    [sym_preproc_warning] = STATE(71),
    [sym_variable_declaration_statement] = STATE(556),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(556),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(556),
    [sym_for_statement] = STATE(556),
    [sym_while_statement] = STATE(556),
    [sym_do_while_statement] = STATE(556),
    [sym_break_statement] = STATE(556),
    [sym_continue_statement] = STATE(556),
    [sym_condition_statement] = STATE(556),
    [sym_switch_statement] = STATE(556),
    [sym_expression_statement] = STATE(556),
    [sym_return_statement] = STATE(556),
    [sym_delete_statement] = STATE(556),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [72] = {
    [sym_preproc_include] = STATE(72),
    [sym_preproc_tryinclude] = STATE(72),
    [sym_preproc_macro] = STATE(72),
    [sym_preproc_define] = STATE(72),
    [sym_preproc_undefine] = STATE(72),
    [sym_preproc_if] = STATE(72),
    [sym_preproc_elseif] = STATE(72),
    [sym_preproc_assert] = STATE(72),
    [sym_preproc_pragma] = STATE(72),
    [sym_preproc_error] = STATE(72),
    [sym_preproc_warning] = STATE(72),
    [sym_variable_declaration_statement] = STATE(561),
    [sym_variable_storage_class] = STATE(992),
    [sym_visibility] = STATE(978),
    [sym_new_expression] = STATE(195),
    [sym_old_variable_declaration_statement] = STATE(561),
    [sym_type] = STATE(1173),
    [sym_old_type] = STATE(329),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym_block] = STATE(561),
    [sym_for_statement] = STATE(561),
    [sym_while_statement] = STATE(561),
    [sym_do_while_statement] = STATE(561),
    [sym_break_statement] = STATE(561),
    [sym_continue_statement] = STATE(561),
    [sym_condition_statement] = STATE(561),
    [sym_switch_statement] = STATE(561),
    [sym_expression_statement] = STATE(561),
    [sym_return_statement] = STATE(561),
    [sym_delete_statement] = STATE(561),
    [sym__expression] = STATE(157),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(523),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(275),
    [anon_sym_decl] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(279),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(281),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_do] = ACTIONS(285),
    [anon_sym_break] = ACTIONS(287),
    [anon_sym_continue] = ACTIONS(289),
    [anon_sym_if] = ACTIONS(291),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_return] = ACTIONS(295),
    [anon_sym_delete] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [73] = {
    [sym_preproc_include] = STATE(73),
    [sym_preproc_tryinclude] = STATE(73),
    [sym_preproc_macro] = STATE(73),
    [sym_preproc_define] = STATE(73),
    [sym_preproc_undefine] = STATE(73),
    [sym_preproc_if] = STATE(73),
    [sym_preproc_elseif] = STATE(73),
    [sym_preproc_assert] = STATE(73),
    [sym_preproc_pragma] = STATE(73),
    [sym_preproc_error] = STATE(73),
    [sym_preproc_warning] = STATE(73),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(246),
    [anon_sym_BANG] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(248),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(250),
    [anon_sym_DASH_EQ] = ACTIONS(250),
    [anon_sym_STAR_EQ] = ACTIONS(250),
    [anon_sym_SLASH_EQ] = ACTIONS(250),
    [anon_sym_PIPE_EQ] = ACTIONS(250),
    [anon_sym_AMP_EQ] = ACTIONS(250),
    [anon_sym_CARET_EQ] = ACTIONS(250),
    [anon_sym_TILDE_EQ] = ACTIONS(250),
    [anon_sym_LT_LT_EQ] = ACTIONS(250),
    [anon_sym_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_LBRACK] = ACTIONS(252),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_do] = ACTIONS(244),
    [anon_sym_break] = ACTIONS(244),
    [anon_sym_continue] = ACTIONS(244),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_else] = ACTIONS(244),
    [anon_sym_switch] = ACTIONS(244),
    [anon_sym_return] = ACTIONS(244),
    [anon_sym_delete] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_PERCENT_EQ] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [anon_sym_sizeof] = ACTIONS(244),
    [anon_sym_view_as] = ACTIONS(244),
    [sym_int_literal] = ACTIONS(244),
    [sym_float_literal] = ACTIONS(246),
    [anon_sym_SQUOTE] = ACTIONS(246),
    [anon_sym_DQUOTE] = ACTIONS(246),
    [sym_bool_literal] = ACTIONS(244),
    [sym_null] = ACTIONS(244),
    [sym_this] = ACTIONS(244),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [74] = {
    [sym_preproc_include] = STATE(74),
    [sym_preproc_tryinclude] = STATE(74),
    [sym_preproc_macro] = STATE(74),
    [sym_preproc_define] = STATE(74),
    [sym_preproc_undefine] = STATE(74),
    [sym_preproc_if] = STATE(74),
    [sym_preproc_elseif] = STATE(74),
    [sym_preproc_assert] = STATE(74),
    [sym_preproc_pragma] = STATE(74),
    [sym_preproc_error] = STATE(74),
    [sym_preproc_warning] = STATE(74),
    [sym_identifier] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_BANG] = ACTIONS(325),
    [anon_sym_TILDE] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(325),
    [anon_sym_PLUS] = ACTIONS(325),
    [anon_sym_AMP] = ACTIONS(325),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(327),
    [anon_sym_STAR] = ACTIONS(325),
    [anon_sym_SLASH] = ACTIONS(325),
    [anon_sym_PERCENT] = ACTIONS(325),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(325),
    [anon_sym_CARET] = ACTIONS(325),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_GT] = ACTIONS(325),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_LT] = ACTIONS(325),
    [anon_sym_LT_LT] = ACTIONS(325),
    [anon_sym_GT_GT] = ACTIONS(325),
    [anon_sym_GT_GT_GT] = ACTIONS(325),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(327),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(325),
    [anon_sym_const] = ACTIONS(325),
    [anon_sym_public] = ACTIONS(325),
    [anon_sym_stock] = ACTIONS(325),
    [anon_sym_static] = ACTIONS(325),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_decl] = ACTIONS(325),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_SLASH_EQ] = ACTIONS(327),
    [anon_sym_PIPE_EQ] = ACTIONS(327),
    [anon_sym_AMP_EQ] = ACTIONS(327),
    [anon_sym_CARET_EQ] = ACTIONS(327),
    [anon_sym_TILDE_EQ] = ACTIONS(327),
    [anon_sym_LT_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_GT_EQ] = ACTIONS(327),
    [anon_sym_LBRACE] = ACTIONS(327),
    [anon_sym_RBRACE] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(327),
    [anon_sym_void] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_int] = ACTIONS(325),
    [anon_sym_float] = ACTIONS(325),
    [anon_sym_char] = ACTIONS(325),
    [anon_sym__] = ACTIONS(325),
    [anon_sym_Float] = ACTIONS(325),
    [anon_sym_String] = ACTIONS(325),
    [sym_any_type] = ACTIONS(325),
    [anon_sym_for] = ACTIONS(325),
    [anon_sym_while] = ACTIONS(325),
    [anon_sym_do] = ACTIONS(325),
    [anon_sym_break] = ACTIONS(325),
    [anon_sym_continue] = ACTIONS(325),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_else] = ACTIONS(325),
    [anon_sym_switch] = ACTIONS(325),
    [anon_sym_return] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(325),
    [anon_sym_SEMI] = ACTIONS(327),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(327),
    [anon_sym_PERCENT_EQ] = ACTIONS(327),
    [anon_sym_DOT] = ACTIONS(325),
    [anon_sym_QMARK] = ACTIONS(327),
    [anon_sym_DASH_DASH] = ACTIONS(327),
    [anon_sym_PLUS_PLUS] = ACTIONS(327),
    [anon_sym_sizeof] = ACTIONS(325),
    [anon_sym_view_as] = ACTIONS(325),
    [sym_int_literal] = ACTIONS(325),
    [sym_float_literal] = ACTIONS(327),
    [anon_sym_SQUOTE] = ACTIONS(327),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [sym_bool_literal] = ACTIONS(325),
    [sym_null] = ACTIONS(325),
    [sym_this] = ACTIONS(325),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(327),
  },
  [75] = {
    [sym_preproc_include] = STATE(75),
    [sym_preproc_tryinclude] = STATE(75),
    [sym_preproc_macro] = STATE(75),
    [sym_preproc_define] = STATE(75),
    [sym_preproc_undefine] = STATE(75),
    [sym_preproc_if] = STATE(75),
    [sym_preproc_elseif] = STATE(75),
    [sym_preproc_assert] = STATE(75),
    [sym_preproc_pragma] = STATE(75),
    [sym_preproc_error] = STATE(75),
    [sym_preproc_warning] = STATE(75),
    [sym_identifier] = ACTIONS(329),
    [anon_sym_LPAREN] = ACTIONS(331),
    [anon_sym_BANG] = ACTIONS(329),
    [anon_sym_TILDE] = ACTIONS(329),
    [anon_sym_DASH] = ACTIONS(329),
    [anon_sym_PLUS] = ACTIONS(329),
    [anon_sym_AMP] = ACTIONS(329),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(331),
    [anon_sym_STAR] = ACTIONS(329),
    [anon_sym_SLASH] = ACTIONS(329),
    [anon_sym_PERCENT] = ACTIONS(329),
    [anon_sym_PIPE_PIPE] = ACTIONS(331),
    [anon_sym_AMP_AMP] = ACTIONS(331),
    [anon_sym_PIPE] = ACTIONS(329),
    [anon_sym_CARET] = ACTIONS(329),
    [anon_sym_EQ_EQ] = ACTIONS(331),
    [anon_sym_BANG_EQ] = ACTIONS(331),
    [anon_sym_GT] = ACTIONS(329),
    [anon_sym_GT_EQ] = ACTIONS(331),
    [anon_sym_LT_EQ] = ACTIONS(331),
    [anon_sym_LT] = ACTIONS(329),
    [anon_sym_LT_LT] = ACTIONS(329),
    [anon_sym_GT_GT] = ACTIONS(329),
    [anon_sym_GT_GT_GT] = ACTIONS(329),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(331),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(329),
    [anon_sym_const] = ACTIONS(329),
    [anon_sym_public] = ACTIONS(329),
    [anon_sym_stock] = ACTIONS(329),
    [anon_sym_static] = ACTIONS(329),
    [anon_sym_new] = ACTIONS(329),
    [anon_sym_decl] = ACTIONS(329),
    [anon_sym_PLUS_EQ] = ACTIONS(331),
    [anon_sym_DASH_EQ] = ACTIONS(331),
    [anon_sym_STAR_EQ] = ACTIONS(331),
    [anon_sym_SLASH_EQ] = ACTIONS(331),
    [anon_sym_PIPE_EQ] = ACTIONS(331),
    [anon_sym_AMP_EQ] = ACTIONS(331),
    [anon_sym_CARET_EQ] = ACTIONS(331),
    [anon_sym_TILDE_EQ] = ACTIONS(331),
    [anon_sym_LT_LT_EQ] = ACTIONS(331),
    [anon_sym_GT_GT_EQ] = ACTIONS(331),
    [anon_sym_LBRACE] = ACTIONS(331),
    [anon_sym_RBRACE] = ACTIONS(331),
    [anon_sym_LBRACK] = ACTIONS(331),
    [anon_sym_void] = ACTIONS(329),
    [anon_sym_bool] = ACTIONS(329),
    [anon_sym_int] = ACTIONS(329),
    [anon_sym_float] = ACTIONS(329),
    [anon_sym_char] = ACTIONS(329),
    [anon_sym__] = ACTIONS(329),
    [anon_sym_Float] = ACTIONS(329),
    [anon_sym_String] = ACTIONS(329),
    [sym_any_type] = ACTIONS(329),
    [anon_sym_for] = ACTIONS(329),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(329),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(329),
    [anon_sym_if] = ACTIONS(329),
    [anon_sym_else] = ACTIONS(329),
    [anon_sym_switch] = ACTIONS(329),
    [anon_sym_return] = ACTIONS(329),
    [anon_sym_delete] = ACTIONS(329),
    [anon_sym_SEMI] = ACTIONS(331),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(331),
    [anon_sym_PERCENT_EQ] = ACTIONS(331),
    [anon_sym_DOT] = ACTIONS(329),
    [anon_sym_QMARK] = ACTIONS(331),
    [anon_sym_DASH_DASH] = ACTIONS(331),
    [anon_sym_PLUS_PLUS] = ACTIONS(331),
    [anon_sym_sizeof] = ACTIONS(329),
    [anon_sym_view_as] = ACTIONS(329),
    [sym_int_literal] = ACTIONS(329),
    [sym_float_literal] = ACTIONS(331),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_DQUOTE] = ACTIONS(331),
    [sym_bool_literal] = ACTIONS(329),
    [sym_null] = ACTIONS(329),
    [sym_this] = ACTIONS(329),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(331),
  },
  [76] = {
    [sym_preproc_include] = STATE(76),
    [sym_preproc_tryinclude] = STATE(76),
    [sym_preproc_macro] = STATE(76),
    [sym_preproc_define] = STATE(76),
    [sym_preproc_undefine] = STATE(76),
    [sym_preproc_if] = STATE(76),
    [sym_preproc_elseif] = STATE(76),
    [sym_preproc_assert] = STATE(76),
    [sym_preproc_pragma] = STATE(76),
    [sym_preproc_error] = STATE(76),
    [sym_preproc_warning] = STATE(76),
    [sym_dimension] = STATE(165),
    [sym_call_arguments] = STATE(169),
    [aux_sym_function_definition_repeat1] = STATE(154),
    [ts_builtin_sym_end] = ACTIONS(127),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_LPAREN] = ACTIONS(333),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(127),
    [anon_sym_assert] = ACTIONS(123),
    [anon_sym_static_assert] = ACTIONS(123),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_forward] = ACTIONS(123),
    [anon_sym_native] = ACTIONS(123),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_const] = ACTIONS(123),
    [anon_sym_public] = ACTIONS(123),
    [anon_sym_stock] = ACTIONS(123),
    [anon_sym_static] = ACTIONS(123),
    [anon_sym_new] = ACTIONS(123),
    [anon_sym_decl] = ACTIONS(123),
    [anon_sym_enum] = ACTIONS(123),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_struct] = ACTIONS(123),
    [anon_sym_typedef] = ACTIONS(123),
    [anon_sym_typeset] = ACTIONS(123),
    [anon_sym_funcenum] = ACTIONS(123),
    [anon_sym_functag] = ACTIONS(123),
    [anon_sym_methodmap] = ACTIONS(123),
    [anon_sym_LBRACK] = ACTIONS(335),
    [anon_sym_void] = ACTIONS(123),
    [anon_sym_bool] = ACTIONS(123),
    [anon_sym_int] = ACTIONS(123),
    [anon_sym_float] = ACTIONS(123),
    [anon_sym_char] = ACTIONS(123),
    [anon_sym__] = ACTIONS(123),
    [anon_sym_Float] = ACTIONS(123),
    [anon_sym_String] = ACTIONS(123),
    [sym_any_type] = ACTIONS(123),
    [anon_sym_while] = ACTIONS(123),
    [anon_sym_else] = ACTIONS(123),
    [anon_sym_case] = ACTIONS(123),
    [anon_sym_default] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_COLON_COLON] = ACTIONS(337),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(127),
  },
  [77] = {
    [sym_preproc_include] = STATE(77),
    [sym_preproc_tryinclude] = STATE(77),
    [sym_preproc_macro] = STATE(77),
    [sym_preproc_define] = STATE(77),
    [sym_preproc_undefine] = STATE(77),
    [sym_preproc_if] = STATE(77),
    [sym_preproc_elseif] = STATE(77),
    [sym_preproc_assert] = STATE(77),
    [sym_preproc_pragma] = STATE(77),
    [sym_preproc_error] = STATE(77),
    [sym_preproc_warning] = STATE(77),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(246),
    [anon_sym_BANG] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(248),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(250),
    [anon_sym_DASH_EQ] = ACTIONS(250),
    [anon_sym_STAR_EQ] = ACTIONS(250),
    [anon_sym_SLASH_EQ] = ACTIONS(250),
    [anon_sym_PIPE_EQ] = ACTIONS(250),
    [anon_sym_AMP_EQ] = ACTIONS(250),
    [anon_sym_CARET_EQ] = ACTIONS(250),
    [anon_sym_TILDE_EQ] = ACTIONS(250),
    [anon_sym_LT_LT_EQ] = ACTIONS(250),
    [anon_sym_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_do] = ACTIONS(244),
    [anon_sym_break] = ACTIONS(244),
    [anon_sym_continue] = ACTIONS(244),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_else] = ACTIONS(244),
    [anon_sym_switch] = ACTIONS(244),
    [anon_sym_return] = ACTIONS(244),
    [anon_sym_delete] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_PERCENT_EQ] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [anon_sym_sizeof] = ACTIONS(244),
    [anon_sym_view_as] = ACTIONS(244),
    [sym_int_literal] = ACTIONS(244),
    [sym_float_literal] = ACTIONS(246),
    [anon_sym_SQUOTE] = ACTIONS(246),
    [anon_sym_DQUOTE] = ACTIONS(246),
    [sym_bool_literal] = ACTIONS(244),
    [sym_null] = ACTIONS(244),
    [sym_this] = ACTIONS(244),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [78] = {
    [sym_preproc_include] = STATE(78),
    [sym_preproc_tryinclude] = STATE(78),
    [sym_preproc_macro] = STATE(78),
    [sym_preproc_define] = STATE(78),
    [sym_preproc_undefine] = STATE(78),
    [sym_preproc_if] = STATE(78),
    [sym_preproc_elseif] = STATE(78),
    [sym_preproc_assert] = STATE(78),
    [sym_preproc_pragma] = STATE(78),
    [sym_preproc_error] = STATE(78),
    [sym_preproc_warning] = STATE(78),
    [aux_sym_array_literal_repeat1] = STATE(1267),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(246),
    [anon_sym_BANG] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(339),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(248),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(250),
    [anon_sym_DASH_EQ] = ACTIONS(250),
    [anon_sym_STAR_EQ] = ACTIONS(250),
    [anon_sym_SLASH_EQ] = ACTIONS(250),
    [anon_sym_PIPE_EQ] = ACTIONS(250),
    [anon_sym_AMP_EQ] = ACTIONS(250),
    [anon_sym_CARET_EQ] = ACTIONS(250),
    [anon_sym_TILDE_EQ] = ACTIONS(250),
    [anon_sym_LT_LT_EQ] = ACTIONS(250),
    [anon_sym_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_RBRACE] = ACTIONS(341),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_do] = ACTIONS(244),
    [anon_sym_break] = ACTIONS(244),
    [anon_sym_continue] = ACTIONS(244),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_switch] = ACTIONS(244),
    [anon_sym_return] = ACTIONS(244),
    [anon_sym_delete] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_PERCENT_EQ] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [anon_sym_sizeof] = ACTIONS(244),
    [anon_sym_view_as] = ACTIONS(244),
    [sym_int_literal] = ACTIONS(244),
    [sym_float_literal] = ACTIONS(246),
    [anon_sym_SQUOTE] = ACTIONS(246),
    [anon_sym_DQUOTE] = ACTIONS(246),
    [sym_bool_literal] = ACTIONS(244),
    [sym_null] = ACTIONS(244),
    [sym_this] = ACTIONS(244),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [79] = {
    [sym_preproc_include] = STATE(79),
    [sym_preproc_tryinclude] = STATE(79),
    [sym_preproc_macro] = STATE(79),
    [sym_preproc_define] = STATE(79),
    [sym_preproc_undefine] = STATE(79),
    [sym_preproc_if] = STATE(79),
    [sym_preproc_elseif] = STATE(79),
    [sym_preproc_assert] = STATE(79),
    [sym_preproc_pragma] = STATE(79),
    [sym_preproc_error] = STATE(79),
    [sym_preproc_warning] = STATE(79),
    [aux_sym_array_literal_repeat1] = STATE(1308),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(246),
    [anon_sym_BANG] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(343),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(248),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(250),
    [anon_sym_DASH_EQ] = ACTIONS(250),
    [anon_sym_STAR_EQ] = ACTIONS(250),
    [anon_sym_SLASH_EQ] = ACTIONS(250),
    [anon_sym_PIPE_EQ] = ACTIONS(250),
    [anon_sym_AMP_EQ] = ACTIONS(250),
    [anon_sym_CARET_EQ] = ACTIONS(250),
    [anon_sym_TILDE_EQ] = ACTIONS(250),
    [anon_sym_LT_LT_EQ] = ACTIONS(250),
    [anon_sym_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_RBRACE] = ACTIONS(345),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_do] = ACTIONS(244),
    [anon_sym_break] = ACTIONS(244),
    [anon_sym_continue] = ACTIONS(244),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_switch] = ACTIONS(244),
    [anon_sym_return] = ACTIONS(244),
    [anon_sym_delete] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(250),
    [anon_sym_PERCENT_EQ] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [anon_sym_sizeof] = ACTIONS(244),
    [anon_sym_view_as] = ACTIONS(244),
    [sym_int_literal] = ACTIONS(244),
    [sym_float_literal] = ACTIONS(246),
    [anon_sym_SQUOTE] = ACTIONS(246),
    [anon_sym_DQUOTE] = ACTIONS(246),
    [sym_bool_literal] = ACTIONS(244),
    [sym_null] = ACTIONS(244),
    [sym_this] = ACTIONS(244),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [80] = {
    [sym_preproc_include] = STATE(80),
    [sym_preproc_tryinclude] = STATE(80),
    [sym_preproc_macro] = STATE(80),
    [sym_preproc_define] = STATE(80),
    [sym_preproc_undefine] = STATE(80),
    [sym_preproc_if] = STATE(80),
    [sym_preproc_elseif] = STATE(80),
    [sym_preproc_assert] = STATE(80),
    [sym_preproc_pragma] = STATE(80),
    [sym_preproc_error] = STATE(80),
    [sym_preproc_warning] = STATE(80),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LPAREN] = ACTIONS(349),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_TILDE] = ACTIONS(347),
    [anon_sym_DASH] = ACTIONS(347),
    [anon_sym_PLUS] = ACTIONS(347),
    [anon_sym_AMP] = ACTIONS(347),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(349),
    [anon_sym_STAR] = ACTIONS(347),
    [anon_sym_SLASH] = ACTIONS(347),
    [anon_sym_PERCENT] = ACTIONS(347),
    [anon_sym_PIPE_PIPE] = ACTIONS(349),
    [anon_sym_AMP_AMP] = ACTIONS(349),
    [anon_sym_PIPE] = ACTIONS(347),
    [anon_sym_CARET] = ACTIONS(347),
    [anon_sym_EQ_EQ] = ACTIONS(349),
    [anon_sym_BANG_EQ] = ACTIONS(349),
    [anon_sym_GT] = ACTIONS(347),
    [anon_sym_GT_EQ] = ACTIONS(349),
    [anon_sym_LT_EQ] = ACTIONS(349),
    [anon_sym_LT] = ACTIONS(347),
    [anon_sym_LT_LT] = ACTIONS(347),
    [anon_sym_GT_GT] = ACTIONS(347),
    [anon_sym_GT_GT_GT] = ACTIONS(347),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(349),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(347),
    [anon_sym_const] = ACTIONS(347),
    [anon_sym_public] = ACTIONS(347),
    [anon_sym_stock] = ACTIONS(347),
    [anon_sym_static] = ACTIONS(347),
    [anon_sym_new] = ACTIONS(347),
    [anon_sym_decl] = ACTIONS(347),
    [anon_sym_PLUS_EQ] = ACTIONS(349),
    [anon_sym_DASH_EQ] = ACTIONS(349),
    [anon_sym_STAR_EQ] = ACTIONS(349),
    [anon_sym_SLASH_EQ] = ACTIONS(349),
    [anon_sym_PIPE_EQ] = ACTIONS(349),
    [anon_sym_AMP_EQ] = ACTIONS(349),
    [anon_sym_CARET_EQ] = ACTIONS(349),
    [anon_sym_TILDE_EQ] = ACTIONS(349),
    [anon_sym_LT_LT_EQ] = ACTIONS(349),
    [anon_sym_GT_GT_EQ] = ACTIONS(349),
    [anon_sym_LBRACE] = ACTIONS(349),
    [anon_sym_RBRACE] = ACTIONS(349),
    [anon_sym_void] = ACTIONS(347),
    [anon_sym_bool] = ACTIONS(347),
    [anon_sym_int] = ACTIONS(347),
    [anon_sym_float] = ACTIONS(347),
    [anon_sym_char] = ACTIONS(347),
    [anon_sym__] = ACTIONS(347),
    [anon_sym_Float] = ACTIONS(347),
    [anon_sym_String] = ACTIONS(347),
    [sym_any_type] = ACTIONS(347),
    [anon_sym_for] = ACTIONS(347),
    [anon_sym_while] = ACTIONS(347),
    [anon_sym_do] = ACTIONS(347),
    [anon_sym_break] = ACTIONS(347),
    [anon_sym_continue] = ACTIONS(347),
    [anon_sym_if] = ACTIONS(347),
    [anon_sym_else] = ACTIONS(347),
    [anon_sym_switch] = ACTIONS(347),
    [anon_sym_return] = ACTIONS(347),
    [anon_sym_delete] = ACTIONS(347),
    [anon_sym_SEMI] = ACTIONS(349),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(349),
    [anon_sym_PERCENT_EQ] = ACTIONS(349),
    [anon_sym_DOT] = ACTIONS(347),
    [anon_sym_QMARK] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_sizeof] = ACTIONS(347),
    [anon_sym_view_as] = ACTIONS(347),
    [sym_int_literal] = ACTIONS(347),
    [sym_float_literal] = ACTIONS(349),
    [anon_sym_SQUOTE] = ACTIONS(349),
    [anon_sym_DQUOTE] = ACTIONS(349),
    [sym_bool_literal] = ACTIONS(347),
    [sym_null] = ACTIONS(347),
    [sym_this] = ACTIONS(347),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(349),
  },
  [81] = {
    [sym_preproc_include] = STATE(81),
    [sym_preproc_tryinclude] = STATE(81),
    [sym_preproc_macro] = STATE(81),
    [sym_preproc_define] = STATE(81),
    [sym_preproc_undefine] = STATE(81),
    [sym_preproc_if] = STATE(81),
    [sym_preproc_elseif] = STATE(81),
    [sym_preproc_assert] = STATE(81),
    [sym_preproc_pragma] = STATE(81),
    [sym_preproc_error] = STATE(81),
    [sym_preproc_warning] = STATE(81),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_BANG] = ACTIONS(123),
    [anon_sym_TILDE] = ACTIONS(123),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_const] = ACTIONS(123),
    [anon_sym_public] = ACTIONS(123),
    [anon_sym_stock] = ACTIONS(123),
    [anon_sym_static] = ACTIONS(123),
    [anon_sym_new] = ACTIONS(123),
    [anon_sym_decl] = ACTIONS(123),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_void] = ACTIONS(123),
    [anon_sym_bool] = ACTIONS(123),
    [anon_sym_int] = ACTIONS(123),
    [anon_sym_float] = ACTIONS(123),
    [anon_sym_char] = ACTIONS(123),
    [anon_sym__] = ACTIONS(123),
    [anon_sym_Float] = ACTIONS(123),
    [anon_sym_String] = ACTIONS(123),
    [sym_any_type] = ACTIONS(123),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_while] = ACTIONS(123),
    [anon_sym_do] = ACTIONS(123),
    [anon_sym_break] = ACTIONS(123),
    [anon_sym_continue] = ACTIONS(123),
    [anon_sym_if] = ACTIONS(123),
    [anon_sym_else] = ACTIONS(123),
    [anon_sym_switch] = ACTIONS(123),
    [anon_sym_return] = ACTIONS(123),
    [anon_sym_delete] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(123),
    [anon_sym_view_as] = ACTIONS(123),
    [sym_int_literal] = ACTIONS(123),
    [sym_float_literal] = ACTIONS(127),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DQUOTE] = ACTIONS(127),
    [sym_bool_literal] = ACTIONS(123),
    [sym_null] = ACTIONS(123),
    [sym_this] = ACTIONS(123),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(127),
  },
  [82] = {
    [sym_preproc_include] = STATE(82),
    [sym_preproc_tryinclude] = STATE(82),
    [sym_preproc_macro] = STATE(82),
    [sym_preproc_define] = STATE(82),
    [sym_preproc_undefine] = STATE(82),
    [sym_preproc_if] = STATE(82),
    [sym_preproc_elseif] = STATE(82),
    [sym_preproc_assert] = STATE(82),
    [sym_preproc_pragma] = STATE(82),
    [sym_preproc_error] = STATE(82),
    [sym_preproc_warning] = STATE(82),
    [sym_identifier] = ACTIONS(351),
    [anon_sym_LPAREN] = ACTIONS(353),
    [anon_sym_BANG] = ACTIONS(351),
    [anon_sym_TILDE] = ACTIONS(351),
    [anon_sym_DASH] = ACTIONS(351),
    [anon_sym_PLUS] = ACTIONS(351),
    [anon_sym_AMP] = ACTIONS(351),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(353),
    [anon_sym_STAR] = ACTIONS(351),
    [anon_sym_SLASH] = ACTIONS(351),
    [anon_sym_PERCENT] = ACTIONS(351),
    [anon_sym_PIPE_PIPE] = ACTIONS(353),
    [anon_sym_AMP_AMP] = ACTIONS(353),
    [anon_sym_PIPE] = ACTIONS(351),
    [anon_sym_CARET] = ACTIONS(351),
    [anon_sym_EQ_EQ] = ACTIONS(353),
    [anon_sym_BANG_EQ] = ACTIONS(353),
    [anon_sym_GT] = ACTIONS(351),
    [anon_sym_GT_EQ] = ACTIONS(353),
    [anon_sym_LT_EQ] = ACTIONS(353),
    [anon_sym_LT] = ACTIONS(351),
    [anon_sym_LT_LT] = ACTIONS(351),
    [anon_sym_GT_GT] = ACTIONS(351),
    [anon_sym_GT_GT_GT] = ACTIONS(351),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(353),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(351),
    [anon_sym_const] = ACTIONS(351),
    [anon_sym_public] = ACTIONS(351),
    [anon_sym_stock] = ACTIONS(351),
    [anon_sym_static] = ACTIONS(351),
    [anon_sym_new] = ACTIONS(351),
    [anon_sym_decl] = ACTIONS(351),
    [anon_sym_PLUS_EQ] = ACTIONS(353),
    [anon_sym_DASH_EQ] = ACTIONS(353),
    [anon_sym_STAR_EQ] = ACTIONS(353),
    [anon_sym_SLASH_EQ] = ACTIONS(353),
    [anon_sym_PIPE_EQ] = ACTIONS(353),
    [anon_sym_AMP_EQ] = ACTIONS(353),
    [anon_sym_CARET_EQ] = ACTIONS(353),
    [anon_sym_TILDE_EQ] = ACTIONS(353),
    [anon_sym_LT_LT_EQ] = ACTIONS(353),
    [anon_sym_GT_GT_EQ] = ACTIONS(353),
    [anon_sym_LBRACE] = ACTIONS(353),
    [anon_sym_RBRACE] = ACTIONS(353),
    [anon_sym_void] = ACTIONS(351),
    [anon_sym_bool] = ACTIONS(351),
    [anon_sym_int] = ACTIONS(351),
    [anon_sym_float] = ACTIONS(351),
    [anon_sym_char] = ACTIONS(351),
    [anon_sym__] = ACTIONS(351),
    [anon_sym_Float] = ACTIONS(351),
    [anon_sym_String] = ACTIONS(351),
    [sym_any_type] = ACTIONS(351),
    [anon_sym_for] = ACTIONS(351),
    [anon_sym_while] = ACTIONS(351),
    [anon_sym_do] = ACTIONS(351),
    [anon_sym_break] = ACTIONS(351),
    [anon_sym_continue] = ACTIONS(351),
    [anon_sym_if] = ACTIONS(351),
    [anon_sym_else] = ACTIONS(351),
    [anon_sym_switch] = ACTIONS(351),
    [anon_sym_return] = ACTIONS(351),
    [anon_sym_delete] = ACTIONS(351),
    [anon_sym_SEMI] = ACTIONS(353),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(353),
    [anon_sym_PERCENT_EQ] = ACTIONS(353),
    [anon_sym_DOT] = ACTIONS(351),
    [anon_sym_QMARK] = ACTIONS(353),
    [anon_sym_DASH_DASH] = ACTIONS(353),
    [anon_sym_PLUS_PLUS] = ACTIONS(353),
    [anon_sym_sizeof] = ACTIONS(351),
    [anon_sym_view_as] = ACTIONS(351),
    [sym_int_literal] = ACTIONS(351),
    [sym_float_literal] = ACTIONS(353),
    [anon_sym_SQUOTE] = ACTIONS(353),
    [anon_sym_DQUOTE] = ACTIONS(353),
    [sym_bool_literal] = ACTIONS(351),
    [sym_null] = ACTIONS(351),
    [sym_this] = ACTIONS(351),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(353),
  },
  [83] = {
    [sym_preproc_include] = STATE(83),
    [sym_preproc_tryinclude] = STATE(83),
    [sym_preproc_macro] = STATE(83),
    [sym_preproc_define] = STATE(83),
    [sym_preproc_undefine] = STATE(83),
    [sym_preproc_if] = STATE(83),
    [sym_preproc_elseif] = STATE(83),
    [sym_preproc_assert] = STATE(83),
    [sym_preproc_pragma] = STATE(83),
    [sym_preproc_error] = STATE(83),
    [sym_preproc_warning] = STATE(83),
    [sym_call_arguments] = STATE(169),
    [ts_builtin_sym_end] = ACTIONS(246),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(333),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(244),
    [anon_sym_static_assert] = ACTIONS(244),
    [anon_sym_EQ] = ACTIONS(355),
    [anon_sym_forward] = ACTIONS(244),
    [anon_sym_native] = ACTIONS(244),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_enum] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(357),
    [anon_sym_DASH_EQ] = ACTIONS(357),
    [anon_sym_STAR_EQ] = ACTIONS(357),
    [anon_sym_SLASH_EQ] = ACTIONS(357),
    [anon_sym_PIPE_EQ] = ACTIONS(357),
    [anon_sym_AMP_EQ] = ACTIONS(357),
    [anon_sym_CARET_EQ] = ACTIONS(357),
    [anon_sym_TILDE_EQ] = ACTIONS(357),
    [anon_sym_LT_LT_EQ] = ACTIONS(357),
    [anon_sym_GT_GT_EQ] = ACTIONS(357),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_struct] = ACTIONS(244),
    [anon_sym_typedef] = ACTIONS(244),
    [anon_sym_typeset] = ACTIONS(244),
    [anon_sym_funcenum] = ACTIONS(244),
    [anon_sym_functag] = ACTIONS(244),
    [anon_sym_methodmap] = ACTIONS(244),
    [anon_sym_LBRACK] = ACTIONS(359),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_else] = ACTIONS(244),
    [anon_sym_case] = ACTIONS(244),
    [anon_sym_default] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(357),
    [anon_sym_PERCENT_EQ] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_COLON_COLON] = ACTIONS(337),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [84] = {
    [sym_preproc_include] = STATE(84),
    [sym_preproc_tryinclude] = STATE(84),
    [sym_preproc_macro] = STATE(84),
    [sym_preproc_define] = STATE(84),
    [sym_preproc_undefine] = STATE(84),
    [sym_preproc_if] = STATE(84),
    [sym_preproc_elseif] = STATE(84),
    [sym_preproc_assert] = STATE(84),
    [sym_preproc_pragma] = STATE(84),
    [sym_preproc_error] = STATE(84),
    [sym_preproc_warning] = STATE(84),
    [sym_call_arguments] = STATE(169),
    [ts_builtin_sym_end] = ACTIONS(246),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(333),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(244),
    [anon_sym_static_assert] = ACTIONS(244),
    [anon_sym_EQ] = ACTIONS(355),
    [anon_sym_forward] = ACTIONS(244),
    [anon_sym_native] = ACTIONS(244),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_enum] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(357),
    [anon_sym_DASH_EQ] = ACTIONS(357),
    [anon_sym_STAR_EQ] = ACTIONS(357),
    [anon_sym_SLASH_EQ] = ACTIONS(357),
    [anon_sym_PIPE_EQ] = ACTIONS(357),
    [anon_sym_AMP_EQ] = ACTIONS(357),
    [anon_sym_CARET_EQ] = ACTIONS(357),
    [anon_sym_TILDE_EQ] = ACTIONS(357),
    [anon_sym_LT_LT_EQ] = ACTIONS(357),
    [anon_sym_GT_GT_EQ] = ACTIONS(357),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_struct] = ACTIONS(244),
    [anon_sym_typedef] = ACTIONS(244),
    [anon_sym_typeset] = ACTIONS(244),
    [anon_sym_funcenum] = ACTIONS(244),
    [anon_sym_functag] = ACTIONS(244),
    [anon_sym_methodmap] = ACTIONS(244),
    [anon_sym_LBRACK] = ACTIONS(359),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_else] = ACTIONS(244),
    [anon_sym_case] = ACTIONS(244),
    [anon_sym_default] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(357),
    [anon_sym_PERCENT_EQ] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [85] = {
    [sym_preproc_include] = STATE(85),
    [sym_preproc_tryinclude] = STATE(85),
    [sym_preproc_macro] = STATE(85),
    [sym_preproc_define] = STATE(85),
    [sym_preproc_undefine] = STATE(85),
    [sym_preproc_if] = STATE(85),
    [sym_preproc_elseif] = STATE(85),
    [sym_preproc_assert] = STATE(85),
    [sym_preproc_pragma] = STATE(85),
    [sym_preproc_error] = STATE(85),
    [sym_preproc_warning] = STATE(85),
    [sym_dimension] = STATE(165),
    [aux_sym_function_definition_repeat1] = STATE(152),
    [ts_builtin_sym_end] = ACTIONS(127),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(127),
    [anon_sym_assert] = ACTIONS(123),
    [anon_sym_static_assert] = ACTIONS(123),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_forward] = ACTIONS(123),
    [anon_sym_native] = ACTIONS(123),
    [anon_sym_const] = ACTIONS(123),
    [anon_sym_public] = ACTIONS(123),
    [anon_sym_stock] = ACTIONS(123),
    [anon_sym_static] = ACTIONS(123),
    [anon_sym_new] = ACTIONS(123),
    [anon_sym_decl] = ACTIONS(123),
    [anon_sym_enum] = ACTIONS(123),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_struct] = ACTIONS(123),
    [anon_sym_typedef] = ACTIONS(123),
    [anon_sym_typeset] = ACTIONS(123),
    [anon_sym_funcenum] = ACTIONS(123),
    [anon_sym_functag] = ACTIONS(123),
    [anon_sym_methodmap] = ACTIONS(123),
    [anon_sym_LBRACK] = ACTIONS(335),
    [anon_sym_void] = ACTIONS(123),
    [anon_sym_bool] = ACTIONS(123),
    [anon_sym_int] = ACTIONS(123),
    [anon_sym_float] = ACTIONS(123),
    [anon_sym_char] = ACTIONS(123),
    [anon_sym__] = ACTIONS(123),
    [anon_sym_Float] = ACTIONS(123),
    [anon_sym_String] = ACTIONS(123),
    [sym_any_type] = ACTIONS(123),
    [anon_sym_while] = ACTIONS(123),
    [anon_sym_else] = ACTIONS(123),
    [anon_sym_case] = ACTIONS(123),
    [anon_sym_default] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(127),
  },
  [86] = {
    [sym_preproc_include] = STATE(86),
    [sym_preproc_tryinclude] = STATE(86),
    [sym_preproc_macro] = STATE(86),
    [sym_preproc_define] = STATE(86),
    [sym_preproc_undefine] = STATE(86),
    [sym_preproc_if] = STATE(86),
    [sym_preproc_elseif] = STATE(86),
    [sym_preproc_assert] = STATE(86),
    [sym_preproc_pragma] = STATE(86),
    [sym_preproc_error] = STATE(86),
    [sym_preproc_warning] = STATE(86),
    [sym_call_arguments] = STATE(169),
    [ts_builtin_sym_end] = ACTIONS(127),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_LPAREN] = ACTIONS(333),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(127),
    [anon_sym_assert] = ACTIONS(123),
    [anon_sym_static_assert] = ACTIONS(123),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_forward] = ACTIONS(123),
    [anon_sym_native] = ACTIONS(123),
    [anon_sym_const] = ACTIONS(123),
    [anon_sym_public] = ACTIONS(123),
    [anon_sym_stock] = ACTIONS(123),
    [anon_sym_static] = ACTIONS(123),
    [anon_sym_new] = ACTIONS(123),
    [anon_sym_decl] = ACTIONS(123),
    [anon_sym_enum] = ACTIONS(123),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_struct] = ACTIONS(123),
    [anon_sym_typedef] = ACTIONS(123),
    [anon_sym_typeset] = ACTIONS(123),
    [anon_sym_funcenum] = ACTIONS(123),
    [anon_sym_functag] = ACTIONS(123),
    [anon_sym_methodmap] = ACTIONS(123),
    [anon_sym_LBRACK] = ACTIONS(359),
    [anon_sym_void] = ACTIONS(123),
    [anon_sym_bool] = ACTIONS(123),
    [anon_sym_int] = ACTIONS(123),
    [anon_sym_float] = ACTIONS(123),
    [anon_sym_char] = ACTIONS(123),
    [anon_sym__] = ACTIONS(123),
    [anon_sym_Float] = ACTIONS(123),
    [anon_sym_String] = ACTIONS(123),
    [sym_any_type] = ACTIONS(123),
    [anon_sym_while] = ACTIONS(123),
    [anon_sym_else] = ACTIONS(123),
    [anon_sym_case] = ACTIONS(123),
    [anon_sym_default] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(127),
  },
  [87] = {
    [sym_preproc_include] = STATE(87),
    [sym_preproc_tryinclude] = STATE(87),
    [sym_preproc_macro] = STATE(87),
    [sym_preproc_define] = STATE(87),
    [sym_preproc_undefine] = STATE(87),
    [sym_preproc_if] = STATE(87),
    [sym_preproc_elseif] = STATE(87),
    [sym_preproc_assert] = STATE(87),
    [sym_preproc_pragma] = STATE(87),
    [sym_preproc_error] = STATE(87),
    [sym_preproc_warning] = STATE(87),
    [ts_builtin_sym_end] = ACTIONS(327),
    [sym_identifier] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_DASH] = ACTIONS(325),
    [anon_sym_PLUS] = ACTIONS(325),
    [anon_sym_AMP] = ACTIONS(325),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(327),
    [anon_sym_STAR] = ACTIONS(325),
    [anon_sym_SLASH] = ACTIONS(325),
    [anon_sym_PERCENT] = ACTIONS(325),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(325),
    [anon_sym_CARET] = ACTIONS(325),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_GT] = ACTIONS(325),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_LT] = ACTIONS(325),
    [anon_sym_LT_LT] = ACTIONS(325),
    [anon_sym_GT_GT] = ACTIONS(325),
    [anon_sym_GT_GT_GT] = ACTIONS(325),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(327),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(327),
    [anon_sym_assert] = ACTIONS(325),
    [anon_sym_static_assert] = ACTIONS(325),
    [anon_sym_EQ] = ACTIONS(325),
    [anon_sym_forward] = ACTIONS(325),
    [anon_sym_native] = ACTIONS(325),
    [anon_sym_const] = ACTIONS(325),
    [anon_sym_public] = ACTIONS(325),
    [anon_sym_stock] = ACTIONS(325),
    [anon_sym_static] = ACTIONS(325),
    [anon_sym_new] = ACTIONS(325),
    [anon_sym_decl] = ACTIONS(325),
    [anon_sym_enum] = ACTIONS(325),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_SLASH_EQ] = ACTIONS(327),
    [anon_sym_PIPE_EQ] = ACTIONS(327),
    [anon_sym_AMP_EQ] = ACTIONS(327),
    [anon_sym_CARET_EQ] = ACTIONS(327),
    [anon_sym_TILDE_EQ] = ACTIONS(327),
    [anon_sym_LT_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_GT_EQ] = ACTIONS(327),
    [anon_sym_RBRACE] = ACTIONS(327),
    [anon_sym_struct] = ACTIONS(325),
    [anon_sym_typedef] = ACTIONS(325),
    [anon_sym_typeset] = ACTIONS(325),
    [anon_sym_funcenum] = ACTIONS(325),
    [anon_sym_functag] = ACTIONS(325),
    [anon_sym_methodmap] = ACTIONS(325),
    [anon_sym_LBRACK] = ACTIONS(327),
    [anon_sym_void] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_int] = ACTIONS(325),
    [anon_sym_float] = ACTIONS(325),
    [anon_sym_char] = ACTIONS(325),
    [anon_sym__] = ACTIONS(325),
    [anon_sym_Float] = ACTIONS(325),
    [anon_sym_String] = ACTIONS(325),
    [sym_any_type] = ACTIONS(325),
    [anon_sym_while] = ACTIONS(325),
    [anon_sym_else] = ACTIONS(325),
    [anon_sym_case] = ACTIONS(325),
    [anon_sym_default] = ACTIONS(325),
    [anon_sym_SEMI] = ACTIONS(327),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(327),
    [anon_sym_PERCENT_EQ] = ACTIONS(327),
    [anon_sym_DOT] = ACTIONS(325),
    [anon_sym_QMARK] = ACTIONS(327),
    [anon_sym_DASH_DASH] = ACTIONS(327),
    [anon_sym_PLUS_PLUS] = ACTIONS(327),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(327),
  },
  [88] = {
    [sym_preproc_include] = STATE(88),
    [sym_preproc_tryinclude] = STATE(88),
    [sym_preproc_macro] = STATE(88),
    [sym_preproc_define] = STATE(88),
    [sym_preproc_undefine] = STATE(88),
    [sym_preproc_if] = STATE(88),
    [sym_preproc_elseif] = STATE(88),
    [sym_preproc_assert] = STATE(88),
    [sym_preproc_pragma] = STATE(88),
    [sym_preproc_error] = STATE(88),
    [sym_preproc_warning] = STATE(88),
    [ts_builtin_sym_end] = ACTIONS(246),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(244),
    [anon_sym_static_assert] = ACTIONS(244),
    [anon_sym_EQ] = ACTIONS(355),
    [anon_sym_forward] = ACTIONS(244),
    [anon_sym_native] = ACTIONS(244),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_enum] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(357),
    [anon_sym_DASH_EQ] = ACTIONS(357),
    [anon_sym_STAR_EQ] = ACTIONS(357),
    [anon_sym_SLASH_EQ] = ACTIONS(357),
    [anon_sym_PIPE_EQ] = ACTIONS(357),
    [anon_sym_AMP_EQ] = ACTIONS(357),
    [anon_sym_CARET_EQ] = ACTIONS(357),
    [anon_sym_TILDE_EQ] = ACTIONS(357),
    [anon_sym_LT_LT_EQ] = ACTIONS(357),
    [anon_sym_GT_GT_EQ] = ACTIONS(357),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_struct] = ACTIONS(244),
    [anon_sym_typedef] = ACTIONS(244),
    [anon_sym_typeset] = ACTIONS(244),
    [anon_sym_funcenum] = ACTIONS(244),
    [anon_sym_functag] = ACTIONS(244),
    [anon_sym_methodmap] = ACTIONS(244),
    [anon_sym_LBRACK] = ACTIONS(359),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_else] = ACTIONS(244),
    [anon_sym_case] = ACTIONS(244),
    [anon_sym_default] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(357),
    [anon_sym_PERCENT_EQ] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [89] = {
    [sym_preproc_include] = STATE(89),
    [sym_preproc_tryinclude] = STATE(89),
    [sym_preproc_macro] = STATE(89),
    [sym_preproc_define] = STATE(89),
    [sym_preproc_undefine] = STATE(89),
    [sym_preproc_if] = STATE(89),
    [sym_preproc_elseif] = STATE(89),
    [sym_preproc_assert] = STATE(89),
    [sym_preproc_pragma] = STATE(89),
    [sym_preproc_error] = STATE(89),
    [sym_preproc_warning] = STATE(89),
    [ts_builtin_sym_end] = ACTIONS(331),
    [sym_identifier] = ACTIONS(329),
    [anon_sym_DASH] = ACTIONS(329),
    [anon_sym_PLUS] = ACTIONS(329),
    [anon_sym_AMP] = ACTIONS(329),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(331),
    [anon_sym_STAR] = ACTIONS(329),
    [anon_sym_SLASH] = ACTIONS(329),
    [anon_sym_PERCENT] = ACTIONS(329),
    [anon_sym_PIPE_PIPE] = ACTIONS(331),
    [anon_sym_AMP_AMP] = ACTIONS(331),
    [anon_sym_PIPE] = ACTIONS(329),
    [anon_sym_CARET] = ACTIONS(329),
    [anon_sym_EQ_EQ] = ACTIONS(331),
    [anon_sym_BANG_EQ] = ACTIONS(331),
    [anon_sym_GT] = ACTIONS(329),
    [anon_sym_GT_EQ] = ACTIONS(331),
    [anon_sym_LT_EQ] = ACTIONS(331),
    [anon_sym_LT] = ACTIONS(329),
    [anon_sym_LT_LT] = ACTIONS(329),
    [anon_sym_GT_GT] = ACTIONS(329),
    [anon_sym_GT_GT_GT] = ACTIONS(329),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(331),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(331),
    [anon_sym_assert] = ACTIONS(329),
    [anon_sym_static_assert] = ACTIONS(329),
    [anon_sym_EQ] = ACTIONS(329),
    [anon_sym_forward] = ACTIONS(329),
    [anon_sym_native] = ACTIONS(329),
    [anon_sym_const] = ACTIONS(329),
    [anon_sym_public] = ACTIONS(329),
    [anon_sym_stock] = ACTIONS(329),
    [anon_sym_static] = ACTIONS(329),
    [anon_sym_new] = ACTIONS(329),
    [anon_sym_decl] = ACTIONS(329),
    [anon_sym_enum] = ACTIONS(329),
    [anon_sym_PLUS_EQ] = ACTIONS(331),
    [anon_sym_DASH_EQ] = ACTIONS(331),
    [anon_sym_STAR_EQ] = ACTIONS(331),
    [anon_sym_SLASH_EQ] = ACTIONS(331),
    [anon_sym_PIPE_EQ] = ACTIONS(331),
    [anon_sym_AMP_EQ] = ACTIONS(331),
    [anon_sym_CARET_EQ] = ACTIONS(331),
    [anon_sym_TILDE_EQ] = ACTIONS(331),
    [anon_sym_LT_LT_EQ] = ACTIONS(331),
    [anon_sym_GT_GT_EQ] = ACTIONS(331),
    [anon_sym_RBRACE] = ACTIONS(331),
    [anon_sym_struct] = ACTIONS(329),
    [anon_sym_typedef] = ACTIONS(329),
    [anon_sym_typeset] = ACTIONS(329),
    [anon_sym_funcenum] = ACTIONS(329),
    [anon_sym_functag] = ACTIONS(329),
    [anon_sym_methodmap] = ACTIONS(329),
    [anon_sym_LBRACK] = ACTIONS(331),
    [anon_sym_void] = ACTIONS(329),
    [anon_sym_bool] = ACTIONS(329),
    [anon_sym_int] = ACTIONS(329),
    [anon_sym_float] = ACTIONS(329),
    [anon_sym_char] = ACTIONS(329),
    [anon_sym__] = ACTIONS(329),
    [anon_sym_Float] = ACTIONS(329),
    [anon_sym_String] = ACTIONS(329),
    [sym_any_type] = ACTIONS(329),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_else] = ACTIONS(329),
    [anon_sym_case] = ACTIONS(329),
    [anon_sym_default] = ACTIONS(329),
    [anon_sym_SEMI] = ACTIONS(331),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(331),
    [anon_sym_PERCENT_EQ] = ACTIONS(331),
    [anon_sym_DOT] = ACTIONS(329),
    [anon_sym_QMARK] = ACTIONS(331),
    [anon_sym_DASH_DASH] = ACTIONS(331),
    [anon_sym_PLUS_PLUS] = ACTIONS(331),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(331),
  },
  [90] = {
    [sym_preproc_include] = STATE(90),
    [sym_preproc_tryinclude] = STATE(90),
    [sym_preproc_macro] = STATE(90),
    [sym_preproc_define] = STATE(90),
    [sym_preproc_undefine] = STATE(90),
    [sym_preproc_if] = STATE(90),
    [sym_preproc_elseif] = STATE(90),
    [sym_preproc_assert] = STATE(90),
    [sym_preproc_pragma] = STATE(90),
    [sym_preproc_error] = STATE(90),
    [sym_preproc_warning] = STATE(90),
    [sym_call_arguments] = STATE(169),
    [ts_builtin_sym_end] = ACTIONS(246),
    [sym_identifier] = ACTIONS(256),
    [anon_sym_LPAREN] = ACTIONS(333),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(244),
    [anon_sym_static_assert] = ACTIONS(244),
    [anon_sym_EQ] = ACTIONS(355),
    [anon_sym_forward] = ACTIONS(244),
    [anon_sym_native] = ACTIONS(244),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_enum] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(357),
    [anon_sym_DASH_EQ] = ACTIONS(357),
    [anon_sym_STAR_EQ] = ACTIONS(357),
    [anon_sym_SLASH_EQ] = ACTIONS(357),
    [anon_sym_PIPE_EQ] = ACTIONS(357),
    [anon_sym_AMP_EQ] = ACTIONS(357),
    [anon_sym_CARET_EQ] = ACTIONS(357),
    [anon_sym_TILDE_EQ] = ACTIONS(357),
    [anon_sym_LT_LT_EQ] = ACTIONS(357),
    [anon_sym_GT_GT_EQ] = ACTIONS(357),
    [anon_sym_struct] = ACTIONS(244),
    [anon_sym_typedef] = ACTIONS(244),
    [anon_sym_typeset] = ACTIONS(244),
    [anon_sym_funcenum] = ACTIONS(244),
    [anon_sym_functag] = ACTIONS(244),
    [anon_sym_methodmap] = ACTIONS(244),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_else] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(357),
    [anon_sym_PERCENT_EQ] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_COLON_COLON] = ACTIONS(337),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [91] = {
    [sym_preproc_include] = STATE(91),
    [sym_preproc_tryinclude] = STATE(91),
    [sym_preproc_macro] = STATE(91),
    [sym_preproc_define] = STATE(91),
    [sym_preproc_undefine] = STATE(91),
    [sym_preproc_if] = STATE(91),
    [sym_preproc_elseif] = STATE(91),
    [sym_preproc_assert] = STATE(91),
    [sym_preproc_pragma] = STATE(91),
    [sym_preproc_error] = STATE(91),
    [sym_preproc_warning] = STATE(91),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(526),
    [sym__semicolon] = STATE(578),
    [sym__expression] = STATE(163),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(521),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [ts_builtin_sym_end] = ACTIONS(364),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(364),
    [anon_sym_assert] = ACTIONS(368),
    [anon_sym_static_assert] = ACTIONS(368),
    [anon_sym_forward] = ACTIONS(368),
    [anon_sym_native] = ACTIONS(368),
    [anon_sym_const] = ACTIONS(368),
    [anon_sym_public] = ACTIONS(368),
    [anon_sym_stock] = ACTIONS(368),
    [anon_sym_static] = ACTIONS(368),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_decl] = ACTIONS(368),
    [anon_sym_enum] = ACTIONS(368),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_struct] = ACTIONS(368),
    [anon_sym_typedef] = ACTIONS(368),
    [anon_sym_typeset] = ACTIONS(368),
    [anon_sym_funcenum] = ACTIONS(368),
    [anon_sym_functag] = ACTIONS(368),
    [anon_sym_methodmap] = ACTIONS(368),
    [anon_sym_void] = ACTIONS(368),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(368),
    [anon_sym_float] = ACTIONS(368),
    [anon_sym_char] = ACTIONS(368),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_else] = ACTIONS(368),
    [anon_sym_SEMI] = ACTIONS(376),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(378),
  },
  [92] = {
    [sym_preproc_include] = STATE(92),
    [sym_preproc_tryinclude] = STATE(92),
    [sym_preproc_macro] = STATE(92),
    [sym_preproc_define] = STATE(92),
    [sym_preproc_undefine] = STATE(92),
    [sym_preproc_if] = STATE(92),
    [sym_preproc_elseif] = STATE(92),
    [sym_preproc_assert] = STATE(92),
    [sym_preproc_pragma] = STATE(92),
    [sym_preproc_error] = STATE(92),
    [sym_preproc_warning] = STATE(92),
    [ts_builtin_sym_end] = ACTIONS(349),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_DASH] = ACTIONS(347),
    [anon_sym_PLUS] = ACTIONS(347),
    [anon_sym_AMP] = ACTIONS(347),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(349),
    [anon_sym_STAR] = ACTIONS(347),
    [anon_sym_SLASH] = ACTIONS(347),
    [anon_sym_PERCENT] = ACTIONS(347),
    [anon_sym_PIPE_PIPE] = ACTIONS(349),
    [anon_sym_AMP_AMP] = ACTIONS(349),
    [anon_sym_PIPE] = ACTIONS(347),
    [anon_sym_CARET] = ACTIONS(347),
    [anon_sym_EQ_EQ] = ACTIONS(349),
    [anon_sym_BANG_EQ] = ACTIONS(349),
    [anon_sym_GT] = ACTIONS(347),
    [anon_sym_GT_EQ] = ACTIONS(349),
    [anon_sym_LT_EQ] = ACTIONS(349),
    [anon_sym_LT] = ACTIONS(347),
    [anon_sym_LT_LT] = ACTIONS(347),
    [anon_sym_GT_GT] = ACTIONS(347),
    [anon_sym_GT_GT_GT] = ACTIONS(347),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(349),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(349),
    [anon_sym_assert] = ACTIONS(347),
    [anon_sym_static_assert] = ACTIONS(347),
    [anon_sym_EQ] = ACTIONS(347),
    [anon_sym_forward] = ACTIONS(347),
    [anon_sym_native] = ACTIONS(347),
    [anon_sym_const] = ACTIONS(347),
    [anon_sym_public] = ACTIONS(347),
    [anon_sym_stock] = ACTIONS(347),
    [anon_sym_static] = ACTIONS(347),
    [anon_sym_new] = ACTIONS(347),
    [anon_sym_decl] = ACTIONS(347),
    [anon_sym_enum] = ACTIONS(347),
    [anon_sym_PLUS_EQ] = ACTIONS(349),
    [anon_sym_DASH_EQ] = ACTIONS(349),
    [anon_sym_STAR_EQ] = ACTIONS(349),
    [anon_sym_SLASH_EQ] = ACTIONS(349),
    [anon_sym_PIPE_EQ] = ACTIONS(349),
    [anon_sym_AMP_EQ] = ACTIONS(349),
    [anon_sym_CARET_EQ] = ACTIONS(349),
    [anon_sym_TILDE_EQ] = ACTIONS(349),
    [anon_sym_LT_LT_EQ] = ACTIONS(349),
    [anon_sym_GT_GT_EQ] = ACTIONS(349),
    [anon_sym_RBRACE] = ACTIONS(349),
    [anon_sym_struct] = ACTIONS(347),
    [anon_sym_typedef] = ACTIONS(347),
    [anon_sym_typeset] = ACTIONS(347),
    [anon_sym_funcenum] = ACTIONS(347),
    [anon_sym_functag] = ACTIONS(347),
    [anon_sym_methodmap] = ACTIONS(347),
    [anon_sym_void] = ACTIONS(347),
    [anon_sym_bool] = ACTIONS(347),
    [anon_sym_int] = ACTIONS(347),
    [anon_sym_float] = ACTIONS(347),
    [anon_sym_char] = ACTIONS(347),
    [anon_sym__] = ACTIONS(347),
    [anon_sym_Float] = ACTIONS(347),
    [anon_sym_String] = ACTIONS(347),
    [sym_any_type] = ACTIONS(347),
    [anon_sym_while] = ACTIONS(347),
    [anon_sym_else] = ACTIONS(347),
    [anon_sym_case] = ACTIONS(347),
    [anon_sym_default] = ACTIONS(347),
    [anon_sym_SEMI] = ACTIONS(349),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(349),
    [anon_sym_PERCENT_EQ] = ACTIONS(349),
    [anon_sym_DOT] = ACTIONS(347),
    [anon_sym_QMARK] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(349),
  },
  [93] = {
    [sym_preproc_include] = STATE(93),
    [sym_preproc_tryinclude] = STATE(93),
    [sym_preproc_macro] = STATE(93),
    [sym_preproc_define] = STATE(93),
    [sym_preproc_undefine] = STATE(93),
    [sym_preproc_if] = STATE(93),
    [sym_preproc_elseif] = STATE(93),
    [sym_preproc_assert] = STATE(93),
    [sym_preproc_pragma] = STATE(93),
    [sym_preproc_error] = STATE(93),
    [sym_preproc_warning] = STATE(93),
    [ts_builtin_sym_end] = ACTIONS(246),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(244),
    [anon_sym_static_assert] = ACTIONS(244),
    [anon_sym_EQ] = ACTIONS(355),
    [anon_sym_forward] = ACTIONS(244),
    [anon_sym_native] = ACTIONS(244),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_enum] = ACTIONS(244),
    [anon_sym_PLUS_EQ] = ACTIONS(357),
    [anon_sym_DASH_EQ] = ACTIONS(357),
    [anon_sym_STAR_EQ] = ACTIONS(357),
    [anon_sym_SLASH_EQ] = ACTIONS(357),
    [anon_sym_PIPE_EQ] = ACTIONS(357),
    [anon_sym_AMP_EQ] = ACTIONS(357),
    [anon_sym_CARET_EQ] = ACTIONS(357),
    [anon_sym_TILDE_EQ] = ACTIONS(357),
    [anon_sym_LT_LT_EQ] = ACTIONS(357),
    [anon_sym_GT_GT_EQ] = ACTIONS(357),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_struct] = ACTIONS(244),
    [anon_sym_typedef] = ACTIONS(244),
    [anon_sym_typeset] = ACTIONS(244),
    [anon_sym_funcenum] = ACTIONS(244),
    [anon_sym_functag] = ACTIONS(244),
    [anon_sym_methodmap] = ACTIONS(244),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_else] = ACTIONS(244),
    [anon_sym_case] = ACTIONS(244),
    [anon_sym_default] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(357),
    [anon_sym_PERCENT_EQ] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [94] = {
    [sym_preproc_include] = STATE(94),
    [sym_preproc_tryinclude] = STATE(94),
    [sym_preproc_macro] = STATE(94),
    [sym_preproc_define] = STATE(94),
    [sym_preproc_undefine] = STATE(94),
    [sym_preproc_if] = STATE(94),
    [sym_preproc_elseif] = STATE(94),
    [sym_preproc_assert] = STATE(94),
    [sym_preproc_pragma] = STATE(94),
    [sym_preproc_error] = STATE(94),
    [sym_preproc_warning] = STATE(94),
    [ts_builtin_sym_end] = ACTIONS(127),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(127),
    [anon_sym_assert] = ACTIONS(123),
    [anon_sym_static_assert] = ACTIONS(123),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_forward] = ACTIONS(123),
    [anon_sym_native] = ACTIONS(123),
    [anon_sym_const] = ACTIONS(123),
    [anon_sym_public] = ACTIONS(123),
    [anon_sym_stock] = ACTIONS(123),
    [anon_sym_static] = ACTIONS(123),
    [anon_sym_new] = ACTIONS(123),
    [anon_sym_decl] = ACTIONS(123),
    [anon_sym_enum] = ACTIONS(123),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_struct] = ACTIONS(123),
    [anon_sym_typedef] = ACTIONS(123),
    [anon_sym_typeset] = ACTIONS(123),
    [anon_sym_funcenum] = ACTIONS(123),
    [anon_sym_functag] = ACTIONS(123),
    [anon_sym_methodmap] = ACTIONS(123),
    [anon_sym_void] = ACTIONS(123),
    [anon_sym_bool] = ACTIONS(123),
    [anon_sym_int] = ACTIONS(123),
    [anon_sym_float] = ACTIONS(123),
    [anon_sym_char] = ACTIONS(123),
    [anon_sym__] = ACTIONS(123),
    [anon_sym_Float] = ACTIONS(123),
    [anon_sym_String] = ACTIONS(123),
    [sym_any_type] = ACTIONS(123),
    [anon_sym_while] = ACTIONS(123),
    [anon_sym_else] = ACTIONS(123),
    [anon_sym_case] = ACTIONS(123),
    [anon_sym_default] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(127),
  },
  [95] = {
    [sym_preproc_include] = STATE(95),
    [sym_preproc_tryinclude] = STATE(95),
    [sym_preproc_macro] = STATE(95),
    [sym_preproc_define] = STATE(95),
    [sym_preproc_undefine] = STATE(95),
    [sym_preproc_if] = STATE(95),
    [sym_preproc_elseif] = STATE(95),
    [sym_preproc_assert] = STATE(95),
    [sym_preproc_pragma] = STATE(95),
    [sym_preproc_error] = STATE(95),
    [sym_preproc_warning] = STATE(95),
    [ts_builtin_sym_end] = ACTIONS(353),
    [sym_identifier] = ACTIONS(351),
    [anon_sym_DASH] = ACTIONS(351),
    [anon_sym_PLUS] = ACTIONS(351),
    [anon_sym_AMP] = ACTIONS(351),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(353),
    [anon_sym_STAR] = ACTIONS(351),
    [anon_sym_SLASH] = ACTIONS(351),
    [anon_sym_PERCENT] = ACTIONS(351),
    [anon_sym_PIPE_PIPE] = ACTIONS(353),
    [anon_sym_AMP_AMP] = ACTIONS(353),
    [anon_sym_PIPE] = ACTIONS(351),
    [anon_sym_CARET] = ACTIONS(351),
    [anon_sym_EQ_EQ] = ACTIONS(353),
    [anon_sym_BANG_EQ] = ACTIONS(353),
    [anon_sym_GT] = ACTIONS(351),
    [anon_sym_GT_EQ] = ACTIONS(353),
    [anon_sym_LT_EQ] = ACTIONS(353),
    [anon_sym_LT] = ACTIONS(351),
    [anon_sym_LT_LT] = ACTIONS(351),
    [anon_sym_GT_GT] = ACTIONS(351),
    [anon_sym_GT_GT_GT] = ACTIONS(351),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(353),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(353),
    [anon_sym_assert] = ACTIONS(351),
    [anon_sym_static_assert] = ACTIONS(351),
    [anon_sym_EQ] = ACTIONS(351),
    [anon_sym_forward] = ACTIONS(351),
    [anon_sym_native] = ACTIONS(351),
    [anon_sym_const] = ACTIONS(351),
    [anon_sym_public] = ACTIONS(351),
    [anon_sym_stock] = ACTIONS(351),
    [anon_sym_static] = ACTIONS(351),
    [anon_sym_new] = ACTIONS(351),
    [anon_sym_decl] = ACTIONS(351),
    [anon_sym_enum] = ACTIONS(351),
    [anon_sym_PLUS_EQ] = ACTIONS(353),
    [anon_sym_DASH_EQ] = ACTIONS(353),
    [anon_sym_STAR_EQ] = ACTIONS(353),
    [anon_sym_SLASH_EQ] = ACTIONS(353),
    [anon_sym_PIPE_EQ] = ACTIONS(353),
    [anon_sym_AMP_EQ] = ACTIONS(353),
    [anon_sym_CARET_EQ] = ACTIONS(353),
    [anon_sym_TILDE_EQ] = ACTIONS(353),
    [anon_sym_LT_LT_EQ] = ACTIONS(353),
    [anon_sym_GT_GT_EQ] = ACTIONS(353),
    [anon_sym_RBRACE] = ACTIONS(353),
    [anon_sym_struct] = ACTIONS(351),
    [anon_sym_typedef] = ACTIONS(351),
    [anon_sym_typeset] = ACTIONS(351),
    [anon_sym_funcenum] = ACTIONS(351),
    [anon_sym_functag] = ACTIONS(351),
    [anon_sym_methodmap] = ACTIONS(351),
    [anon_sym_void] = ACTIONS(351),
    [anon_sym_bool] = ACTIONS(351),
    [anon_sym_int] = ACTIONS(351),
    [anon_sym_float] = ACTIONS(351),
    [anon_sym_char] = ACTIONS(351),
    [anon_sym__] = ACTIONS(351),
    [anon_sym_Float] = ACTIONS(351),
    [anon_sym_String] = ACTIONS(351),
    [sym_any_type] = ACTIONS(351),
    [anon_sym_while] = ACTIONS(351),
    [anon_sym_else] = ACTIONS(351),
    [anon_sym_case] = ACTIONS(351),
    [anon_sym_default] = ACTIONS(351),
    [anon_sym_SEMI] = ACTIONS(353),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(353),
    [anon_sym_PERCENT_EQ] = ACTIONS(353),
    [anon_sym_DOT] = ACTIONS(351),
    [anon_sym_QMARK] = ACTIONS(353),
    [anon_sym_DASH_DASH] = ACTIONS(353),
    [anon_sym_PLUS_PLUS] = ACTIONS(353),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(353),
  },
  [96] = {
    [sym_preproc_include] = STATE(96),
    [sym_preproc_tryinclude] = STATE(96),
    [sym_preproc_macro] = STATE(96),
    [sym_preproc_define] = STATE(96),
    [sym_preproc_undefine] = STATE(96),
    [sym_preproc_if] = STATE(96),
    [sym_preproc_elseif] = STATE(96),
    [sym_preproc_assert] = STATE(96),
    [sym_preproc_pragma] = STATE(96),
    [sym_preproc_error] = STATE(96),
    [sym_preproc_warning] = STATE(96),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(452),
    [sym__expression] = STATE(102),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(236),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(368),
    [anon_sym_public] = ACTIONS(368),
    [anon_sym_stock] = ACTIONS(368),
    [anon_sym_static] = ACTIONS(368),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_decl] = ACTIONS(368),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_RBRACE] = ACTIONS(364),
    [anon_sym_void] = ACTIONS(368),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(368),
    [anon_sym_float] = ACTIONS(368),
    [anon_sym_char] = ACTIONS(368),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_for] = ACTIONS(368),
    [anon_sym_while] = ACTIONS(368),
    [anon_sym_do] = ACTIONS(368),
    [anon_sym_break] = ACTIONS(368),
    [anon_sym_continue] = ACTIONS(368),
    [anon_sym_if] = ACTIONS(368),
    [anon_sym_else] = ACTIONS(368),
    [anon_sym_switch] = ACTIONS(368),
    [anon_sym_return] = ACTIONS(368),
    [anon_sym_delete] = ACTIONS(368),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [97] = {
    [sym_preproc_include] = STATE(97),
    [sym_preproc_tryinclude] = STATE(97),
    [sym_preproc_macro] = STATE(97),
    [sym_preproc_define] = STATE(97),
    [sym_preproc_undefine] = STATE(97),
    [sym_preproc_if] = STATE(97),
    [sym_preproc_elseif] = STATE(97),
    [sym_preproc_assert] = STATE(97),
    [sym_preproc_pragma] = STATE(97),
    [sym_preproc_error] = STATE(97),
    [sym_preproc_warning] = STATE(97),
    [sym_fixed_dimension] = STATE(104),
    [aux_sym_dynamic_array_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(390),
    [anon_sym_LPAREN] = ACTIONS(392),
    [anon_sym_BANG] = ACTIONS(390),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_DASH] = ACTIONS(390),
    [anon_sym_PLUS] = ACTIONS(390),
    [anon_sym_AMP] = ACTIONS(390),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(392),
    [anon_sym_SLASH] = ACTIONS(390),
    [anon_sym_PERCENT] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE] = ACTIONS(390),
    [anon_sym_CARET] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT] = ACTIONS(390),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_LT] = ACTIONS(390),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(390),
    [anon_sym_GT_GT_GT] = ACTIONS(392),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(390),
    [anon_sym_public] = ACTIONS(390),
    [anon_sym_stock] = ACTIONS(390),
    [anon_sym_static] = ACTIONS(390),
    [anon_sym_new] = ACTIONS(390),
    [anon_sym_decl] = ACTIONS(390),
    [anon_sym_LBRACE] = ACTIONS(392),
    [anon_sym_RBRACE] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(394),
    [anon_sym_void] = ACTIONS(390),
    [anon_sym_bool] = ACTIONS(390),
    [anon_sym_int] = ACTIONS(390),
    [anon_sym_float] = ACTIONS(390),
    [anon_sym_char] = ACTIONS(390),
    [anon_sym__] = ACTIONS(390),
    [anon_sym_Float] = ACTIONS(390),
    [anon_sym_String] = ACTIONS(390),
    [sym_any_type] = ACTIONS(390),
    [anon_sym_for] = ACTIONS(390),
    [anon_sym_while] = ACTIONS(390),
    [anon_sym_do] = ACTIONS(390),
    [anon_sym_break] = ACTIONS(390),
    [anon_sym_continue] = ACTIONS(390),
    [anon_sym_if] = ACTIONS(390),
    [anon_sym_else] = ACTIONS(390),
    [anon_sym_switch] = ACTIONS(390),
    [anon_sym_return] = ACTIONS(390),
    [anon_sym_delete] = ACTIONS(390),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(390),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_DASH_DASH] = ACTIONS(392),
    [anon_sym_PLUS_PLUS] = ACTIONS(392),
    [anon_sym_sizeof] = ACTIONS(390),
    [anon_sym_view_as] = ACTIONS(390),
    [sym_int_literal] = ACTIONS(390),
    [sym_float_literal] = ACTIONS(392),
    [anon_sym_SQUOTE] = ACTIONS(392),
    [anon_sym_DQUOTE] = ACTIONS(392),
    [sym_bool_literal] = ACTIONS(390),
    [sym_null] = ACTIONS(390),
    [sym_this] = ACTIONS(390),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(392),
  },
  [98] = {
    [sym_preproc_include] = STATE(98),
    [sym_preproc_tryinclude] = STATE(98),
    [sym_preproc_macro] = STATE(98),
    [sym_preproc_define] = STATE(98),
    [sym_preproc_undefine] = STATE(98),
    [sym_preproc_if] = STATE(98),
    [sym_preproc_elseif] = STATE(98),
    [sym_preproc_assert] = STATE(98),
    [sym_preproc_pragma] = STATE(98),
    [sym_preproc_error] = STATE(98),
    [sym_preproc_warning] = STATE(98),
    [sym_fixed_dimension] = STATE(104),
    [aux_sym_dynamic_array_repeat1] = STATE(98),
    [sym_identifier] = ACTIONS(396),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym_BANG] = ACTIONS(396),
    [anon_sym_TILDE] = ACTIONS(398),
    [anon_sym_DASH] = ACTIONS(396),
    [anon_sym_PLUS] = ACTIONS(396),
    [anon_sym_AMP] = ACTIONS(396),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(398),
    [anon_sym_STAR] = ACTIONS(398),
    [anon_sym_SLASH] = ACTIONS(396),
    [anon_sym_PERCENT] = ACTIONS(398),
    [anon_sym_PIPE_PIPE] = ACTIONS(398),
    [anon_sym_AMP_AMP] = ACTIONS(398),
    [anon_sym_PIPE] = ACTIONS(396),
    [anon_sym_CARET] = ACTIONS(398),
    [anon_sym_EQ_EQ] = ACTIONS(398),
    [anon_sym_BANG_EQ] = ACTIONS(398),
    [anon_sym_GT] = ACTIONS(396),
    [anon_sym_GT_EQ] = ACTIONS(398),
    [anon_sym_LT_EQ] = ACTIONS(398),
    [anon_sym_LT] = ACTIONS(396),
    [anon_sym_LT_LT] = ACTIONS(398),
    [anon_sym_GT_GT] = ACTIONS(396),
    [anon_sym_GT_GT_GT] = ACTIONS(398),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(398),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(396),
    [anon_sym_public] = ACTIONS(396),
    [anon_sym_stock] = ACTIONS(396),
    [anon_sym_static] = ACTIONS(396),
    [anon_sym_new] = ACTIONS(396),
    [anon_sym_decl] = ACTIONS(396),
    [anon_sym_LBRACE] = ACTIONS(398),
    [anon_sym_RBRACE] = ACTIONS(398),
    [anon_sym_LBRACK] = ACTIONS(400),
    [anon_sym_void] = ACTIONS(396),
    [anon_sym_bool] = ACTIONS(396),
    [anon_sym_int] = ACTIONS(396),
    [anon_sym_float] = ACTIONS(396),
    [anon_sym_char] = ACTIONS(396),
    [anon_sym__] = ACTIONS(396),
    [anon_sym_Float] = ACTIONS(396),
    [anon_sym_String] = ACTIONS(396),
    [sym_any_type] = ACTIONS(396),
    [anon_sym_for] = ACTIONS(396),
    [anon_sym_while] = ACTIONS(396),
    [anon_sym_do] = ACTIONS(396),
    [anon_sym_break] = ACTIONS(396),
    [anon_sym_continue] = ACTIONS(396),
    [anon_sym_if] = ACTIONS(396),
    [anon_sym_else] = ACTIONS(396),
    [anon_sym_switch] = ACTIONS(396),
    [anon_sym_return] = ACTIONS(396),
    [anon_sym_delete] = ACTIONS(396),
    [anon_sym_SEMI] = ACTIONS(398),
    [anon_sym_DOT] = ACTIONS(396),
    [anon_sym_QMARK] = ACTIONS(398),
    [anon_sym_DASH_DASH] = ACTIONS(398),
    [anon_sym_PLUS_PLUS] = ACTIONS(398),
    [anon_sym_sizeof] = ACTIONS(396),
    [anon_sym_view_as] = ACTIONS(396),
    [sym_int_literal] = ACTIONS(396),
    [sym_float_literal] = ACTIONS(398),
    [anon_sym_SQUOTE] = ACTIONS(398),
    [anon_sym_DQUOTE] = ACTIONS(398),
    [sym_bool_literal] = ACTIONS(396),
    [sym_null] = ACTIONS(396),
    [sym_this] = ACTIONS(396),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(398),
  },
  [99] = {
    [sym_preproc_include] = STATE(99),
    [sym_preproc_tryinclude] = STATE(99),
    [sym_preproc_macro] = STATE(99),
    [sym_preproc_define] = STATE(99),
    [sym_preproc_undefine] = STATE(99),
    [sym_preproc_if] = STATE(99),
    [sym_preproc_elseif] = STATE(99),
    [sym_preproc_assert] = STATE(99),
    [sym_preproc_pragma] = STATE(99),
    [sym_preproc_error] = STATE(99),
    [sym_preproc_warning] = STATE(99),
    [sym_dimension] = STATE(106),
    [aux_sym_function_definition_repeat1] = STATE(101),
    [sym_identifier] = ACTIONS(403),
    [anon_sym_LPAREN] = ACTIONS(405),
    [anon_sym_BANG] = ACTIONS(403),
    [anon_sym_TILDE] = ACTIONS(405),
    [anon_sym_DASH] = ACTIONS(403),
    [anon_sym_PLUS] = ACTIONS(403),
    [anon_sym_AMP] = ACTIONS(403),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(405),
    [anon_sym_STAR] = ACTIONS(405),
    [anon_sym_SLASH] = ACTIONS(403),
    [anon_sym_PERCENT] = ACTIONS(405),
    [anon_sym_PIPE_PIPE] = ACTIONS(405),
    [anon_sym_AMP_AMP] = ACTIONS(405),
    [anon_sym_PIPE] = ACTIONS(403),
    [anon_sym_CARET] = ACTIONS(405),
    [anon_sym_EQ_EQ] = ACTIONS(405),
    [anon_sym_BANG_EQ] = ACTIONS(405),
    [anon_sym_GT] = ACTIONS(403),
    [anon_sym_GT_EQ] = ACTIONS(405),
    [anon_sym_LT_EQ] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(403),
    [anon_sym_LT_LT] = ACTIONS(405),
    [anon_sym_GT_GT] = ACTIONS(403),
    [anon_sym_GT_GT_GT] = ACTIONS(405),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(405),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(403),
    [anon_sym_public] = ACTIONS(403),
    [anon_sym_stock] = ACTIONS(403),
    [anon_sym_static] = ACTIONS(403),
    [anon_sym_new] = ACTIONS(403),
    [anon_sym_decl] = ACTIONS(403),
    [anon_sym_LBRACE] = ACTIONS(405),
    [anon_sym_RBRACE] = ACTIONS(405),
    [anon_sym_LBRACK] = ACTIONS(407),
    [anon_sym_void] = ACTIONS(403),
    [anon_sym_bool] = ACTIONS(403),
    [anon_sym_int] = ACTIONS(403),
    [anon_sym_float] = ACTIONS(403),
    [anon_sym_char] = ACTIONS(403),
    [anon_sym__] = ACTIONS(403),
    [anon_sym_Float] = ACTIONS(403),
    [anon_sym_String] = ACTIONS(403),
    [sym_any_type] = ACTIONS(403),
    [anon_sym_for] = ACTIONS(403),
    [anon_sym_while] = ACTIONS(403),
    [anon_sym_do] = ACTIONS(403),
    [anon_sym_break] = ACTIONS(403),
    [anon_sym_continue] = ACTIONS(403),
    [anon_sym_if] = ACTIONS(403),
    [anon_sym_else] = ACTIONS(403),
    [anon_sym_switch] = ACTIONS(403),
    [anon_sym_return] = ACTIONS(403),
    [anon_sym_delete] = ACTIONS(403),
    [anon_sym_SEMI] = ACTIONS(405),
    [anon_sym_DOT] = ACTIONS(403),
    [anon_sym_QMARK] = ACTIONS(405),
    [anon_sym_DASH_DASH] = ACTIONS(405),
    [anon_sym_PLUS_PLUS] = ACTIONS(405),
    [anon_sym_sizeof] = ACTIONS(403),
    [anon_sym_view_as] = ACTIONS(403),
    [sym_int_literal] = ACTIONS(403),
    [sym_float_literal] = ACTIONS(405),
    [anon_sym_SQUOTE] = ACTIONS(405),
    [anon_sym_DQUOTE] = ACTIONS(405),
    [sym_bool_literal] = ACTIONS(403),
    [sym_null] = ACTIONS(403),
    [sym_this] = ACTIONS(403),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(405),
  },
  [100] = {
    [sym_preproc_include] = STATE(100),
    [sym_preproc_tryinclude] = STATE(100),
    [sym_preproc_macro] = STATE(100),
    [sym_preproc_define] = STATE(100),
    [sym_preproc_undefine] = STATE(100),
    [sym_preproc_if] = STATE(100),
    [sym_preproc_elseif] = STATE(100),
    [sym_preproc_assert] = STATE(100),
    [sym_preproc_pragma] = STATE(100),
    [sym_preproc_error] = STATE(100),
    [sym_preproc_warning] = STATE(100),
    [sym_dimension] = STATE(106),
    [aux_sym_function_definition_repeat1] = STATE(101),
    [sym_identifier] = ACTIONS(403),
    [anon_sym_LPAREN] = ACTIONS(405),
    [anon_sym_BANG] = ACTIONS(403),
    [anon_sym_TILDE] = ACTIONS(405),
    [anon_sym_DASH] = ACTIONS(403),
    [anon_sym_PLUS] = ACTIONS(403),
    [anon_sym_AMP] = ACTIONS(403),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(405),
    [anon_sym_STAR] = ACTIONS(405),
    [anon_sym_SLASH] = ACTIONS(403),
    [anon_sym_PERCENT] = ACTIONS(405),
    [anon_sym_PIPE_PIPE] = ACTIONS(405),
    [anon_sym_AMP_AMP] = ACTIONS(405),
    [anon_sym_PIPE] = ACTIONS(403),
    [anon_sym_CARET] = ACTIONS(405),
    [anon_sym_EQ_EQ] = ACTIONS(405),
    [anon_sym_BANG_EQ] = ACTIONS(405),
    [anon_sym_GT] = ACTIONS(403),
    [anon_sym_GT_EQ] = ACTIONS(405),
    [anon_sym_LT_EQ] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(403),
    [anon_sym_LT_LT] = ACTIONS(405),
    [anon_sym_GT_GT] = ACTIONS(403),
    [anon_sym_GT_GT_GT] = ACTIONS(405),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(405),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(403),
    [anon_sym_public] = ACTIONS(403),
    [anon_sym_stock] = ACTIONS(403),
    [anon_sym_static] = ACTIONS(403),
    [anon_sym_new] = ACTIONS(403),
    [anon_sym_decl] = ACTIONS(403),
    [anon_sym_LBRACE] = ACTIONS(405),
    [anon_sym_RBRACE] = ACTIONS(405),
    [anon_sym_LBRACK] = ACTIONS(407),
    [anon_sym_void] = ACTIONS(403),
    [anon_sym_bool] = ACTIONS(403),
    [anon_sym_int] = ACTIONS(403),
    [anon_sym_float] = ACTIONS(403),
    [anon_sym_char] = ACTIONS(403),
    [anon_sym__] = ACTIONS(403),
    [anon_sym_Float] = ACTIONS(403),
    [anon_sym_String] = ACTIONS(403),
    [sym_any_type] = ACTIONS(403),
    [anon_sym_for] = ACTIONS(403),
    [anon_sym_while] = ACTIONS(403),
    [anon_sym_do] = ACTIONS(403),
    [anon_sym_break] = ACTIONS(403),
    [anon_sym_continue] = ACTIONS(403),
    [anon_sym_if] = ACTIONS(403),
    [anon_sym_else] = ACTIONS(403),
    [anon_sym_switch] = ACTIONS(403),
    [anon_sym_return] = ACTIONS(403),
    [anon_sym_delete] = ACTIONS(403),
    [anon_sym_SEMI] = ACTIONS(405),
    [anon_sym_DOT] = ACTIONS(409),
    [anon_sym_QMARK] = ACTIONS(405),
    [anon_sym_DASH_DASH] = ACTIONS(405),
    [anon_sym_PLUS_PLUS] = ACTIONS(405),
    [anon_sym_sizeof] = ACTIONS(403),
    [anon_sym_view_as] = ACTIONS(403),
    [sym_int_literal] = ACTIONS(403),
    [sym_float_literal] = ACTIONS(405),
    [anon_sym_SQUOTE] = ACTIONS(405),
    [anon_sym_DQUOTE] = ACTIONS(405),
    [sym_bool_literal] = ACTIONS(403),
    [sym_null] = ACTIONS(403),
    [sym_this] = ACTIONS(403),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(405),
  },
  [101] = {
    [sym_preproc_include] = STATE(101),
    [sym_preproc_tryinclude] = STATE(101),
    [sym_preproc_macro] = STATE(101),
    [sym_preproc_define] = STATE(101),
    [sym_preproc_undefine] = STATE(101),
    [sym_preproc_if] = STATE(101),
    [sym_preproc_elseif] = STATE(101),
    [sym_preproc_assert] = STATE(101),
    [sym_preproc_pragma] = STATE(101),
    [sym_preproc_error] = STATE(101),
    [sym_preproc_warning] = STATE(101),
    [sym_dimension] = STATE(106),
    [aux_sym_function_definition_repeat1] = STATE(101),
    [sym_identifier] = ACTIONS(411),
    [anon_sym_LPAREN] = ACTIONS(413),
    [anon_sym_BANG] = ACTIONS(411),
    [anon_sym_TILDE] = ACTIONS(413),
    [anon_sym_DASH] = ACTIONS(411),
    [anon_sym_PLUS] = ACTIONS(411),
    [anon_sym_AMP] = ACTIONS(411),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(413),
    [anon_sym_STAR] = ACTIONS(413),
    [anon_sym_SLASH] = ACTIONS(411),
    [anon_sym_PERCENT] = ACTIONS(413),
    [anon_sym_PIPE_PIPE] = ACTIONS(413),
    [anon_sym_AMP_AMP] = ACTIONS(413),
    [anon_sym_PIPE] = ACTIONS(411),
    [anon_sym_CARET] = ACTIONS(413),
    [anon_sym_EQ_EQ] = ACTIONS(413),
    [anon_sym_BANG_EQ] = ACTIONS(413),
    [anon_sym_GT] = ACTIONS(411),
    [anon_sym_GT_EQ] = ACTIONS(413),
    [anon_sym_LT_EQ] = ACTIONS(413),
    [anon_sym_LT] = ACTIONS(411),
    [anon_sym_LT_LT] = ACTIONS(413),
    [anon_sym_GT_GT] = ACTIONS(411),
    [anon_sym_GT_GT_GT] = ACTIONS(413),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(413),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(411),
    [anon_sym_public] = ACTIONS(411),
    [anon_sym_stock] = ACTIONS(411),
    [anon_sym_static] = ACTIONS(411),
    [anon_sym_new] = ACTIONS(411),
    [anon_sym_decl] = ACTIONS(411),
    [anon_sym_LBRACE] = ACTIONS(413),
    [anon_sym_RBRACE] = ACTIONS(413),
    [anon_sym_LBRACK] = ACTIONS(415),
    [anon_sym_void] = ACTIONS(411),
    [anon_sym_bool] = ACTIONS(411),
    [anon_sym_int] = ACTIONS(411),
    [anon_sym_float] = ACTIONS(411),
    [anon_sym_char] = ACTIONS(411),
    [anon_sym__] = ACTIONS(411),
    [anon_sym_Float] = ACTIONS(411),
    [anon_sym_String] = ACTIONS(411),
    [sym_any_type] = ACTIONS(411),
    [anon_sym_for] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(411),
    [anon_sym_break] = ACTIONS(411),
    [anon_sym_continue] = ACTIONS(411),
    [anon_sym_if] = ACTIONS(411),
    [anon_sym_else] = ACTIONS(411),
    [anon_sym_switch] = ACTIONS(411),
    [anon_sym_return] = ACTIONS(411),
    [anon_sym_delete] = ACTIONS(411),
    [anon_sym_SEMI] = ACTIONS(413),
    [anon_sym_DOT] = ACTIONS(411),
    [anon_sym_QMARK] = ACTIONS(413),
    [anon_sym_DASH_DASH] = ACTIONS(413),
    [anon_sym_PLUS_PLUS] = ACTIONS(413),
    [anon_sym_sizeof] = ACTIONS(411),
    [anon_sym_view_as] = ACTIONS(411),
    [sym_int_literal] = ACTIONS(411),
    [sym_float_literal] = ACTIONS(413),
    [anon_sym_SQUOTE] = ACTIONS(413),
    [anon_sym_DQUOTE] = ACTIONS(413),
    [sym_bool_literal] = ACTIONS(411),
    [sym_null] = ACTIONS(411),
    [sym_this] = ACTIONS(411),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(413),
  },
  [102] = {
    [sym_preproc_include] = STATE(102),
    [sym_preproc_tryinclude] = STATE(102),
    [sym_preproc_macro] = STATE(102),
    [sym_preproc_define] = STATE(102),
    [sym_preproc_undefine] = STATE(102),
    [sym_preproc_if] = STATE(102),
    [sym_preproc_elseif] = STATE(102),
    [sym_preproc_assert] = STATE(102),
    [sym_preproc_pragma] = STATE(102),
    [sym_preproc_error] = STATE(102),
    [sym_preproc_warning] = STATE(102),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(440),
    [sym_identifier] = ACTIONS(418),
    [anon_sym_LPAREN] = ACTIONS(420),
    [anon_sym_BANG] = ACTIONS(418),
    [anon_sym_TILDE] = ACTIONS(420),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(424),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(432),
    [anon_sym_AMP_AMP] = ACTIONS(434),
    [anon_sym_PIPE] = ACTIONS(436),
    [anon_sym_CARET] = ACTIONS(438),
    [anon_sym_EQ_EQ] = ACTIONS(440),
    [anon_sym_BANG_EQ] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(450),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(418),
    [anon_sym_public] = ACTIONS(418),
    [anon_sym_stock] = ACTIONS(418),
    [anon_sym_static] = ACTIONS(418),
    [anon_sym_new] = ACTIONS(418),
    [anon_sym_decl] = ACTIONS(418),
    [anon_sym_LBRACE] = ACTIONS(420),
    [anon_sym_RBRACE] = ACTIONS(420),
    [anon_sym_void] = ACTIONS(418),
    [anon_sym_bool] = ACTIONS(418),
    [anon_sym_int] = ACTIONS(418),
    [anon_sym_float] = ACTIONS(418),
    [anon_sym_char] = ACTIONS(418),
    [anon_sym__] = ACTIONS(418),
    [anon_sym_Float] = ACTIONS(418),
    [anon_sym_String] = ACTIONS(418),
    [sym_any_type] = ACTIONS(418),
    [anon_sym_for] = ACTIONS(418),
    [anon_sym_while] = ACTIONS(418),
    [anon_sym_do] = ACTIONS(418),
    [anon_sym_break] = ACTIONS(418),
    [anon_sym_continue] = ACTIONS(418),
    [anon_sym_if] = ACTIONS(418),
    [anon_sym_else] = ACTIONS(418),
    [anon_sym_switch] = ACTIONS(418),
    [anon_sym_return] = ACTIONS(418),
    [anon_sym_delete] = ACTIONS(418),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(454),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(418),
    [anon_sym_view_as] = ACTIONS(418),
    [sym_int_literal] = ACTIONS(418),
    [sym_float_literal] = ACTIONS(420),
    [anon_sym_SQUOTE] = ACTIONS(420),
    [anon_sym_DQUOTE] = ACTIONS(420),
    [sym_bool_literal] = ACTIONS(418),
    [sym_null] = ACTIONS(418),
    [sym_this] = ACTIONS(418),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [103] = {
    [sym_preproc_include] = STATE(103),
    [sym_preproc_tryinclude] = STATE(103),
    [sym_preproc_macro] = STATE(103),
    [sym_preproc_define] = STATE(103),
    [sym_preproc_undefine] = STATE(103),
    [sym_preproc_if] = STATE(103),
    [sym_preproc_elseif] = STATE(103),
    [sym_preproc_assert] = STATE(103),
    [sym_preproc_pragma] = STATE(103),
    [sym_preproc_error] = STATE(103),
    [sym_preproc_warning] = STATE(103),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(466),
    [sym_identifier] = ACTIONS(458),
    [anon_sym_LPAREN] = ACTIONS(460),
    [anon_sym_BANG] = ACTIONS(458),
    [anon_sym_TILDE] = ACTIONS(460),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(424),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(432),
    [anon_sym_AMP_AMP] = ACTIONS(434),
    [anon_sym_PIPE] = ACTIONS(436),
    [anon_sym_CARET] = ACTIONS(438),
    [anon_sym_EQ_EQ] = ACTIONS(440),
    [anon_sym_BANG_EQ] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(450),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_public] = ACTIONS(458),
    [anon_sym_stock] = ACTIONS(458),
    [anon_sym_static] = ACTIONS(458),
    [anon_sym_new] = ACTIONS(458),
    [anon_sym_decl] = ACTIONS(458),
    [anon_sym_LBRACE] = ACTIONS(460),
    [anon_sym_RBRACE] = ACTIONS(460),
    [anon_sym_void] = ACTIONS(458),
    [anon_sym_bool] = ACTIONS(458),
    [anon_sym_int] = ACTIONS(458),
    [anon_sym_float] = ACTIONS(458),
    [anon_sym_char] = ACTIONS(458),
    [anon_sym__] = ACTIONS(458),
    [anon_sym_Float] = ACTIONS(458),
    [anon_sym_String] = ACTIONS(458),
    [sym_any_type] = ACTIONS(458),
    [anon_sym_for] = ACTIONS(458),
    [anon_sym_while] = ACTIONS(458),
    [anon_sym_do] = ACTIONS(458),
    [anon_sym_break] = ACTIONS(458),
    [anon_sym_continue] = ACTIONS(458),
    [anon_sym_if] = ACTIONS(458),
    [anon_sym_else] = ACTIONS(458),
    [anon_sym_switch] = ACTIONS(458),
    [anon_sym_return] = ACTIONS(458),
    [anon_sym_delete] = ACTIONS(458),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(454),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(458),
    [anon_sym_view_as] = ACTIONS(458),
    [sym_int_literal] = ACTIONS(458),
    [sym_float_literal] = ACTIONS(460),
    [anon_sym_SQUOTE] = ACTIONS(460),
    [anon_sym_DQUOTE] = ACTIONS(460),
    [sym_bool_literal] = ACTIONS(458),
    [sym_null] = ACTIONS(458),
    [sym_this] = ACTIONS(458),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [104] = {
    [sym_preproc_include] = STATE(104),
    [sym_preproc_tryinclude] = STATE(104),
    [sym_preproc_macro] = STATE(104),
    [sym_preproc_define] = STATE(104),
    [sym_preproc_undefine] = STATE(104),
    [sym_preproc_if] = STATE(104),
    [sym_preproc_elseif] = STATE(104),
    [sym_preproc_assert] = STATE(104),
    [sym_preproc_pragma] = STATE(104),
    [sym_preproc_error] = STATE(104),
    [sym_preproc_warning] = STATE(104),
    [sym_identifier] = ACTIONS(462),
    [anon_sym_LPAREN] = ACTIONS(464),
    [anon_sym_BANG] = ACTIONS(462),
    [anon_sym_TILDE] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(462),
    [anon_sym_PLUS] = ACTIONS(462),
    [anon_sym_AMP] = ACTIONS(462),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(462),
    [anon_sym_PERCENT] = ACTIONS(464),
    [anon_sym_PIPE_PIPE] = ACTIONS(464),
    [anon_sym_AMP_AMP] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(462),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_EQ_EQ] = ACTIONS(464),
    [anon_sym_BANG_EQ] = ACTIONS(464),
    [anon_sym_GT] = ACTIONS(462),
    [anon_sym_GT_EQ] = ACTIONS(464),
    [anon_sym_LT_EQ] = ACTIONS(464),
    [anon_sym_LT] = ACTIONS(462),
    [anon_sym_LT_LT] = ACTIONS(464),
    [anon_sym_GT_GT] = ACTIONS(462),
    [anon_sym_GT_GT_GT] = ACTIONS(464),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(464),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(462),
    [anon_sym_public] = ACTIONS(462),
    [anon_sym_stock] = ACTIONS(462),
    [anon_sym_static] = ACTIONS(462),
    [anon_sym_new] = ACTIONS(462),
    [anon_sym_decl] = ACTIONS(462),
    [anon_sym_LBRACE] = ACTIONS(464),
    [anon_sym_RBRACE] = ACTIONS(464),
    [anon_sym_LBRACK] = ACTIONS(464),
    [anon_sym_void] = ACTIONS(462),
    [anon_sym_bool] = ACTIONS(462),
    [anon_sym_int] = ACTIONS(462),
    [anon_sym_float] = ACTIONS(462),
    [anon_sym_char] = ACTIONS(462),
    [anon_sym__] = ACTIONS(462),
    [anon_sym_Float] = ACTIONS(462),
    [anon_sym_String] = ACTIONS(462),
    [sym_any_type] = ACTIONS(462),
    [anon_sym_for] = ACTIONS(462),
    [anon_sym_while] = ACTIONS(462),
    [anon_sym_do] = ACTIONS(462),
    [anon_sym_break] = ACTIONS(462),
    [anon_sym_continue] = ACTIONS(462),
    [anon_sym_if] = ACTIONS(462),
    [anon_sym_else] = ACTIONS(462),
    [anon_sym_switch] = ACTIONS(462),
    [anon_sym_return] = ACTIONS(462),
    [anon_sym_delete] = ACTIONS(462),
    [anon_sym_SEMI] = ACTIONS(464),
    [anon_sym_DOT] = ACTIONS(462),
    [anon_sym_QMARK] = ACTIONS(464),
    [anon_sym_DASH_DASH] = ACTIONS(464),
    [anon_sym_PLUS_PLUS] = ACTIONS(464),
    [anon_sym_sizeof] = ACTIONS(462),
    [anon_sym_view_as] = ACTIONS(462),
    [sym_int_literal] = ACTIONS(462),
    [sym_float_literal] = ACTIONS(464),
    [anon_sym_SQUOTE] = ACTIONS(464),
    [anon_sym_DQUOTE] = ACTIONS(464),
    [sym_bool_literal] = ACTIONS(462),
    [sym_null] = ACTIONS(462),
    [sym_this] = ACTIONS(462),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(464),
  },
  [105] = {
    [sym_preproc_include] = STATE(105),
    [sym_preproc_tryinclude] = STATE(105),
    [sym_preproc_macro] = STATE(105),
    [sym_preproc_define] = STATE(105),
    [sym_preproc_undefine] = STATE(105),
    [sym_preproc_if] = STATE(105),
    [sym_preproc_elseif] = STATE(105),
    [sym_preproc_assert] = STATE(105),
    [sym_preproc_pragma] = STATE(105),
    [sym_preproc_error] = STATE(105),
    [sym_preproc_warning] = STATE(105),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(441),
    [sym_identifier] = ACTIONS(466),
    [anon_sym_LPAREN] = ACTIONS(468),
    [anon_sym_BANG] = ACTIONS(466),
    [anon_sym_TILDE] = ACTIONS(468),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(424),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(432),
    [anon_sym_AMP_AMP] = ACTIONS(434),
    [anon_sym_PIPE] = ACTIONS(436),
    [anon_sym_CARET] = ACTIONS(438),
    [anon_sym_EQ_EQ] = ACTIONS(440),
    [anon_sym_BANG_EQ] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(466),
    [anon_sym_public] = ACTIONS(466),
    [anon_sym_stock] = ACTIONS(466),
    [anon_sym_static] = ACTIONS(466),
    [anon_sym_new] = ACTIONS(466),
    [anon_sym_decl] = ACTIONS(466),
    [anon_sym_LBRACE] = ACTIONS(468),
    [anon_sym_RBRACE] = ACTIONS(468),
    [anon_sym_void] = ACTIONS(466),
    [anon_sym_bool] = ACTIONS(466),
    [anon_sym_int] = ACTIONS(466),
    [anon_sym_float] = ACTIONS(466),
    [anon_sym_char] = ACTIONS(466),
    [anon_sym__] = ACTIONS(466),
    [anon_sym_Float] = ACTIONS(466),
    [anon_sym_String] = ACTIONS(466),
    [sym_any_type] = ACTIONS(466),
    [anon_sym_for] = ACTIONS(466),
    [anon_sym_while] = ACTIONS(466),
    [anon_sym_do] = ACTIONS(466),
    [anon_sym_break] = ACTIONS(466),
    [anon_sym_continue] = ACTIONS(466),
    [anon_sym_if] = ACTIONS(466),
    [anon_sym_else] = ACTIONS(466),
    [anon_sym_switch] = ACTIONS(466),
    [anon_sym_return] = ACTIONS(466),
    [anon_sym_delete] = ACTIONS(466),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(454),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(466),
    [anon_sym_view_as] = ACTIONS(466),
    [sym_int_literal] = ACTIONS(466),
    [sym_float_literal] = ACTIONS(468),
    [anon_sym_SQUOTE] = ACTIONS(468),
    [anon_sym_DQUOTE] = ACTIONS(468),
    [sym_bool_literal] = ACTIONS(466),
    [sym_null] = ACTIONS(466),
    [sym_this] = ACTIONS(466),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [106] = {
    [sym_preproc_include] = STATE(106),
    [sym_preproc_tryinclude] = STATE(106),
    [sym_preproc_macro] = STATE(106),
    [sym_preproc_define] = STATE(106),
    [sym_preproc_undefine] = STATE(106),
    [sym_preproc_if] = STATE(106),
    [sym_preproc_elseif] = STATE(106),
    [sym_preproc_assert] = STATE(106),
    [sym_preproc_pragma] = STATE(106),
    [sym_preproc_error] = STATE(106),
    [sym_preproc_warning] = STATE(106),
    [sym_identifier] = ACTIONS(470),
    [anon_sym_LPAREN] = ACTIONS(472),
    [anon_sym_BANG] = ACTIONS(470),
    [anon_sym_TILDE] = ACTIONS(472),
    [anon_sym_DASH] = ACTIONS(470),
    [anon_sym_PLUS] = ACTIONS(470),
    [anon_sym_AMP] = ACTIONS(470),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(472),
    [anon_sym_STAR] = ACTIONS(472),
    [anon_sym_SLASH] = ACTIONS(470),
    [anon_sym_PERCENT] = ACTIONS(472),
    [anon_sym_PIPE_PIPE] = ACTIONS(472),
    [anon_sym_AMP_AMP] = ACTIONS(472),
    [anon_sym_PIPE] = ACTIONS(470),
    [anon_sym_CARET] = ACTIONS(472),
    [anon_sym_EQ_EQ] = ACTIONS(472),
    [anon_sym_BANG_EQ] = ACTIONS(472),
    [anon_sym_GT] = ACTIONS(470),
    [anon_sym_GT_EQ] = ACTIONS(472),
    [anon_sym_LT_EQ] = ACTIONS(472),
    [anon_sym_LT] = ACTIONS(470),
    [anon_sym_LT_LT] = ACTIONS(472),
    [anon_sym_GT_GT] = ACTIONS(470),
    [anon_sym_GT_GT_GT] = ACTIONS(472),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(472),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(470),
    [anon_sym_public] = ACTIONS(470),
    [anon_sym_stock] = ACTIONS(470),
    [anon_sym_static] = ACTIONS(470),
    [anon_sym_new] = ACTIONS(470),
    [anon_sym_decl] = ACTIONS(470),
    [anon_sym_LBRACE] = ACTIONS(472),
    [anon_sym_RBRACE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(472),
    [anon_sym_void] = ACTIONS(470),
    [anon_sym_bool] = ACTIONS(470),
    [anon_sym_int] = ACTIONS(470),
    [anon_sym_float] = ACTIONS(470),
    [anon_sym_char] = ACTIONS(470),
    [anon_sym__] = ACTIONS(470),
    [anon_sym_Float] = ACTIONS(470),
    [anon_sym_String] = ACTIONS(470),
    [sym_any_type] = ACTIONS(470),
    [anon_sym_for] = ACTIONS(470),
    [anon_sym_while] = ACTIONS(470),
    [anon_sym_do] = ACTIONS(470),
    [anon_sym_break] = ACTIONS(470),
    [anon_sym_continue] = ACTIONS(470),
    [anon_sym_if] = ACTIONS(470),
    [anon_sym_else] = ACTIONS(470),
    [anon_sym_switch] = ACTIONS(470),
    [anon_sym_return] = ACTIONS(470),
    [anon_sym_delete] = ACTIONS(470),
    [anon_sym_SEMI] = ACTIONS(472),
    [anon_sym_DOT] = ACTIONS(470),
    [anon_sym_QMARK] = ACTIONS(472),
    [anon_sym_DASH_DASH] = ACTIONS(472),
    [anon_sym_PLUS_PLUS] = ACTIONS(472),
    [anon_sym_sizeof] = ACTIONS(470),
    [anon_sym_view_as] = ACTIONS(470),
    [sym_int_literal] = ACTIONS(470),
    [sym_float_literal] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_DQUOTE] = ACTIONS(472),
    [sym_bool_literal] = ACTIONS(470),
    [sym_null] = ACTIONS(470),
    [sym_this] = ACTIONS(470),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(472),
  },
  [107] = {
    [sym_preproc_include] = STATE(107),
    [sym_preproc_tryinclude] = STATE(107),
    [sym_preproc_macro] = STATE(107),
    [sym_preproc_define] = STATE(107),
    [sym_preproc_undefine] = STATE(107),
    [sym_preproc_if] = STATE(107),
    [sym_preproc_elseif] = STATE(107),
    [sym_preproc_assert] = STATE(107),
    [sym_preproc_pragma] = STATE(107),
    [sym_preproc_error] = STATE(107),
    [sym_preproc_warning] = STATE(107),
    [sym_identifier] = ACTIONS(474),
    [anon_sym_LPAREN] = ACTIONS(476),
    [anon_sym_BANG] = ACTIONS(474),
    [anon_sym_TILDE] = ACTIONS(476),
    [anon_sym_DASH] = ACTIONS(474),
    [anon_sym_PLUS] = ACTIONS(474),
    [anon_sym_AMP] = ACTIONS(474),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(476),
    [anon_sym_STAR] = ACTIONS(476),
    [anon_sym_SLASH] = ACTIONS(474),
    [anon_sym_PERCENT] = ACTIONS(476),
    [anon_sym_PIPE_PIPE] = ACTIONS(476),
    [anon_sym_AMP_AMP] = ACTIONS(476),
    [anon_sym_PIPE] = ACTIONS(474),
    [anon_sym_CARET] = ACTIONS(476),
    [anon_sym_EQ_EQ] = ACTIONS(476),
    [anon_sym_BANG_EQ] = ACTIONS(476),
    [anon_sym_GT] = ACTIONS(474),
    [anon_sym_GT_EQ] = ACTIONS(476),
    [anon_sym_LT_EQ] = ACTIONS(476),
    [anon_sym_LT] = ACTIONS(474),
    [anon_sym_LT_LT] = ACTIONS(476),
    [anon_sym_GT_GT] = ACTIONS(474),
    [anon_sym_GT_GT_GT] = ACTIONS(476),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(476),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(474),
    [anon_sym_public] = ACTIONS(474),
    [anon_sym_stock] = ACTIONS(474),
    [anon_sym_static] = ACTIONS(474),
    [anon_sym_new] = ACTIONS(474),
    [anon_sym_decl] = ACTIONS(474),
    [anon_sym_LBRACE] = ACTIONS(476),
    [anon_sym_RBRACE] = ACTIONS(476),
    [anon_sym_LBRACK] = ACTIONS(476),
    [anon_sym_void] = ACTIONS(474),
    [anon_sym_bool] = ACTIONS(474),
    [anon_sym_int] = ACTIONS(474),
    [anon_sym_float] = ACTIONS(474),
    [anon_sym_char] = ACTIONS(474),
    [anon_sym__] = ACTIONS(474),
    [anon_sym_Float] = ACTIONS(474),
    [anon_sym_String] = ACTIONS(474),
    [sym_any_type] = ACTIONS(474),
    [anon_sym_for] = ACTIONS(474),
    [anon_sym_while] = ACTIONS(474),
    [anon_sym_do] = ACTIONS(474),
    [anon_sym_break] = ACTIONS(474),
    [anon_sym_continue] = ACTIONS(474),
    [anon_sym_if] = ACTIONS(474),
    [anon_sym_else] = ACTIONS(474),
    [anon_sym_switch] = ACTIONS(474),
    [anon_sym_return] = ACTIONS(474),
    [anon_sym_delete] = ACTIONS(474),
    [anon_sym_SEMI] = ACTIONS(476),
    [anon_sym_DOT] = ACTIONS(474),
    [anon_sym_QMARK] = ACTIONS(476),
    [anon_sym_DASH_DASH] = ACTIONS(476),
    [anon_sym_PLUS_PLUS] = ACTIONS(476),
    [anon_sym_sizeof] = ACTIONS(474),
    [anon_sym_view_as] = ACTIONS(474),
    [sym_int_literal] = ACTIONS(474),
    [sym_float_literal] = ACTIONS(476),
    [anon_sym_SQUOTE] = ACTIONS(476),
    [anon_sym_DQUOTE] = ACTIONS(476),
    [sym_bool_literal] = ACTIONS(474),
    [sym_null] = ACTIONS(474),
    [sym_this] = ACTIONS(474),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(476),
  },
  [108] = {
    [sym_preproc_include] = STATE(108),
    [sym_preproc_tryinclude] = STATE(108),
    [sym_preproc_macro] = STATE(108),
    [sym_preproc_define] = STATE(108),
    [sym_preproc_undefine] = STATE(108),
    [sym_preproc_if] = STATE(108),
    [sym_preproc_elseif] = STATE(108),
    [sym_preproc_assert] = STATE(108),
    [sym_preproc_pragma] = STATE(108),
    [sym_preproc_error] = STATE(108),
    [sym_preproc_warning] = STATE(108),
    [sym_identifier] = ACTIONS(478),
    [anon_sym_LPAREN] = ACTIONS(480),
    [anon_sym_BANG] = ACTIONS(478),
    [anon_sym_TILDE] = ACTIONS(480),
    [anon_sym_DASH] = ACTIONS(478),
    [anon_sym_PLUS] = ACTIONS(478),
    [anon_sym_AMP] = ACTIONS(478),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(480),
    [anon_sym_STAR] = ACTIONS(480),
    [anon_sym_SLASH] = ACTIONS(478),
    [anon_sym_PERCENT] = ACTIONS(480),
    [anon_sym_PIPE_PIPE] = ACTIONS(480),
    [anon_sym_AMP_AMP] = ACTIONS(480),
    [anon_sym_PIPE] = ACTIONS(478),
    [anon_sym_CARET] = ACTIONS(480),
    [anon_sym_EQ_EQ] = ACTIONS(480),
    [anon_sym_BANG_EQ] = ACTIONS(480),
    [anon_sym_GT] = ACTIONS(478),
    [anon_sym_GT_EQ] = ACTIONS(480),
    [anon_sym_LT_EQ] = ACTIONS(480),
    [anon_sym_LT] = ACTIONS(478),
    [anon_sym_LT_LT] = ACTIONS(480),
    [anon_sym_GT_GT] = ACTIONS(478),
    [anon_sym_GT_GT_GT] = ACTIONS(480),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(480),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(478),
    [anon_sym_public] = ACTIONS(478),
    [anon_sym_stock] = ACTIONS(478),
    [anon_sym_static] = ACTIONS(478),
    [anon_sym_new] = ACTIONS(478),
    [anon_sym_decl] = ACTIONS(478),
    [anon_sym_LBRACE] = ACTIONS(480),
    [anon_sym_RBRACE] = ACTIONS(480),
    [anon_sym_LBRACK] = ACTIONS(480),
    [anon_sym_void] = ACTIONS(478),
    [anon_sym_bool] = ACTIONS(478),
    [anon_sym_int] = ACTIONS(478),
    [anon_sym_float] = ACTIONS(478),
    [anon_sym_char] = ACTIONS(478),
    [anon_sym__] = ACTIONS(478),
    [anon_sym_Float] = ACTIONS(478),
    [anon_sym_String] = ACTIONS(478),
    [sym_any_type] = ACTIONS(478),
    [anon_sym_for] = ACTIONS(478),
    [anon_sym_while] = ACTIONS(478),
    [anon_sym_do] = ACTIONS(478),
    [anon_sym_break] = ACTIONS(478),
    [anon_sym_continue] = ACTIONS(478),
    [anon_sym_if] = ACTIONS(478),
    [anon_sym_else] = ACTIONS(478),
    [anon_sym_switch] = ACTIONS(478),
    [anon_sym_return] = ACTIONS(478),
    [anon_sym_delete] = ACTIONS(478),
    [anon_sym_SEMI] = ACTIONS(480),
    [anon_sym_DOT] = ACTIONS(478),
    [anon_sym_QMARK] = ACTIONS(480),
    [anon_sym_DASH_DASH] = ACTIONS(480),
    [anon_sym_PLUS_PLUS] = ACTIONS(480),
    [anon_sym_sizeof] = ACTIONS(478),
    [anon_sym_view_as] = ACTIONS(478),
    [sym_int_literal] = ACTIONS(478),
    [sym_float_literal] = ACTIONS(480),
    [anon_sym_SQUOTE] = ACTIONS(480),
    [anon_sym_DQUOTE] = ACTIONS(480),
    [sym_bool_literal] = ACTIONS(478),
    [sym_null] = ACTIONS(478),
    [sym_this] = ACTIONS(478),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(480),
  },
  [109] = {
    [sym_preproc_include] = STATE(109),
    [sym_preproc_tryinclude] = STATE(109),
    [sym_preproc_macro] = STATE(109),
    [sym_preproc_define] = STATE(109),
    [sym_preproc_undefine] = STATE(109),
    [sym_preproc_if] = STATE(109),
    [sym_preproc_elseif] = STATE(109),
    [sym_preproc_assert] = STATE(109),
    [sym_preproc_pragma] = STATE(109),
    [sym_preproc_error] = STATE(109),
    [sym_preproc_warning] = STATE(109),
    [sym_identifier] = ACTIONS(482),
    [anon_sym_LPAREN] = ACTIONS(484),
    [anon_sym_BANG] = ACTIONS(482),
    [anon_sym_TILDE] = ACTIONS(484),
    [anon_sym_DASH] = ACTIONS(482),
    [anon_sym_PLUS] = ACTIONS(482),
    [anon_sym_AMP] = ACTIONS(482),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(484),
    [anon_sym_STAR] = ACTIONS(484),
    [anon_sym_SLASH] = ACTIONS(482),
    [anon_sym_PERCENT] = ACTIONS(484),
    [anon_sym_PIPE_PIPE] = ACTIONS(484),
    [anon_sym_AMP_AMP] = ACTIONS(484),
    [anon_sym_PIPE] = ACTIONS(482),
    [anon_sym_CARET] = ACTIONS(484),
    [anon_sym_EQ_EQ] = ACTIONS(484),
    [anon_sym_BANG_EQ] = ACTIONS(484),
    [anon_sym_GT] = ACTIONS(482),
    [anon_sym_GT_EQ] = ACTIONS(484),
    [anon_sym_LT_EQ] = ACTIONS(484),
    [anon_sym_LT] = ACTIONS(482),
    [anon_sym_LT_LT] = ACTIONS(484),
    [anon_sym_GT_GT] = ACTIONS(482),
    [anon_sym_GT_GT_GT] = ACTIONS(484),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(484),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(482),
    [anon_sym_public] = ACTIONS(482),
    [anon_sym_stock] = ACTIONS(482),
    [anon_sym_static] = ACTIONS(482),
    [anon_sym_new] = ACTIONS(482),
    [anon_sym_decl] = ACTIONS(482),
    [anon_sym_LBRACE] = ACTIONS(484),
    [anon_sym_RBRACE] = ACTIONS(484),
    [anon_sym_void] = ACTIONS(482),
    [anon_sym_bool] = ACTIONS(482),
    [anon_sym_int] = ACTIONS(482),
    [anon_sym_float] = ACTIONS(482),
    [anon_sym_char] = ACTIONS(482),
    [anon_sym__] = ACTIONS(482),
    [anon_sym_Float] = ACTIONS(482),
    [anon_sym_String] = ACTIONS(482),
    [sym_any_type] = ACTIONS(482),
    [anon_sym_for] = ACTIONS(482),
    [anon_sym_while] = ACTIONS(482),
    [anon_sym_do] = ACTIONS(482),
    [anon_sym_break] = ACTIONS(482),
    [anon_sym_continue] = ACTIONS(482),
    [anon_sym_if] = ACTIONS(482),
    [anon_sym_else] = ACTIONS(482),
    [anon_sym_switch] = ACTIONS(482),
    [anon_sym_return] = ACTIONS(482),
    [anon_sym_delete] = ACTIONS(482),
    [anon_sym_SEMI] = ACTIONS(484),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(484),
    [anon_sym_DASH_DASH] = ACTIONS(484),
    [anon_sym_PLUS_PLUS] = ACTIONS(484),
    [anon_sym_sizeof] = ACTIONS(482),
    [anon_sym_view_as] = ACTIONS(482),
    [sym_int_literal] = ACTIONS(482),
    [sym_float_literal] = ACTIONS(484),
    [anon_sym_SQUOTE] = ACTIONS(484),
    [anon_sym_DQUOTE] = ACTIONS(484),
    [sym_bool_literal] = ACTIONS(482),
    [sym_null] = ACTIONS(482),
    [sym_this] = ACTIONS(482),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(484),
  },
  [110] = {
    [sym_preproc_include] = STATE(110),
    [sym_preproc_tryinclude] = STATE(110),
    [sym_preproc_macro] = STATE(110),
    [sym_preproc_define] = STATE(110),
    [sym_preproc_undefine] = STATE(110),
    [sym_preproc_if] = STATE(110),
    [sym_preproc_elseif] = STATE(110),
    [sym_preproc_assert] = STATE(110),
    [sym_preproc_pragma] = STATE(110),
    [sym_preproc_error] = STATE(110),
    [sym_preproc_warning] = STATE(110),
    [sym_identifier] = ACTIONS(486),
    [anon_sym_LPAREN] = ACTIONS(488),
    [anon_sym_BANG] = ACTIONS(486),
    [anon_sym_TILDE] = ACTIONS(488),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(424),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(432),
    [anon_sym_AMP_AMP] = ACTIONS(434),
    [anon_sym_PIPE] = ACTIONS(436),
    [anon_sym_CARET] = ACTIONS(438),
    [anon_sym_EQ_EQ] = ACTIONS(440),
    [anon_sym_BANG_EQ] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(488),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(486),
    [anon_sym_public] = ACTIONS(486),
    [anon_sym_stock] = ACTIONS(486),
    [anon_sym_static] = ACTIONS(486),
    [anon_sym_new] = ACTIONS(486),
    [anon_sym_decl] = ACTIONS(486),
    [anon_sym_LBRACE] = ACTIONS(488),
    [anon_sym_RBRACE] = ACTIONS(488),
    [anon_sym_void] = ACTIONS(486),
    [anon_sym_bool] = ACTIONS(486),
    [anon_sym_int] = ACTIONS(486),
    [anon_sym_float] = ACTIONS(486),
    [anon_sym_char] = ACTIONS(486),
    [anon_sym__] = ACTIONS(486),
    [anon_sym_Float] = ACTIONS(486),
    [anon_sym_String] = ACTIONS(486),
    [sym_any_type] = ACTIONS(486),
    [anon_sym_for] = ACTIONS(486),
    [anon_sym_while] = ACTIONS(486),
    [anon_sym_do] = ACTIONS(486),
    [anon_sym_break] = ACTIONS(486),
    [anon_sym_continue] = ACTIONS(486),
    [anon_sym_if] = ACTIONS(486),
    [anon_sym_else] = ACTIONS(486),
    [anon_sym_switch] = ACTIONS(486),
    [anon_sym_return] = ACTIONS(486),
    [anon_sym_delete] = ACTIONS(486),
    [anon_sym_SEMI] = ACTIONS(488),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(454),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(486),
    [anon_sym_view_as] = ACTIONS(486),
    [sym_int_literal] = ACTIONS(486),
    [sym_float_literal] = ACTIONS(488),
    [anon_sym_SQUOTE] = ACTIONS(488),
    [anon_sym_DQUOTE] = ACTIONS(488),
    [sym_bool_literal] = ACTIONS(486),
    [sym_null] = ACTIONS(486),
    [sym_this] = ACTIONS(486),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(488),
  },
  [111] = {
    [sym_preproc_include] = STATE(111),
    [sym_preproc_tryinclude] = STATE(111),
    [sym_preproc_macro] = STATE(111),
    [sym_preproc_define] = STATE(111),
    [sym_preproc_undefine] = STATE(111),
    [sym_preproc_if] = STATE(111),
    [sym_preproc_elseif] = STATE(111),
    [sym_preproc_assert] = STATE(111),
    [sym_preproc_pragma] = STATE(111),
    [sym_preproc_error] = STATE(111),
    [sym_preproc_warning] = STATE(111),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(246),
    [anon_sym_BANG] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(246),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(246),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(246),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(246),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(246),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(246),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_do] = ACTIONS(244),
    [anon_sym_break] = ACTIONS(244),
    [anon_sym_continue] = ACTIONS(244),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_else] = ACTIONS(244),
    [anon_sym_switch] = ACTIONS(244),
    [anon_sym_return] = ACTIONS(244),
    [anon_sym_delete] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [anon_sym_sizeof] = ACTIONS(244),
    [anon_sym_view_as] = ACTIONS(244),
    [sym_int_literal] = ACTIONS(244),
    [sym_float_literal] = ACTIONS(246),
    [anon_sym_SQUOTE] = ACTIONS(246),
    [anon_sym_DQUOTE] = ACTIONS(246),
    [sym_bool_literal] = ACTIONS(244),
    [sym_null] = ACTIONS(244),
    [sym_this] = ACTIONS(244),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [112] = {
    [sym_preproc_include] = STATE(112),
    [sym_preproc_tryinclude] = STATE(112),
    [sym_preproc_macro] = STATE(112),
    [sym_preproc_define] = STATE(112),
    [sym_preproc_undefine] = STATE(112),
    [sym_preproc_if] = STATE(112),
    [sym_preproc_elseif] = STATE(112),
    [sym_preproc_assert] = STATE(112),
    [sym_preproc_pragma] = STATE(112),
    [sym_preproc_error] = STATE(112),
    [sym_preproc_warning] = STATE(112),
    [sym_identifier] = ACTIONS(490),
    [anon_sym_LPAREN] = ACTIONS(492),
    [anon_sym_BANG] = ACTIONS(490),
    [anon_sym_TILDE] = ACTIONS(492),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(424),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(432),
    [anon_sym_AMP_AMP] = ACTIONS(434),
    [anon_sym_PIPE] = ACTIONS(436),
    [anon_sym_CARET] = ACTIONS(438),
    [anon_sym_EQ_EQ] = ACTIONS(440),
    [anon_sym_BANG_EQ] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(492),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(490),
    [anon_sym_public] = ACTIONS(490),
    [anon_sym_stock] = ACTIONS(490),
    [anon_sym_static] = ACTIONS(490),
    [anon_sym_new] = ACTIONS(490),
    [anon_sym_decl] = ACTIONS(490),
    [anon_sym_LBRACE] = ACTIONS(492),
    [anon_sym_RBRACE] = ACTIONS(492),
    [anon_sym_void] = ACTIONS(490),
    [anon_sym_bool] = ACTIONS(490),
    [anon_sym_int] = ACTIONS(490),
    [anon_sym_float] = ACTIONS(490),
    [anon_sym_char] = ACTIONS(490),
    [anon_sym__] = ACTIONS(490),
    [anon_sym_Float] = ACTIONS(490),
    [anon_sym_String] = ACTIONS(490),
    [sym_any_type] = ACTIONS(490),
    [anon_sym_for] = ACTIONS(490),
    [anon_sym_while] = ACTIONS(490),
    [anon_sym_do] = ACTIONS(490),
    [anon_sym_break] = ACTIONS(490),
    [anon_sym_continue] = ACTIONS(490),
    [anon_sym_if] = ACTIONS(490),
    [anon_sym_else] = ACTIONS(490),
    [anon_sym_switch] = ACTIONS(490),
    [anon_sym_return] = ACTIONS(490),
    [anon_sym_delete] = ACTIONS(490),
    [anon_sym_SEMI] = ACTIONS(492),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(454),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(490),
    [anon_sym_view_as] = ACTIONS(490),
    [sym_int_literal] = ACTIONS(490),
    [sym_float_literal] = ACTIONS(492),
    [anon_sym_SQUOTE] = ACTIONS(492),
    [anon_sym_DQUOTE] = ACTIONS(492),
    [sym_bool_literal] = ACTIONS(490),
    [sym_null] = ACTIONS(490),
    [sym_this] = ACTIONS(490),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(492),
  },
  [113] = {
    [sym_preproc_include] = STATE(113),
    [sym_preproc_tryinclude] = STATE(113),
    [sym_preproc_macro] = STATE(113),
    [sym_preproc_define] = STATE(113),
    [sym_preproc_undefine] = STATE(113),
    [sym_preproc_if] = STATE(113),
    [sym_preproc_elseif] = STATE(113),
    [sym_preproc_assert] = STATE(113),
    [sym_preproc_pragma] = STATE(113),
    [sym_preproc_error] = STATE(113),
    [sym_preproc_warning] = STATE(113),
    [sym_identifier] = ACTIONS(494),
    [anon_sym_LPAREN] = ACTIONS(496),
    [anon_sym_BANG] = ACTIONS(494),
    [anon_sym_TILDE] = ACTIONS(496),
    [anon_sym_DASH] = ACTIONS(494),
    [anon_sym_PLUS] = ACTIONS(494),
    [anon_sym_AMP] = ACTIONS(494),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(496),
    [anon_sym_STAR] = ACTIONS(496),
    [anon_sym_SLASH] = ACTIONS(494),
    [anon_sym_PERCENT] = ACTIONS(496),
    [anon_sym_PIPE_PIPE] = ACTIONS(496),
    [anon_sym_AMP_AMP] = ACTIONS(496),
    [anon_sym_PIPE] = ACTIONS(494),
    [anon_sym_CARET] = ACTIONS(496),
    [anon_sym_EQ_EQ] = ACTIONS(496),
    [anon_sym_BANG_EQ] = ACTIONS(496),
    [anon_sym_GT] = ACTIONS(494),
    [anon_sym_GT_EQ] = ACTIONS(496),
    [anon_sym_LT_EQ] = ACTIONS(496),
    [anon_sym_LT] = ACTIONS(494),
    [anon_sym_LT_LT] = ACTIONS(496),
    [anon_sym_GT_GT] = ACTIONS(494),
    [anon_sym_GT_GT_GT] = ACTIONS(496),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(496),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(494),
    [anon_sym_public] = ACTIONS(494),
    [anon_sym_stock] = ACTIONS(494),
    [anon_sym_static] = ACTIONS(494),
    [anon_sym_new] = ACTIONS(494),
    [anon_sym_decl] = ACTIONS(494),
    [anon_sym_LBRACE] = ACTIONS(496),
    [anon_sym_RBRACE] = ACTIONS(496),
    [anon_sym_void] = ACTIONS(494),
    [anon_sym_bool] = ACTIONS(494),
    [anon_sym_int] = ACTIONS(494),
    [anon_sym_float] = ACTIONS(494),
    [anon_sym_char] = ACTIONS(494),
    [anon_sym__] = ACTIONS(494),
    [anon_sym_Float] = ACTIONS(494),
    [anon_sym_String] = ACTIONS(494),
    [sym_any_type] = ACTIONS(494),
    [anon_sym_for] = ACTIONS(494),
    [anon_sym_while] = ACTIONS(494),
    [anon_sym_do] = ACTIONS(494),
    [anon_sym_break] = ACTIONS(494),
    [anon_sym_continue] = ACTIONS(494),
    [anon_sym_if] = ACTIONS(494),
    [anon_sym_else] = ACTIONS(494),
    [anon_sym_switch] = ACTIONS(494),
    [anon_sym_return] = ACTIONS(494),
    [anon_sym_delete] = ACTIONS(494),
    [anon_sym_SEMI] = ACTIONS(496),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(496),
    [anon_sym_DASH_DASH] = ACTIONS(496),
    [anon_sym_PLUS_PLUS] = ACTIONS(496),
    [anon_sym_sizeof] = ACTIONS(494),
    [anon_sym_view_as] = ACTIONS(494),
    [sym_int_literal] = ACTIONS(494),
    [sym_float_literal] = ACTIONS(496),
    [anon_sym_SQUOTE] = ACTIONS(496),
    [anon_sym_DQUOTE] = ACTIONS(496),
    [sym_bool_literal] = ACTIONS(494),
    [sym_null] = ACTIONS(494),
    [sym_this] = ACTIONS(494),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(496),
  },
  [114] = {
    [sym_preproc_include] = STATE(114),
    [sym_preproc_tryinclude] = STATE(114),
    [sym_preproc_macro] = STATE(114),
    [sym_preproc_define] = STATE(114),
    [sym_preproc_undefine] = STATE(114),
    [sym_preproc_if] = STATE(114),
    [sym_preproc_elseif] = STATE(114),
    [sym_preproc_assert] = STATE(114),
    [sym_preproc_pragma] = STATE(114),
    [sym_preproc_error] = STATE(114),
    [sym_preproc_warning] = STATE(114),
    [sym_identifier] = ACTIONS(498),
    [anon_sym_LPAREN] = ACTIONS(500),
    [anon_sym_BANG] = ACTIONS(498),
    [anon_sym_TILDE] = ACTIONS(500),
    [anon_sym_DASH] = ACTIONS(498),
    [anon_sym_PLUS] = ACTIONS(498),
    [anon_sym_AMP] = ACTIONS(498),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(500),
    [anon_sym_STAR] = ACTIONS(500),
    [anon_sym_SLASH] = ACTIONS(498),
    [anon_sym_PERCENT] = ACTIONS(500),
    [anon_sym_PIPE_PIPE] = ACTIONS(500),
    [anon_sym_AMP_AMP] = ACTIONS(500),
    [anon_sym_PIPE] = ACTIONS(498),
    [anon_sym_CARET] = ACTIONS(500),
    [anon_sym_EQ_EQ] = ACTIONS(500),
    [anon_sym_BANG_EQ] = ACTIONS(500),
    [anon_sym_GT] = ACTIONS(498),
    [anon_sym_GT_EQ] = ACTIONS(500),
    [anon_sym_LT_EQ] = ACTIONS(500),
    [anon_sym_LT] = ACTIONS(498),
    [anon_sym_LT_LT] = ACTIONS(500),
    [anon_sym_GT_GT] = ACTIONS(498),
    [anon_sym_GT_GT_GT] = ACTIONS(500),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(500),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(498),
    [anon_sym_public] = ACTIONS(498),
    [anon_sym_stock] = ACTIONS(498),
    [anon_sym_static] = ACTIONS(498),
    [anon_sym_new] = ACTIONS(498),
    [anon_sym_decl] = ACTIONS(498),
    [anon_sym_LBRACE] = ACTIONS(500),
    [anon_sym_RBRACE] = ACTIONS(500),
    [anon_sym_void] = ACTIONS(498),
    [anon_sym_bool] = ACTIONS(498),
    [anon_sym_int] = ACTIONS(498),
    [anon_sym_float] = ACTIONS(498),
    [anon_sym_char] = ACTIONS(498),
    [anon_sym__] = ACTIONS(498),
    [anon_sym_Float] = ACTIONS(498),
    [anon_sym_String] = ACTIONS(498),
    [sym_any_type] = ACTIONS(498),
    [anon_sym_for] = ACTIONS(498),
    [anon_sym_while] = ACTIONS(498),
    [anon_sym_do] = ACTIONS(498),
    [anon_sym_break] = ACTIONS(498),
    [anon_sym_continue] = ACTIONS(498),
    [anon_sym_if] = ACTIONS(498),
    [anon_sym_else] = ACTIONS(498),
    [anon_sym_switch] = ACTIONS(498),
    [anon_sym_return] = ACTIONS(498),
    [anon_sym_delete] = ACTIONS(498),
    [anon_sym_SEMI] = ACTIONS(500),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(500),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(498),
    [anon_sym_view_as] = ACTIONS(498),
    [sym_int_literal] = ACTIONS(498),
    [sym_float_literal] = ACTIONS(500),
    [anon_sym_SQUOTE] = ACTIONS(500),
    [anon_sym_DQUOTE] = ACTIONS(500),
    [sym_bool_literal] = ACTIONS(498),
    [sym_null] = ACTIONS(498),
    [sym_this] = ACTIONS(498),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(500),
  },
  [115] = {
    [sym_preproc_include] = STATE(115),
    [sym_preproc_tryinclude] = STATE(115),
    [sym_preproc_macro] = STATE(115),
    [sym_preproc_define] = STATE(115),
    [sym_preproc_undefine] = STATE(115),
    [sym_preproc_if] = STATE(115),
    [sym_preproc_elseif] = STATE(115),
    [sym_preproc_assert] = STATE(115),
    [sym_preproc_pragma] = STATE(115),
    [sym_preproc_error] = STATE(115),
    [sym_preproc_warning] = STATE(115),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_LPAREN] = ACTIONS(504),
    [anon_sym_BANG] = ACTIONS(502),
    [anon_sym_TILDE] = ACTIONS(504),
    [anon_sym_DASH] = ACTIONS(502),
    [anon_sym_PLUS] = ACTIONS(502),
    [anon_sym_AMP] = ACTIONS(502),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(504),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(504),
    [anon_sym_BANG_EQ] = ACTIONS(504),
    [anon_sym_GT] = ACTIONS(502),
    [anon_sym_GT_EQ] = ACTIONS(504),
    [anon_sym_LT_EQ] = ACTIONS(504),
    [anon_sym_LT] = ACTIONS(502),
    [anon_sym_LT_LT] = ACTIONS(504),
    [anon_sym_GT_GT] = ACTIONS(502),
    [anon_sym_GT_GT_GT] = ACTIONS(504),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_LBRACE] = ACTIONS(504),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_for] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_do] = ACTIONS(502),
    [anon_sym_break] = ACTIONS(502),
    [anon_sym_continue] = ACTIONS(502),
    [anon_sym_if] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_switch] = ACTIONS(502),
    [anon_sym_return] = ACTIONS(502),
    [anon_sym_delete] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(502),
    [anon_sym_view_as] = ACTIONS(502),
    [sym_int_literal] = ACTIONS(502),
    [sym_float_literal] = ACTIONS(504),
    [anon_sym_SQUOTE] = ACTIONS(504),
    [anon_sym_DQUOTE] = ACTIONS(504),
    [sym_bool_literal] = ACTIONS(502),
    [sym_null] = ACTIONS(502),
    [sym_this] = ACTIONS(502),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [116] = {
    [sym_preproc_include] = STATE(116),
    [sym_preproc_tryinclude] = STATE(116),
    [sym_preproc_macro] = STATE(116),
    [sym_preproc_define] = STATE(116),
    [sym_preproc_undefine] = STATE(116),
    [sym_preproc_if] = STATE(116),
    [sym_preproc_elseif] = STATE(116),
    [sym_preproc_assert] = STATE(116),
    [sym_preproc_pragma] = STATE(116),
    [sym_preproc_error] = STATE(116),
    [sym_preproc_warning] = STATE(116),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_LPAREN] = ACTIONS(504),
    [anon_sym_BANG] = ACTIONS(502),
    [anon_sym_TILDE] = ACTIONS(504),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(502),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(440),
    [anon_sym_BANG_EQ] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_LBRACE] = ACTIONS(504),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_for] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_do] = ACTIONS(502),
    [anon_sym_break] = ACTIONS(502),
    [anon_sym_continue] = ACTIONS(502),
    [anon_sym_if] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_switch] = ACTIONS(502),
    [anon_sym_return] = ACTIONS(502),
    [anon_sym_delete] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(502),
    [anon_sym_view_as] = ACTIONS(502),
    [sym_int_literal] = ACTIONS(502),
    [sym_float_literal] = ACTIONS(504),
    [anon_sym_SQUOTE] = ACTIONS(504),
    [anon_sym_DQUOTE] = ACTIONS(504),
    [sym_bool_literal] = ACTIONS(502),
    [sym_null] = ACTIONS(502),
    [sym_this] = ACTIONS(502),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [117] = {
    [sym_preproc_include] = STATE(117),
    [sym_preproc_tryinclude] = STATE(117),
    [sym_preproc_macro] = STATE(117),
    [sym_preproc_define] = STATE(117),
    [sym_preproc_undefine] = STATE(117),
    [sym_preproc_if] = STATE(117),
    [sym_preproc_elseif] = STATE(117),
    [sym_preproc_assert] = STATE(117),
    [sym_preproc_pragma] = STATE(117),
    [sym_preproc_error] = STATE(117),
    [sym_preproc_warning] = STATE(117),
    [sym_identifier] = ACTIONS(506),
    [anon_sym_LPAREN] = ACTIONS(508),
    [anon_sym_BANG] = ACTIONS(506),
    [anon_sym_TILDE] = ACTIONS(508),
    [anon_sym_DASH] = ACTIONS(506),
    [anon_sym_PLUS] = ACTIONS(506),
    [anon_sym_AMP] = ACTIONS(506),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(508),
    [anon_sym_STAR] = ACTIONS(508),
    [anon_sym_SLASH] = ACTIONS(506),
    [anon_sym_PERCENT] = ACTIONS(508),
    [anon_sym_PIPE_PIPE] = ACTIONS(508),
    [anon_sym_AMP_AMP] = ACTIONS(508),
    [anon_sym_PIPE] = ACTIONS(506),
    [anon_sym_CARET] = ACTIONS(508),
    [anon_sym_EQ_EQ] = ACTIONS(508),
    [anon_sym_BANG_EQ] = ACTIONS(508),
    [anon_sym_GT] = ACTIONS(506),
    [anon_sym_GT_EQ] = ACTIONS(508),
    [anon_sym_LT_EQ] = ACTIONS(508),
    [anon_sym_LT] = ACTIONS(506),
    [anon_sym_LT_LT] = ACTIONS(508),
    [anon_sym_GT_GT] = ACTIONS(506),
    [anon_sym_GT_GT_GT] = ACTIONS(508),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(508),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(506),
    [anon_sym_public] = ACTIONS(506),
    [anon_sym_stock] = ACTIONS(506),
    [anon_sym_static] = ACTIONS(506),
    [anon_sym_new] = ACTIONS(506),
    [anon_sym_decl] = ACTIONS(506),
    [anon_sym_LBRACE] = ACTIONS(508),
    [anon_sym_RBRACE] = ACTIONS(508),
    [anon_sym_void] = ACTIONS(506),
    [anon_sym_bool] = ACTIONS(506),
    [anon_sym_int] = ACTIONS(506),
    [anon_sym_float] = ACTIONS(506),
    [anon_sym_char] = ACTIONS(506),
    [anon_sym__] = ACTIONS(506),
    [anon_sym_Float] = ACTIONS(506),
    [anon_sym_String] = ACTIONS(506),
    [sym_any_type] = ACTIONS(506),
    [anon_sym_for] = ACTIONS(506),
    [anon_sym_while] = ACTIONS(506),
    [anon_sym_do] = ACTIONS(506),
    [anon_sym_break] = ACTIONS(506),
    [anon_sym_continue] = ACTIONS(506),
    [anon_sym_if] = ACTIONS(506),
    [anon_sym_else] = ACTIONS(506),
    [anon_sym_switch] = ACTIONS(506),
    [anon_sym_return] = ACTIONS(506),
    [anon_sym_delete] = ACTIONS(506),
    [anon_sym_SEMI] = ACTIONS(508),
    [anon_sym_DOT] = ACTIONS(506),
    [anon_sym_QMARK] = ACTIONS(508),
    [anon_sym_DASH_DASH] = ACTIONS(508),
    [anon_sym_PLUS_PLUS] = ACTIONS(508),
    [anon_sym_sizeof] = ACTIONS(506),
    [anon_sym_view_as] = ACTIONS(506),
    [sym_int_literal] = ACTIONS(506),
    [sym_float_literal] = ACTIONS(508),
    [anon_sym_SQUOTE] = ACTIONS(508),
    [anon_sym_DQUOTE] = ACTIONS(508),
    [sym_bool_literal] = ACTIONS(506),
    [sym_null] = ACTIONS(506),
    [sym_this] = ACTIONS(506),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(508),
  },
  [118] = {
    [sym_preproc_include] = STATE(118),
    [sym_preproc_tryinclude] = STATE(118),
    [sym_preproc_macro] = STATE(118),
    [sym_preproc_define] = STATE(118),
    [sym_preproc_undefine] = STATE(118),
    [sym_preproc_if] = STATE(118),
    [sym_preproc_elseif] = STATE(118),
    [sym_preproc_assert] = STATE(118),
    [sym_preproc_pragma] = STATE(118),
    [sym_preproc_error] = STATE(118),
    [sym_preproc_warning] = STATE(118),
    [sym_identifier] = ACTIONS(510),
    [anon_sym_LPAREN] = ACTIONS(512),
    [anon_sym_BANG] = ACTIONS(510),
    [anon_sym_TILDE] = ACTIONS(512),
    [anon_sym_DASH] = ACTIONS(510),
    [anon_sym_PLUS] = ACTIONS(510),
    [anon_sym_AMP] = ACTIONS(510),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(512),
    [anon_sym_STAR] = ACTIONS(512),
    [anon_sym_SLASH] = ACTIONS(510),
    [anon_sym_PERCENT] = ACTIONS(512),
    [anon_sym_PIPE_PIPE] = ACTIONS(512),
    [anon_sym_AMP_AMP] = ACTIONS(512),
    [anon_sym_PIPE] = ACTIONS(510),
    [anon_sym_CARET] = ACTIONS(512),
    [anon_sym_EQ_EQ] = ACTIONS(512),
    [anon_sym_BANG_EQ] = ACTIONS(512),
    [anon_sym_GT] = ACTIONS(510),
    [anon_sym_GT_EQ] = ACTIONS(512),
    [anon_sym_LT_EQ] = ACTIONS(512),
    [anon_sym_LT] = ACTIONS(510),
    [anon_sym_LT_LT] = ACTIONS(512),
    [anon_sym_GT_GT] = ACTIONS(510),
    [anon_sym_GT_GT_GT] = ACTIONS(512),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(512),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(510),
    [anon_sym_public] = ACTIONS(510),
    [anon_sym_stock] = ACTIONS(510),
    [anon_sym_static] = ACTIONS(510),
    [anon_sym_new] = ACTIONS(510),
    [anon_sym_decl] = ACTIONS(510),
    [anon_sym_LBRACE] = ACTIONS(512),
    [anon_sym_RBRACE] = ACTIONS(512),
    [anon_sym_void] = ACTIONS(510),
    [anon_sym_bool] = ACTIONS(510),
    [anon_sym_int] = ACTIONS(510),
    [anon_sym_float] = ACTIONS(510),
    [anon_sym_char] = ACTIONS(510),
    [anon_sym__] = ACTIONS(510),
    [anon_sym_Float] = ACTIONS(510),
    [anon_sym_String] = ACTIONS(510),
    [sym_any_type] = ACTIONS(510),
    [anon_sym_for] = ACTIONS(510),
    [anon_sym_while] = ACTIONS(510),
    [anon_sym_do] = ACTIONS(510),
    [anon_sym_break] = ACTIONS(510),
    [anon_sym_continue] = ACTIONS(510),
    [anon_sym_if] = ACTIONS(510),
    [anon_sym_else] = ACTIONS(510),
    [anon_sym_switch] = ACTIONS(510),
    [anon_sym_return] = ACTIONS(510),
    [anon_sym_delete] = ACTIONS(510),
    [anon_sym_SEMI] = ACTIONS(512),
    [anon_sym_DOT] = ACTIONS(510),
    [anon_sym_QMARK] = ACTIONS(512),
    [anon_sym_DASH_DASH] = ACTIONS(512),
    [anon_sym_PLUS_PLUS] = ACTIONS(512),
    [anon_sym_sizeof] = ACTIONS(510),
    [anon_sym_view_as] = ACTIONS(510),
    [sym_int_literal] = ACTIONS(510),
    [sym_float_literal] = ACTIONS(512),
    [anon_sym_SQUOTE] = ACTIONS(512),
    [anon_sym_DQUOTE] = ACTIONS(512),
    [sym_bool_literal] = ACTIONS(510),
    [sym_null] = ACTIONS(510),
    [sym_this] = ACTIONS(510),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(512),
  },
  [119] = {
    [sym_preproc_include] = STATE(119),
    [sym_preproc_tryinclude] = STATE(119),
    [sym_preproc_macro] = STATE(119),
    [sym_preproc_define] = STATE(119),
    [sym_preproc_undefine] = STATE(119),
    [sym_preproc_if] = STATE(119),
    [sym_preproc_elseif] = STATE(119),
    [sym_preproc_assert] = STATE(119),
    [sym_preproc_pragma] = STATE(119),
    [sym_preproc_error] = STATE(119),
    [sym_preproc_warning] = STATE(119),
    [sym_identifier] = ACTIONS(490),
    [anon_sym_LPAREN] = ACTIONS(492),
    [anon_sym_BANG] = ACTIONS(490),
    [anon_sym_TILDE] = ACTIONS(492),
    [anon_sym_DASH] = ACTIONS(490),
    [anon_sym_PLUS] = ACTIONS(490),
    [anon_sym_AMP] = ACTIONS(490),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(492),
    [anon_sym_STAR] = ACTIONS(492),
    [anon_sym_SLASH] = ACTIONS(490),
    [anon_sym_PERCENT] = ACTIONS(492),
    [anon_sym_PIPE_PIPE] = ACTIONS(492),
    [anon_sym_AMP_AMP] = ACTIONS(492),
    [anon_sym_PIPE] = ACTIONS(490),
    [anon_sym_CARET] = ACTIONS(492),
    [anon_sym_EQ_EQ] = ACTIONS(492),
    [anon_sym_BANG_EQ] = ACTIONS(492),
    [anon_sym_GT] = ACTIONS(490),
    [anon_sym_GT_EQ] = ACTIONS(492),
    [anon_sym_LT_EQ] = ACTIONS(492),
    [anon_sym_LT] = ACTIONS(490),
    [anon_sym_LT_LT] = ACTIONS(492),
    [anon_sym_GT_GT] = ACTIONS(490),
    [anon_sym_GT_GT_GT] = ACTIONS(492),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(492),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(490),
    [anon_sym_public] = ACTIONS(490),
    [anon_sym_stock] = ACTIONS(490),
    [anon_sym_static] = ACTIONS(490),
    [anon_sym_new] = ACTIONS(490),
    [anon_sym_decl] = ACTIONS(490),
    [anon_sym_LBRACE] = ACTIONS(492),
    [anon_sym_RBRACE] = ACTIONS(492),
    [anon_sym_void] = ACTIONS(490),
    [anon_sym_bool] = ACTIONS(490),
    [anon_sym_int] = ACTIONS(490),
    [anon_sym_float] = ACTIONS(490),
    [anon_sym_char] = ACTIONS(490),
    [anon_sym__] = ACTIONS(490),
    [anon_sym_Float] = ACTIONS(490),
    [anon_sym_String] = ACTIONS(490),
    [sym_any_type] = ACTIONS(490),
    [anon_sym_for] = ACTIONS(490),
    [anon_sym_while] = ACTIONS(490),
    [anon_sym_do] = ACTIONS(490),
    [anon_sym_break] = ACTIONS(490),
    [anon_sym_continue] = ACTIONS(490),
    [anon_sym_if] = ACTIONS(490),
    [anon_sym_else] = ACTIONS(490),
    [anon_sym_switch] = ACTIONS(490),
    [anon_sym_return] = ACTIONS(490),
    [anon_sym_delete] = ACTIONS(490),
    [anon_sym_SEMI] = ACTIONS(492),
    [anon_sym_DOT] = ACTIONS(490),
    [anon_sym_QMARK] = ACTIONS(492),
    [anon_sym_DASH_DASH] = ACTIONS(492),
    [anon_sym_PLUS_PLUS] = ACTIONS(492),
    [anon_sym_sizeof] = ACTIONS(490),
    [anon_sym_view_as] = ACTIONS(490),
    [sym_int_literal] = ACTIONS(490),
    [sym_float_literal] = ACTIONS(492),
    [anon_sym_SQUOTE] = ACTIONS(492),
    [anon_sym_DQUOTE] = ACTIONS(492),
    [sym_bool_literal] = ACTIONS(490),
    [sym_null] = ACTIONS(490),
    [sym_this] = ACTIONS(490),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(492),
  },
  [120] = {
    [sym_preproc_include] = STATE(120),
    [sym_preproc_tryinclude] = STATE(120),
    [sym_preproc_macro] = STATE(120),
    [sym_preproc_define] = STATE(120),
    [sym_preproc_undefine] = STATE(120),
    [sym_preproc_if] = STATE(120),
    [sym_preproc_elseif] = STATE(120),
    [sym_preproc_assert] = STATE(120),
    [sym_preproc_pragma] = STATE(120),
    [sym_preproc_error] = STATE(120),
    [sym_preproc_warning] = STATE(120),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_LPAREN] = ACTIONS(504),
    [anon_sym_BANG] = ACTIONS(502),
    [anon_sym_TILDE] = ACTIONS(504),
    [anon_sym_DASH] = ACTIONS(502),
    [anon_sym_PLUS] = ACTIONS(502),
    [anon_sym_AMP] = ACTIONS(502),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(504),
    [anon_sym_STAR] = ACTIONS(504),
    [anon_sym_SLASH] = ACTIONS(502),
    [anon_sym_PERCENT] = ACTIONS(504),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(504),
    [anon_sym_BANG_EQ] = ACTIONS(504),
    [anon_sym_GT] = ACTIONS(502),
    [anon_sym_GT_EQ] = ACTIONS(504),
    [anon_sym_LT_EQ] = ACTIONS(504),
    [anon_sym_LT] = ACTIONS(502),
    [anon_sym_LT_LT] = ACTIONS(504),
    [anon_sym_GT_GT] = ACTIONS(502),
    [anon_sym_GT_GT_GT] = ACTIONS(504),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_LBRACE] = ACTIONS(504),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_for] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_do] = ACTIONS(502),
    [anon_sym_break] = ACTIONS(502),
    [anon_sym_continue] = ACTIONS(502),
    [anon_sym_if] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_switch] = ACTIONS(502),
    [anon_sym_return] = ACTIONS(502),
    [anon_sym_delete] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(502),
    [anon_sym_view_as] = ACTIONS(502),
    [sym_int_literal] = ACTIONS(502),
    [sym_float_literal] = ACTIONS(504),
    [anon_sym_SQUOTE] = ACTIONS(504),
    [anon_sym_DQUOTE] = ACTIONS(504),
    [sym_bool_literal] = ACTIONS(502),
    [sym_null] = ACTIONS(502),
    [sym_this] = ACTIONS(502),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [121] = {
    [sym_preproc_include] = STATE(121),
    [sym_preproc_tryinclude] = STATE(121),
    [sym_preproc_macro] = STATE(121),
    [sym_preproc_define] = STATE(121),
    [sym_preproc_undefine] = STATE(121),
    [sym_preproc_if] = STATE(121),
    [sym_preproc_elseif] = STATE(121),
    [sym_preproc_assert] = STATE(121),
    [sym_preproc_pragma] = STATE(121),
    [sym_preproc_error] = STATE(121),
    [sym_preproc_warning] = STATE(121),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_LPAREN] = ACTIONS(504),
    [anon_sym_BANG] = ACTIONS(502),
    [anon_sym_TILDE] = ACTIONS(504),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(424),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(434),
    [anon_sym_PIPE] = ACTIONS(436),
    [anon_sym_CARET] = ACTIONS(438),
    [anon_sym_EQ_EQ] = ACTIONS(440),
    [anon_sym_BANG_EQ] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_LBRACE] = ACTIONS(504),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_for] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_do] = ACTIONS(502),
    [anon_sym_break] = ACTIONS(502),
    [anon_sym_continue] = ACTIONS(502),
    [anon_sym_if] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_switch] = ACTIONS(502),
    [anon_sym_return] = ACTIONS(502),
    [anon_sym_delete] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(502),
    [anon_sym_view_as] = ACTIONS(502),
    [sym_int_literal] = ACTIONS(502),
    [sym_float_literal] = ACTIONS(504),
    [anon_sym_SQUOTE] = ACTIONS(504),
    [anon_sym_DQUOTE] = ACTIONS(504),
    [sym_bool_literal] = ACTIONS(502),
    [sym_null] = ACTIONS(502),
    [sym_this] = ACTIONS(502),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [122] = {
    [sym_preproc_include] = STATE(122),
    [sym_preproc_tryinclude] = STATE(122),
    [sym_preproc_macro] = STATE(122),
    [sym_preproc_define] = STATE(122),
    [sym_preproc_undefine] = STATE(122),
    [sym_preproc_if] = STATE(122),
    [sym_preproc_elseif] = STATE(122),
    [sym_preproc_assert] = STATE(122),
    [sym_preproc_pragma] = STATE(122),
    [sym_preproc_error] = STATE(122),
    [sym_preproc_warning] = STATE(122),
    [sym_identifier] = ACTIONS(514),
    [anon_sym_LPAREN] = ACTIONS(516),
    [anon_sym_BANG] = ACTIONS(514),
    [anon_sym_TILDE] = ACTIONS(516),
    [anon_sym_DASH] = ACTIONS(514),
    [anon_sym_PLUS] = ACTIONS(514),
    [anon_sym_AMP] = ACTIONS(514),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(516),
    [anon_sym_STAR] = ACTIONS(516),
    [anon_sym_SLASH] = ACTIONS(514),
    [anon_sym_PERCENT] = ACTIONS(516),
    [anon_sym_PIPE_PIPE] = ACTIONS(516),
    [anon_sym_AMP_AMP] = ACTIONS(516),
    [anon_sym_PIPE] = ACTIONS(514),
    [anon_sym_CARET] = ACTIONS(516),
    [anon_sym_EQ_EQ] = ACTIONS(516),
    [anon_sym_BANG_EQ] = ACTIONS(516),
    [anon_sym_GT] = ACTIONS(514),
    [anon_sym_GT_EQ] = ACTIONS(516),
    [anon_sym_LT_EQ] = ACTIONS(516),
    [anon_sym_LT] = ACTIONS(514),
    [anon_sym_LT_LT] = ACTIONS(516),
    [anon_sym_GT_GT] = ACTIONS(514),
    [anon_sym_GT_GT_GT] = ACTIONS(516),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(516),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(514),
    [anon_sym_public] = ACTIONS(514),
    [anon_sym_stock] = ACTIONS(514),
    [anon_sym_static] = ACTIONS(514),
    [anon_sym_new] = ACTIONS(514),
    [anon_sym_decl] = ACTIONS(514),
    [anon_sym_LBRACE] = ACTIONS(516),
    [anon_sym_RBRACE] = ACTIONS(516),
    [anon_sym_void] = ACTIONS(514),
    [anon_sym_bool] = ACTIONS(514),
    [anon_sym_int] = ACTIONS(514),
    [anon_sym_float] = ACTIONS(514),
    [anon_sym_char] = ACTIONS(514),
    [anon_sym__] = ACTIONS(514),
    [anon_sym_Float] = ACTIONS(514),
    [anon_sym_String] = ACTIONS(514),
    [sym_any_type] = ACTIONS(514),
    [anon_sym_for] = ACTIONS(514),
    [anon_sym_while] = ACTIONS(514),
    [anon_sym_do] = ACTIONS(514),
    [anon_sym_break] = ACTIONS(514),
    [anon_sym_continue] = ACTIONS(514),
    [anon_sym_if] = ACTIONS(514),
    [anon_sym_else] = ACTIONS(514),
    [anon_sym_switch] = ACTIONS(514),
    [anon_sym_return] = ACTIONS(514),
    [anon_sym_delete] = ACTIONS(514),
    [anon_sym_SEMI] = ACTIONS(516),
    [anon_sym_DOT] = ACTIONS(514),
    [anon_sym_QMARK] = ACTIONS(516),
    [anon_sym_DASH_DASH] = ACTIONS(516),
    [anon_sym_PLUS_PLUS] = ACTIONS(516),
    [anon_sym_sizeof] = ACTIONS(514),
    [anon_sym_view_as] = ACTIONS(514),
    [sym_int_literal] = ACTIONS(514),
    [sym_float_literal] = ACTIONS(516),
    [anon_sym_SQUOTE] = ACTIONS(516),
    [anon_sym_DQUOTE] = ACTIONS(516),
    [sym_bool_literal] = ACTIONS(514),
    [sym_null] = ACTIONS(514),
    [sym_this] = ACTIONS(514),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(516),
  },
  [123] = {
    [sym_preproc_include] = STATE(123),
    [sym_preproc_tryinclude] = STATE(123),
    [sym_preproc_macro] = STATE(123),
    [sym_preproc_define] = STATE(123),
    [sym_preproc_undefine] = STATE(123),
    [sym_preproc_if] = STATE(123),
    [sym_preproc_elseif] = STATE(123),
    [sym_preproc_assert] = STATE(123),
    [sym_preproc_pragma] = STATE(123),
    [sym_preproc_error] = STATE(123),
    [sym_preproc_warning] = STATE(123),
    [sym_identifier] = ACTIONS(518),
    [anon_sym_LPAREN] = ACTIONS(520),
    [anon_sym_BANG] = ACTIONS(518),
    [anon_sym_TILDE] = ACTIONS(520),
    [anon_sym_DASH] = ACTIONS(518),
    [anon_sym_PLUS] = ACTIONS(518),
    [anon_sym_AMP] = ACTIONS(518),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(520),
    [anon_sym_STAR] = ACTIONS(520),
    [anon_sym_SLASH] = ACTIONS(518),
    [anon_sym_PERCENT] = ACTIONS(520),
    [anon_sym_PIPE_PIPE] = ACTIONS(520),
    [anon_sym_AMP_AMP] = ACTIONS(520),
    [anon_sym_PIPE] = ACTIONS(518),
    [anon_sym_CARET] = ACTIONS(520),
    [anon_sym_EQ_EQ] = ACTIONS(520),
    [anon_sym_BANG_EQ] = ACTIONS(520),
    [anon_sym_GT] = ACTIONS(518),
    [anon_sym_GT_EQ] = ACTIONS(520),
    [anon_sym_LT_EQ] = ACTIONS(520),
    [anon_sym_LT] = ACTIONS(518),
    [anon_sym_LT_LT] = ACTIONS(520),
    [anon_sym_GT_GT] = ACTIONS(518),
    [anon_sym_GT_GT_GT] = ACTIONS(520),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(520),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(518),
    [anon_sym_public] = ACTIONS(518),
    [anon_sym_stock] = ACTIONS(518),
    [anon_sym_static] = ACTIONS(518),
    [anon_sym_new] = ACTIONS(518),
    [anon_sym_decl] = ACTIONS(518),
    [anon_sym_LBRACE] = ACTIONS(520),
    [anon_sym_RBRACE] = ACTIONS(520),
    [anon_sym_void] = ACTIONS(518),
    [anon_sym_bool] = ACTIONS(518),
    [anon_sym_int] = ACTIONS(518),
    [anon_sym_float] = ACTIONS(518),
    [anon_sym_char] = ACTIONS(518),
    [anon_sym__] = ACTIONS(518),
    [anon_sym_Float] = ACTIONS(518),
    [anon_sym_String] = ACTIONS(518),
    [sym_any_type] = ACTIONS(518),
    [anon_sym_for] = ACTIONS(518),
    [anon_sym_while] = ACTIONS(518),
    [anon_sym_do] = ACTIONS(518),
    [anon_sym_break] = ACTIONS(518),
    [anon_sym_continue] = ACTIONS(518),
    [anon_sym_if] = ACTIONS(518),
    [anon_sym_else] = ACTIONS(518),
    [anon_sym_switch] = ACTIONS(518),
    [anon_sym_return] = ACTIONS(518),
    [anon_sym_delete] = ACTIONS(518),
    [anon_sym_SEMI] = ACTIONS(520),
    [anon_sym_DOT] = ACTIONS(518),
    [anon_sym_QMARK] = ACTIONS(520),
    [anon_sym_DASH_DASH] = ACTIONS(520),
    [anon_sym_PLUS_PLUS] = ACTIONS(520),
    [anon_sym_sizeof] = ACTIONS(518),
    [anon_sym_view_as] = ACTIONS(518),
    [sym_int_literal] = ACTIONS(518),
    [sym_float_literal] = ACTIONS(520),
    [anon_sym_SQUOTE] = ACTIONS(520),
    [anon_sym_DQUOTE] = ACTIONS(520),
    [sym_bool_literal] = ACTIONS(518),
    [sym_null] = ACTIONS(518),
    [sym_this] = ACTIONS(518),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(520),
  },
  [124] = {
    [sym_preproc_include] = STATE(124),
    [sym_preproc_tryinclude] = STATE(124),
    [sym_preproc_macro] = STATE(124),
    [sym_preproc_define] = STATE(124),
    [sym_preproc_undefine] = STATE(124),
    [sym_preproc_if] = STATE(124),
    [sym_preproc_elseif] = STATE(124),
    [sym_preproc_assert] = STATE(124),
    [sym_preproc_pragma] = STATE(124),
    [sym_preproc_error] = STATE(124),
    [sym_preproc_warning] = STATE(124),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_LPAREN] = ACTIONS(504),
    [anon_sym_BANG] = ACTIONS(502),
    [anon_sym_TILDE] = ACTIONS(504),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(424),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(436),
    [anon_sym_CARET] = ACTIONS(438),
    [anon_sym_EQ_EQ] = ACTIONS(440),
    [anon_sym_BANG_EQ] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_LBRACE] = ACTIONS(504),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_for] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_do] = ACTIONS(502),
    [anon_sym_break] = ACTIONS(502),
    [anon_sym_continue] = ACTIONS(502),
    [anon_sym_if] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_switch] = ACTIONS(502),
    [anon_sym_return] = ACTIONS(502),
    [anon_sym_delete] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(502),
    [anon_sym_view_as] = ACTIONS(502),
    [sym_int_literal] = ACTIONS(502),
    [sym_float_literal] = ACTIONS(504),
    [anon_sym_SQUOTE] = ACTIONS(504),
    [anon_sym_DQUOTE] = ACTIONS(504),
    [sym_bool_literal] = ACTIONS(502),
    [sym_null] = ACTIONS(502),
    [sym_this] = ACTIONS(502),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [125] = {
    [sym_preproc_include] = STATE(125),
    [sym_preproc_tryinclude] = STATE(125),
    [sym_preproc_macro] = STATE(125),
    [sym_preproc_define] = STATE(125),
    [sym_preproc_undefine] = STATE(125),
    [sym_preproc_if] = STATE(125),
    [sym_preproc_elseif] = STATE(125),
    [sym_preproc_assert] = STATE(125),
    [sym_preproc_pragma] = STATE(125),
    [sym_preproc_error] = STATE(125),
    [sym_preproc_warning] = STATE(125),
    [sym_identifier] = ACTIONS(522),
    [anon_sym_LPAREN] = ACTIONS(524),
    [anon_sym_BANG] = ACTIONS(522),
    [anon_sym_TILDE] = ACTIONS(524),
    [anon_sym_DASH] = ACTIONS(522),
    [anon_sym_PLUS] = ACTIONS(522),
    [anon_sym_AMP] = ACTIONS(522),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(524),
    [anon_sym_STAR] = ACTIONS(524),
    [anon_sym_SLASH] = ACTIONS(522),
    [anon_sym_PERCENT] = ACTIONS(524),
    [anon_sym_PIPE_PIPE] = ACTIONS(524),
    [anon_sym_AMP_AMP] = ACTIONS(524),
    [anon_sym_PIPE] = ACTIONS(522),
    [anon_sym_CARET] = ACTIONS(524),
    [anon_sym_EQ_EQ] = ACTIONS(524),
    [anon_sym_BANG_EQ] = ACTIONS(524),
    [anon_sym_GT] = ACTIONS(522),
    [anon_sym_GT_EQ] = ACTIONS(524),
    [anon_sym_LT_EQ] = ACTIONS(524),
    [anon_sym_LT] = ACTIONS(522),
    [anon_sym_LT_LT] = ACTIONS(524),
    [anon_sym_GT_GT] = ACTIONS(522),
    [anon_sym_GT_GT_GT] = ACTIONS(524),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(524),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(522),
    [anon_sym_public] = ACTIONS(522),
    [anon_sym_stock] = ACTIONS(522),
    [anon_sym_static] = ACTIONS(522),
    [anon_sym_new] = ACTIONS(522),
    [anon_sym_decl] = ACTIONS(522),
    [anon_sym_LBRACE] = ACTIONS(524),
    [anon_sym_RBRACE] = ACTIONS(524),
    [anon_sym_void] = ACTIONS(522),
    [anon_sym_bool] = ACTIONS(522),
    [anon_sym_int] = ACTIONS(522),
    [anon_sym_float] = ACTIONS(522),
    [anon_sym_char] = ACTIONS(522),
    [anon_sym__] = ACTIONS(522),
    [anon_sym_Float] = ACTIONS(522),
    [anon_sym_String] = ACTIONS(522),
    [sym_any_type] = ACTIONS(522),
    [anon_sym_for] = ACTIONS(522),
    [anon_sym_while] = ACTIONS(522),
    [anon_sym_do] = ACTIONS(522),
    [anon_sym_break] = ACTIONS(522),
    [anon_sym_continue] = ACTIONS(522),
    [anon_sym_if] = ACTIONS(522),
    [anon_sym_else] = ACTIONS(522),
    [anon_sym_switch] = ACTIONS(522),
    [anon_sym_return] = ACTIONS(522),
    [anon_sym_delete] = ACTIONS(522),
    [anon_sym_SEMI] = ACTIONS(524),
    [anon_sym_DOT] = ACTIONS(522),
    [anon_sym_QMARK] = ACTIONS(524),
    [anon_sym_DASH_DASH] = ACTIONS(524),
    [anon_sym_PLUS_PLUS] = ACTIONS(524),
    [anon_sym_sizeof] = ACTIONS(522),
    [anon_sym_view_as] = ACTIONS(522),
    [sym_int_literal] = ACTIONS(522),
    [sym_float_literal] = ACTIONS(524),
    [anon_sym_SQUOTE] = ACTIONS(524),
    [anon_sym_DQUOTE] = ACTIONS(524),
    [sym_bool_literal] = ACTIONS(522),
    [sym_null] = ACTIONS(522),
    [sym_this] = ACTIONS(522),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(524),
  },
  [126] = {
    [sym_preproc_include] = STATE(126),
    [sym_preproc_tryinclude] = STATE(126),
    [sym_preproc_macro] = STATE(126),
    [sym_preproc_define] = STATE(126),
    [sym_preproc_undefine] = STATE(126),
    [sym_preproc_if] = STATE(126),
    [sym_preproc_elseif] = STATE(126),
    [sym_preproc_assert] = STATE(126),
    [sym_preproc_pragma] = STATE(126),
    [sym_preproc_error] = STATE(126),
    [sym_preproc_warning] = STATE(126),
    [sym_identifier] = ACTIONS(526),
    [anon_sym_LPAREN] = ACTIONS(528),
    [anon_sym_BANG] = ACTIONS(526),
    [anon_sym_TILDE] = ACTIONS(528),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(424),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(432),
    [anon_sym_AMP_AMP] = ACTIONS(434),
    [anon_sym_PIPE] = ACTIONS(436),
    [anon_sym_CARET] = ACTIONS(438),
    [anon_sym_EQ_EQ] = ACTIONS(440),
    [anon_sym_BANG_EQ] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(528),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(526),
    [anon_sym_public] = ACTIONS(526),
    [anon_sym_stock] = ACTIONS(526),
    [anon_sym_static] = ACTIONS(526),
    [anon_sym_new] = ACTIONS(526),
    [anon_sym_decl] = ACTIONS(526),
    [anon_sym_LBRACE] = ACTIONS(528),
    [anon_sym_RBRACE] = ACTIONS(528),
    [anon_sym_void] = ACTIONS(526),
    [anon_sym_bool] = ACTIONS(526),
    [anon_sym_int] = ACTIONS(526),
    [anon_sym_float] = ACTIONS(526),
    [anon_sym_char] = ACTIONS(526),
    [anon_sym__] = ACTIONS(526),
    [anon_sym_Float] = ACTIONS(526),
    [anon_sym_String] = ACTIONS(526),
    [sym_any_type] = ACTIONS(526),
    [anon_sym_for] = ACTIONS(526),
    [anon_sym_while] = ACTIONS(526),
    [anon_sym_do] = ACTIONS(526),
    [anon_sym_break] = ACTIONS(526),
    [anon_sym_continue] = ACTIONS(526),
    [anon_sym_if] = ACTIONS(526),
    [anon_sym_else] = ACTIONS(526),
    [anon_sym_switch] = ACTIONS(526),
    [anon_sym_return] = ACTIONS(526),
    [anon_sym_delete] = ACTIONS(526),
    [anon_sym_SEMI] = ACTIONS(528),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(454),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(526),
    [anon_sym_view_as] = ACTIONS(526),
    [sym_int_literal] = ACTIONS(526),
    [sym_float_literal] = ACTIONS(528),
    [anon_sym_SQUOTE] = ACTIONS(528),
    [anon_sym_DQUOTE] = ACTIONS(528),
    [sym_bool_literal] = ACTIONS(526),
    [sym_null] = ACTIONS(526),
    [sym_this] = ACTIONS(526),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(528),
  },
  [127] = {
    [sym_preproc_include] = STATE(127),
    [sym_preproc_tryinclude] = STATE(127),
    [sym_preproc_macro] = STATE(127),
    [sym_preproc_define] = STATE(127),
    [sym_preproc_undefine] = STATE(127),
    [sym_preproc_if] = STATE(127),
    [sym_preproc_elseif] = STATE(127),
    [sym_preproc_assert] = STATE(127),
    [sym_preproc_pragma] = STATE(127),
    [sym_preproc_error] = STATE(127),
    [sym_preproc_warning] = STATE(127),
    [sym_identifier] = ACTIONS(530),
    [anon_sym_LPAREN] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(530),
    [anon_sym_TILDE] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(530),
    [anon_sym_AMP] = ACTIONS(530),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(532),
    [anon_sym_STAR] = ACTIONS(532),
    [anon_sym_SLASH] = ACTIONS(530),
    [anon_sym_PERCENT] = ACTIONS(532),
    [anon_sym_PIPE_PIPE] = ACTIONS(532),
    [anon_sym_AMP_AMP] = ACTIONS(532),
    [anon_sym_PIPE] = ACTIONS(530),
    [anon_sym_CARET] = ACTIONS(532),
    [anon_sym_EQ_EQ] = ACTIONS(532),
    [anon_sym_BANG_EQ] = ACTIONS(532),
    [anon_sym_GT] = ACTIONS(530),
    [anon_sym_GT_EQ] = ACTIONS(532),
    [anon_sym_LT_EQ] = ACTIONS(532),
    [anon_sym_LT] = ACTIONS(530),
    [anon_sym_LT_LT] = ACTIONS(532),
    [anon_sym_GT_GT] = ACTIONS(530),
    [anon_sym_GT_GT_GT] = ACTIONS(532),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(532),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(530),
    [anon_sym_public] = ACTIONS(530),
    [anon_sym_stock] = ACTIONS(530),
    [anon_sym_static] = ACTIONS(530),
    [anon_sym_new] = ACTIONS(530),
    [anon_sym_decl] = ACTIONS(530),
    [anon_sym_LBRACE] = ACTIONS(532),
    [anon_sym_RBRACE] = ACTIONS(532),
    [anon_sym_void] = ACTIONS(530),
    [anon_sym_bool] = ACTIONS(530),
    [anon_sym_int] = ACTIONS(530),
    [anon_sym_float] = ACTIONS(530),
    [anon_sym_char] = ACTIONS(530),
    [anon_sym__] = ACTIONS(530),
    [anon_sym_Float] = ACTIONS(530),
    [anon_sym_String] = ACTIONS(530),
    [sym_any_type] = ACTIONS(530),
    [anon_sym_for] = ACTIONS(530),
    [anon_sym_while] = ACTIONS(530),
    [anon_sym_do] = ACTIONS(530),
    [anon_sym_break] = ACTIONS(530),
    [anon_sym_continue] = ACTIONS(530),
    [anon_sym_if] = ACTIONS(530),
    [anon_sym_else] = ACTIONS(530),
    [anon_sym_switch] = ACTIONS(530),
    [anon_sym_return] = ACTIONS(530),
    [anon_sym_delete] = ACTIONS(530),
    [anon_sym_SEMI] = ACTIONS(532),
    [anon_sym_DOT] = ACTIONS(530),
    [anon_sym_QMARK] = ACTIONS(532),
    [anon_sym_DASH_DASH] = ACTIONS(532),
    [anon_sym_PLUS_PLUS] = ACTIONS(532),
    [anon_sym_sizeof] = ACTIONS(530),
    [anon_sym_view_as] = ACTIONS(530),
    [sym_int_literal] = ACTIONS(530),
    [sym_float_literal] = ACTIONS(532),
    [anon_sym_SQUOTE] = ACTIONS(532),
    [anon_sym_DQUOTE] = ACTIONS(532),
    [sym_bool_literal] = ACTIONS(530),
    [sym_null] = ACTIONS(530),
    [sym_this] = ACTIONS(530),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(532),
  },
  [128] = {
    [sym_preproc_include] = STATE(128),
    [sym_preproc_tryinclude] = STATE(128),
    [sym_preproc_macro] = STATE(128),
    [sym_preproc_define] = STATE(128),
    [sym_preproc_undefine] = STATE(128),
    [sym_preproc_if] = STATE(128),
    [sym_preproc_elseif] = STATE(128),
    [sym_preproc_assert] = STATE(128),
    [sym_preproc_pragma] = STATE(128),
    [sym_preproc_error] = STATE(128),
    [sym_preproc_warning] = STATE(128),
    [aux_sym_array_literal_repeat1] = STATE(1267),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(246),
    [anon_sym_BANG] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(246),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(246),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(246),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(246),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(246),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(246),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(339),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_RBRACE] = ACTIONS(341),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_do] = ACTIONS(244),
    [anon_sym_break] = ACTIONS(244),
    [anon_sym_continue] = ACTIONS(244),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_switch] = ACTIONS(244),
    [anon_sym_return] = ACTIONS(244),
    [anon_sym_delete] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [anon_sym_sizeof] = ACTIONS(244),
    [anon_sym_view_as] = ACTIONS(244),
    [sym_int_literal] = ACTIONS(244),
    [sym_float_literal] = ACTIONS(246),
    [anon_sym_SQUOTE] = ACTIONS(246),
    [anon_sym_DQUOTE] = ACTIONS(246),
    [sym_bool_literal] = ACTIONS(244),
    [sym_null] = ACTIONS(244),
    [sym_this] = ACTIONS(244),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [129] = {
    [sym_preproc_include] = STATE(129),
    [sym_preproc_tryinclude] = STATE(129),
    [sym_preproc_macro] = STATE(129),
    [sym_preproc_define] = STATE(129),
    [sym_preproc_undefine] = STATE(129),
    [sym_preproc_if] = STATE(129),
    [sym_preproc_elseif] = STATE(129),
    [sym_preproc_assert] = STATE(129),
    [sym_preproc_pragma] = STATE(129),
    [sym_preproc_error] = STATE(129),
    [sym_preproc_warning] = STATE(129),
    [sym_identifier] = ACTIONS(534),
    [anon_sym_LPAREN] = ACTIONS(536),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(536),
    [anon_sym_DASH] = ACTIONS(534),
    [anon_sym_PLUS] = ACTIONS(534),
    [anon_sym_AMP] = ACTIONS(534),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(536),
    [anon_sym_STAR] = ACTIONS(536),
    [anon_sym_SLASH] = ACTIONS(534),
    [anon_sym_PERCENT] = ACTIONS(536),
    [anon_sym_PIPE_PIPE] = ACTIONS(536),
    [anon_sym_AMP_AMP] = ACTIONS(536),
    [anon_sym_PIPE] = ACTIONS(534),
    [anon_sym_CARET] = ACTIONS(536),
    [anon_sym_EQ_EQ] = ACTIONS(536),
    [anon_sym_BANG_EQ] = ACTIONS(536),
    [anon_sym_GT] = ACTIONS(534),
    [anon_sym_GT_EQ] = ACTIONS(536),
    [anon_sym_LT_EQ] = ACTIONS(536),
    [anon_sym_LT] = ACTIONS(534),
    [anon_sym_LT_LT] = ACTIONS(536),
    [anon_sym_GT_GT] = ACTIONS(534),
    [anon_sym_GT_GT_GT] = ACTIONS(536),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(536),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(534),
    [anon_sym_public] = ACTIONS(534),
    [anon_sym_stock] = ACTIONS(534),
    [anon_sym_static] = ACTIONS(534),
    [anon_sym_new] = ACTIONS(534),
    [anon_sym_decl] = ACTIONS(534),
    [anon_sym_LBRACE] = ACTIONS(536),
    [anon_sym_RBRACE] = ACTIONS(536),
    [anon_sym_void] = ACTIONS(534),
    [anon_sym_bool] = ACTIONS(534),
    [anon_sym_int] = ACTIONS(534),
    [anon_sym_float] = ACTIONS(534),
    [anon_sym_char] = ACTIONS(534),
    [anon_sym__] = ACTIONS(534),
    [anon_sym_Float] = ACTIONS(534),
    [anon_sym_String] = ACTIONS(534),
    [sym_any_type] = ACTIONS(534),
    [anon_sym_for] = ACTIONS(534),
    [anon_sym_while] = ACTIONS(534),
    [anon_sym_do] = ACTIONS(534),
    [anon_sym_break] = ACTIONS(534),
    [anon_sym_continue] = ACTIONS(534),
    [anon_sym_if] = ACTIONS(534),
    [anon_sym_else] = ACTIONS(534),
    [anon_sym_switch] = ACTIONS(534),
    [anon_sym_return] = ACTIONS(534),
    [anon_sym_delete] = ACTIONS(534),
    [anon_sym_SEMI] = ACTIONS(536),
    [anon_sym_DOT] = ACTIONS(534),
    [anon_sym_QMARK] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_sizeof] = ACTIONS(534),
    [anon_sym_view_as] = ACTIONS(534),
    [sym_int_literal] = ACTIONS(534),
    [sym_float_literal] = ACTIONS(536),
    [anon_sym_SQUOTE] = ACTIONS(536),
    [anon_sym_DQUOTE] = ACTIONS(536),
    [sym_bool_literal] = ACTIONS(534),
    [sym_null] = ACTIONS(534),
    [sym_this] = ACTIONS(534),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(536),
  },
  [130] = {
    [sym_preproc_include] = STATE(130),
    [sym_preproc_tryinclude] = STATE(130),
    [sym_preproc_macro] = STATE(130),
    [sym_preproc_define] = STATE(130),
    [sym_preproc_undefine] = STATE(130),
    [sym_preproc_if] = STATE(130),
    [sym_preproc_elseif] = STATE(130),
    [sym_preproc_assert] = STATE(130),
    [sym_preproc_pragma] = STATE(130),
    [sym_preproc_error] = STATE(130),
    [sym_preproc_warning] = STATE(130),
    [sym_identifier] = ACTIONS(538),
    [anon_sym_LPAREN] = ACTIONS(540),
    [anon_sym_BANG] = ACTIONS(538),
    [anon_sym_TILDE] = ACTIONS(540),
    [anon_sym_DASH] = ACTIONS(538),
    [anon_sym_PLUS] = ACTIONS(538),
    [anon_sym_AMP] = ACTIONS(538),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(540),
    [anon_sym_STAR] = ACTIONS(540),
    [anon_sym_SLASH] = ACTIONS(538),
    [anon_sym_PERCENT] = ACTIONS(540),
    [anon_sym_PIPE_PIPE] = ACTIONS(540),
    [anon_sym_AMP_AMP] = ACTIONS(540),
    [anon_sym_PIPE] = ACTIONS(538),
    [anon_sym_CARET] = ACTIONS(540),
    [anon_sym_EQ_EQ] = ACTIONS(540),
    [anon_sym_BANG_EQ] = ACTIONS(540),
    [anon_sym_GT] = ACTIONS(538),
    [anon_sym_GT_EQ] = ACTIONS(540),
    [anon_sym_LT_EQ] = ACTIONS(540),
    [anon_sym_LT] = ACTIONS(538),
    [anon_sym_LT_LT] = ACTIONS(540),
    [anon_sym_GT_GT] = ACTIONS(538),
    [anon_sym_GT_GT_GT] = ACTIONS(540),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(540),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(538),
    [anon_sym_public] = ACTIONS(538),
    [anon_sym_stock] = ACTIONS(538),
    [anon_sym_static] = ACTIONS(538),
    [anon_sym_new] = ACTIONS(538),
    [anon_sym_decl] = ACTIONS(538),
    [anon_sym_LBRACE] = ACTIONS(540),
    [anon_sym_RBRACE] = ACTIONS(540),
    [anon_sym_void] = ACTIONS(538),
    [anon_sym_bool] = ACTIONS(538),
    [anon_sym_int] = ACTIONS(538),
    [anon_sym_float] = ACTIONS(538),
    [anon_sym_char] = ACTIONS(538),
    [anon_sym__] = ACTIONS(538),
    [anon_sym_Float] = ACTIONS(538),
    [anon_sym_String] = ACTIONS(538),
    [sym_any_type] = ACTIONS(538),
    [anon_sym_for] = ACTIONS(538),
    [anon_sym_while] = ACTIONS(538),
    [anon_sym_do] = ACTIONS(538),
    [anon_sym_break] = ACTIONS(538),
    [anon_sym_continue] = ACTIONS(538),
    [anon_sym_if] = ACTIONS(538),
    [anon_sym_else] = ACTIONS(538),
    [anon_sym_switch] = ACTIONS(538),
    [anon_sym_return] = ACTIONS(538),
    [anon_sym_delete] = ACTIONS(538),
    [anon_sym_SEMI] = ACTIONS(540),
    [anon_sym_DOT] = ACTIONS(538),
    [anon_sym_QMARK] = ACTIONS(540),
    [anon_sym_DASH_DASH] = ACTIONS(540),
    [anon_sym_PLUS_PLUS] = ACTIONS(540),
    [anon_sym_sizeof] = ACTIONS(538),
    [anon_sym_view_as] = ACTIONS(538),
    [sym_int_literal] = ACTIONS(538),
    [sym_float_literal] = ACTIONS(540),
    [anon_sym_SQUOTE] = ACTIONS(540),
    [anon_sym_DQUOTE] = ACTIONS(540),
    [sym_bool_literal] = ACTIONS(538),
    [sym_null] = ACTIONS(538),
    [sym_this] = ACTIONS(538),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(540),
  },
  [131] = {
    [sym_preproc_include] = STATE(131),
    [sym_preproc_tryinclude] = STATE(131),
    [sym_preproc_macro] = STATE(131),
    [sym_preproc_define] = STATE(131),
    [sym_preproc_undefine] = STATE(131),
    [sym_preproc_if] = STATE(131),
    [sym_preproc_elseif] = STATE(131),
    [sym_preproc_assert] = STATE(131),
    [sym_preproc_pragma] = STATE(131),
    [sym_preproc_error] = STATE(131),
    [sym_preproc_warning] = STATE(131),
    [sym_identifier] = ACTIONS(542),
    [anon_sym_LPAREN] = ACTIONS(544),
    [anon_sym_BANG] = ACTIONS(542),
    [anon_sym_TILDE] = ACTIONS(544),
    [anon_sym_DASH] = ACTIONS(542),
    [anon_sym_PLUS] = ACTIONS(542),
    [anon_sym_AMP] = ACTIONS(542),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(544),
    [anon_sym_STAR] = ACTIONS(544),
    [anon_sym_SLASH] = ACTIONS(542),
    [anon_sym_PERCENT] = ACTIONS(544),
    [anon_sym_PIPE_PIPE] = ACTIONS(544),
    [anon_sym_AMP_AMP] = ACTIONS(544),
    [anon_sym_PIPE] = ACTIONS(542),
    [anon_sym_CARET] = ACTIONS(544),
    [anon_sym_EQ_EQ] = ACTIONS(544),
    [anon_sym_BANG_EQ] = ACTIONS(544),
    [anon_sym_GT] = ACTIONS(542),
    [anon_sym_GT_EQ] = ACTIONS(544),
    [anon_sym_LT_EQ] = ACTIONS(544),
    [anon_sym_LT] = ACTIONS(542),
    [anon_sym_LT_LT] = ACTIONS(544),
    [anon_sym_GT_GT] = ACTIONS(542),
    [anon_sym_GT_GT_GT] = ACTIONS(544),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(544),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(542),
    [anon_sym_public] = ACTIONS(542),
    [anon_sym_stock] = ACTIONS(542),
    [anon_sym_static] = ACTIONS(542),
    [anon_sym_new] = ACTIONS(542),
    [anon_sym_decl] = ACTIONS(542),
    [anon_sym_LBRACE] = ACTIONS(544),
    [anon_sym_RBRACE] = ACTIONS(544),
    [anon_sym_void] = ACTIONS(542),
    [anon_sym_bool] = ACTIONS(542),
    [anon_sym_int] = ACTIONS(542),
    [anon_sym_float] = ACTIONS(542),
    [anon_sym_char] = ACTIONS(542),
    [anon_sym__] = ACTIONS(542),
    [anon_sym_Float] = ACTIONS(542),
    [anon_sym_String] = ACTIONS(542),
    [sym_any_type] = ACTIONS(542),
    [anon_sym_for] = ACTIONS(542),
    [anon_sym_while] = ACTIONS(542),
    [anon_sym_do] = ACTIONS(542),
    [anon_sym_break] = ACTIONS(542),
    [anon_sym_continue] = ACTIONS(542),
    [anon_sym_if] = ACTIONS(542),
    [anon_sym_else] = ACTIONS(542),
    [anon_sym_switch] = ACTIONS(542),
    [anon_sym_return] = ACTIONS(542),
    [anon_sym_delete] = ACTIONS(542),
    [anon_sym_SEMI] = ACTIONS(544),
    [anon_sym_DOT] = ACTIONS(542),
    [anon_sym_QMARK] = ACTIONS(544),
    [anon_sym_DASH_DASH] = ACTIONS(544),
    [anon_sym_PLUS_PLUS] = ACTIONS(544),
    [anon_sym_sizeof] = ACTIONS(542),
    [anon_sym_view_as] = ACTIONS(542),
    [sym_int_literal] = ACTIONS(542),
    [sym_float_literal] = ACTIONS(544),
    [anon_sym_SQUOTE] = ACTIONS(544),
    [anon_sym_DQUOTE] = ACTIONS(544),
    [sym_bool_literal] = ACTIONS(542),
    [sym_null] = ACTIONS(542),
    [sym_this] = ACTIONS(542),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(544),
  },
  [132] = {
    [sym_preproc_include] = STATE(132),
    [sym_preproc_tryinclude] = STATE(132),
    [sym_preproc_macro] = STATE(132),
    [sym_preproc_define] = STATE(132),
    [sym_preproc_undefine] = STATE(132),
    [sym_preproc_if] = STATE(132),
    [sym_preproc_elseif] = STATE(132),
    [sym_preproc_assert] = STATE(132),
    [sym_preproc_pragma] = STATE(132),
    [sym_preproc_error] = STATE(132),
    [sym_preproc_warning] = STATE(132),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_LPAREN] = ACTIONS(504),
    [anon_sym_BANG] = ACTIONS(502),
    [anon_sym_TILDE] = ACTIONS(504),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(424),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(438),
    [anon_sym_EQ_EQ] = ACTIONS(440),
    [anon_sym_BANG_EQ] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_LBRACE] = ACTIONS(504),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_for] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_do] = ACTIONS(502),
    [anon_sym_break] = ACTIONS(502),
    [anon_sym_continue] = ACTIONS(502),
    [anon_sym_if] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_switch] = ACTIONS(502),
    [anon_sym_return] = ACTIONS(502),
    [anon_sym_delete] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(502),
    [anon_sym_view_as] = ACTIONS(502),
    [sym_int_literal] = ACTIONS(502),
    [sym_float_literal] = ACTIONS(504),
    [anon_sym_SQUOTE] = ACTIONS(504),
    [anon_sym_DQUOTE] = ACTIONS(504),
    [sym_bool_literal] = ACTIONS(502),
    [sym_null] = ACTIONS(502),
    [sym_this] = ACTIONS(502),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [133] = {
    [sym_preproc_include] = STATE(133),
    [sym_preproc_tryinclude] = STATE(133),
    [sym_preproc_macro] = STATE(133),
    [sym_preproc_define] = STATE(133),
    [sym_preproc_undefine] = STATE(133),
    [sym_preproc_if] = STATE(133),
    [sym_preproc_elseif] = STATE(133),
    [sym_preproc_assert] = STATE(133),
    [sym_preproc_pragma] = STATE(133),
    [sym_preproc_error] = STATE(133),
    [sym_preproc_warning] = STATE(133),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_LPAREN] = ACTIONS(504),
    [anon_sym_BANG] = ACTIONS(502),
    [anon_sym_TILDE] = ACTIONS(504),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(424),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(440),
    [anon_sym_BANG_EQ] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_LBRACE] = ACTIONS(504),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_for] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_do] = ACTIONS(502),
    [anon_sym_break] = ACTIONS(502),
    [anon_sym_continue] = ACTIONS(502),
    [anon_sym_if] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_switch] = ACTIONS(502),
    [anon_sym_return] = ACTIONS(502),
    [anon_sym_delete] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(502),
    [anon_sym_view_as] = ACTIONS(502),
    [sym_int_literal] = ACTIONS(502),
    [sym_float_literal] = ACTIONS(504),
    [anon_sym_SQUOTE] = ACTIONS(504),
    [anon_sym_DQUOTE] = ACTIONS(504),
    [sym_bool_literal] = ACTIONS(502),
    [sym_null] = ACTIONS(502),
    [sym_this] = ACTIONS(502),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [134] = {
    [sym_preproc_include] = STATE(134),
    [sym_preproc_tryinclude] = STATE(134),
    [sym_preproc_macro] = STATE(134),
    [sym_preproc_define] = STATE(134),
    [sym_preproc_undefine] = STATE(134),
    [sym_preproc_if] = STATE(134),
    [sym_preproc_elseif] = STATE(134),
    [sym_preproc_assert] = STATE(134),
    [sym_preproc_pragma] = STATE(134),
    [sym_preproc_error] = STATE(134),
    [sym_preproc_warning] = STATE(134),
    [sym_identifier] = ACTIONS(546),
    [anon_sym_LPAREN] = ACTIONS(548),
    [anon_sym_BANG] = ACTIONS(546),
    [anon_sym_TILDE] = ACTIONS(548),
    [anon_sym_DASH] = ACTIONS(546),
    [anon_sym_PLUS] = ACTIONS(546),
    [anon_sym_AMP] = ACTIONS(546),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(548),
    [anon_sym_STAR] = ACTIONS(548),
    [anon_sym_SLASH] = ACTIONS(546),
    [anon_sym_PERCENT] = ACTIONS(548),
    [anon_sym_PIPE_PIPE] = ACTIONS(548),
    [anon_sym_AMP_AMP] = ACTIONS(548),
    [anon_sym_PIPE] = ACTIONS(546),
    [anon_sym_CARET] = ACTIONS(548),
    [anon_sym_EQ_EQ] = ACTIONS(548),
    [anon_sym_BANG_EQ] = ACTIONS(548),
    [anon_sym_GT] = ACTIONS(546),
    [anon_sym_GT_EQ] = ACTIONS(548),
    [anon_sym_LT_EQ] = ACTIONS(548),
    [anon_sym_LT] = ACTIONS(546),
    [anon_sym_LT_LT] = ACTIONS(548),
    [anon_sym_GT_GT] = ACTIONS(546),
    [anon_sym_GT_GT_GT] = ACTIONS(548),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(548),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(546),
    [anon_sym_public] = ACTIONS(546),
    [anon_sym_stock] = ACTIONS(546),
    [anon_sym_static] = ACTIONS(546),
    [anon_sym_new] = ACTIONS(546),
    [anon_sym_decl] = ACTIONS(546),
    [anon_sym_LBRACE] = ACTIONS(548),
    [anon_sym_RBRACE] = ACTIONS(548),
    [anon_sym_void] = ACTIONS(546),
    [anon_sym_bool] = ACTIONS(546),
    [anon_sym_int] = ACTIONS(546),
    [anon_sym_float] = ACTIONS(546),
    [anon_sym_char] = ACTIONS(546),
    [anon_sym__] = ACTIONS(546),
    [anon_sym_Float] = ACTIONS(546),
    [anon_sym_String] = ACTIONS(546),
    [sym_any_type] = ACTIONS(546),
    [anon_sym_for] = ACTIONS(546),
    [anon_sym_while] = ACTIONS(546),
    [anon_sym_do] = ACTIONS(546),
    [anon_sym_break] = ACTIONS(546),
    [anon_sym_continue] = ACTIONS(546),
    [anon_sym_if] = ACTIONS(546),
    [anon_sym_else] = ACTIONS(546),
    [anon_sym_switch] = ACTIONS(546),
    [anon_sym_return] = ACTIONS(546),
    [anon_sym_delete] = ACTIONS(546),
    [anon_sym_SEMI] = ACTIONS(548),
    [anon_sym_DOT] = ACTIONS(546),
    [anon_sym_QMARK] = ACTIONS(548),
    [anon_sym_DASH_DASH] = ACTIONS(548),
    [anon_sym_PLUS_PLUS] = ACTIONS(548),
    [anon_sym_sizeof] = ACTIONS(546),
    [anon_sym_view_as] = ACTIONS(546),
    [sym_int_literal] = ACTIONS(546),
    [sym_float_literal] = ACTIONS(548),
    [anon_sym_SQUOTE] = ACTIONS(548),
    [anon_sym_DQUOTE] = ACTIONS(548),
    [sym_bool_literal] = ACTIONS(546),
    [sym_null] = ACTIONS(546),
    [sym_this] = ACTIONS(546),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(548),
  },
  [135] = {
    [sym_preproc_include] = STATE(135),
    [sym_preproc_tryinclude] = STATE(135),
    [sym_preproc_macro] = STATE(135),
    [sym_preproc_define] = STATE(135),
    [sym_preproc_undefine] = STATE(135),
    [sym_preproc_if] = STATE(135),
    [sym_preproc_elseif] = STATE(135),
    [sym_preproc_assert] = STATE(135),
    [sym_preproc_pragma] = STATE(135),
    [sym_preproc_error] = STATE(135),
    [sym_preproc_warning] = STATE(135),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_LPAREN] = ACTIONS(504),
    [anon_sym_BANG] = ACTIONS(502),
    [anon_sym_TILDE] = ACTIONS(504),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(502),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(504),
    [anon_sym_BANG_EQ] = ACTIONS(504),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_LBRACE] = ACTIONS(504),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_for] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_do] = ACTIONS(502),
    [anon_sym_break] = ACTIONS(502),
    [anon_sym_continue] = ACTIONS(502),
    [anon_sym_if] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_switch] = ACTIONS(502),
    [anon_sym_return] = ACTIONS(502),
    [anon_sym_delete] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(502),
    [anon_sym_view_as] = ACTIONS(502),
    [sym_int_literal] = ACTIONS(502),
    [sym_float_literal] = ACTIONS(504),
    [anon_sym_SQUOTE] = ACTIONS(504),
    [anon_sym_DQUOTE] = ACTIONS(504),
    [sym_bool_literal] = ACTIONS(502),
    [sym_null] = ACTIONS(502),
    [sym_this] = ACTIONS(502),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [136] = {
    [sym_preproc_include] = STATE(136),
    [sym_preproc_tryinclude] = STATE(136),
    [sym_preproc_macro] = STATE(136),
    [sym_preproc_define] = STATE(136),
    [sym_preproc_undefine] = STATE(136),
    [sym_preproc_if] = STATE(136),
    [sym_preproc_elseif] = STATE(136),
    [sym_preproc_assert] = STATE(136),
    [sym_preproc_pragma] = STATE(136),
    [sym_preproc_error] = STATE(136),
    [sym_preproc_warning] = STATE(136),
    [sym_identifier] = ACTIONS(550),
    [anon_sym_LPAREN] = ACTIONS(552),
    [anon_sym_BANG] = ACTIONS(550),
    [anon_sym_TILDE] = ACTIONS(552),
    [anon_sym_DASH] = ACTIONS(550),
    [anon_sym_PLUS] = ACTIONS(550),
    [anon_sym_AMP] = ACTIONS(550),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(552),
    [anon_sym_STAR] = ACTIONS(552),
    [anon_sym_SLASH] = ACTIONS(550),
    [anon_sym_PERCENT] = ACTIONS(552),
    [anon_sym_PIPE_PIPE] = ACTIONS(552),
    [anon_sym_AMP_AMP] = ACTIONS(552),
    [anon_sym_PIPE] = ACTIONS(550),
    [anon_sym_CARET] = ACTIONS(552),
    [anon_sym_EQ_EQ] = ACTIONS(552),
    [anon_sym_BANG_EQ] = ACTIONS(552),
    [anon_sym_GT] = ACTIONS(550),
    [anon_sym_GT_EQ] = ACTIONS(552),
    [anon_sym_LT_EQ] = ACTIONS(552),
    [anon_sym_LT] = ACTIONS(550),
    [anon_sym_LT_LT] = ACTIONS(552),
    [anon_sym_GT_GT] = ACTIONS(550),
    [anon_sym_GT_GT_GT] = ACTIONS(552),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(552),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(550),
    [anon_sym_public] = ACTIONS(550),
    [anon_sym_stock] = ACTIONS(550),
    [anon_sym_static] = ACTIONS(550),
    [anon_sym_new] = ACTIONS(550),
    [anon_sym_decl] = ACTIONS(550),
    [anon_sym_LBRACE] = ACTIONS(552),
    [anon_sym_RBRACE] = ACTIONS(552),
    [anon_sym_void] = ACTIONS(550),
    [anon_sym_bool] = ACTIONS(550),
    [anon_sym_int] = ACTIONS(550),
    [anon_sym_float] = ACTIONS(550),
    [anon_sym_char] = ACTIONS(550),
    [anon_sym__] = ACTIONS(550),
    [anon_sym_Float] = ACTIONS(550),
    [anon_sym_String] = ACTIONS(550),
    [sym_any_type] = ACTIONS(550),
    [anon_sym_for] = ACTIONS(550),
    [anon_sym_while] = ACTIONS(550),
    [anon_sym_do] = ACTIONS(550),
    [anon_sym_break] = ACTIONS(550),
    [anon_sym_continue] = ACTIONS(550),
    [anon_sym_if] = ACTIONS(550),
    [anon_sym_else] = ACTIONS(550),
    [anon_sym_switch] = ACTIONS(550),
    [anon_sym_return] = ACTIONS(550),
    [anon_sym_delete] = ACTIONS(550),
    [anon_sym_SEMI] = ACTIONS(552),
    [anon_sym_DOT] = ACTIONS(550),
    [anon_sym_QMARK] = ACTIONS(552),
    [anon_sym_DASH_DASH] = ACTIONS(552),
    [anon_sym_PLUS_PLUS] = ACTIONS(552),
    [anon_sym_sizeof] = ACTIONS(550),
    [anon_sym_view_as] = ACTIONS(550),
    [sym_int_literal] = ACTIONS(550),
    [sym_float_literal] = ACTIONS(552),
    [anon_sym_SQUOTE] = ACTIONS(552),
    [anon_sym_DQUOTE] = ACTIONS(552),
    [sym_bool_literal] = ACTIONS(550),
    [sym_null] = ACTIONS(550),
    [sym_this] = ACTIONS(550),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(552),
  },
  [137] = {
    [sym_preproc_include] = STATE(137),
    [sym_preproc_tryinclude] = STATE(137),
    [sym_preproc_macro] = STATE(137),
    [sym_preproc_define] = STATE(137),
    [sym_preproc_undefine] = STATE(137),
    [sym_preproc_if] = STATE(137),
    [sym_preproc_elseif] = STATE(137),
    [sym_preproc_assert] = STATE(137),
    [sym_preproc_pragma] = STATE(137),
    [sym_preproc_error] = STATE(137),
    [sym_preproc_warning] = STATE(137),
    [sym_identifier] = ACTIONS(554),
    [anon_sym_LPAREN] = ACTIONS(556),
    [anon_sym_BANG] = ACTIONS(554),
    [anon_sym_TILDE] = ACTIONS(556),
    [anon_sym_DASH] = ACTIONS(554),
    [anon_sym_PLUS] = ACTIONS(554),
    [anon_sym_AMP] = ACTIONS(554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(556),
    [anon_sym_STAR] = ACTIONS(556),
    [anon_sym_SLASH] = ACTIONS(554),
    [anon_sym_PERCENT] = ACTIONS(556),
    [anon_sym_PIPE_PIPE] = ACTIONS(556),
    [anon_sym_AMP_AMP] = ACTIONS(556),
    [anon_sym_PIPE] = ACTIONS(554),
    [anon_sym_CARET] = ACTIONS(556),
    [anon_sym_EQ_EQ] = ACTIONS(556),
    [anon_sym_BANG_EQ] = ACTIONS(556),
    [anon_sym_GT] = ACTIONS(554),
    [anon_sym_GT_EQ] = ACTIONS(556),
    [anon_sym_LT_EQ] = ACTIONS(556),
    [anon_sym_LT] = ACTIONS(554),
    [anon_sym_LT_LT] = ACTIONS(556),
    [anon_sym_GT_GT] = ACTIONS(554),
    [anon_sym_GT_GT_GT] = ACTIONS(556),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(556),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(554),
    [anon_sym_public] = ACTIONS(554),
    [anon_sym_stock] = ACTIONS(554),
    [anon_sym_static] = ACTIONS(554),
    [anon_sym_new] = ACTIONS(554),
    [anon_sym_decl] = ACTIONS(554),
    [anon_sym_LBRACE] = ACTIONS(556),
    [anon_sym_RBRACE] = ACTIONS(556),
    [anon_sym_void] = ACTIONS(554),
    [anon_sym_bool] = ACTIONS(554),
    [anon_sym_int] = ACTIONS(554),
    [anon_sym_float] = ACTIONS(554),
    [anon_sym_char] = ACTIONS(554),
    [anon_sym__] = ACTIONS(554),
    [anon_sym_Float] = ACTIONS(554),
    [anon_sym_String] = ACTIONS(554),
    [sym_any_type] = ACTIONS(554),
    [anon_sym_for] = ACTIONS(554),
    [anon_sym_while] = ACTIONS(554),
    [anon_sym_do] = ACTIONS(554),
    [anon_sym_break] = ACTIONS(554),
    [anon_sym_continue] = ACTIONS(554),
    [anon_sym_if] = ACTIONS(554),
    [anon_sym_else] = ACTIONS(554),
    [anon_sym_switch] = ACTIONS(554),
    [anon_sym_return] = ACTIONS(554),
    [anon_sym_delete] = ACTIONS(554),
    [anon_sym_SEMI] = ACTIONS(556),
    [anon_sym_DOT] = ACTIONS(554),
    [anon_sym_QMARK] = ACTIONS(556),
    [anon_sym_DASH_DASH] = ACTIONS(556),
    [anon_sym_PLUS_PLUS] = ACTIONS(556),
    [anon_sym_sizeof] = ACTIONS(554),
    [anon_sym_view_as] = ACTIONS(554),
    [sym_int_literal] = ACTIONS(554),
    [sym_float_literal] = ACTIONS(556),
    [anon_sym_SQUOTE] = ACTIONS(556),
    [anon_sym_DQUOTE] = ACTIONS(556),
    [sym_bool_literal] = ACTIONS(554),
    [sym_null] = ACTIONS(554),
    [sym_this] = ACTIONS(554),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(556),
  },
  [138] = {
    [sym_preproc_include] = STATE(138),
    [sym_preproc_tryinclude] = STATE(138),
    [sym_preproc_macro] = STATE(138),
    [sym_preproc_define] = STATE(138),
    [sym_preproc_undefine] = STATE(138),
    [sym_preproc_if] = STATE(138),
    [sym_preproc_elseif] = STATE(138),
    [sym_preproc_assert] = STATE(138),
    [sym_preproc_pragma] = STATE(138),
    [sym_preproc_error] = STATE(138),
    [sym_preproc_warning] = STATE(138),
    [sym_identifier] = ACTIONS(558),
    [anon_sym_LPAREN] = ACTIONS(560),
    [anon_sym_BANG] = ACTIONS(558),
    [anon_sym_TILDE] = ACTIONS(560),
    [anon_sym_DASH] = ACTIONS(558),
    [anon_sym_PLUS] = ACTIONS(558),
    [anon_sym_AMP] = ACTIONS(558),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(560),
    [anon_sym_STAR] = ACTIONS(560),
    [anon_sym_SLASH] = ACTIONS(558),
    [anon_sym_PERCENT] = ACTIONS(560),
    [anon_sym_PIPE_PIPE] = ACTIONS(560),
    [anon_sym_AMP_AMP] = ACTIONS(560),
    [anon_sym_PIPE] = ACTIONS(558),
    [anon_sym_CARET] = ACTIONS(560),
    [anon_sym_EQ_EQ] = ACTIONS(560),
    [anon_sym_BANG_EQ] = ACTIONS(560),
    [anon_sym_GT] = ACTIONS(558),
    [anon_sym_GT_EQ] = ACTIONS(560),
    [anon_sym_LT_EQ] = ACTIONS(560),
    [anon_sym_LT] = ACTIONS(558),
    [anon_sym_LT_LT] = ACTIONS(560),
    [anon_sym_GT_GT] = ACTIONS(558),
    [anon_sym_GT_GT_GT] = ACTIONS(560),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(560),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(558),
    [anon_sym_public] = ACTIONS(558),
    [anon_sym_stock] = ACTIONS(558),
    [anon_sym_static] = ACTIONS(558),
    [anon_sym_new] = ACTIONS(558),
    [anon_sym_decl] = ACTIONS(558),
    [anon_sym_LBRACE] = ACTIONS(560),
    [anon_sym_RBRACE] = ACTIONS(560),
    [anon_sym_void] = ACTIONS(558),
    [anon_sym_bool] = ACTIONS(558),
    [anon_sym_int] = ACTIONS(558),
    [anon_sym_float] = ACTIONS(558),
    [anon_sym_char] = ACTIONS(558),
    [anon_sym__] = ACTIONS(558),
    [anon_sym_Float] = ACTIONS(558),
    [anon_sym_String] = ACTIONS(558),
    [sym_any_type] = ACTIONS(558),
    [anon_sym_for] = ACTIONS(558),
    [anon_sym_while] = ACTIONS(558),
    [anon_sym_do] = ACTIONS(558),
    [anon_sym_break] = ACTIONS(558),
    [anon_sym_continue] = ACTIONS(558),
    [anon_sym_if] = ACTIONS(558),
    [anon_sym_else] = ACTIONS(558),
    [anon_sym_switch] = ACTIONS(558),
    [anon_sym_return] = ACTIONS(558),
    [anon_sym_delete] = ACTIONS(558),
    [anon_sym_SEMI] = ACTIONS(560),
    [anon_sym_DOT] = ACTIONS(558),
    [anon_sym_QMARK] = ACTIONS(560),
    [anon_sym_DASH_DASH] = ACTIONS(560),
    [anon_sym_PLUS_PLUS] = ACTIONS(560),
    [anon_sym_sizeof] = ACTIONS(558),
    [anon_sym_view_as] = ACTIONS(558),
    [sym_int_literal] = ACTIONS(558),
    [sym_float_literal] = ACTIONS(560),
    [anon_sym_SQUOTE] = ACTIONS(560),
    [anon_sym_DQUOTE] = ACTIONS(560),
    [sym_bool_literal] = ACTIONS(558),
    [sym_null] = ACTIONS(558),
    [sym_this] = ACTIONS(558),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(560),
  },
  [139] = {
    [sym_preproc_include] = STATE(139),
    [sym_preproc_tryinclude] = STATE(139),
    [sym_preproc_macro] = STATE(139),
    [sym_preproc_define] = STATE(139),
    [sym_preproc_undefine] = STATE(139),
    [sym_preproc_if] = STATE(139),
    [sym_preproc_elseif] = STATE(139),
    [sym_preproc_assert] = STATE(139),
    [sym_preproc_pragma] = STATE(139),
    [sym_preproc_error] = STATE(139),
    [sym_preproc_warning] = STATE(139),
    [sym_identifier] = ACTIONS(562),
    [anon_sym_LPAREN] = ACTIONS(564),
    [anon_sym_BANG] = ACTIONS(562),
    [anon_sym_TILDE] = ACTIONS(564),
    [anon_sym_DASH] = ACTIONS(562),
    [anon_sym_PLUS] = ACTIONS(562),
    [anon_sym_AMP] = ACTIONS(562),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(564),
    [anon_sym_STAR] = ACTIONS(564),
    [anon_sym_SLASH] = ACTIONS(562),
    [anon_sym_PERCENT] = ACTIONS(564),
    [anon_sym_PIPE_PIPE] = ACTIONS(564),
    [anon_sym_AMP_AMP] = ACTIONS(564),
    [anon_sym_PIPE] = ACTIONS(562),
    [anon_sym_CARET] = ACTIONS(564),
    [anon_sym_EQ_EQ] = ACTIONS(564),
    [anon_sym_BANG_EQ] = ACTIONS(564),
    [anon_sym_GT] = ACTIONS(562),
    [anon_sym_GT_EQ] = ACTIONS(564),
    [anon_sym_LT_EQ] = ACTIONS(564),
    [anon_sym_LT] = ACTIONS(562),
    [anon_sym_LT_LT] = ACTIONS(564),
    [anon_sym_GT_GT] = ACTIONS(562),
    [anon_sym_GT_GT_GT] = ACTIONS(564),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(564),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(562),
    [anon_sym_public] = ACTIONS(562),
    [anon_sym_stock] = ACTIONS(562),
    [anon_sym_static] = ACTIONS(562),
    [anon_sym_new] = ACTIONS(562),
    [anon_sym_decl] = ACTIONS(562),
    [anon_sym_LBRACE] = ACTIONS(564),
    [anon_sym_RBRACE] = ACTIONS(564),
    [anon_sym_void] = ACTIONS(562),
    [anon_sym_bool] = ACTIONS(562),
    [anon_sym_int] = ACTIONS(562),
    [anon_sym_float] = ACTIONS(562),
    [anon_sym_char] = ACTIONS(562),
    [anon_sym__] = ACTIONS(562),
    [anon_sym_Float] = ACTIONS(562),
    [anon_sym_String] = ACTIONS(562),
    [sym_any_type] = ACTIONS(562),
    [anon_sym_for] = ACTIONS(562),
    [anon_sym_while] = ACTIONS(562),
    [anon_sym_do] = ACTIONS(562),
    [anon_sym_break] = ACTIONS(562),
    [anon_sym_continue] = ACTIONS(562),
    [anon_sym_if] = ACTIONS(562),
    [anon_sym_else] = ACTIONS(562),
    [anon_sym_switch] = ACTIONS(562),
    [anon_sym_return] = ACTIONS(562),
    [anon_sym_delete] = ACTIONS(562),
    [anon_sym_SEMI] = ACTIONS(564),
    [anon_sym_DOT] = ACTIONS(562),
    [anon_sym_QMARK] = ACTIONS(564),
    [anon_sym_DASH_DASH] = ACTIONS(564),
    [anon_sym_PLUS_PLUS] = ACTIONS(564),
    [anon_sym_sizeof] = ACTIONS(562),
    [anon_sym_view_as] = ACTIONS(562),
    [sym_int_literal] = ACTIONS(562),
    [sym_float_literal] = ACTIONS(564),
    [anon_sym_SQUOTE] = ACTIONS(564),
    [anon_sym_DQUOTE] = ACTIONS(564),
    [sym_bool_literal] = ACTIONS(562),
    [sym_null] = ACTIONS(562),
    [sym_this] = ACTIONS(562),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(564),
  },
  [140] = {
    [sym_preproc_include] = STATE(140),
    [sym_preproc_tryinclude] = STATE(140),
    [sym_preproc_macro] = STATE(140),
    [sym_preproc_define] = STATE(140),
    [sym_preproc_undefine] = STATE(140),
    [sym_preproc_if] = STATE(140),
    [sym_preproc_elseif] = STATE(140),
    [sym_preproc_assert] = STATE(140),
    [sym_preproc_pragma] = STATE(140),
    [sym_preproc_error] = STATE(140),
    [sym_preproc_warning] = STATE(140),
    [sym_identifier] = ACTIONS(566),
    [anon_sym_LPAREN] = ACTIONS(568),
    [anon_sym_BANG] = ACTIONS(566),
    [anon_sym_TILDE] = ACTIONS(568),
    [anon_sym_DASH] = ACTIONS(566),
    [anon_sym_PLUS] = ACTIONS(566),
    [anon_sym_AMP] = ACTIONS(566),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(568),
    [anon_sym_STAR] = ACTIONS(568),
    [anon_sym_SLASH] = ACTIONS(566),
    [anon_sym_PERCENT] = ACTIONS(568),
    [anon_sym_PIPE_PIPE] = ACTIONS(568),
    [anon_sym_AMP_AMP] = ACTIONS(568),
    [anon_sym_PIPE] = ACTIONS(566),
    [anon_sym_CARET] = ACTIONS(568),
    [anon_sym_EQ_EQ] = ACTIONS(568),
    [anon_sym_BANG_EQ] = ACTIONS(568),
    [anon_sym_GT] = ACTIONS(566),
    [anon_sym_GT_EQ] = ACTIONS(568),
    [anon_sym_LT_EQ] = ACTIONS(568),
    [anon_sym_LT] = ACTIONS(566),
    [anon_sym_LT_LT] = ACTIONS(568),
    [anon_sym_GT_GT] = ACTIONS(566),
    [anon_sym_GT_GT_GT] = ACTIONS(568),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(568),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(566),
    [anon_sym_public] = ACTIONS(566),
    [anon_sym_stock] = ACTIONS(566),
    [anon_sym_static] = ACTIONS(566),
    [anon_sym_new] = ACTIONS(566),
    [anon_sym_decl] = ACTIONS(566),
    [anon_sym_LBRACE] = ACTIONS(568),
    [anon_sym_RBRACE] = ACTIONS(568),
    [anon_sym_void] = ACTIONS(566),
    [anon_sym_bool] = ACTIONS(566),
    [anon_sym_int] = ACTIONS(566),
    [anon_sym_float] = ACTIONS(566),
    [anon_sym_char] = ACTIONS(566),
    [anon_sym__] = ACTIONS(566),
    [anon_sym_Float] = ACTIONS(566),
    [anon_sym_String] = ACTIONS(566),
    [sym_any_type] = ACTIONS(566),
    [anon_sym_for] = ACTIONS(566),
    [anon_sym_while] = ACTIONS(566),
    [anon_sym_do] = ACTIONS(566),
    [anon_sym_break] = ACTIONS(566),
    [anon_sym_continue] = ACTIONS(566),
    [anon_sym_if] = ACTIONS(566),
    [anon_sym_else] = ACTIONS(566),
    [anon_sym_switch] = ACTIONS(566),
    [anon_sym_return] = ACTIONS(566),
    [anon_sym_delete] = ACTIONS(566),
    [anon_sym_SEMI] = ACTIONS(568),
    [anon_sym_DOT] = ACTIONS(566),
    [anon_sym_QMARK] = ACTIONS(568),
    [anon_sym_DASH_DASH] = ACTIONS(568),
    [anon_sym_PLUS_PLUS] = ACTIONS(568),
    [anon_sym_sizeof] = ACTIONS(566),
    [anon_sym_view_as] = ACTIONS(566),
    [sym_int_literal] = ACTIONS(566),
    [sym_float_literal] = ACTIONS(568),
    [anon_sym_SQUOTE] = ACTIONS(568),
    [anon_sym_DQUOTE] = ACTIONS(568),
    [sym_bool_literal] = ACTIONS(566),
    [sym_null] = ACTIONS(566),
    [sym_this] = ACTIONS(566),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(568),
  },
  [141] = {
    [sym_preproc_include] = STATE(141),
    [sym_preproc_tryinclude] = STATE(141),
    [sym_preproc_macro] = STATE(141),
    [sym_preproc_define] = STATE(141),
    [sym_preproc_undefine] = STATE(141),
    [sym_preproc_if] = STATE(141),
    [sym_preproc_elseif] = STATE(141),
    [sym_preproc_assert] = STATE(141),
    [sym_preproc_pragma] = STATE(141),
    [sym_preproc_error] = STATE(141),
    [sym_preproc_warning] = STATE(141),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_LPAREN] = ACTIONS(504),
    [anon_sym_BANG] = ACTIONS(502),
    [anon_sym_TILDE] = ACTIONS(504),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(502),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(504),
    [anon_sym_BANG_EQ] = ACTIONS(504),
    [anon_sym_GT] = ACTIONS(502),
    [anon_sym_GT_EQ] = ACTIONS(504),
    [anon_sym_LT_EQ] = ACTIONS(504),
    [anon_sym_LT] = ACTIONS(502),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_LBRACE] = ACTIONS(504),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_for] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_do] = ACTIONS(502),
    [anon_sym_break] = ACTIONS(502),
    [anon_sym_continue] = ACTIONS(502),
    [anon_sym_if] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_switch] = ACTIONS(502),
    [anon_sym_return] = ACTIONS(502),
    [anon_sym_delete] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(502),
    [anon_sym_view_as] = ACTIONS(502),
    [sym_int_literal] = ACTIONS(502),
    [sym_float_literal] = ACTIONS(504),
    [anon_sym_SQUOTE] = ACTIONS(504),
    [anon_sym_DQUOTE] = ACTIONS(504),
    [sym_bool_literal] = ACTIONS(502),
    [sym_null] = ACTIONS(502),
    [sym_this] = ACTIONS(502),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [142] = {
    [sym_preproc_include] = STATE(142),
    [sym_preproc_tryinclude] = STATE(142),
    [sym_preproc_macro] = STATE(142),
    [sym_preproc_define] = STATE(142),
    [sym_preproc_undefine] = STATE(142),
    [sym_preproc_if] = STATE(142),
    [sym_preproc_elseif] = STATE(142),
    [sym_preproc_assert] = STATE(142),
    [sym_preproc_pragma] = STATE(142),
    [sym_preproc_error] = STATE(142),
    [sym_preproc_warning] = STATE(142),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_LPAREN] = ACTIONS(504),
    [anon_sym_BANG] = ACTIONS(502),
    [anon_sym_TILDE] = ACTIONS(504),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(502),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(504),
    [anon_sym_BANG_EQ] = ACTIONS(504),
    [anon_sym_GT] = ACTIONS(502),
    [anon_sym_GT_EQ] = ACTIONS(504),
    [anon_sym_LT_EQ] = ACTIONS(504),
    [anon_sym_LT] = ACTIONS(502),
    [anon_sym_LT_LT] = ACTIONS(504),
    [anon_sym_GT_GT] = ACTIONS(502),
    [anon_sym_GT_GT_GT] = ACTIONS(504),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_LBRACE] = ACTIONS(504),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_for] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_do] = ACTIONS(502),
    [anon_sym_break] = ACTIONS(502),
    [anon_sym_continue] = ACTIONS(502),
    [anon_sym_if] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_switch] = ACTIONS(502),
    [anon_sym_return] = ACTIONS(502),
    [anon_sym_delete] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(502),
    [anon_sym_view_as] = ACTIONS(502),
    [sym_int_literal] = ACTIONS(502),
    [sym_float_literal] = ACTIONS(504),
    [anon_sym_SQUOTE] = ACTIONS(504),
    [anon_sym_DQUOTE] = ACTIONS(504),
    [sym_bool_literal] = ACTIONS(502),
    [sym_null] = ACTIONS(502),
    [sym_this] = ACTIONS(502),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [143] = {
    [sym_preproc_include] = STATE(143),
    [sym_preproc_tryinclude] = STATE(143),
    [sym_preproc_macro] = STATE(143),
    [sym_preproc_define] = STATE(143),
    [sym_preproc_undefine] = STATE(143),
    [sym_preproc_if] = STATE(143),
    [sym_preproc_elseif] = STATE(143),
    [sym_preproc_assert] = STATE(143),
    [sym_preproc_pragma] = STATE(143),
    [sym_preproc_error] = STATE(143),
    [sym_preproc_warning] = STATE(143),
    [sym_identifier] = ACTIONS(570),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_BANG] = ACTIONS(570),
    [anon_sym_TILDE] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(570),
    [anon_sym_PLUS] = ACTIONS(570),
    [anon_sym_AMP] = ACTIONS(570),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(572),
    [anon_sym_STAR] = ACTIONS(572),
    [anon_sym_SLASH] = ACTIONS(570),
    [anon_sym_PERCENT] = ACTIONS(572),
    [anon_sym_PIPE_PIPE] = ACTIONS(572),
    [anon_sym_AMP_AMP] = ACTIONS(572),
    [anon_sym_PIPE] = ACTIONS(570),
    [anon_sym_CARET] = ACTIONS(572),
    [anon_sym_EQ_EQ] = ACTIONS(572),
    [anon_sym_BANG_EQ] = ACTIONS(572),
    [anon_sym_GT] = ACTIONS(570),
    [anon_sym_GT_EQ] = ACTIONS(572),
    [anon_sym_LT_EQ] = ACTIONS(572),
    [anon_sym_LT] = ACTIONS(570),
    [anon_sym_LT_LT] = ACTIONS(572),
    [anon_sym_GT_GT] = ACTIONS(570),
    [anon_sym_GT_GT_GT] = ACTIONS(572),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(572),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(570),
    [anon_sym_public] = ACTIONS(570),
    [anon_sym_stock] = ACTIONS(570),
    [anon_sym_static] = ACTIONS(570),
    [anon_sym_new] = ACTIONS(570),
    [anon_sym_decl] = ACTIONS(570),
    [anon_sym_LBRACE] = ACTIONS(572),
    [anon_sym_RBRACE] = ACTIONS(572),
    [anon_sym_void] = ACTIONS(570),
    [anon_sym_bool] = ACTIONS(570),
    [anon_sym_int] = ACTIONS(570),
    [anon_sym_float] = ACTIONS(570),
    [anon_sym_char] = ACTIONS(570),
    [anon_sym__] = ACTIONS(570),
    [anon_sym_Float] = ACTIONS(570),
    [anon_sym_String] = ACTIONS(570),
    [sym_any_type] = ACTIONS(570),
    [anon_sym_for] = ACTIONS(570),
    [anon_sym_while] = ACTIONS(570),
    [anon_sym_do] = ACTIONS(570),
    [anon_sym_break] = ACTIONS(570),
    [anon_sym_continue] = ACTIONS(570),
    [anon_sym_if] = ACTIONS(570),
    [anon_sym_else] = ACTIONS(570),
    [anon_sym_switch] = ACTIONS(570),
    [anon_sym_return] = ACTIONS(570),
    [anon_sym_delete] = ACTIONS(570),
    [anon_sym_SEMI] = ACTIONS(572),
    [anon_sym_DOT] = ACTIONS(570),
    [anon_sym_QMARK] = ACTIONS(572),
    [anon_sym_DASH_DASH] = ACTIONS(572),
    [anon_sym_PLUS_PLUS] = ACTIONS(572),
    [anon_sym_sizeof] = ACTIONS(570),
    [anon_sym_view_as] = ACTIONS(570),
    [sym_int_literal] = ACTIONS(570),
    [sym_float_literal] = ACTIONS(572),
    [anon_sym_SQUOTE] = ACTIONS(572),
    [anon_sym_DQUOTE] = ACTIONS(572),
    [sym_bool_literal] = ACTIONS(570),
    [sym_null] = ACTIONS(570),
    [sym_this] = ACTIONS(570),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(572),
  },
  [144] = {
    [sym_preproc_include] = STATE(144),
    [sym_preproc_tryinclude] = STATE(144),
    [sym_preproc_macro] = STATE(144),
    [sym_preproc_define] = STATE(144),
    [sym_preproc_undefine] = STATE(144),
    [sym_preproc_if] = STATE(144),
    [sym_preproc_elseif] = STATE(144),
    [sym_preproc_assert] = STATE(144),
    [sym_preproc_pragma] = STATE(144),
    [sym_preproc_error] = STATE(144),
    [sym_preproc_warning] = STATE(144),
    [sym_identifier] = ACTIONS(574),
    [anon_sym_LPAREN] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(424),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(432),
    [anon_sym_AMP_AMP] = ACTIONS(434),
    [anon_sym_PIPE] = ACTIONS(436),
    [anon_sym_CARET] = ACTIONS(438),
    [anon_sym_EQ_EQ] = ACTIONS(440),
    [anon_sym_BANG_EQ] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(450),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(574),
    [anon_sym_public] = ACTIONS(574),
    [anon_sym_stock] = ACTIONS(574),
    [anon_sym_static] = ACTIONS(574),
    [anon_sym_new] = ACTIONS(574),
    [anon_sym_decl] = ACTIONS(574),
    [anon_sym_LBRACE] = ACTIONS(576),
    [anon_sym_RBRACE] = ACTIONS(576),
    [anon_sym_void] = ACTIONS(574),
    [anon_sym_bool] = ACTIONS(574),
    [anon_sym_int] = ACTIONS(574),
    [anon_sym_float] = ACTIONS(574),
    [anon_sym_char] = ACTIONS(574),
    [anon_sym__] = ACTIONS(574),
    [anon_sym_Float] = ACTIONS(574),
    [anon_sym_String] = ACTIONS(574),
    [sym_any_type] = ACTIONS(574),
    [anon_sym_for] = ACTIONS(574),
    [anon_sym_while] = ACTIONS(574),
    [anon_sym_do] = ACTIONS(574),
    [anon_sym_break] = ACTIONS(574),
    [anon_sym_continue] = ACTIONS(574),
    [anon_sym_if] = ACTIONS(574),
    [anon_sym_else] = ACTIONS(574),
    [anon_sym_switch] = ACTIONS(574),
    [anon_sym_return] = ACTIONS(574),
    [anon_sym_delete] = ACTIONS(574),
    [anon_sym_SEMI] = ACTIONS(576),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(454),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(574),
    [anon_sym_view_as] = ACTIONS(574),
    [sym_int_literal] = ACTIONS(574),
    [sym_float_literal] = ACTIONS(576),
    [anon_sym_SQUOTE] = ACTIONS(576),
    [anon_sym_DQUOTE] = ACTIONS(576),
    [sym_bool_literal] = ACTIONS(574),
    [sym_null] = ACTIONS(574),
    [sym_this] = ACTIONS(574),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(576),
  },
  [145] = {
    [sym_preproc_include] = STATE(145),
    [sym_preproc_tryinclude] = STATE(145),
    [sym_preproc_macro] = STATE(145),
    [sym_preproc_define] = STATE(145),
    [sym_preproc_undefine] = STATE(145),
    [sym_preproc_if] = STATE(145),
    [sym_preproc_elseif] = STATE(145),
    [sym_preproc_assert] = STATE(145),
    [sym_preproc_pragma] = STATE(145),
    [sym_preproc_error] = STATE(145),
    [sym_preproc_warning] = STATE(145),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_BANG] = ACTIONS(123),
    [anon_sym_TILDE] = ACTIONS(127),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(127),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(127),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(123),
    [anon_sym_public] = ACTIONS(123),
    [anon_sym_stock] = ACTIONS(123),
    [anon_sym_static] = ACTIONS(123),
    [anon_sym_new] = ACTIONS(123),
    [anon_sym_decl] = ACTIONS(123),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_void] = ACTIONS(123),
    [anon_sym_bool] = ACTIONS(123),
    [anon_sym_int] = ACTIONS(123),
    [anon_sym_float] = ACTIONS(123),
    [anon_sym_char] = ACTIONS(123),
    [anon_sym__] = ACTIONS(123),
    [anon_sym_Float] = ACTIONS(123),
    [anon_sym_String] = ACTIONS(123),
    [sym_any_type] = ACTIONS(123),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_while] = ACTIONS(123),
    [anon_sym_do] = ACTIONS(123),
    [anon_sym_break] = ACTIONS(123),
    [anon_sym_continue] = ACTIONS(123),
    [anon_sym_if] = ACTIONS(123),
    [anon_sym_else] = ACTIONS(123),
    [anon_sym_switch] = ACTIONS(123),
    [anon_sym_return] = ACTIONS(123),
    [anon_sym_delete] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(123),
    [anon_sym_view_as] = ACTIONS(123),
    [sym_int_literal] = ACTIONS(123),
    [sym_float_literal] = ACTIONS(127),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DQUOTE] = ACTIONS(127),
    [sym_bool_literal] = ACTIONS(123),
    [sym_null] = ACTIONS(123),
    [sym_this] = ACTIONS(123),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(127),
  },
  [146] = {
    [sym_preproc_include] = STATE(146),
    [sym_preproc_tryinclude] = STATE(146),
    [sym_preproc_macro] = STATE(146),
    [sym_preproc_define] = STATE(146),
    [sym_preproc_undefine] = STATE(146),
    [sym_preproc_if] = STATE(146),
    [sym_preproc_elseif] = STATE(146),
    [sym_preproc_assert] = STATE(146),
    [sym_preproc_pragma] = STATE(146),
    [sym_preproc_error] = STATE(146),
    [sym_preproc_warning] = STATE(146),
    [sym_identifier] = ACTIONS(578),
    [anon_sym_LPAREN] = ACTIONS(580),
    [anon_sym_BANG] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(580),
    [anon_sym_DASH] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(424),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(426),
    [anon_sym_STAR] = ACTIONS(428),
    [anon_sym_SLASH] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(428),
    [anon_sym_PIPE_PIPE] = ACTIONS(432),
    [anon_sym_AMP_AMP] = ACTIONS(434),
    [anon_sym_PIPE] = ACTIONS(436),
    [anon_sym_CARET] = ACTIONS(438),
    [anon_sym_EQ_EQ] = ACTIONS(440),
    [anon_sym_BANG_EQ] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(442),
    [anon_sym_GT_EQ] = ACTIONS(444),
    [anon_sym_LT_EQ] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(446),
    [anon_sym_GT_GT] = ACTIONS(448),
    [anon_sym_GT_GT_GT] = ACTIONS(446),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(580),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(578),
    [anon_sym_public] = ACTIONS(578),
    [anon_sym_stock] = ACTIONS(578),
    [anon_sym_static] = ACTIONS(578),
    [anon_sym_new] = ACTIONS(578),
    [anon_sym_decl] = ACTIONS(578),
    [anon_sym_LBRACE] = ACTIONS(580),
    [anon_sym_RBRACE] = ACTIONS(580),
    [anon_sym_void] = ACTIONS(578),
    [anon_sym_bool] = ACTIONS(578),
    [anon_sym_int] = ACTIONS(578),
    [anon_sym_float] = ACTIONS(578),
    [anon_sym_char] = ACTIONS(578),
    [anon_sym__] = ACTIONS(578),
    [anon_sym_Float] = ACTIONS(578),
    [anon_sym_String] = ACTIONS(578),
    [sym_any_type] = ACTIONS(578),
    [anon_sym_for] = ACTIONS(578),
    [anon_sym_while] = ACTIONS(578),
    [anon_sym_do] = ACTIONS(578),
    [anon_sym_break] = ACTIONS(578),
    [anon_sym_continue] = ACTIONS(578),
    [anon_sym_if] = ACTIONS(578),
    [anon_sym_else] = ACTIONS(578),
    [anon_sym_switch] = ACTIONS(578),
    [anon_sym_return] = ACTIONS(578),
    [anon_sym_delete] = ACTIONS(578),
    [anon_sym_SEMI] = ACTIONS(580),
    [anon_sym_DOT] = ACTIONS(452),
    [anon_sym_QMARK] = ACTIONS(454),
    [anon_sym_DASH_DASH] = ACTIONS(456),
    [anon_sym_PLUS_PLUS] = ACTIONS(456),
    [anon_sym_sizeof] = ACTIONS(578),
    [anon_sym_view_as] = ACTIONS(578),
    [sym_int_literal] = ACTIONS(578),
    [sym_float_literal] = ACTIONS(580),
    [anon_sym_SQUOTE] = ACTIONS(580),
    [anon_sym_DQUOTE] = ACTIONS(580),
    [sym_bool_literal] = ACTIONS(578),
    [sym_null] = ACTIONS(578),
    [sym_this] = ACTIONS(578),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(580),
  },
  [147] = {
    [sym_preproc_include] = STATE(147),
    [sym_preproc_tryinclude] = STATE(147),
    [sym_preproc_macro] = STATE(147),
    [sym_preproc_define] = STATE(147),
    [sym_preproc_undefine] = STATE(147),
    [sym_preproc_if] = STATE(147),
    [sym_preproc_elseif] = STATE(147),
    [sym_preproc_assert] = STATE(147),
    [sym_preproc_pragma] = STATE(147),
    [sym_preproc_error] = STATE(147),
    [sym_preproc_warning] = STATE(147),
    [sym_identifier] = ACTIONS(582),
    [anon_sym_LPAREN] = ACTIONS(584),
    [anon_sym_BANG] = ACTIONS(582),
    [anon_sym_TILDE] = ACTIONS(584),
    [anon_sym_DASH] = ACTIONS(582),
    [anon_sym_PLUS] = ACTIONS(582),
    [anon_sym_AMP] = ACTIONS(582),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(584),
    [anon_sym_STAR] = ACTIONS(584),
    [anon_sym_SLASH] = ACTIONS(582),
    [anon_sym_PERCENT] = ACTIONS(584),
    [anon_sym_PIPE_PIPE] = ACTIONS(584),
    [anon_sym_AMP_AMP] = ACTIONS(584),
    [anon_sym_PIPE] = ACTIONS(582),
    [anon_sym_CARET] = ACTIONS(584),
    [anon_sym_EQ_EQ] = ACTIONS(584),
    [anon_sym_BANG_EQ] = ACTIONS(584),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(584),
    [anon_sym_LT_EQ] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_LT] = ACTIONS(584),
    [anon_sym_GT_GT] = ACTIONS(582),
    [anon_sym_GT_GT_GT] = ACTIONS(584),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(584),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(582),
    [anon_sym_public] = ACTIONS(582),
    [anon_sym_stock] = ACTIONS(582),
    [anon_sym_static] = ACTIONS(582),
    [anon_sym_new] = ACTIONS(582),
    [anon_sym_decl] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(584),
    [anon_sym_RBRACE] = ACTIONS(584),
    [anon_sym_void] = ACTIONS(582),
    [anon_sym_bool] = ACTIONS(582),
    [anon_sym_int] = ACTIONS(582),
    [anon_sym_float] = ACTIONS(582),
    [anon_sym_char] = ACTIONS(582),
    [anon_sym__] = ACTIONS(582),
    [anon_sym_Float] = ACTIONS(582),
    [anon_sym_String] = ACTIONS(582),
    [sym_any_type] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_do] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_delete] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(584),
    [anon_sym_DOT] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(584),
    [anon_sym_DASH_DASH] = ACTIONS(584),
    [anon_sym_PLUS_PLUS] = ACTIONS(584),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_view_as] = ACTIONS(582),
    [sym_int_literal] = ACTIONS(582),
    [sym_float_literal] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_DQUOTE] = ACTIONS(584),
    [sym_bool_literal] = ACTIONS(582),
    [sym_null] = ACTIONS(582),
    [sym_this] = ACTIONS(582),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(584),
  },
  [148] = {
    [sym_preproc_include] = STATE(148),
    [sym_preproc_tryinclude] = STATE(148),
    [sym_preproc_macro] = STATE(148),
    [sym_preproc_define] = STATE(148),
    [sym_preproc_undefine] = STATE(148),
    [sym_preproc_if] = STATE(148),
    [sym_preproc_elseif] = STATE(148),
    [sym_preproc_assert] = STATE(148),
    [sym_preproc_pragma] = STATE(148),
    [sym_preproc_error] = STATE(148),
    [sym_preproc_warning] = STATE(148),
    [sym_identifier] = ACTIONS(586),
    [anon_sym_LPAREN] = ACTIONS(588),
    [anon_sym_BANG] = ACTIONS(586),
    [anon_sym_TILDE] = ACTIONS(588),
    [anon_sym_DASH] = ACTIONS(586),
    [anon_sym_PLUS] = ACTIONS(586),
    [anon_sym_AMP] = ACTIONS(586),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(588),
    [anon_sym_STAR] = ACTIONS(588),
    [anon_sym_SLASH] = ACTIONS(586),
    [anon_sym_PERCENT] = ACTIONS(588),
    [anon_sym_PIPE_PIPE] = ACTIONS(588),
    [anon_sym_AMP_AMP] = ACTIONS(588),
    [anon_sym_PIPE] = ACTIONS(586),
    [anon_sym_CARET] = ACTIONS(588),
    [anon_sym_EQ_EQ] = ACTIONS(588),
    [anon_sym_BANG_EQ] = ACTIONS(588),
    [anon_sym_GT] = ACTIONS(586),
    [anon_sym_GT_EQ] = ACTIONS(588),
    [anon_sym_LT_EQ] = ACTIONS(588),
    [anon_sym_LT] = ACTIONS(586),
    [anon_sym_LT_LT] = ACTIONS(588),
    [anon_sym_GT_GT] = ACTIONS(586),
    [anon_sym_GT_GT_GT] = ACTIONS(588),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(588),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(586),
    [anon_sym_public] = ACTIONS(586),
    [anon_sym_stock] = ACTIONS(586),
    [anon_sym_static] = ACTIONS(586),
    [anon_sym_new] = ACTIONS(586),
    [anon_sym_decl] = ACTIONS(586),
    [anon_sym_LBRACE] = ACTIONS(588),
    [anon_sym_RBRACE] = ACTIONS(588),
    [anon_sym_void] = ACTIONS(586),
    [anon_sym_bool] = ACTIONS(586),
    [anon_sym_int] = ACTIONS(586),
    [anon_sym_float] = ACTIONS(586),
    [anon_sym_char] = ACTIONS(586),
    [anon_sym__] = ACTIONS(586),
    [anon_sym_Float] = ACTIONS(586),
    [anon_sym_String] = ACTIONS(586),
    [sym_any_type] = ACTIONS(586),
    [anon_sym_for] = ACTIONS(586),
    [anon_sym_while] = ACTIONS(586),
    [anon_sym_do] = ACTIONS(586),
    [anon_sym_break] = ACTIONS(586),
    [anon_sym_continue] = ACTIONS(586),
    [anon_sym_if] = ACTIONS(586),
    [anon_sym_else] = ACTIONS(586),
    [anon_sym_switch] = ACTIONS(586),
    [anon_sym_return] = ACTIONS(586),
    [anon_sym_delete] = ACTIONS(586),
    [anon_sym_SEMI] = ACTIONS(588),
    [anon_sym_DOT] = ACTIONS(586),
    [anon_sym_QMARK] = ACTIONS(588),
    [anon_sym_DASH_DASH] = ACTIONS(588),
    [anon_sym_PLUS_PLUS] = ACTIONS(588),
    [anon_sym_sizeof] = ACTIONS(586),
    [anon_sym_view_as] = ACTIONS(586),
    [sym_int_literal] = ACTIONS(586),
    [sym_float_literal] = ACTIONS(588),
    [anon_sym_SQUOTE] = ACTIONS(588),
    [anon_sym_DQUOTE] = ACTIONS(588),
    [sym_bool_literal] = ACTIONS(586),
    [sym_null] = ACTIONS(586),
    [sym_this] = ACTIONS(586),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(588),
  },
  [149] = {
    [sym_preproc_include] = STATE(149),
    [sym_preproc_tryinclude] = STATE(149),
    [sym_preproc_macro] = STATE(149),
    [sym_preproc_define] = STATE(149),
    [sym_preproc_undefine] = STATE(149),
    [sym_preproc_if] = STATE(149),
    [sym_preproc_elseif] = STATE(149),
    [sym_preproc_assert] = STATE(149),
    [sym_preproc_pragma] = STATE(149),
    [sym_preproc_error] = STATE(149),
    [sym_preproc_warning] = STATE(149),
    [aux_sym_array_literal_repeat1] = STATE(1308),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(246),
    [anon_sym_BANG] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(246),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(246),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(246),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(246),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(246),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(246),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(343),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_RBRACE] = ACTIONS(345),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_do] = ACTIONS(244),
    [anon_sym_break] = ACTIONS(244),
    [anon_sym_continue] = ACTIONS(244),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_switch] = ACTIONS(244),
    [anon_sym_return] = ACTIONS(244),
    [anon_sym_delete] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [anon_sym_sizeof] = ACTIONS(244),
    [anon_sym_view_as] = ACTIONS(244),
    [sym_int_literal] = ACTIONS(244),
    [sym_float_literal] = ACTIONS(246),
    [anon_sym_SQUOTE] = ACTIONS(246),
    [anon_sym_DQUOTE] = ACTIONS(246),
    [sym_bool_literal] = ACTIONS(244),
    [sym_null] = ACTIONS(244),
    [sym_this] = ACTIONS(244),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [150] = {
    [sym_preproc_include] = STATE(150),
    [sym_preproc_tryinclude] = STATE(150),
    [sym_preproc_macro] = STATE(150),
    [sym_preproc_define] = STATE(150),
    [sym_preproc_undefine] = STATE(150),
    [sym_preproc_if] = STATE(150),
    [sym_preproc_elseif] = STATE(150),
    [sym_preproc_assert] = STATE(150),
    [sym_preproc_pragma] = STATE(150),
    [sym_preproc_error] = STATE(150),
    [sym_preproc_warning] = STATE(150),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_BANG] = ACTIONS(123),
    [anon_sym_TILDE] = ACTIONS(127),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(127),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(127),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(123),
    [anon_sym_public] = ACTIONS(123),
    [anon_sym_stock] = ACTIONS(123),
    [anon_sym_static] = ACTIONS(123),
    [anon_sym_new] = ACTIONS(123),
    [anon_sym_decl] = ACTIONS(123),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_void] = ACTIONS(123),
    [anon_sym_bool] = ACTIONS(123),
    [anon_sym_int] = ACTIONS(123),
    [anon_sym_float] = ACTIONS(123),
    [anon_sym_char] = ACTIONS(123),
    [anon_sym__] = ACTIONS(123),
    [anon_sym_Float] = ACTIONS(123),
    [anon_sym_String] = ACTIONS(123),
    [sym_any_type] = ACTIONS(123),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_while] = ACTIONS(123),
    [anon_sym_do] = ACTIONS(123),
    [anon_sym_break] = ACTIONS(123),
    [anon_sym_continue] = ACTIONS(123),
    [anon_sym_if] = ACTIONS(123),
    [anon_sym_else] = ACTIONS(123),
    [anon_sym_switch] = ACTIONS(123),
    [anon_sym_return] = ACTIONS(123),
    [anon_sym_delete] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(123),
    [anon_sym_view_as] = ACTIONS(123),
    [sym_int_literal] = ACTIONS(123),
    [sym_float_literal] = ACTIONS(127),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DQUOTE] = ACTIONS(127),
    [sym_bool_literal] = ACTIONS(123),
    [sym_null] = ACTIONS(123),
    [sym_this] = ACTIONS(123),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(127),
  },
  [151] = {
    [sym_preproc_include] = STATE(151),
    [sym_preproc_tryinclude] = STATE(151),
    [sym_preproc_macro] = STATE(151),
    [sym_preproc_define] = STATE(151),
    [sym_preproc_undefine] = STATE(151),
    [sym_preproc_if] = STATE(151),
    [sym_preproc_elseif] = STATE(151),
    [sym_preproc_assert] = STATE(151),
    [sym_preproc_pragma] = STATE(151),
    [sym_preproc_error] = STATE(151),
    [sym_preproc_warning] = STATE(151),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(246),
    [anon_sym_BANG] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(246),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_PLUS] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(261),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(264),
    [anon_sym_SLASH] = ACTIONS(261),
    [anon_sym_PERCENT] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_CARET] = ACTIONS(264),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_GT] = ACTIONS(261),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(261),
    [anon_sym_LT_LT] = ACTIONS(264),
    [anon_sym_GT_GT] = ACTIONS(261),
    [anon_sym_GT_GT_GT] = ACTIONS(264),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_LBRACE] = ACTIONS(246),
    [anon_sym_RBRACE] = ACTIONS(264),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_do] = ACTIONS(244),
    [anon_sym_break] = ACTIONS(244),
    [anon_sym_continue] = ACTIONS(244),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_switch] = ACTIONS(244),
    [anon_sym_return] = ACTIONS(244),
    [anon_sym_delete] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [anon_sym_sizeof] = ACTIONS(244),
    [anon_sym_view_as] = ACTIONS(244),
    [sym_int_literal] = ACTIONS(244),
    [sym_float_literal] = ACTIONS(246),
    [anon_sym_SQUOTE] = ACTIONS(246),
    [anon_sym_DQUOTE] = ACTIONS(246),
    [sym_bool_literal] = ACTIONS(244),
    [sym_null] = ACTIONS(244),
    [sym_this] = ACTIONS(244),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [152] = {
    [sym_preproc_include] = STATE(152),
    [sym_preproc_tryinclude] = STATE(152),
    [sym_preproc_macro] = STATE(152),
    [sym_preproc_define] = STATE(152),
    [sym_preproc_undefine] = STATE(152),
    [sym_preproc_if] = STATE(152),
    [sym_preproc_elseif] = STATE(152),
    [sym_preproc_assert] = STATE(152),
    [sym_preproc_pragma] = STATE(152),
    [sym_preproc_error] = STATE(152),
    [sym_preproc_warning] = STATE(152),
    [sym_dimension] = STATE(165),
    [aux_sym_function_definition_repeat1] = STATE(153),
    [ts_builtin_sym_end] = ACTIONS(405),
    [sym_identifier] = ACTIONS(403),
    [anon_sym_DASH] = ACTIONS(403),
    [anon_sym_PLUS] = ACTIONS(403),
    [anon_sym_AMP] = ACTIONS(403),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(405),
    [anon_sym_STAR] = ACTIONS(405),
    [anon_sym_SLASH] = ACTIONS(403),
    [anon_sym_PERCENT] = ACTIONS(405),
    [anon_sym_PIPE_PIPE] = ACTIONS(405),
    [anon_sym_AMP_AMP] = ACTIONS(405),
    [anon_sym_PIPE] = ACTIONS(403),
    [anon_sym_CARET] = ACTIONS(405),
    [anon_sym_EQ_EQ] = ACTIONS(405),
    [anon_sym_BANG_EQ] = ACTIONS(405),
    [anon_sym_GT] = ACTIONS(403),
    [anon_sym_GT_EQ] = ACTIONS(405),
    [anon_sym_LT_EQ] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(403),
    [anon_sym_LT_LT] = ACTIONS(405),
    [anon_sym_GT_GT] = ACTIONS(403),
    [anon_sym_GT_GT_GT] = ACTIONS(405),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(405),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(405),
    [anon_sym_assert] = ACTIONS(403),
    [anon_sym_static_assert] = ACTIONS(403),
    [anon_sym_forward] = ACTIONS(403),
    [anon_sym_native] = ACTIONS(403),
    [anon_sym_const] = ACTIONS(403),
    [anon_sym_public] = ACTIONS(403),
    [anon_sym_stock] = ACTIONS(403),
    [anon_sym_static] = ACTIONS(403),
    [anon_sym_new] = ACTIONS(403),
    [anon_sym_decl] = ACTIONS(403),
    [anon_sym_enum] = ACTIONS(403),
    [anon_sym_RBRACE] = ACTIONS(405),
    [anon_sym_struct] = ACTIONS(403),
    [anon_sym_typedef] = ACTIONS(403),
    [anon_sym_typeset] = ACTIONS(403),
    [anon_sym_funcenum] = ACTIONS(403),
    [anon_sym_functag] = ACTIONS(403),
    [anon_sym_methodmap] = ACTIONS(403),
    [anon_sym_LBRACK] = ACTIONS(590),
    [anon_sym_void] = ACTIONS(403),
    [anon_sym_bool] = ACTIONS(403),
    [anon_sym_int] = ACTIONS(403),
    [anon_sym_float] = ACTIONS(403),
    [anon_sym_char] = ACTIONS(403),
    [anon_sym__] = ACTIONS(403),
    [anon_sym_Float] = ACTIONS(403),
    [anon_sym_String] = ACTIONS(403),
    [sym_any_type] = ACTIONS(403),
    [anon_sym_while] = ACTIONS(403),
    [anon_sym_else] = ACTIONS(403),
    [anon_sym_case] = ACTIONS(403),
    [anon_sym_default] = ACTIONS(403),
    [anon_sym_SEMI] = ACTIONS(405),
    [anon_sym_DOT] = ACTIONS(403),
    [anon_sym_QMARK] = ACTIONS(405),
    [anon_sym_DASH_DASH] = ACTIONS(405),
    [anon_sym_PLUS_PLUS] = ACTIONS(405),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(405),
  },
  [153] = {
    [sym_preproc_include] = STATE(153),
    [sym_preproc_tryinclude] = STATE(153),
    [sym_preproc_macro] = STATE(153),
    [sym_preproc_define] = STATE(153),
    [sym_preproc_undefine] = STATE(153),
    [sym_preproc_if] = STATE(153),
    [sym_preproc_elseif] = STATE(153),
    [sym_preproc_assert] = STATE(153),
    [sym_preproc_pragma] = STATE(153),
    [sym_preproc_error] = STATE(153),
    [sym_preproc_warning] = STATE(153),
    [sym_dimension] = STATE(165),
    [aux_sym_function_definition_repeat1] = STATE(153),
    [ts_builtin_sym_end] = ACTIONS(413),
    [sym_identifier] = ACTIONS(411),
    [anon_sym_DASH] = ACTIONS(411),
    [anon_sym_PLUS] = ACTIONS(411),
    [anon_sym_AMP] = ACTIONS(411),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(413),
    [anon_sym_STAR] = ACTIONS(413),
    [anon_sym_SLASH] = ACTIONS(411),
    [anon_sym_PERCENT] = ACTIONS(413),
    [anon_sym_PIPE_PIPE] = ACTIONS(413),
    [anon_sym_AMP_AMP] = ACTIONS(413),
    [anon_sym_PIPE] = ACTIONS(411),
    [anon_sym_CARET] = ACTIONS(413),
    [anon_sym_EQ_EQ] = ACTIONS(413),
    [anon_sym_BANG_EQ] = ACTIONS(413),
    [anon_sym_GT] = ACTIONS(411),
    [anon_sym_GT_EQ] = ACTIONS(413),
    [anon_sym_LT_EQ] = ACTIONS(413),
    [anon_sym_LT] = ACTIONS(411),
    [anon_sym_LT_LT] = ACTIONS(413),
    [anon_sym_GT_GT] = ACTIONS(411),
    [anon_sym_GT_GT_GT] = ACTIONS(413),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(413),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(413),
    [anon_sym_assert] = ACTIONS(411),
    [anon_sym_static_assert] = ACTIONS(411),
    [anon_sym_forward] = ACTIONS(411),
    [anon_sym_native] = ACTIONS(411),
    [anon_sym_const] = ACTIONS(411),
    [anon_sym_public] = ACTIONS(411),
    [anon_sym_stock] = ACTIONS(411),
    [anon_sym_static] = ACTIONS(411),
    [anon_sym_new] = ACTIONS(411),
    [anon_sym_decl] = ACTIONS(411),
    [anon_sym_enum] = ACTIONS(411),
    [anon_sym_RBRACE] = ACTIONS(413),
    [anon_sym_struct] = ACTIONS(411),
    [anon_sym_typedef] = ACTIONS(411),
    [anon_sym_typeset] = ACTIONS(411),
    [anon_sym_funcenum] = ACTIONS(411),
    [anon_sym_functag] = ACTIONS(411),
    [anon_sym_methodmap] = ACTIONS(411),
    [anon_sym_LBRACK] = ACTIONS(592),
    [anon_sym_void] = ACTIONS(411),
    [anon_sym_bool] = ACTIONS(411),
    [anon_sym_int] = ACTIONS(411),
    [anon_sym_float] = ACTIONS(411),
    [anon_sym_char] = ACTIONS(411),
    [anon_sym__] = ACTIONS(411),
    [anon_sym_Float] = ACTIONS(411),
    [anon_sym_String] = ACTIONS(411),
    [sym_any_type] = ACTIONS(411),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_else] = ACTIONS(411),
    [anon_sym_case] = ACTIONS(411),
    [anon_sym_default] = ACTIONS(411),
    [anon_sym_SEMI] = ACTIONS(413),
    [anon_sym_DOT] = ACTIONS(411),
    [anon_sym_QMARK] = ACTIONS(413),
    [anon_sym_DASH_DASH] = ACTIONS(413),
    [anon_sym_PLUS_PLUS] = ACTIONS(413),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(413),
  },
  [154] = {
    [sym_preproc_include] = STATE(154),
    [sym_preproc_tryinclude] = STATE(154),
    [sym_preproc_macro] = STATE(154),
    [sym_preproc_define] = STATE(154),
    [sym_preproc_undefine] = STATE(154),
    [sym_preproc_if] = STATE(154),
    [sym_preproc_elseif] = STATE(154),
    [sym_preproc_assert] = STATE(154),
    [sym_preproc_pragma] = STATE(154),
    [sym_preproc_error] = STATE(154),
    [sym_preproc_warning] = STATE(154),
    [sym_dimension] = STATE(165),
    [aux_sym_function_definition_repeat1] = STATE(153),
    [ts_builtin_sym_end] = ACTIONS(405),
    [sym_identifier] = ACTIONS(403),
    [anon_sym_DASH] = ACTIONS(403),
    [anon_sym_PLUS] = ACTIONS(403),
    [anon_sym_AMP] = ACTIONS(403),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(405),
    [anon_sym_STAR] = ACTIONS(405),
    [anon_sym_SLASH] = ACTIONS(403),
    [anon_sym_PERCENT] = ACTIONS(405),
    [anon_sym_PIPE_PIPE] = ACTIONS(405),
    [anon_sym_AMP_AMP] = ACTIONS(405),
    [anon_sym_PIPE] = ACTIONS(403),
    [anon_sym_CARET] = ACTIONS(405),
    [anon_sym_EQ_EQ] = ACTIONS(405),
    [anon_sym_BANG_EQ] = ACTIONS(405),
    [anon_sym_GT] = ACTIONS(403),
    [anon_sym_GT_EQ] = ACTIONS(405),
    [anon_sym_LT_EQ] = ACTIONS(405),
    [anon_sym_LT] = ACTIONS(403),
    [anon_sym_LT_LT] = ACTIONS(405),
    [anon_sym_GT_GT] = ACTIONS(403),
    [anon_sym_GT_GT_GT] = ACTIONS(405),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(405),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(405),
    [anon_sym_assert] = ACTIONS(403),
    [anon_sym_static_assert] = ACTIONS(403),
    [anon_sym_forward] = ACTIONS(403),
    [anon_sym_native] = ACTIONS(403),
    [anon_sym_const] = ACTIONS(403),
    [anon_sym_public] = ACTIONS(403),
    [anon_sym_stock] = ACTIONS(403),
    [anon_sym_static] = ACTIONS(403),
    [anon_sym_new] = ACTIONS(403),
    [anon_sym_decl] = ACTIONS(403),
    [anon_sym_enum] = ACTIONS(403),
    [anon_sym_RBRACE] = ACTIONS(405),
    [anon_sym_struct] = ACTIONS(403),
    [anon_sym_typedef] = ACTIONS(403),
    [anon_sym_typeset] = ACTIONS(403),
    [anon_sym_funcenum] = ACTIONS(403),
    [anon_sym_functag] = ACTIONS(403),
    [anon_sym_methodmap] = ACTIONS(403),
    [anon_sym_LBRACK] = ACTIONS(590),
    [anon_sym_void] = ACTIONS(403),
    [anon_sym_bool] = ACTIONS(403),
    [anon_sym_int] = ACTIONS(403),
    [anon_sym_float] = ACTIONS(403),
    [anon_sym_char] = ACTIONS(403),
    [anon_sym__] = ACTIONS(403),
    [anon_sym_Float] = ACTIONS(403),
    [anon_sym_String] = ACTIONS(403),
    [sym_any_type] = ACTIONS(403),
    [anon_sym_while] = ACTIONS(403),
    [anon_sym_else] = ACTIONS(403),
    [anon_sym_case] = ACTIONS(403),
    [anon_sym_default] = ACTIONS(403),
    [anon_sym_SEMI] = ACTIONS(405),
    [anon_sym_DOT] = ACTIONS(595),
    [anon_sym_QMARK] = ACTIONS(405),
    [anon_sym_DASH_DASH] = ACTIONS(405),
    [anon_sym_PLUS_PLUS] = ACTIONS(405),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(405),
  },
  [155] = {
    [sym_preproc_include] = STATE(155),
    [sym_preproc_tryinclude] = STATE(155),
    [sym_preproc_macro] = STATE(155),
    [sym_preproc_define] = STATE(155),
    [sym_preproc_undefine] = STATE(155),
    [sym_preproc_if] = STATE(155),
    [sym_preproc_elseif] = STATE(155),
    [sym_preproc_assert] = STATE(155),
    [sym_preproc_pragma] = STATE(155),
    [sym_preproc_error] = STATE(155),
    [sym_preproc_warning] = STATE(155),
    [sym_fixed_dimension] = STATE(164),
    [aux_sym_dynamic_array_repeat1] = STATE(156),
    [ts_builtin_sym_end] = ACTIONS(392),
    [sym_identifier] = ACTIONS(390),
    [anon_sym_DASH] = ACTIONS(390),
    [anon_sym_PLUS] = ACTIONS(390),
    [anon_sym_AMP] = ACTIONS(390),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(392),
    [anon_sym_SLASH] = ACTIONS(390),
    [anon_sym_PERCENT] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE] = ACTIONS(390),
    [anon_sym_CARET] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT] = ACTIONS(390),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_LT] = ACTIONS(390),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(390),
    [anon_sym_GT_GT_GT] = ACTIONS(392),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(392),
    [anon_sym_assert] = ACTIONS(390),
    [anon_sym_static_assert] = ACTIONS(390),
    [anon_sym_forward] = ACTIONS(390),
    [anon_sym_native] = ACTIONS(390),
    [anon_sym_const] = ACTIONS(390),
    [anon_sym_public] = ACTIONS(390),
    [anon_sym_stock] = ACTIONS(390),
    [anon_sym_static] = ACTIONS(390),
    [anon_sym_new] = ACTIONS(390),
    [anon_sym_decl] = ACTIONS(390),
    [anon_sym_enum] = ACTIONS(390),
    [anon_sym_RBRACE] = ACTIONS(392),
    [anon_sym_struct] = ACTIONS(390),
    [anon_sym_typedef] = ACTIONS(390),
    [anon_sym_typeset] = ACTIONS(390),
    [anon_sym_funcenum] = ACTIONS(390),
    [anon_sym_functag] = ACTIONS(390),
    [anon_sym_methodmap] = ACTIONS(390),
    [anon_sym_LBRACK] = ACTIONS(597),
    [anon_sym_void] = ACTIONS(390),
    [anon_sym_bool] = ACTIONS(390),
    [anon_sym_int] = ACTIONS(390),
    [anon_sym_float] = ACTIONS(390),
    [anon_sym_char] = ACTIONS(390),
    [anon_sym__] = ACTIONS(390),
    [anon_sym_Float] = ACTIONS(390),
    [anon_sym_String] = ACTIONS(390),
    [sym_any_type] = ACTIONS(390),
    [anon_sym_while] = ACTIONS(390),
    [anon_sym_else] = ACTIONS(390),
    [anon_sym_case] = ACTIONS(390),
    [anon_sym_default] = ACTIONS(390),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(390),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_DASH_DASH] = ACTIONS(392),
    [anon_sym_PLUS_PLUS] = ACTIONS(392),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(392),
  },
  [156] = {
    [sym_preproc_include] = STATE(156),
    [sym_preproc_tryinclude] = STATE(156),
    [sym_preproc_macro] = STATE(156),
    [sym_preproc_define] = STATE(156),
    [sym_preproc_undefine] = STATE(156),
    [sym_preproc_if] = STATE(156),
    [sym_preproc_elseif] = STATE(156),
    [sym_preproc_assert] = STATE(156),
    [sym_preproc_pragma] = STATE(156),
    [sym_preproc_error] = STATE(156),
    [sym_preproc_warning] = STATE(156),
    [sym_fixed_dimension] = STATE(164),
    [aux_sym_dynamic_array_repeat1] = STATE(156),
    [ts_builtin_sym_end] = ACTIONS(398),
    [sym_identifier] = ACTIONS(396),
    [anon_sym_DASH] = ACTIONS(396),
    [anon_sym_PLUS] = ACTIONS(396),
    [anon_sym_AMP] = ACTIONS(396),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(398),
    [anon_sym_STAR] = ACTIONS(398),
    [anon_sym_SLASH] = ACTIONS(396),
    [anon_sym_PERCENT] = ACTIONS(398),
    [anon_sym_PIPE_PIPE] = ACTIONS(398),
    [anon_sym_AMP_AMP] = ACTIONS(398),
    [anon_sym_PIPE] = ACTIONS(396),
    [anon_sym_CARET] = ACTIONS(398),
    [anon_sym_EQ_EQ] = ACTIONS(398),
    [anon_sym_BANG_EQ] = ACTIONS(398),
    [anon_sym_GT] = ACTIONS(396),
    [anon_sym_GT_EQ] = ACTIONS(398),
    [anon_sym_LT_EQ] = ACTIONS(398),
    [anon_sym_LT] = ACTIONS(396),
    [anon_sym_LT_LT] = ACTIONS(398),
    [anon_sym_GT_GT] = ACTIONS(396),
    [anon_sym_GT_GT_GT] = ACTIONS(398),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(398),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(398),
    [anon_sym_assert] = ACTIONS(396),
    [anon_sym_static_assert] = ACTIONS(396),
    [anon_sym_forward] = ACTIONS(396),
    [anon_sym_native] = ACTIONS(396),
    [anon_sym_const] = ACTIONS(396),
    [anon_sym_public] = ACTIONS(396),
    [anon_sym_stock] = ACTIONS(396),
    [anon_sym_static] = ACTIONS(396),
    [anon_sym_new] = ACTIONS(396),
    [anon_sym_decl] = ACTIONS(396),
    [anon_sym_enum] = ACTIONS(396),
    [anon_sym_RBRACE] = ACTIONS(398),
    [anon_sym_struct] = ACTIONS(396),
    [anon_sym_typedef] = ACTIONS(396),
    [anon_sym_typeset] = ACTIONS(396),
    [anon_sym_funcenum] = ACTIONS(396),
    [anon_sym_functag] = ACTIONS(396),
    [anon_sym_methodmap] = ACTIONS(396),
    [anon_sym_LBRACK] = ACTIONS(599),
    [anon_sym_void] = ACTIONS(396),
    [anon_sym_bool] = ACTIONS(396),
    [anon_sym_int] = ACTIONS(396),
    [anon_sym_float] = ACTIONS(396),
    [anon_sym_char] = ACTIONS(396),
    [anon_sym__] = ACTIONS(396),
    [anon_sym_Float] = ACTIONS(396),
    [anon_sym_String] = ACTIONS(396),
    [sym_any_type] = ACTIONS(396),
    [anon_sym_while] = ACTIONS(396),
    [anon_sym_else] = ACTIONS(396),
    [anon_sym_case] = ACTIONS(396),
    [anon_sym_default] = ACTIONS(396),
    [anon_sym_SEMI] = ACTIONS(398),
    [anon_sym_DOT] = ACTIONS(396),
    [anon_sym_QMARK] = ACTIONS(398),
    [anon_sym_DASH_DASH] = ACTIONS(398),
    [anon_sym_PLUS_PLUS] = ACTIONS(398),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(398),
  },
  [157] = {
    [sym_preproc_include] = STATE(157),
    [sym_preproc_tryinclude] = STATE(157),
    [sym_preproc_macro] = STATE(157),
    [sym_preproc_define] = STATE(157),
    [sym_preproc_undefine] = STATE(157),
    [sym_preproc_if] = STATE(157),
    [sym_preproc_elseif] = STATE(157),
    [sym_preproc_assert] = STATE(157),
    [sym_preproc_pragma] = STATE(157),
    [sym_preproc_error] = STATE(157),
    [sym_preproc_warning] = STATE(157),
    [sym__manual_semicolon] = STATE(526),
    [sym__semicolon] = STATE(579),
    [ts_builtin_sym_end] = ACTIONS(460),
    [sym_identifier] = ACTIONS(458),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(604),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(612),
    [anon_sym_AMP_AMP] = ACTIONS(614),
    [anon_sym_PIPE] = ACTIONS(616),
    [anon_sym_CARET] = ACTIONS(618),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(630),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(460),
    [anon_sym_assert] = ACTIONS(458),
    [anon_sym_static_assert] = ACTIONS(458),
    [anon_sym_forward] = ACTIONS(458),
    [anon_sym_native] = ACTIONS(458),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_public] = ACTIONS(458),
    [anon_sym_stock] = ACTIONS(458),
    [anon_sym_static] = ACTIONS(458),
    [anon_sym_new] = ACTIONS(458),
    [anon_sym_decl] = ACTIONS(458),
    [anon_sym_enum] = ACTIONS(458),
    [anon_sym_RBRACE] = ACTIONS(460),
    [anon_sym_struct] = ACTIONS(458),
    [anon_sym_typedef] = ACTIONS(458),
    [anon_sym_typeset] = ACTIONS(458),
    [anon_sym_funcenum] = ACTIONS(458),
    [anon_sym_functag] = ACTIONS(458),
    [anon_sym_methodmap] = ACTIONS(458),
    [anon_sym_void] = ACTIONS(458),
    [anon_sym_bool] = ACTIONS(458),
    [anon_sym_int] = ACTIONS(458),
    [anon_sym_float] = ACTIONS(458),
    [anon_sym_char] = ACTIONS(458),
    [anon_sym__] = ACTIONS(458),
    [anon_sym_Float] = ACTIONS(458),
    [anon_sym_String] = ACTIONS(458),
    [sym_any_type] = ACTIONS(458),
    [anon_sym_while] = ACTIONS(458),
    [anon_sym_else] = ACTIONS(458),
    [anon_sym_case] = ACTIONS(458),
    [anon_sym_default] = ACTIONS(458),
    [anon_sym_SEMI] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(634),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(378),
  },
  [158] = {
    [sym_preproc_include] = STATE(158),
    [sym_preproc_tryinclude] = STATE(158),
    [sym_preproc_macro] = STATE(158),
    [sym_preproc_define] = STATE(158),
    [sym_preproc_undefine] = STATE(158),
    [sym_preproc_if] = STATE(158),
    [sym_preproc_elseif] = STATE(158),
    [sym_preproc_assert] = STATE(158),
    [sym_preproc_pragma] = STATE(158),
    [sym_preproc_error] = STATE(158),
    [sym_preproc_warning] = STATE(158),
    [ts_builtin_sym_end] = ACTIONS(480),
    [sym_identifier] = ACTIONS(478),
    [anon_sym_DASH] = ACTIONS(478),
    [anon_sym_PLUS] = ACTIONS(478),
    [anon_sym_AMP] = ACTIONS(478),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(480),
    [anon_sym_STAR] = ACTIONS(480),
    [anon_sym_SLASH] = ACTIONS(478),
    [anon_sym_PERCENT] = ACTIONS(480),
    [anon_sym_PIPE_PIPE] = ACTIONS(480),
    [anon_sym_AMP_AMP] = ACTIONS(480),
    [anon_sym_PIPE] = ACTIONS(478),
    [anon_sym_CARET] = ACTIONS(480),
    [anon_sym_EQ_EQ] = ACTIONS(480),
    [anon_sym_BANG_EQ] = ACTIONS(480),
    [anon_sym_GT] = ACTIONS(478),
    [anon_sym_GT_EQ] = ACTIONS(480),
    [anon_sym_LT_EQ] = ACTIONS(480),
    [anon_sym_LT] = ACTIONS(478),
    [anon_sym_LT_LT] = ACTIONS(480),
    [anon_sym_GT_GT] = ACTIONS(478),
    [anon_sym_GT_GT_GT] = ACTIONS(480),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(480),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(480),
    [anon_sym_assert] = ACTIONS(478),
    [anon_sym_static_assert] = ACTIONS(478),
    [anon_sym_EQ] = ACTIONS(478),
    [anon_sym_forward] = ACTIONS(478),
    [anon_sym_native] = ACTIONS(478),
    [anon_sym_const] = ACTIONS(478),
    [anon_sym_public] = ACTIONS(478),
    [anon_sym_stock] = ACTIONS(478),
    [anon_sym_static] = ACTIONS(478),
    [anon_sym_new] = ACTIONS(478),
    [anon_sym_decl] = ACTIONS(478),
    [anon_sym_enum] = ACTIONS(478),
    [anon_sym_RBRACE] = ACTIONS(480),
    [anon_sym_struct] = ACTIONS(478),
    [anon_sym_typedef] = ACTIONS(478),
    [anon_sym_typeset] = ACTIONS(478),
    [anon_sym_funcenum] = ACTIONS(478),
    [anon_sym_functag] = ACTIONS(478),
    [anon_sym_methodmap] = ACTIONS(478),
    [anon_sym_LBRACK] = ACTIONS(480),
    [anon_sym_void] = ACTIONS(478),
    [anon_sym_bool] = ACTIONS(478),
    [anon_sym_int] = ACTIONS(478),
    [anon_sym_float] = ACTIONS(478),
    [anon_sym_char] = ACTIONS(478),
    [anon_sym__] = ACTIONS(478),
    [anon_sym_Float] = ACTIONS(478),
    [anon_sym_String] = ACTIONS(478),
    [sym_any_type] = ACTIONS(478),
    [anon_sym_while] = ACTIONS(478),
    [anon_sym_else] = ACTIONS(478),
    [anon_sym_case] = ACTIONS(478),
    [anon_sym_default] = ACTIONS(478),
    [anon_sym_SEMI] = ACTIONS(480),
    [anon_sym_DOT] = ACTIONS(478),
    [anon_sym_QMARK] = ACTIONS(480),
    [anon_sym_DASH_DASH] = ACTIONS(480),
    [anon_sym_PLUS_PLUS] = ACTIONS(480),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(480),
  },
  [159] = {
    [sym_preproc_include] = STATE(159),
    [sym_preproc_tryinclude] = STATE(159),
    [sym_preproc_macro] = STATE(159),
    [sym_preproc_define] = STATE(159),
    [sym_preproc_undefine] = STATE(159),
    [sym_preproc_if] = STATE(159),
    [sym_preproc_elseif] = STATE(159),
    [sym_preproc_assert] = STATE(159),
    [sym_preproc_pragma] = STATE(159),
    [sym_preproc_error] = STATE(159),
    [sym_preproc_warning] = STATE(159),
    [sym_variable_declaration_statement] = STATE(1453),
    [sym_variable_storage_class] = STATE(988),
    [sym_visibility] = STATE(981),
    [sym_new_expression] = STATE(729),
    [sym_old_for_loop_variable_declaration_statement] = STATE(1453),
    [sym_type] = STATE(1167),
    [sym_old_type] = STATE(405),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(277),
    [sym__expression] = STATE(902),
    [sym_assignment_expression] = STATE(748),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(638),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(646),
    [anon_sym_decl] = ACTIONS(648),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [160] = {
    [sym_preproc_include] = STATE(160),
    [sym_preproc_tryinclude] = STATE(160),
    [sym_preproc_macro] = STATE(160),
    [sym_preproc_define] = STATE(160),
    [sym_preproc_undefine] = STATE(160),
    [sym_preproc_if] = STATE(160),
    [sym_preproc_elseif] = STATE(160),
    [sym_preproc_assert] = STATE(160),
    [sym_preproc_pragma] = STATE(160),
    [sym_preproc_error] = STATE(160),
    [sym_preproc_warning] = STATE(160),
    [ts_builtin_sym_end] = ACTIONS(476),
    [sym_identifier] = ACTIONS(474),
    [anon_sym_DASH] = ACTIONS(474),
    [anon_sym_PLUS] = ACTIONS(474),
    [anon_sym_AMP] = ACTIONS(474),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(476),
    [anon_sym_STAR] = ACTIONS(476),
    [anon_sym_SLASH] = ACTIONS(474),
    [anon_sym_PERCENT] = ACTIONS(476),
    [anon_sym_PIPE_PIPE] = ACTIONS(476),
    [anon_sym_AMP_AMP] = ACTIONS(476),
    [anon_sym_PIPE] = ACTIONS(474),
    [anon_sym_CARET] = ACTIONS(476),
    [anon_sym_EQ_EQ] = ACTIONS(476),
    [anon_sym_BANG_EQ] = ACTIONS(476),
    [anon_sym_GT] = ACTIONS(474),
    [anon_sym_GT_EQ] = ACTIONS(476),
    [anon_sym_LT_EQ] = ACTIONS(476),
    [anon_sym_LT] = ACTIONS(474),
    [anon_sym_LT_LT] = ACTIONS(476),
    [anon_sym_GT_GT] = ACTIONS(474),
    [anon_sym_GT_GT_GT] = ACTIONS(476),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(476),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(476),
    [anon_sym_assert] = ACTIONS(474),
    [anon_sym_static_assert] = ACTIONS(474),
    [anon_sym_EQ] = ACTIONS(474),
    [anon_sym_forward] = ACTIONS(474),
    [anon_sym_native] = ACTIONS(474),
    [anon_sym_const] = ACTIONS(474),
    [anon_sym_public] = ACTIONS(474),
    [anon_sym_stock] = ACTIONS(474),
    [anon_sym_static] = ACTIONS(474),
    [anon_sym_new] = ACTIONS(474),
    [anon_sym_decl] = ACTIONS(474),
    [anon_sym_enum] = ACTIONS(474),
    [anon_sym_RBRACE] = ACTIONS(476),
    [anon_sym_struct] = ACTIONS(474),
    [anon_sym_typedef] = ACTIONS(474),
    [anon_sym_typeset] = ACTIONS(474),
    [anon_sym_funcenum] = ACTIONS(474),
    [anon_sym_functag] = ACTIONS(474),
    [anon_sym_methodmap] = ACTIONS(474),
    [anon_sym_LBRACK] = ACTIONS(476),
    [anon_sym_void] = ACTIONS(474),
    [anon_sym_bool] = ACTIONS(474),
    [anon_sym_int] = ACTIONS(474),
    [anon_sym_float] = ACTIONS(474),
    [anon_sym_char] = ACTIONS(474),
    [anon_sym__] = ACTIONS(474),
    [anon_sym_Float] = ACTIONS(474),
    [anon_sym_String] = ACTIONS(474),
    [sym_any_type] = ACTIONS(474),
    [anon_sym_while] = ACTIONS(474),
    [anon_sym_else] = ACTIONS(474),
    [anon_sym_case] = ACTIONS(474),
    [anon_sym_default] = ACTIONS(474),
    [anon_sym_SEMI] = ACTIONS(476),
    [anon_sym_DOT] = ACTIONS(474),
    [anon_sym_QMARK] = ACTIONS(476),
    [anon_sym_DASH_DASH] = ACTIONS(476),
    [anon_sym_PLUS_PLUS] = ACTIONS(476),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(476),
  },
  [161] = {
    [sym_preproc_include] = STATE(161),
    [sym_preproc_tryinclude] = STATE(161),
    [sym_preproc_macro] = STATE(161),
    [sym_preproc_define] = STATE(161),
    [sym_preproc_undefine] = STATE(161),
    [sym_preproc_if] = STATE(161),
    [sym_preproc_elseif] = STATE(161),
    [sym_preproc_assert] = STATE(161),
    [sym_preproc_pragma] = STATE(161),
    [sym_preproc_error] = STATE(161),
    [sym_preproc_warning] = STATE(161),
    [sym_variable_declaration_statement] = STATE(1430),
    [sym_variable_storage_class] = STATE(988),
    [sym_visibility] = STATE(981),
    [sym_new_expression] = STATE(729),
    [sym_old_for_loop_variable_declaration_statement] = STATE(1430),
    [sym_type] = STATE(1167),
    [sym_old_type] = STATE(405),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(260),
    [sym__expression] = STATE(902),
    [sym_assignment_expression] = STATE(747),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(638),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(646),
    [anon_sym_decl] = ACTIONS(648),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [162] = {
    [sym_preproc_include] = STATE(162),
    [sym_preproc_tryinclude] = STATE(162),
    [sym_preproc_macro] = STATE(162),
    [sym_preproc_define] = STATE(162),
    [sym_preproc_undefine] = STATE(162),
    [sym_preproc_if] = STATE(162),
    [sym_preproc_elseif] = STATE(162),
    [sym_preproc_assert] = STATE(162),
    [sym_preproc_pragma] = STATE(162),
    [sym_preproc_error] = STATE(162),
    [sym_preproc_warning] = STATE(162),
    [sym_variable_declaration_statement] = STATE(1454),
    [sym_variable_storage_class] = STATE(988),
    [sym_visibility] = STATE(981),
    [sym_new_expression] = STATE(729),
    [sym_old_for_loop_variable_declaration_statement] = STATE(1454),
    [sym_type] = STATE(1167),
    [sym_old_type] = STATE(405),
    [sym_builtin_type] = STATE(1103),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(280),
    [sym__expression] = STATE(902),
    [sym_assignment_expression] = STATE(744),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(638),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(41),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(646),
    [anon_sym_decl] = ACTIONS(648),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [163] = {
    [sym_preproc_include] = STATE(163),
    [sym_preproc_tryinclude] = STATE(163),
    [sym_preproc_macro] = STATE(163),
    [sym_preproc_define] = STATE(163),
    [sym_preproc_undefine] = STATE(163),
    [sym_preproc_if] = STATE(163),
    [sym_preproc_elseif] = STATE(163),
    [sym_preproc_assert] = STATE(163),
    [sym_preproc_pragma] = STATE(163),
    [sym_preproc_error] = STATE(163),
    [sym_preproc_warning] = STATE(163),
    [sym__manual_semicolon] = STATE(526),
    [sym__semicolon] = STATE(554),
    [ts_builtin_sym_end] = ACTIONS(420),
    [sym_identifier] = ACTIONS(418),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(604),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(612),
    [anon_sym_AMP_AMP] = ACTIONS(614),
    [anon_sym_PIPE] = ACTIONS(616),
    [anon_sym_CARET] = ACTIONS(618),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(630),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(420),
    [anon_sym_assert] = ACTIONS(418),
    [anon_sym_static_assert] = ACTIONS(418),
    [anon_sym_forward] = ACTIONS(418),
    [anon_sym_native] = ACTIONS(418),
    [anon_sym_const] = ACTIONS(418),
    [anon_sym_public] = ACTIONS(418),
    [anon_sym_stock] = ACTIONS(418),
    [anon_sym_static] = ACTIONS(418),
    [anon_sym_new] = ACTIONS(418),
    [anon_sym_decl] = ACTIONS(418),
    [anon_sym_enum] = ACTIONS(418),
    [anon_sym_RBRACE] = ACTIONS(420),
    [anon_sym_struct] = ACTIONS(418),
    [anon_sym_typedef] = ACTIONS(418),
    [anon_sym_typeset] = ACTIONS(418),
    [anon_sym_funcenum] = ACTIONS(418),
    [anon_sym_functag] = ACTIONS(418),
    [anon_sym_methodmap] = ACTIONS(418),
    [anon_sym_void] = ACTIONS(418),
    [anon_sym_bool] = ACTIONS(418),
    [anon_sym_int] = ACTIONS(418),
    [anon_sym_float] = ACTIONS(418),
    [anon_sym_char] = ACTIONS(418),
    [anon_sym__] = ACTIONS(418),
    [anon_sym_Float] = ACTIONS(418),
    [anon_sym_String] = ACTIONS(418),
    [sym_any_type] = ACTIONS(418),
    [anon_sym_while] = ACTIONS(418),
    [anon_sym_else] = ACTIONS(418),
    [anon_sym_case] = ACTIONS(418),
    [anon_sym_default] = ACTIONS(418),
    [anon_sym_SEMI] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(634),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(378),
  },
  [164] = {
    [sym_preproc_include] = STATE(164),
    [sym_preproc_tryinclude] = STATE(164),
    [sym_preproc_macro] = STATE(164),
    [sym_preproc_define] = STATE(164),
    [sym_preproc_undefine] = STATE(164),
    [sym_preproc_if] = STATE(164),
    [sym_preproc_elseif] = STATE(164),
    [sym_preproc_assert] = STATE(164),
    [sym_preproc_pragma] = STATE(164),
    [sym_preproc_error] = STATE(164),
    [sym_preproc_warning] = STATE(164),
    [ts_builtin_sym_end] = ACTIONS(464),
    [sym_identifier] = ACTIONS(462),
    [anon_sym_DASH] = ACTIONS(462),
    [anon_sym_PLUS] = ACTIONS(462),
    [anon_sym_AMP] = ACTIONS(462),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(462),
    [anon_sym_PERCENT] = ACTIONS(464),
    [anon_sym_PIPE_PIPE] = ACTIONS(464),
    [anon_sym_AMP_AMP] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(462),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_EQ_EQ] = ACTIONS(464),
    [anon_sym_BANG_EQ] = ACTIONS(464),
    [anon_sym_GT] = ACTIONS(462),
    [anon_sym_GT_EQ] = ACTIONS(464),
    [anon_sym_LT_EQ] = ACTIONS(464),
    [anon_sym_LT] = ACTIONS(462),
    [anon_sym_LT_LT] = ACTIONS(464),
    [anon_sym_GT_GT] = ACTIONS(462),
    [anon_sym_GT_GT_GT] = ACTIONS(464),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(464),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(464),
    [anon_sym_assert] = ACTIONS(462),
    [anon_sym_static_assert] = ACTIONS(462),
    [anon_sym_forward] = ACTIONS(462),
    [anon_sym_native] = ACTIONS(462),
    [anon_sym_const] = ACTIONS(462),
    [anon_sym_public] = ACTIONS(462),
    [anon_sym_stock] = ACTIONS(462),
    [anon_sym_static] = ACTIONS(462),
    [anon_sym_new] = ACTIONS(462),
    [anon_sym_decl] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(462),
    [anon_sym_RBRACE] = ACTIONS(464),
    [anon_sym_struct] = ACTIONS(462),
    [anon_sym_typedef] = ACTIONS(462),
    [anon_sym_typeset] = ACTIONS(462),
    [anon_sym_funcenum] = ACTIONS(462),
    [anon_sym_functag] = ACTIONS(462),
    [anon_sym_methodmap] = ACTIONS(462),
    [anon_sym_LBRACK] = ACTIONS(464),
    [anon_sym_void] = ACTIONS(462),
    [anon_sym_bool] = ACTIONS(462),
    [anon_sym_int] = ACTIONS(462),
    [anon_sym_float] = ACTIONS(462),
    [anon_sym_char] = ACTIONS(462),
    [anon_sym__] = ACTIONS(462),
    [anon_sym_Float] = ACTIONS(462),
    [anon_sym_String] = ACTIONS(462),
    [sym_any_type] = ACTIONS(462),
    [anon_sym_while] = ACTIONS(462),
    [anon_sym_else] = ACTIONS(462),
    [anon_sym_case] = ACTIONS(462),
    [anon_sym_default] = ACTIONS(462),
    [anon_sym_SEMI] = ACTIONS(464),
    [anon_sym_DOT] = ACTIONS(462),
    [anon_sym_QMARK] = ACTIONS(464),
    [anon_sym_DASH_DASH] = ACTIONS(464),
    [anon_sym_PLUS_PLUS] = ACTIONS(464),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(464),
  },
  [165] = {
    [sym_preproc_include] = STATE(165),
    [sym_preproc_tryinclude] = STATE(165),
    [sym_preproc_macro] = STATE(165),
    [sym_preproc_define] = STATE(165),
    [sym_preproc_undefine] = STATE(165),
    [sym_preproc_if] = STATE(165),
    [sym_preproc_elseif] = STATE(165),
    [sym_preproc_assert] = STATE(165),
    [sym_preproc_pragma] = STATE(165),
    [sym_preproc_error] = STATE(165),
    [sym_preproc_warning] = STATE(165),
    [ts_builtin_sym_end] = ACTIONS(472),
    [sym_identifier] = ACTIONS(470),
    [anon_sym_DASH] = ACTIONS(470),
    [anon_sym_PLUS] = ACTIONS(470),
    [anon_sym_AMP] = ACTIONS(470),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(472),
    [anon_sym_STAR] = ACTIONS(472),
    [anon_sym_SLASH] = ACTIONS(470),
    [anon_sym_PERCENT] = ACTIONS(472),
    [anon_sym_PIPE_PIPE] = ACTIONS(472),
    [anon_sym_AMP_AMP] = ACTIONS(472),
    [anon_sym_PIPE] = ACTIONS(470),
    [anon_sym_CARET] = ACTIONS(472),
    [anon_sym_EQ_EQ] = ACTIONS(472),
    [anon_sym_BANG_EQ] = ACTIONS(472),
    [anon_sym_GT] = ACTIONS(470),
    [anon_sym_GT_EQ] = ACTIONS(472),
    [anon_sym_LT_EQ] = ACTIONS(472),
    [anon_sym_LT] = ACTIONS(470),
    [anon_sym_LT_LT] = ACTIONS(472),
    [anon_sym_GT_GT] = ACTIONS(470),
    [anon_sym_GT_GT_GT] = ACTIONS(472),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(472),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(472),
    [anon_sym_assert] = ACTIONS(470),
    [anon_sym_static_assert] = ACTIONS(470),
    [anon_sym_forward] = ACTIONS(470),
    [anon_sym_native] = ACTIONS(470),
    [anon_sym_const] = ACTIONS(470),
    [anon_sym_public] = ACTIONS(470),
    [anon_sym_stock] = ACTIONS(470),
    [anon_sym_static] = ACTIONS(470),
    [anon_sym_new] = ACTIONS(470),
    [anon_sym_decl] = ACTIONS(470),
    [anon_sym_enum] = ACTIONS(470),
    [anon_sym_RBRACE] = ACTIONS(472),
    [anon_sym_struct] = ACTIONS(470),
    [anon_sym_typedef] = ACTIONS(470),
    [anon_sym_typeset] = ACTIONS(470),
    [anon_sym_funcenum] = ACTIONS(470),
    [anon_sym_functag] = ACTIONS(470),
    [anon_sym_methodmap] = ACTIONS(470),
    [anon_sym_LBRACK] = ACTIONS(472),
    [anon_sym_void] = ACTIONS(470),
    [anon_sym_bool] = ACTIONS(470),
    [anon_sym_int] = ACTIONS(470),
    [anon_sym_float] = ACTIONS(470),
    [anon_sym_char] = ACTIONS(470),
    [anon_sym__] = ACTIONS(470),
    [anon_sym_Float] = ACTIONS(470),
    [anon_sym_String] = ACTIONS(470),
    [sym_any_type] = ACTIONS(470),
    [anon_sym_while] = ACTIONS(470),
    [anon_sym_else] = ACTIONS(470),
    [anon_sym_case] = ACTIONS(470),
    [anon_sym_default] = ACTIONS(470),
    [anon_sym_SEMI] = ACTIONS(472),
    [anon_sym_DOT] = ACTIONS(470),
    [anon_sym_QMARK] = ACTIONS(472),
    [anon_sym_DASH_DASH] = ACTIONS(472),
    [anon_sym_PLUS_PLUS] = ACTIONS(472),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(472),
  },
  [166] = {
    [sym_preproc_include] = STATE(166),
    [sym_preproc_tryinclude] = STATE(166),
    [sym_preproc_macro] = STATE(166),
    [sym_preproc_define] = STATE(166),
    [sym_preproc_undefine] = STATE(166),
    [sym_preproc_if] = STATE(166),
    [sym_preproc_elseif] = STATE(166),
    [sym_preproc_assert] = STATE(166),
    [sym_preproc_pragma] = STATE(166),
    [sym_preproc_error] = STATE(166),
    [sym_preproc_warning] = STATE(166),
    [sym__manual_semicolon] = STATE(526),
    [sym__semicolon] = STATE(574),
    [ts_builtin_sym_end] = ACTIONS(468),
    [sym_identifier] = ACTIONS(466),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(604),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(612),
    [anon_sym_AMP_AMP] = ACTIONS(614),
    [anon_sym_PIPE] = ACTIONS(616),
    [anon_sym_CARET] = ACTIONS(618),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(468),
    [anon_sym_assert] = ACTIONS(466),
    [anon_sym_static_assert] = ACTIONS(466),
    [anon_sym_forward] = ACTIONS(466),
    [anon_sym_native] = ACTIONS(466),
    [anon_sym_const] = ACTIONS(466),
    [anon_sym_public] = ACTIONS(466),
    [anon_sym_stock] = ACTIONS(466),
    [anon_sym_static] = ACTIONS(466),
    [anon_sym_new] = ACTIONS(466),
    [anon_sym_decl] = ACTIONS(466),
    [anon_sym_enum] = ACTIONS(466),
    [anon_sym_RBRACE] = ACTIONS(468),
    [anon_sym_struct] = ACTIONS(466),
    [anon_sym_typedef] = ACTIONS(466),
    [anon_sym_typeset] = ACTIONS(466),
    [anon_sym_funcenum] = ACTIONS(466),
    [anon_sym_functag] = ACTIONS(466),
    [anon_sym_methodmap] = ACTIONS(466),
    [anon_sym_void] = ACTIONS(466),
    [anon_sym_bool] = ACTIONS(466),
    [anon_sym_int] = ACTIONS(466),
    [anon_sym_float] = ACTIONS(466),
    [anon_sym_char] = ACTIONS(466),
    [anon_sym__] = ACTIONS(466),
    [anon_sym_Float] = ACTIONS(466),
    [anon_sym_String] = ACTIONS(466),
    [sym_any_type] = ACTIONS(466),
    [anon_sym_while] = ACTIONS(466),
    [anon_sym_else] = ACTIONS(466),
    [anon_sym_case] = ACTIONS(466),
    [anon_sym_default] = ACTIONS(466),
    [anon_sym_SEMI] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(634),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(378),
  },
  [167] = {
    [sym_preproc_include] = STATE(167),
    [sym_preproc_tryinclude] = STATE(167),
    [sym_preproc_macro] = STATE(167),
    [sym_preproc_define] = STATE(167),
    [sym_preproc_undefine] = STATE(167),
    [sym_preproc_if] = STATE(167),
    [sym_preproc_elseif] = STATE(167),
    [sym_preproc_assert] = STATE(167),
    [sym_preproc_pragma] = STATE(167),
    [sym_preproc_error] = STATE(167),
    [sym_preproc_warning] = STATE(167),
    [ts_builtin_sym_end] = ACTIONS(532),
    [sym_identifier] = ACTIONS(530),
    [anon_sym_DASH] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(530),
    [anon_sym_AMP] = ACTIONS(530),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(532),
    [anon_sym_STAR] = ACTIONS(532),
    [anon_sym_SLASH] = ACTIONS(530),
    [anon_sym_PERCENT] = ACTIONS(532),
    [anon_sym_PIPE_PIPE] = ACTIONS(532),
    [anon_sym_AMP_AMP] = ACTIONS(532),
    [anon_sym_PIPE] = ACTIONS(530),
    [anon_sym_CARET] = ACTIONS(532),
    [anon_sym_EQ_EQ] = ACTIONS(532),
    [anon_sym_BANG_EQ] = ACTIONS(532),
    [anon_sym_GT] = ACTIONS(530),
    [anon_sym_GT_EQ] = ACTIONS(532),
    [anon_sym_LT_EQ] = ACTIONS(532),
    [anon_sym_LT] = ACTIONS(530),
    [anon_sym_LT_LT] = ACTIONS(532),
    [anon_sym_GT_GT] = ACTIONS(530),
    [anon_sym_GT_GT_GT] = ACTIONS(532),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(532),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(532),
    [anon_sym_assert] = ACTIONS(530),
    [anon_sym_static_assert] = ACTIONS(530),
    [anon_sym_forward] = ACTIONS(530),
    [anon_sym_native] = ACTIONS(530),
    [anon_sym_const] = ACTIONS(530),
    [anon_sym_public] = ACTIONS(530),
    [anon_sym_stock] = ACTIONS(530),
    [anon_sym_static] = ACTIONS(530),
    [anon_sym_new] = ACTIONS(530),
    [anon_sym_decl] = ACTIONS(530),
    [anon_sym_enum] = ACTIONS(530),
    [anon_sym_RBRACE] = ACTIONS(532),
    [anon_sym_struct] = ACTIONS(530),
    [anon_sym_typedef] = ACTIONS(530),
    [anon_sym_typeset] = ACTIONS(530),
    [anon_sym_funcenum] = ACTIONS(530),
    [anon_sym_functag] = ACTIONS(530),
    [anon_sym_methodmap] = ACTIONS(530),
    [anon_sym_void] = ACTIONS(530),
    [anon_sym_bool] = ACTIONS(530),
    [anon_sym_int] = ACTIONS(530),
    [anon_sym_float] = ACTIONS(530),
    [anon_sym_char] = ACTIONS(530),
    [anon_sym__] = ACTIONS(530),
    [anon_sym_Float] = ACTIONS(530),
    [anon_sym_String] = ACTIONS(530),
    [sym_any_type] = ACTIONS(530),
    [anon_sym_while] = ACTIONS(530),
    [anon_sym_else] = ACTIONS(530),
    [anon_sym_case] = ACTIONS(530),
    [anon_sym_default] = ACTIONS(530),
    [anon_sym_SEMI] = ACTIONS(532),
    [anon_sym_DOT] = ACTIONS(530),
    [anon_sym_QMARK] = ACTIONS(532),
    [anon_sym_DASH_DASH] = ACTIONS(532),
    [anon_sym_PLUS_PLUS] = ACTIONS(532),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(532),
  },
  [168] = {
    [sym_preproc_include] = STATE(168),
    [sym_preproc_tryinclude] = STATE(168),
    [sym_preproc_macro] = STATE(168),
    [sym_preproc_define] = STATE(168),
    [sym_preproc_undefine] = STATE(168),
    [sym_preproc_if] = STATE(168),
    [sym_preproc_elseif] = STATE(168),
    [sym_preproc_assert] = STATE(168),
    [sym_preproc_pragma] = STATE(168),
    [sym_preproc_error] = STATE(168),
    [sym_preproc_warning] = STATE(168),
    [ts_builtin_sym_end] = ACTIONS(127),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(127),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(127),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(127),
    [anon_sym_assert] = ACTIONS(123),
    [anon_sym_static_assert] = ACTIONS(123),
    [anon_sym_forward] = ACTIONS(123),
    [anon_sym_native] = ACTIONS(123),
    [anon_sym_const] = ACTIONS(123),
    [anon_sym_public] = ACTIONS(123),
    [anon_sym_stock] = ACTIONS(123),
    [anon_sym_static] = ACTIONS(123),
    [anon_sym_new] = ACTIONS(123),
    [anon_sym_decl] = ACTIONS(123),
    [anon_sym_enum] = ACTIONS(123),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_struct] = ACTIONS(123),
    [anon_sym_typedef] = ACTIONS(123),
    [anon_sym_typeset] = ACTIONS(123),
    [anon_sym_funcenum] = ACTIONS(123),
    [anon_sym_functag] = ACTIONS(123),
    [anon_sym_methodmap] = ACTIONS(123),
    [anon_sym_void] = ACTIONS(123),
    [anon_sym_bool] = ACTIONS(123),
    [anon_sym_int] = ACTIONS(123),
    [anon_sym_float] = ACTIONS(123),
    [anon_sym_char] = ACTIONS(123),
    [anon_sym__] = ACTIONS(123),
    [anon_sym_Float] = ACTIONS(123),
    [anon_sym_String] = ACTIONS(123),
    [sym_any_type] = ACTIONS(123),
    [anon_sym_while] = ACTIONS(123),
    [anon_sym_else] = ACTIONS(123),
    [anon_sym_case] = ACTIONS(123),
    [anon_sym_default] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(127),
  },
  [169] = {
    [sym_preproc_include] = STATE(169),
    [sym_preproc_tryinclude] = STATE(169),
    [sym_preproc_macro] = STATE(169),
    [sym_preproc_define] = STATE(169),
    [sym_preproc_undefine] = STATE(169),
    [sym_preproc_if] = STATE(169),
    [sym_preproc_elseif] = STATE(169),
    [sym_preproc_assert] = STATE(169),
    [sym_preproc_pragma] = STATE(169),
    [sym_preproc_error] = STATE(169),
    [sym_preproc_warning] = STATE(169),
    [ts_builtin_sym_end] = ACTIONS(508),
    [sym_identifier] = ACTIONS(506),
    [anon_sym_DASH] = ACTIONS(506),
    [anon_sym_PLUS] = ACTIONS(506),
    [anon_sym_AMP] = ACTIONS(506),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(508),
    [anon_sym_STAR] = ACTIONS(508),
    [anon_sym_SLASH] = ACTIONS(506),
    [anon_sym_PERCENT] = ACTIONS(508),
    [anon_sym_PIPE_PIPE] = ACTIONS(508),
    [anon_sym_AMP_AMP] = ACTIONS(508),
    [anon_sym_PIPE] = ACTIONS(506),
    [anon_sym_CARET] = ACTIONS(508),
    [anon_sym_EQ_EQ] = ACTIONS(508),
    [anon_sym_BANG_EQ] = ACTIONS(508),
    [anon_sym_GT] = ACTIONS(506),
    [anon_sym_GT_EQ] = ACTIONS(508),
    [anon_sym_LT_EQ] = ACTIONS(508),
    [anon_sym_LT] = ACTIONS(506),
    [anon_sym_LT_LT] = ACTIONS(508),
    [anon_sym_GT_GT] = ACTIONS(506),
    [anon_sym_GT_GT_GT] = ACTIONS(508),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(508),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(508),
    [anon_sym_assert] = ACTIONS(506),
    [anon_sym_static_assert] = ACTIONS(506),
    [anon_sym_forward] = ACTIONS(506),
    [anon_sym_native] = ACTIONS(506),
    [anon_sym_const] = ACTIONS(506),
    [anon_sym_public] = ACTIONS(506),
    [anon_sym_stock] = ACTIONS(506),
    [anon_sym_static] = ACTIONS(506),
    [anon_sym_new] = ACTIONS(506),
    [anon_sym_decl] = ACTIONS(506),
    [anon_sym_enum] = ACTIONS(506),
    [anon_sym_RBRACE] = ACTIONS(508),
    [anon_sym_struct] = ACTIONS(506),
    [anon_sym_typedef] = ACTIONS(506),
    [anon_sym_typeset] = ACTIONS(506),
    [anon_sym_funcenum] = ACTIONS(506),
    [anon_sym_functag] = ACTIONS(506),
    [anon_sym_methodmap] = ACTIONS(506),
    [anon_sym_void] = ACTIONS(506),
    [anon_sym_bool] = ACTIONS(506),
    [anon_sym_int] = ACTIONS(506),
    [anon_sym_float] = ACTIONS(506),
    [anon_sym_char] = ACTIONS(506),
    [anon_sym__] = ACTIONS(506),
    [anon_sym_Float] = ACTIONS(506),
    [anon_sym_String] = ACTIONS(506),
    [sym_any_type] = ACTIONS(506),
    [anon_sym_while] = ACTIONS(506),
    [anon_sym_else] = ACTIONS(506),
    [anon_sym_case] = ACTIONS(506),
    [anon_sym_default] = ACTIONS(506),
    [anon_sym_SEMI] = ACTIONS(508),
    [anon_sym_DOT] = ACTIONS(506),
    [anon_sym_QMARK] = ACTIONS(508),
    [anon_sym_DASH_DASH] = ACTIONS(508),
    [anon_sym_PLUS_PLUS] = ACTIONS(508),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(508),
  },
  [170] = {
    [sym_preproc_include] = STATE(170),
    [sym_preproc_tryinclude] = STATE(170),
    [sym_preproc_macro] = STATE(170),
    [sym_preproc_define] = STATE(170),
    [sym_preproc_undefine] = STATE(170),
    [sym_preproc_if] = STATE(170),
    [sym_preproc_elseif] = STATE(170),
    [sym_preproc_assert] = STATE(170),
    [sym_preproc_pragma] = STATE(170),
    [sym_preproc_error] = STATE(170),
    [sym_preproc_warning] = STATE(170),
    [ts_builtin_sym_end] = ACTIONS(484),
    [sym_identifier] = ACTIONS(482),
    [anon_sym_DASH] = ACTIONS(482),
    [anon_sym_PLUS] = ACTIONS(482),
    [anon_sym_AMP] = ACTIONS(482),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(484),
    [anon_sym_STAR] = ACTIONS(484),
    [anon_sym_SLASH] = ACTIONS(482),
    [anon_sym_PERCENT] = ACTIONS(484),
    [anon_sym_PIPE_PIPE] = ACTIONS(484),
    [anon_sym_AMP_AMP] = ACTIONS(484),
    [anon_sym_PIPE] = ACTIONS(482),
    [anon_sym_CARET] = ACTIONS(484),
    [anon_sym_EQ_EQ] = ACTIONS(484),
    [anon_sym_BANG_EQ] = ACTIONS(484),
    [anon_sym_GT] = ACTIONS(482),
    [anon_sym_GT_EQ] = ACTIONS(484),
    [anon_sym_LT_EQ] = ACTIONS(484),
    [anon_sym_LT] = ACTIONS(482),
    [anon_sym_LT_LT] = ACTIONS(484),
    [anon_sym_GT_GT] = ACTIONS(482),
    [anon_sym_GT_GT_GT] = ACTIONS(484),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(484),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(484),
    [anon_sym_assert] = ACTIONS(482),
    [anon_sym_static_assert] = ACTIONS(482),
    [anon_sym_forward] = ACTIONS(482),
    [anon_sym_native] = ACTIONS(482),
    [anon_sym_const] = ACTIONS(482),
    [anon_sym_public] = ACTIONS(482),
    [anon_sym_stock] = ACTIONS(482),
    [anon_sym_static] = ACTIONS(482),
    [anon_sym_new] = ACTIONS(482),
    [anon_sym_decl] = ACTIONS(482),
    [anon_sym_enum] = ACTIONS(482),
    [anon_sym_RBRACE] = ACTIONS(484),
    [anon_sym_struct] = ACTIONS(482),
    [anon_sym_typedef] = ACTIONS(482),
    [anon_sym_typeset] = ACTIONS(482),
    [anon_sym_funcenum] = ACTIONS(482),
    [anon_sym_functag] = ACTIONS(482),
    [anon_sym_methodmap] = ACTIONS(482),
    [anon_sym_void] = ACTIONS(482),
    [anon_sym_bool] = ACTIONS(482),
    [anon_sym_int] = ACTIONS(482),
    [anon_sym_float] = ACTIONS(482),
    [anon_sym_char] = ACTIONS(482),
    [anon_sym__] = ACTIONS(482),
    [anon_sym_Float] = ACTIONS(482),
    [anon_sym_String] = ACTIONS(482),
    [sym_any_type] = ACTIONS(482),
    [anon_sym_while] = ACTIONS(482),
    [anon_sym_else] = ACTIONS(482),
    [anon_sym_case] = ACTIONS(482),
    [anon_sym_default] = ACTIONS(482),
    [anon_sym_SEMI] = ACTIONS(484),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(484),
    [anon_sym_DASH_DASH] = ACTIONS(484),
    [anon_sym_PLUS_PLUS] = ACTIONS(484),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(484),
  },
  [171] = {
    [sym_preproc_include] = STATE(171),
    [sym_preproc_tryinclude] = STATE(171),
    [sym_preproc_macro] = STATE(171),
    [sym_preproc_define] = STATE(171),
    [sym_preproc_undefine] = STATE(171),
    [sym_preproc_if] = STATE(171),
    [sym_preproc_elseif] = STATE(171),
    [sym_preproc_assert] = STATE(171),
    [sym_preproc_pragma] = STATE(171),
    [sym_preproc_error] = STATE(171),
    [sym_preproc_warning] = STATE(171),
    [ts_builtin_sym_end] = ACTIONS(512),
    [sym_identifier] = ACTIONS(510),
    [anon_sym_DASH] = ACTIONS(510),
    [anon_sym_PLUS] = ACTIONS(510),
    [anon_sym_AMP] = ACTIONS(510),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(512),
    [anon_sym_STAR] = ACTIONS(512),
    [anon_sym_SLASH] = ACTIONS(510),
    [anon_sym_PERCENT] = ACTIONS(512),
    [anon_sym_PIPE_PIPE] = ACTIONS(512),
    [anon_sym_AMP_AMP] = ACTIONS(512),
    [anon_sym_PIPE] = ACTIONS(510),
    [anon_sym_CARET] = ACTIONS(512),
    [anon_sym_EQ_EQ] = ACTIONS(512),
    [anon_sym_BANG_EQ] = ACTIONS(512),
    [anon_sym_GT] = ACTIONS(510),
    [anon_sym_GT_EQ] = ACTIONS(512),
    [anon_sym_LT_EQ] = ACTIONS(512),
    [anon_sym_LT] = ACTIONS(510),
    [anon_sym_LT_LT] = ACTIONS(512),
    [anon_sym_GT_GT] = ACTIONS(510),
    [anon_sym_GT_GT_GT] = ACTIONS(512),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(512),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(512),
    [anon_sym_assert] = ACTIONS(510),
    [anon_sym_static_assert] = ACTIONS(510),
    [anon_sym_forward] = ACTIONS(510),
    [anon_sym_native] = ACTIONS(510),
    [anon_sym_const] = ACTIONS(510),
    [anon_sym_public] = ACTIONS(510),
    [anon_sym_stock] = ACTIONS(510),
    [anon_sym_static] = ACTIONS(510),
    [anon_sym_new] = ACTIONS(510),
    [anon_sym_decl] = ACTIONS(510),
    [anon_sym_enum] = ACTIONS(510),
    [anon_sym_RBRACE] = ACTIONS(512),
    [anon_sym_struct] = ACTIONS(510),
    [anon_sym_typedef] = ACTIONS(510),
    [anon_sym_typeset] = ACTIONS(510),
    [anon_sym_funcenum] = ACTIONS(510),
    [anon_sym_functag] = ACTIONS(510),
    [anon_sym_methodmap] = ACTIONS(510),
    [anon_sym_void] = ACTIONS(510),
    [anon_sym_bool] = ACTIONS(510),
    [anon_sym_int] = ACTIONS(510),
    [anon_sym_float] = ACTIONS(510),
    [anon_sym_char] = ACTIONS(510),
    [anon_sym__] = ACTIONS(510),
    [anon_sym_Float] = ACTIONS(510),
    [anon_sym_String] = ACTIONS(510),
    [sym_any_type] = ACTIONS(510),
    [anon_sym_while] = ACTIONS(510),
    [anon_sym_else] = ACTIONS(510),
    [anon_sym_case] = ACTIONS(510),
    [anon_sym_default] = ACTIONS(510),
    [anon_sym_SEMI] = ACTIONS(512),
    [anon_sym_DOT] = ACTIONS(510),
    [anon_sym_QMARK] = ACTIONS(512),
    [anon_sym_DASH_DASH] = ACTIONS(512),
    [anon_sym_PLUS_PLUS] = ACTIONS(512),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(512),
  },
  [172] = {
    [sym_preproc_include] = STATE(172),
    [sym_preproc_tryinclude] = STATE(172),
    [sym_preproc_macro] = STATE(172),
    [sym_preproc_define] = STATE(172),
    [sym_preproc_undefine] = STATE(172),
    [sym_preproc_if] = STATE(172),
    [sym_preproc_elseif] = STATE(172),
    [sym_preproc_assert] = STATE(172),
    [sym_preproc_pragma] = STATE(172),
    [sym_preproc_error] = STATE(172),
    [sym_preproc_warning] = STATE(172),
    [ts_builtin_sym_end] = ACTIONS(576),
    [sym_identifier] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(604),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(612),
    [anon_sym_AMP_AMP] = ACTIONS(614),
    [anon_sym_PIPE] = ACTIONS(616),
    [anon_sym_CARET] = ACTIONS(618),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(630),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(576),
    [anon_sym_assert] = ACTIONS(574),
    [anon_sym_static_assert] = ACTIONS(574),
    [anon_sym_forward] = ACTIONS(574),
    [anon_sym_native] = ACTIONS(574),
    [anon_sym_const] = ACTIONS(574),
    [anon_sym_public] = ACTIONS(574),
    [anon_sym_stock] = ACTIONS(574),
    [anon_sym_static] = ACTIONS(574),
    [anon_sym_new] = ACTIONS(574),
    [anon_sym_decl] = ACTIONS(574),
    [anon_sym_enum] = ACTIONS(574),
    [anon_sym_RBRACE] = ACTIONS(576),
    [anon_sym_struct] = ACTIONS(574),
    [anon_sym_typedef] = ACTIONS(574),
    [anon_sym_typeset] = ACTIONS(574),
    [anon_sym_funcenum] = ACTIONS(574),
    [anon_sym_functag] = ACTIONS(574),
    [anon_sym_methodmap] = ACTIONS(574),
    [anon_sym_void] = ACTIONS(574),
    [anon_sym_bool] = ACTIONS(574),
    [anon_sym_int] = ACTIONS(574),
    [anon_sym_float] = ACTIONS(574),
    [anon_sym_char] = ACTIONS(574),
    [anon_sym__] = ACTIONS(574),
    [anon_sym_Float] = ACTIONS(574),
    [anon_sym_String] = ACTIONS(574),
    [sym_any_type] = ACTIONS(574),
    [anon_sym_while] = ACTIONS(574),
    [anon_sym_else] = ACTIONS(574),
    [anon_sym_case] = ACTIONS(574),
    [anon_sym_default] = ACTIONS(574),
    [anon_sym_SEMI] = ACTIONS(576),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(634),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(576),
  },
  [173] = {
    [sym_preproc_include] = STATE(173),
    [sym_preproc_tryinclude] = STATE(173),
    [sym_preproc_macro] = STATE(173),
    [sym_preproc_define] = STATE(173),
    [sym_preproc_undefine] = STATE(173),
    [sym_preproc_if] = STATE(173),
    [sym_preproc_elseif] = STATE(173),
    [sym_preproc_assert] = STATE(173),
    [sym_preproc_pragma] = STATE(173),
    [sym_preproc_error] = STATE(173),
    [sym_preproc_warning] = STATE(173),
    [ts_builtin_sym_end] = ACTIONS(536),
    [sym_identifier] = ACTIONS(534),
    [anon_sym_DASH] = ACTIONS(534),
    [anon_sym_PLUS] = ACTIONS(534),
    [anon_sym_AMP] = ACTIONS(534),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(536),
    [anon_sym_STAR] = ACTIONS(536),
    [anon_sym_SLASH] = ACTIONS(534),
    [anon_sym_PERCENT] = ACTIONS(536),
    [anon_sym_PIPE_PIPE] = ACTIONS(536),
    [anon_sym_AMP_AMP] = ACTIONS(536),
    [anon_sym_PIPE] = ACTIONS(534),
    [anon_sym_CARET] = ACTIONS(536),
    [anon_sym_EQ_EQ] = ACTIONS(536),
    [anon_sym_BANG_EQ] = ACTIONS(536),
    [anon_sym_GT] = ACTIONS(534),
    [anon_sym_GT_EQ] = ACTIONS(536),
    [anon_sym_LT_EQ] = ACTIONS(536),
    [anon_sym_LT] = ACTIONS(534),
    [anon_sym_LT_LT] = ACTIONS(536),
    [anon_sym_GT_GT] = ACTIONS(534),
    [anon_sym_GT_GT_GT] = ACTIONS(536),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(536),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(536),
    [anon_sym_assert] = ACTIONS(534),
    [anon_sym_static_assert] = ACTIONS(534),
    [anon_sym_forward] = ACTIONS(534),
    [anon_sym_native] = ACTIONS(534),
    [anon_sym_const] = ACTIONS(534),
    [anon_sym_public] = ACTIONS(534),
    [anon_sym_stock] = ACTIONS(534),
    [anon_sym_static] = ACTIONS(534),
    [anon_sym_new] = ACTIONS(534),
    [anon_sym_decl] = ACTIONS(534),
    [anon_sym_enum] = ACTIONS(534),
    [anon_sym_RBRACE] = ACTIONS(536),
    [anon_sym_struct] = ACTIONS(534),
    [anon_sym_typedef] = ACTIONS(534),
    [anon_sym_typeset] = ACTIONS(534),
    [anon_sym_funcenum] = ACTIONS(534),
    [anon_sym_functag] = ACTIONS(534),
    [anon_sym_methodmap] = ACTIONS(534),
    [anon_sym_void] = ACTIONS(534),
    [anon_sym_bool] = ACTIONS(534),
    [anon_sym_int] = ACTIONS(534),
    [anon_sym_float] = ACTIONS(534),
    [anon_sym_char] = ACTIONS(534),
    [anon_sym__] = ACTIONS(534),
    [anon_sym_Float] = ACTIONS(534),
    [anon_sym_String] = ACTIONS(534),
    [sym_any_type] = ACTIONS(534),
    [anon_sym_while] = ACTIONS(534),
    [anon_sym_else] = ACTIONS(534),
    [anon_sym_case] = ACTIONS(534),
    [anon_sym_default] = ACTIONS(534),
    [anon_sym_SEMI] = ACTIONS(536),
    [anon_sym_DOT] = ACTIONS(534),
    [anon_sym_QMARK] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(536),
  },
  [174] = {
    [sym_preproc_include] = STATE(174),
    [sym_preproc_tryinclude] = STATE(174),
    [sym_preproc_macro] = STATE(174),
    [sym_preproc_define] = STATE(174),
    [sym_preproc_undefine] = STATE(174),
    [sym_preproc_if] = STATE(174),
    [sym_preproc_elseif] = STATE(174),
    [sym_preproc_assert] = STATE(174),
    [sym_preproc_pragma] = STATE(174),
    [sym_preproc_error] = STATE(174),
    [sym_preproc_warning] = STATE(174),
    [ts_builtin_sym_end] = ACTIONS(540),
    [sym_identifier] = ACTIONS(538),
    [anon_sym_DASH] = ACTIONS(538),
    [anon_sym_PLUS] = ACTIONS(538),
    [anon_sym_AMP] = ACTIONS(538),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(540),
    [anon_sym_STAR] = ACTIONS(540),
    [anon_sym_SLASH] = ACTIONS(538),
    [anon_sym_PERCENT] = ACTIONS(540),
    [anon_sym_PIPE_PIPE] = ACTIONS(540),
    [anon_sym_AMP_AMP] = ACTIONS(540),
    [anon_sym_PIPE] = ACTIONS(538),
    [anon_sym_CARET] = ACTIONS(540),
    [anon_sym_EQ_EQ] = ACTIONS(540),
    [anon_sym_BANG_EQ] = ACTIONS(540),
    [anon_sym_GT] = ACTIONS(538),
    [anon_sym_GT_EQ] = ACTIONS(540),
    [anon_sym_LT_EQ] = ACTIONS(540),
    [anon_sym_LT] = ACTIONS(538),
    [anon_sym_LT_LT] = ACTIONS(540),
    [anon_sym_GT_GT] = ACTIONS(538),
    [anon_sym_GT_GT_GT] = ACTIONS(540),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(540),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(540),
    [anon_sym_assert] = ACTIONS(538),
    [anon_sym_static_assert] = ACTIONS(538),
    [anon_sym_forward] = ACTIONS(538),
    [anon_sym_native] = ACTIONS(538),
    [anon_sym_const] = ACTIONS(538),
    [anon_sym_public] = ACTIONS(538),
    [anon_sym_stock] = ACTIONS(538),
    [anon_sym_static] = ACTIONS(538),
    [anon_sym_new] = ACTIONS(538),
    [anon_sym_decl] = ACTIONS(538),
    [anon_sym_enum] = ACTIONS(538),
    [anon_sym_RBRACE] = ACTIONS(540),
    [anon_sym_struct] = ACTIONS(538),
    [anon_sym_typedef] = ACTIONS(538),
    [anon_sym_typeset] = ACTIONS(538),
    [anon_sym_funcenum] = ACTIONS(538),
    [anon_sym_functag] = ACTIONS(538),
    [anon_sym_methodmap] = ACTIONS(538),
    [anon_sym_void] = ACTIONS(538),
    [anon_sym_bool] = ACTIONS(538),
    [anon_sym_int] = ACTIONS(538),
    [anon_sym_float] = ACTIONS(538),
    [anon_sym_char] = ACTIONS(538),
    [anon_sym__] = ACTIONS(538),
    [anon_sym_Float] = ACTIONS(538),
    [anon_sym_String] = ACTIONS(538),
    [sym_any_type] = ACTIONS(538),
    [anon_sym_while] = ACTIONS(538),
    [anon_sym_else] = ACTIONS(538),
    [anon_sym_case] = ACTIONS(538),
    [anon_sym_default] = ACTIONS(538),
    [anon_sym_SEMI] = ACTIONS(540),
    [anon_sym_DOT] = ACTIONS(538),
    [anon_sym_QMARK] = ACTIONS(540),
    [anon_sym_DASH_DASH] = ACTIONS(540),
    [anon_sym_PLUS_PLUS] = ACTIONS(540),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(540),
  },
  [175] = {
    [sym_preproc_include] = STATE(175),
    [sym_preproc_tryinclude] = STATE(175),
    [sym_preproc_macro] = STATE(175),
    [sym_preproc_define] = STATE(175),
    [sym_preproc_undefine] = STATE(175),
    [sym_preproc_if] = STATE(175),
    [sym_preproc_elseif] = STATE(175),
    [sym_preproc_assert] = STATE(175),
    [sym_preproc_pragma] = STATE(175),
    [sym_preproc_error] = STATE(175),
    [sym_preproc_warning] = STATE(175),
    [ts_builtin_sym_end] = ACTIONS(544),
    [sym_identifier] = ACTIONS(542),
    [anon_sym_DASH] = ACTIONS(542),
    [anon_sym_PLUS] = ACTIONS(542),
    [anon_sym_AMP] = ACTIONS(542),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(544),
    [anon_sym_STAR] = ACTIONS(544),
    [anon_sym_SLASH] = ACTIONS(542),
    [anon_sym_PERCENT] = ACTIONS(544),
    [anon_sym_PIPE_PIPE] = ACTIONS(544),
    [anon_sym_AMP_AMP] = ACTIONS(544),
    [anon_sym_PIPE] = ACTIONS(542),
    [anon_sym_CARET] = ACTIONS(544),
    [anon_sym_EQ_EQ] = ACTIONS(544),
    [anon_sym_BANG_EQ] = ACTIONS(544),
    [anon_sym_GT] = ACTIONS(542),
    [anon_sym_GT_EQ] = ACTIONS(544),
    [anon_sym_LT_EQ] = ACTIONS(544),
    [anon_sym_LT] = ACTIONS(542),
    [anon_sym_LT_LT] = ACTIONS(544),
    [anon_sym_GT_GT] = ACTIONS(542),
    [anon_sym_GT_GT_GT] = ACTIONS(544),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(544),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(544),
    [anon_sym_assert] = ACTIONS(542),
    [anon_sym_static_assert] = ACTIONS(542),
    [anon_sym_forward] = ACTIONS(542),
    [anon_sym_native] = ACTIONS(542),
    [anon_sym_const] = ACTIONS(542),
    [anon_sym_public] = ACTIONS(542),
    [anon_sym_stock] = ACTIONS(542),
    [anon_sym_static] = ACTIONS(542),
    [anon_sym_new] = ACTIONS(542),
    [anon_sym_decl] = ACTIONS(542),
    [anon_sym_enum] = ACTIONS(542),
    [anon_sym_RBRACE] = ACTIONS(544),
    [anon_sym_struct] = ACTIONS(542),
    [anon_sym_typedef] = ACTIONS(542),
    [anon_sym_typeset] = ACTIONS(542),
    [anon_sym_funcenum] = ACTIONS(542),
    [anon_sym_functag] = ACTIONS(542),
    [anon_sym_methodmap] = ACTIONS(542),
    [anon_sym_void] = ACTIONS(542),
    [anon_sym_bool] = ACTIONS(542),
    [anon_sym_int] = ACTIONS(542),
    [anon_sym_float] = ACTIONS(542),
    [anon_sym_char] = ACTIONS(542),
    [anon_sym__] = ACTIONS(542),
    [anon_sym_Float] = ACTIONS(542),
    [anon_sym_String] = ACTIONS(542),
    [sym_any_type] = ACTIONS(542),
    [anon_sym_while] = ACTIONS(542),
    [anon_sym_else] = ACTIONS(542),
    [anon_sym_case] = ACTIONS(542),
    [anon_sym_default] = ACTIONS(542),
    [anon_sym_SEMI] = ACTIONS(544),
    [anon_sym_DOT] = ACTIONS(542),
    [anon_sym_QMARK] = ACTIONS(544),
    [anon_sym_DASH_DASH] = ACTIONS(544),
    [anon_sym_PLUS_PLUS] = ACTIONS(544),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(544),
  },
  [176] = {
    [sym_preproc_include] = STATE(176),
    [sym_preproc_tryinclude] = STATE(176),
    [sym_preproc_macro] = STATE(176),
    [sym_preproc_define] = STATE(176),
    [sym_preproc_undefine] = STATE(176),
    [sym_preproc_if] = STATE(176),
    [sym_preproc_elseif] = STATE(176),
    [sym_preproc_assert] = STATE(176),
    [sym_preproc_pragma] = STATE(176),
    [sym_preproc_error] = STATE(176),
    [sym_preproc_warning] = STATE(176),
    [ts_builtin_sym_end] = ACTIONS(488),
    [sym_identifier] = ACTIONS(486),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(604),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(612),
    [anon_sym_AMP_AMP] = ACTIONS(614),
    [anon_sym_PIPE] = ACTIONS(616),
    [anon_sym_CARET] = ACTIONS(618),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(488),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(488),
    [anon_sym_assert] = ACTIONS(486),
    [anon_sym_static_assert] = ACTIONS(486),
    [anon_sym_forward] = ACTIONS(486),
    [anon_sym_native] = ACTIONS(486),
    [anon_sym_const] = ACTIONS(486),
    [anon_sym_public] = ACTIONS(486),
    [anon_sym_stock] = ACTIONS(486),
    [anon_sym_static] = ACTIONS(486),
    [anon_sym_new] = ACTIONS(486),
    [anon_sym_decl] = ACTIONS(486),
    [anon_sym_enum] = ACTIONS(486),
    [anon_sym_RBRACE] = ACTIONS(488),
    [anon_sym_struct] = ACTIONS(486),
    [anon_sym_typedef] = ACTIONS(486),
    [anon_sym_typeset] = ACTIONS(486),
    [anon_sym_funcenum] = ACTIONS(486),
    [anon_sym_functag] = ACTIONS(486),
    [anon_sym_methodmap] = ACTIONS(486),
    [anon_sym_void] = ACTIONS(486),
    [anon_sym_bool] = ACTIONS(486),
    [anon_sym_int] = ACTIONS(486),
    [anon_sym_float] = ACTIONS(486),
    [anon_sym_char] = ACTIONS(486),
    [anon_sym__] = ACTIONS(486),
    [anon_sym_Float] = ACTIONS(486),
    [anon_sym_String] = ACTIONS(486),
    [sym_any_type] = ACTIONS(486),
    [anon_sym_while] = ACTIONS(486),
    [anon_sym_else] = ACTIONS(486),
    [anon_sym_case] = ACTIONS(486),
    [anon_sym_default] = ACTIONS(486),
    [anon_sym_SEMI] = ACTIONS(488),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(634),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(488),
  },
  [177] = {
    [sym_preproc_include] = STATE(177),
    [sym_preproc_tryinclude] = STATE(177),
    [sym_preproc_macro] = STATE(177),
    [sym_preproc_define] = STATE(177),
    [sym_preproc_undefine] = STATE(177),
    [sym_preproc_if] = STATE(177),
    [sym_preproc_elseif] = STATE(177),
    [sym_preproc_assert] = STATE(177),
    [sym_preproc_pragma] = STATE(177),
    [sym_preproc_error] = STATE(177),
    [sym_preproc_warning] = STATE(177),
    [ts_builtin_sym_end] = ACTIONS(548),
    [sym_identifier] = ACTIONS(546),
    [anon_sym_DASH] = ACTIONS(546),
    [anon_sym_PLUS] = ACTIONS(546),
    [anon_sym_AMP] = ACTIONS(546),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(548),
    [anon_sym_STAR] = ACTIONS(548),
    [anon_sym_SLASH] = ACTIONS(546),
    [anon_sym_PERCENT] = ACTIONS(548),
    [anon_sym_PIPE_PIPE] = ACTIONS(548),
    [anon_sym_AMP_AMP] = ACTIONS(548),
    [anon_sym_PIPE] = ACTIONS(546),
    [anon_sym_CARET] = ACTIONS(548),
    [anon_sym_EQ_EQ] = ACTIONS(548),
    [anon_sym_BANG_EQ] = ACTIONS(548),
    [anon_sym_GT] = ACTIONS(546),
    [anon_sym_GT_EQ] = ACTIONS(548),
    [anon_sym_LT_EQ] = ACTIONS(548),
    [anon_sym_LT] = ACTIONS(546),
    [anon_sym_LT_LT] = ACTIONS(548),
    [anon_sym_GT_GT] = ACTIONS(546),
    [anon_sym_GT_GT_GT] = ACTIONS(548),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(548),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(548),
    [anon_sym_assert] = ACTIONS(546),
    [anon_sym_static_assert] = ACTIONS(546),
    [anon_sym_forward] = ACTIONS(546),
    [anon_sym_native] = ACTIONS(546),
    [anon_sym_const] = ACTIONS(546),
    [anon_sym_public] = ACTIONS(546),
    [anon_sym_stock] = ACTIONS(546),
    [anon_sym_static] = ACTIONS(546),
    [anon_sym_new] = ACTIONS(546),
    [anon_sym_decl] = ACTIONS(546),
    [anon_sym_enum] = ACTIONS(546),
    [anon_sym_RBRACE] = ACTIONS(548),
    [anon_sym_struct] = ACTIONS(546),
    [anon_sym_typedef] = ACTIONS(546),
    [anon_sym_typeset] = ACTIONS(546),
    [anon_sym_funcenum] = ACTIONS(546),
    [anon_sym_functag] = ACTIONS(546),
    [anon_sym_methodmap] = ACTIONS(546),
    [anon_sym_void] = ACTIONS(546),
    [anon_sym_bool] = ACTIONS(546),
    [anon_sym_int] = ACTIONS(546),
    [anon_sym_float] = ACTIONS(546),
    [anon_sym_char] = ACTIONS(546),
    [anon_sym__] = ACTIONS(546),
    [anon_sym_Float] = ACTIONS(546),
    [anon_sym_String] = ACTIONS(546),
    [sym_any_type] = ACTIONS(546),
    [anon_sym_while] = ACTIONS(546),
    [anon_sym_else] = ACTIONS(546),
    [anon_sym_case] = ACTIONS(546),
    [anon_sym_default] = ACTIONS(546),
    [anon_sym_SEMI] = ACTIONS(548),
    [anon_sym_DOT] = ACTIONS(546),
    [anon_sym_QMARK] = ACTIONS(548),
    [anon_sym_DASH_DASH] = ACTIONS(548),
    [anon_sym_PLUS_PLUS] = ACTIONS(548),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(548),
  },
  [178] = {
    [sym_preproc_include] = STATE(178),
    [sym_preproc_tryinclude] = STATE(178),
    [sym_preproc_macro] = STATE(178),
    [sym_preproc_define] = STATE(178),
    [sym_preproc_undefine] = STATE(178),
    [sym_preproc_if] = STATE(178),
    [sym_preproc_elseif] = STATE(178),
    [sym_preproc_assert] = STATE(178),
    [sym_preproc_pragma] = STATE(178),
    [sym_preproc_error] = STATE(178),
    [sym_preproc_warning] = STATE(178),
    [ts_builtin_sym_end] = ACTIONS(492),
    [sym_identifier] = ACTIONS(490),
    [anon_sym_DASH] = ACTIONS(490),
    [anon_sym_PLUS] = ACTIONS(490),
    [anon_sym_AMP] = ACTIONS(490),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(492),
    [anon_sym_STAR] = ACTIONS(492),
    [anon_sym_SLASH] = ACTIONS(490),
    [anon_sym_PERCENT] = ACTIONS(492),
    [anon_sym_PIPE_PIPE] = ACTIONS(492),
    [anon_sym_AMP_AMP] = ACTIONS(492),
    [anon_sym_PIPE] = ACTIONS(490),
    [anon_sym_CARET] = ACTIONS(492),
    [anon_sym_EQ_EQ] = ACTIONS(492),
    [anon_sym_BANG_EQ] = ACTIONS(492),
    [anon_sym_GT] = ACTIONS(490),
    [anon_sym_GT_EQ] = ACTIONS(492),
    [anon_sym_LT_EQ] = ACTIONS(492),
    [anon_sym_LT] = ACTIONS(490),
    [anon_sym_LT_LT] = ACTIONS(492),
    [anon_sym_GT_GT] = ACTIONS(490),
    [anon_sym_GT_GT_GT] = ACTIONS(492),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(492),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(492),
    [anon_sym_assert] = ACTIONS(490),
    [anon_sym_static_assert] = ACTIONS(490),
    [anon_sym_forward] = ACTIONS(490),
    [anon_sym_native] = ACTIONS(490),
    [anon_sym_const] = ACTIONS(490),
    [anon_sym_public] = ACTIONS(490),
    [anon_sym_stock] = ACTIONS(490),
    [anon_sym_static] = ACTIONS(490),
    [anon_sym_new] = ACTIONS(490),
    [anon_sym_decl] = ACTIONS(490),
    [anon_sym_enum] = ACTIONS(490),
    [anon_sym_RBRACE] = ACTIONS(492),
    [anon_sym_struct] = ACTIONS(490),
    [anon_sym_typedef] = ACTIONS(490),
    [anon_sym_typeset] = ACTIONS(490),
    [anon_sym_funcenum] = ACTIONS(490),
    [anon_sym_functag] = ACTIONS(490),
    [anon_sym_methodmap] = ACTIONS(490),
    [anon_sym_void] = ACTIONS(490),
    [anon_sym_bool] = ACTIONS(490),
    [anon_sym_int] = ACTIONS(490),
    [anon_sym_float] = ACTIONS(490),
    [anon_sym_char] = ACTIONS(490),
    [anon_sym__] = ACTIONS(490),
    [anon_sym_Float] = ACTIONS(490),
    [anon_sym_String] = ACTIONS(490),
    [sym_any_type] = ACTIONS(490),
    [anon_sym_while] = ACTIONS(490),
    [anon_sym_else] = ACTIONS(490),
    [anon_sym_case] = ACTIONS(490),
    [anon_sym_default] = ACTIONS(490),
    [anon_sym_SEMI] = ACTIONS(492),
    [anon_sym_DOT] = ACTIONS(490),
    [anon_sym_QMARK] = ACTIONS(492),
    [anon_sym_DASH_DASH] = ACTIONS(492),
    [anon_sym_PLUS_PLUS] = ACTIONS(492),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(492),
  },
  [179] = {
    [sym_preproc_include] = STATE(179),
    [sym_preproc_tryinclude] = STATE(179),
    [sym_preproc_macro] = STATE(179),
    [sym_preproc_define] = STATE(179),
    [sym_preproc_undefine] = STATE(179),
    [sym_preproc_if] = STATE(179),
    [sym_preproc_elseif] = STATE(179),
    [sym_preproc_assert] = STATE(179),
    [sym_preproc_pragma] = STATE(179),
    [sym_preproc_error] = STATE(179),
    [sym_preproc_warning] = STATE(179),
    [ts_builtin_sym_end] = ACTIONS(492),
    [sym_identifier] = ACTIONS(490),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(604),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(612),
    [anon_sym_AMP_AMP] = ACTIONS(614),
    [anon_sym_PIPE] = ACTIONS(616),
    [anon_sym_CARET] = ACTIONS(618),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(492),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(492),
    [anon_sym_assert] = ACTIONS(490),
    [anon_sym_static_assert] = ACTIONS(490),
    [anon_sym_forward] = ACTIONS(490),
    [anon_sym_native] = ACTIONS(490),
    [anon_sym_const] = ACTIONS(490),
    [anon_sym_public] = ACTIONS(490),
    [anon_sym_stock] = ACTIONS(490),
    [anon_sym_static] = ACTIONS(490),
    [anon_sym_new] = ACTIONS(490),
    [anon_sym_decl] = ACTIONS(490),
    [anon_sym_enum] = ACTIONS(490),
    [anon_sym_RBRACE] = ACTIONS(492),
    [anon_sym_struct] = ACTIONS(490),
    [anon_sym_typedef] = ACTIONS(490),
    [anon_sym_typeset] = ACTIONS(490),
    [anon_sym_funcenum] = ACTIONS(490),
    [anon_sym_functag] = ACTIONS(490),
    [anon_sym_methodmap] = ACTIONS(490),
    [anon_sym_void] = ACTIONS(490),
    [anon_sym_bool] = ACTIONS(490),
    [anon_sym_int] = ACTIONS(490),
    [anon_sym_float] = ACTIONS(490),
    [anon_sym_char] = ACTIONS(490),
    [anon_sym__] = ACTIONS(490),
    [anon_sym_Float] = ACTIONS(490),
    [anon_sym_String] = ACTIONS(490),
    [sym_any_type] = ACTIONS(490),
    [anon_sym_while] = ACTIONS(490),
    [anon_sym_else] = ACTIONS(490),
    [anon_sym_case] = ACTIONS(490),
    [anon_sym_default] = ACTIONS(490),
    [anon_sym_SEMI] = ACTIONS(492),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(634),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(492),
  },
  [180] = {
    [sym_preproc_include] = STATE(180),
    [sym_preproc_tryinclude] = STATE(180),
    [sym_preproc_macro] = STATE(180),
    [sym_preproc_define] = STATE(180),
    [sym_preproc_undefine] = STATE(180),
    [sym_preproc_if] = STATE(180),
    [sym_preproc_elseif] = STATE(180),
    [sym_preproc_assert] = STATE(180),
    [sym_preproc_pragma] = STATE(180),
    [sym_preproc_error] = STATE(180),
    [sym_preproc_warning] = STATE(180),
    [ts_builtin_sym_end] = ACTIONS(504),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_DASH] = ACTIONS(502),
    [anon_sym_PLUS] = ACTIONS(502),
    [anon_sym_AMP] = ACTIONS(502),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(504),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(504),
    [anon_sym_BANG_EQ] = ACTIONS(504),
    [anon_sym_GT] = ACTIONS(502),
    [anon_sym_GT_EQ] = ACTIONS(504),
    [anon_sym_LT_EQ] = ACTIONS(504),
    [anon_sym_LT] = ACTIONS(502),
    [anon_sym_LT_LT] = ACTIONS(504),
    [anon_sym_GT_GT] = ACTIONS(502),
    [anon_sym_GT_GT_GT] = ACTIONS(504),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(504),
    [anon_sym_assert] = ACTIONS(502),
    [anon_sym_static_assert] = ACTIONS(502),
    [anon_sym_forward] = ACTIONS(502),
    [anon_sym_native] = ACTIONS(502),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_enum] = ACTIONS(502),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_struct] = ACTIONS(502),
    [anon_sym_typedef] = ACTIONS(502),
    [anon_sym_typeset] = ACTIONS(502),
    [anon_sym_funcenum] = ACTIONS(502),
    [anon_sym_functag] = ACTIONS(502),
    [anon_sym_methodmap] = ACTIONS(502),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_case] = ACTIONS(502),
    [anon_sym_default] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [181] = {
    [sym_preproc_include] = STATE(181),
    [sym_preproc_tryinclude] = STATE(181),
    [sym_preproc_macro] = STATE(181),
    [sym_preproc_define] = STATE(181),
    [sym_preproc_undefine] = STATE(181),
    [sym_preproc_if] = STATE(181),
    [sym_preproc_elseif] = STATE(181),
    [sym_preproc_assert] = STATE(181),
    [sym_preproc_pragma] = STATE(181),
    [sym_preproc_error] = STATE(181),
    [sym_preproc_warning] = STATE(181),
    [ts_builtin_sym_end] = ACTIONS(504),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(502),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(504),
    [anon_sym_assert] = ACTIONS(502),
    [anon_sym_static_assert] = ACTIONS(502),
    [anon_sym_forward] = ACTIONS(502),
    [anon_sym_native] = ACTIONS(502),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_enum] = ACTIONS(502),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_struct] = ACTIONS(502),
    [anon_sym_typedef] = ACTIONS(502),
    [anon_sym_typeset] = ACTIONS(502),
    [anon_sym_funcenum] = ACTIONS(502),
    [anon_sym_functag] = ACTIONS(502),
    [anon_sym_methodmap] = ACTIONS(502),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_case] = ACTIONS(502),
    [anon_sym_default] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [182] = {
    [sym_preproc_include] = STATE(182),
    [sym_preproc_tryinclude] = STATE(182),
    [sym_preproc_macro] = STATE(182),
    [sym_preproc_define] = STATE(182),
    [sym_preproc_undefine] = STATE(182),
    [sym_preproc_if] = STATE(182),
    [sym_preproc_elseif] = STATE(182),
    [sym_preproc_assert] = STATE(182),
    [sym_preproc_pragma] = STATE(182),
    [sym_preproc_error] = STATE(182),
    [sym_preproc_warning] = STATE(182),
    [ts_builtin_sym_end] = ACTIONS(504),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_DASH] = ACTIONS(502),
    [anon_sym_PLUS] = ACTIONS(502),
    [anon_sym_AMP] = ACTIONS(502),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(504),
    [anon_sym_STAR] = ACTIONS(504),
    [anon_sym_SLASH] = ACTIONS(502),
    [anon_sym_PERCENT] = ACTIONS(504),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(504),
    [anon_sym_BANG_EQ] = ACTIONS(504),
    [anon_sym_GT] = ACTIONS(502),
    [anon_sym_GT_EQ] = ACTIONS(504),
    [anon_sym_LT_EQ] = ACTIONS(504),
    [anon_sym_LT] = ACTIONS(502),
    [anon_sym_LT_LT] = ACTIONS(504),
    [anon_sym_GT_GT] = ACTIONS(502),
    [anon_sym_GT_GT_GT] = ACTIONS(504),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(504),
    [anon_sym_assert] = ACTIONS(502),
    [anon_sym_static_assert] = ACTIONS(502),
    [anon_sym_forward] = ACTIONS(502),
    [anon_sym_native] = ACTIONS(502),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_enum] = ACTIONS(502),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_struct] = ACTIONS(502),
    [anon_sym_typedef] = ACTIONS(502),
    [anon_sym_typeset] = ACTIONS(502),
    [anon_sym_funcenum] = ACTIONS(502),
    [anon_sym_functag] = ACTIONS(502),
    [anon_sym_methodmap] = ACTIONS(502),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_case] = ACTIONS(502),
    [anon_sym_default] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [183] = {
    [sym_preproc_include] = STATE(183),
    [sym_preproc_tryinclude] = STATE(183),
    [sym_preproc_macro] = STATE(183),
    [sym_preproc_define] = STATE(183),
    [sym_preproc_undefine] = STATE(183),
    [sym_preproc_if] = STATE(183),
    [sym_preproc_elseif] = STATE(183),
    [sym_preproc_assert] = STATE(183),
    [sym_preproc_pragma] = STATE(183),
    [sym_preproc_error] = STATE(183),
    [sym_preproc_warning] = STATE(183),
    [ts_builtin_sym_end] = ACTIONS(504),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(604),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(614),
    [anon_sym_PIPE] = ACTIONS(616),
    [anon_sym_CARET] = ACTIONS(618),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(504),
    [anon_sym_assert] = ACTIONS(502),
    [anon_sym_static_assert] = ACTIONS(502),
    [anon_sym_forward] = ACTIONS(502),
    [anon_sym_native] = ACTIONS(502),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_enum] = ACTIONS(502),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_struct] = ACTIONS(502),
    [anon_sym_typedef] = ACTIONS(502),
    [anon_sym_typeset] = ACTIONS(502),
    [anon_sym_funcenum] = ACTIONS(502),
    [anon_sym_functag] = ACTIONS(502),
    [anon_sym_methodmap] = ACTIONS(502),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_case] = ACTIONS(502),
    [anon_sym_default] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [184] = {
    [sym_preproc_include] = STATE(184),
    [sym_preproc_tryinclude] = STATE(184),
    [sym_preproc_macro] = STATE(184),
    [sym_preproc_define] = STATE(184),
    [sym_preproc_undefine] = STATE(184),
    [sym_preproc_if] = STATE(184),
    [sym_preproc_elseif] = STATE(184),
    [sym_preproc_assert] = STATE(184),
    [sym_preproc_pragma] = STATE(184),
    [sym_preproc_error] = STATE(184),
    [sym_preproc_warning] = STATE(184),
    [ts_builtin_sym_end] = ACTIONS(504),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(604),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(616),
    [anon_sym_CARET] = ACTIONS(618),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(504),
    [anon_sym_assert] = ACTIONS(502),
    [anon_sym_static_assert] = ACTIONS(502),
    [anon_sym_forward] = ACTIONS(502),
    [anon_sym_native] = ACTIONS(502),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_enum] = ACTIONS(502),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_struct] = ACTIONS(502),
    [anon_sym_typedef] = ACTIONS(502),
    [anon_sym_typeset] = ACTIONS(502),
    [anon_sym_funcenum] = ACTIONS(502),
    [anon_sym_functag] = ACTIONS(502),
    [anon_sym_methodmap] = ACTIONS(502),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_case] = ACTIONS(502),
    [anon_sym_default] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [185] = {
    [sym_preproc_include] = STATE(185),
    [sym_preproc_tryinclude] = STATE(185),
    [sym_preproc_macro] = STATE(185),
    [sym_preproc_define] = STATE(185),
    [sym_preproc_undefine] = STATE(185),
    [sym_preproc_if] = STATE(185),
    [sym_preproc_elseif] = STATE(185),
    [sym_preproc_assert] = STATE(185),
    [sym_preproc_pragma] = STATE(185),
    [sym_preproc_error] = STATE(185),
    [sym_preproc_warning] = STATE(185),
    [ts_builtin_sym_end] = ACTIONS(504),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(604),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(618),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(504),
    [anon_sym_assert] = ACTIONS(502),
    [anon_sym_static_assert] = ACTIONS(502),
    [anon_sym_forward] = ACTIONS(502),
    [anon_sym_native] = ACTIONS(502),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_enum] = ACTIONS(502),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_struct] = ACTIONS(502),
    [anon_sym_typedef] = ACTIONS(502),
    [anon_sym_typeset] = ACTIONS(502),
    [anon_sym_funcenum] = ACTIONS(502),
    [anon_sym_functag] = ACTIONS(502),
    [anon_sym_methodmap] = ACTIONS(502),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_case] = ACTIONS(502),
    [anon_sym_default] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [186] = {
    [sym_preproc_include] = STATE(186),
    [sym_preproc_tryinclude] = STATE(186),
    [sym_preproc_macro] = STATE(186),
    [sym_preproc_define] = STATE(186),
    [sym_preproc_undefine] = STATE(186),
    [sym_preproc_if] = STATE(186),
    [sym_preproc_elseif] = STATE(186),
    [sym_preproc_assert] = STATE(186),
    [sym_preproc_pragma] = STATE(186),
    [sym_preproc_error] = STATE(186),
    [sym_preproc_warning] = STATE(186),
    [ts_builtin_sym_end] = ACTIONS(504),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(604),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(504),
    [anon_sym_assert] = ACTIONS(502),
    [anon_sym_static_assert] = ACTIONS(502),
    [anon_sym_forward] = ACTIONS(502),
    [anon_sym_native] = ACTIONS(502),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_enum] = ACTIONS(502),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_struct] = ACTIONS(502),
    [anon_sym_typedef] = ACTIONS(502),
    [anon_sym_typeset] = ACTIONS(502),
    [anon_sym_funcenum] = ACTIONS(502),
    [anon_sym_functag] = ACTIONS(502),
    [anon_sym_methodmap] = ACTIONS(502),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_case] = ACTIONS(502),
    [anon_sym_default] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [187] = {
    [sym_preproc_include] = STATE(187),
    [sym_preproc_tryinclude] = STATE(187),
    [sym_preproc_macro] = STATE(187),
    [sym_preproc_define] = STATE(187),
    [sym_preproc_undefine] = STATE(187),
    [sym_preproc_if] = STATE(187),
    [sym_preproc_elseif] = STATE(187),
    [sym_preproc_assert] = STATE(187),
    [sym_preproc_pragma] = STATE(187),
    [sym_preproc_error] = STATE(187),
    [sym_preproc_warning] = STATE(187),
    [ts_builtin_sym_end] = ACTIONS(504),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(502),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(504),
    [anon_sym_BANG_EQ] = ACTIONS(504),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(504),
    [anon_sym_assert] = ACTIONS(502),
    [anon_sym_static_assert] = ACTIONS(502),
    [anon_sym_forward] = ACTIONS(502),
    [anon_sym_native] = ACTIONS(502),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_enum] = ACTIONS(502),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_struct] = ACTIONS(502),
    [anon_sym_typedef] = ACTIONS(502),
    [anon_sym_typeset] = ACTIONS(502),
    [anon_sym_funcenum] = ACTIONS(502),
    [anon_sym_functag] = ACTIONS(502),
    [anon_sym_methodmap] = ACTIONS(502),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_case] = ACTIONS(502),
    [anon_sym_default] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [188] = {
    [sym_preproc_include] = STATE(188),
    [sym_preproc_tryinclude] = STATE(188),
    [sym_preproc_macro] = STATE(188),
    [sym_preproc_define] = STATE(188),
    [sym_preproc_undefine] = STATE(188),
    [sym_preproc_if] = STATE(188),
    [sym_preproc_elseif] = STATE(188),
    [sym_preproc_assert] = STATE(188),
    [sym_preproc_pragma] = STATE(188),
    [sym_preproc_error] = STATE(188),
    [sym_preproc_warning] = STATE(188),
    [ts_builtin_sym_end] = ACTIONS(504),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(502),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(504),
    [anon_sym_BANG_EQ] = ACTIONS(504),
    [anon_sym_GT] = ACTIONS(502),
    [anon_sym_GT_EQ] = ACTIONS(504),
    [anon_sym_LT_EQ] = ACTIONS(504),
    [anon_sym_LT] = ACTIONS(502),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(504),
    [anon_sym_assert] = ACTIONS(502),
    [anon_sym_static_assert] = ACTIONS(502),
    [anon_sym_forward] = ACTIONS(502),
    [anon_sym_native] = ACTIONS(502),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_enum] = ACTIONS(502),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_struct] = ACTIONS(502),
    [anon_sym_typedef] = ACTIONS(502),
    [anon_sym_typeset] = ACTIONS(502),
    [anon_sym_funcenum] = ACTIONS(502),
    [anon_sym_functag] = ACTIONS(502),
    [anon_sym_methodmap] = ACTIONS(502),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_case] = ACTIONS(502),
    [anon_sym_default] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [189] = {
    [sym_preproc_include] = STATE(189),
    [sym_preproc_tryinclude] = STATE(189),
    [sym_preproc_macro] = STATE(189),
    [sym_preproc_define] = STATE(189),
    [sym_preproc_undefine] = STATE(189),
    [sym_preproc_if] = STATE(189),
    [sym_preproc_elseif] = STATE(189),
    [sym_preproc_assert] = STATE(189),
    [sym_preproc_pragma] = STATE(189),
    [sym_preproc_error] = STATE(189),
    [sym_preproc_warning] = STATE(189),
    [ts_builtin_sym_end] = ACTIONS(504),
    [sym_identifier] = ACTIONS(502),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(502),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(502),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(504),
    [anon_sym_BANG_EQ] = ACTIONS(504),
    [anon_sym_GT] = ACTIONS(502),
    [anon_sym_GT_EQ] = ACTIONS(504),
    [anon_sym_LT_EQ] = ACTIONS(504),
    [anon_sym_LT] = ACTIONS(502),
    [anon_sym_LT_LT] = ACTIONS(504),
    [anon_sym_GT_GT] = ACTIONS(502),
    [anon_sym_GT_GT_GT] = ACTIONS(504),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(504),
    [anon_sym_assert] = ACTIONS(502),
    [anon_sym_static_assert] = ACTIONS(502),
    [anon_sym_forward] = ACTIONS(502),
    [anon_sym_native] = ACTIONS(502),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_public] = ACTIONS(502),
    [anon_sym_stock] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_new] = ACTIONS(502),
    [anon_sym_decl] = ACTIONS(502),
    [anon_sym_enum] = ACTIONS(502),
    [anon_sym_RBRACE] = ACTIONS(504),
    [anon_sym_struct] = ACTIONS(502),
    [anon_sym_typedef] = ACTIONS(502),
    [anon_sym_typeset] = ACTIONS(502),
    [anon_sym_funcenum] = ACTIONS(502),
    [anon_sym_functag] = ACTIONS(502),
    [anon_sym_methodmap] = ACTIONS(502),
    [anon_sym_void] = ACTIONS(502),
    [anon_sym_bool] = ACTIONS(502),
    [anon_sym_int] = ACTIONS(502),
    [anon_sym_float] = ACTIONS(502),
    [anon_sym_char] = ACTIONS(502),
    [anon_sym__] = ACTIONS(502),
    [anon_sym_Float] = ACTIONS(502),
    [anon_sym_String] = ACTIONS(502),
    [sym_any_type] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_else] = ACTIONS(502),
    [anon_sym_case] = ACTIONS(502),
    [anon_sym_default] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(504),
  },
  [190] = {
    [sym_preproc_include] = STATE(190),
    [sym_preproc_tryinclude] = STATE(190),
    [sym_preproc_macro] = STATE(190),
    [sym_preproc_define] = STATE(190),
    [sym_preproc_undefine] = STATE(190),
    [sym_preproc_if] = STATE(190),
    [sym_preproc_elseif] = STATE(190),
    [sym_preproc_assert] = STATE(190),
    [sym_preproc_pragma] = STATE(190),
    [sym_preproc_error] = STATE(190),
    [sym_preproc_warning] = STATE(190),
    [ts_builtin_sym_end] = ACTIONS(556),
    [sym_identifier] = ACTIONS(554),
    [anon_sym_DASH] = ACTIONS(554),
    [anon_sym_PLUS] = ACTIONS(554),
    [anon_sym_AMP] = ACTIONS(554),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(556),
    [anon_sym_STAR] = ACTIONS(556),
    [anon_sym_SLASH] = ACTIONS(554),
    [anon_sym_PERCENT] = ACTIONS(556),
    [anon_sym_PIPE_PIPE] = ACTIONS(556),
    [anon_sym_AMP_AMP] = ACTIONS(556),
    [anon_sym_PIPE] = ACTIONS(554),
    [anon_sym_CARET] = ACTIONS(556),
    [anon_sym_EQ_EQ] = ACTIONS(556),
    [anon_sym_BANG_EQ] = ACTIONS(556),
    [anon_sym_GT] = ACTIONS(554),
    [anon_sym_GT_EQ] = ACTIONS(556),
    [anon_sym_LT_EQ] = ACTIONS(556),
    [anon_sym_LT] = ACTIONS(554),
    [anon_sym_LT_LT] = ACTIONS(556),
    [anon_sym_GT_GT] = ACTIONS(554),
    [anon_sym_GT_GT_GT] = ACTIONS(556),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(556),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(556),
    [anon_sym_assert] = ACTIONS(554),
    [anon_sym_static_assert] = ACTIONS(554),
    [anon_sym_forward] = ACTIONS(554),
    [anon_sym_native] = ACTIONS(554),
    [anon_sym_const] = ACTIONS(554),
    [anon_sym_public] = ACTIONS(554),
    [anon_sym_stock] = ACTIONS(554),
    [anon_sym_static] = ACTIONS(554),
    [anon_sym_new] = ACTIONS(554),
    [anon_sym_decl] = ACTIONS(554),
    [anon_sym_enum] = ACTIONS(554),
    [anon_sym_RBRACE] = ACTIONS(556),
    [anon_sym_struct] = ACTIONS(554),
    [anon_sym_typedef] = ACTIONS(554),
    [anon_sym_typeset] = ACTIONS(554),
    [anon_sym_funcenum] = ACTIONS(554),
    [anon_sym_functag] = ACTIONS(554),
    [anon_sym_methodmap] = ACTIONS(554),
    [anon_sym_void] = ACTIONS(554),
    [anon_sym_bool] = ACTIONS(554),
    [anon_sym_int] = ACTIONS(554),
    [anon_sym_float] = ACTIONS(554),
    [anon_sym_char] = ACTIONS(554),
    [anon_sym__] = ACTIONS(554),
    [anon_sym_Float] = ACTIONS(554),
    [anon_sym_String] = ACTIONS(554),
    [sym_any_type] = ACTIONS(554),
    [anon_sym_while] = ACTIONS(554),
    [anon_sym_else] = ACTIONS(554),
    [anon_sym_case] = ACTIONS(554),
    [anon_sym_default] = ACTIONS(554),
    [anon_sym_SEMI] = ACTIONS(556),
    [anon_sym_DOT] = ACTIONS(554),
    [anon_sym_QMARK] = ACTIONS(556),
    [anon_sym_DASH_DASH] = ACTIONS(556),
    [anon_sym_PLUS_PLUS] = ACTIONS(556),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(556),
  },
  [191] = {
    [sym_preproc_include] = STATE(191),
    [sym_preproc_tryinclude] = STATE(191),
    [sym_preproc_macro] = STATE(191),
    [sym_preproc_define] = STATE(191),
    [sym_preproc_undefine] = STATE(191),
    [sym_preproc_if] = STATE(191),
    [sym_preproc_elseif] = STATE(191),
    [sym_preproc_assert] = STATE(191),
    [sym_preproc_pragma] = STATE(191),
    [sym_preproc_error] = STATE(191),
    [sym_preproc_warning] = STATE(191),
    [ts_builtin_sym_end] = ACTIONS(560),
    [sym_identifier] = ACTIONS(558),
    [anon_sym_DASH] = ACTIONS(558),
    [anon_sym_PLUS] = ACTIONS(558),
    [anon_sym_AMP] = ACTIONS(558),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(560),
    [anon_sym_STAR] = ACTIONS(560),
    [anon_sym_SLASH] = ACTIONS(558),
    [anon_sym_PERCENT] = ACTIONS(560),
    [anon_sym_PIPE_PIPE] = ACTIONS(560),
    [anon_sym_AMP_AMP] = ACTIONS(560),
    [anon_sym_PIPE] = ACTIONS(558),
    [anon_sym_CARET] = ACTIONS(560),
    [anon_sym_EQ_EQ] = ACTIONS(560),
    [anon_sym_BANG_EQ] = ACTIONS(560),
    [anon_sym_GT] = ACTIONS(558),
    [anon_sym_GT_EQ] = ACTIONS(560),
    [anon_sym_LT_EQ] = ACTIONS(560),
    [anon_sym_LT] = ACTIONS(558),
    [anon_sym_LT_LT] = ACTIONS(560),
    [anon_sym_GT_GT] = ACTIONS(558),
    [anon_sym_GT_GT_GT] = ACTIONS(560),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(560),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(560),
    [anon_sym_assert] = ACTIONS(558),
    [anon_sym_static_assert] = ACTIONS(558),
    [anon_sym_forward] = ACTIONS(558),
    [anon_sym_native] = ACTIONS(558),
    [anon_sym_const] = ACTIONS(558),
    [anon_sym_public] = ACTIONS(558),
    [anon_sym_stock] = ACTIONS(558),
    [anon_sym_static] = ACTIONS(558),
    [anon_sym_new] = ACTIONS(558),
    [anon_sym_decl] = ACTIONS(558),
    [anon_sym_enum] = ACTIONS(558),
    [anon_sym_RBRACE] = ACTIONS(560),
    [anon_sym_struct] = ACTIONS(558),
    [anon_sym_typedef] = ACTIONS(558),
    [anon_sym_typeset] = ACTIONS(558),
    [anon_sym_funcenum] = ACTIONS(558),
    [anon_sym_functag] = ACTIONS(558),
    [anon_sym_methodmap] = ACTIONS(558),
    [anon_sym_void] = ACTIONS(558),
    [anon_sym_bool] = ACTIONS(558),
    [anon_sym_int] = ACTIONS(558),
    [anon_sym_float] = ACTIONS(558),
    [anon_sym_char] = ACTIONS(558),
    [anon_sym__] = ACTIONS(558),
    [anon_sym_Float] = ACTIONS(558),
    [anon_sym_String] = ACTIONS(558),
    [sym_any_type] = ACTIONS(558),
    [anon_sym_while] = ACTIONS(558),
    [anon_sym_else] = ACTIONS(558),
    [anon_sym_case] = ACTIONS(558),
    [anon_sym_default] = ACTIONS(558),
    [anon_sym_SEMI] = ACTIONS(560),
    [anon_sym_DOT] = ACTIONS(558),
    [anon_sym_QMARK] = ACTIONS(560),
    [anon_sym_DASH_DASH] = ACTIONS(560),
    [anon_sym_PLUS_PLUS] = ACTIONS(560),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(560),
  },
  [192] = {
    [sym_preproc_include] = STATE(192),
    [sym_preproc_tryinclude] = STATE(192),
    [sym_preproc_macro] = STATE(192),
    [sym_preproc_define] = STATE(192),
    [sym_preproc_undefine] = STATE(192),
    [sym_preproc_if] = STATE(192),
    [sym_preproc_elseif] = STATE(192),
    [sym_preproc_assert] = STATE(192),
    [sym_preproc_pragma] = STATE(192),
    [sym_preproc_error] = STATE(192),
    [sym_preproc_warning] = STATE(192),
    [ts_builtin_sym_end] = ACTIONS(520),
    [sym_identifier] = ACTIONS(518),
    [anon_sym_DASH] = ACTIONS(518),
    [anon_sym_PLUS] = ACTIONS(518),
    [anon_sym_AMP] = ACTIONS(518),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(520),
    [anon_sym_STAR] = ACTIONS(520),
    [anon_sym_SLASH] = ACTIONS(518),
    [anon_sym_PERCENT] = ACTIONS(520),
    [anon_sym_PIPE_PIPE] = ACTIONS(520),
    [anon_sym_AMP_AMP] = ACTIONS(520),
    [anon_sym_PIPE] = ACTIONS(518),
    [anon_sym_CARET] = ACTIONS(520),
    [anon_sym_EQ_EQ] = ACTIONS(520),
    [anon_sym_BANG_EQ] = ACTIONS(520),
    [anon_sym_GT] = ACTIONS(518),
    [anon_sym_GT_EQ] = ACTIONS(520),
    [anon_sym_LT_EQ] = ACTIONS(520),
    [anon_sym_LT] = ACTIONS(518),
    [anon_sym_LT_LT] = ACTIONS(520),
    [anon_sym_GT_GT] = ACTIONS(518),
    [anon_sym_GT_GT_GT] = ACTIONS(520),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(520),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(520),
    [anon_sym_assert] = ACTIONS(518),
    [anon_sym_static_assert] = ACTIONS(518),
    [anon_sym_forward] = ACTIONS(518),
    [anon_sym_native] = ACTIONS(518),
    [anon_sym_const] = ACTIONS(518),
    [anon_sym_public] = ACTIONS(518),
    [anon_sym_stock] = ACTIONS(518),
    [anon_sym_static] = ACTIONS(518),
    [anon_sym_new] = ACTIONS(518),
    [anon_sym_decl] = ACTIONS(518),
    [anon_sym_enum] = ACTIONS(518),
    [anon_sym_RBRACE] = ACTIONS(520),
    [anon_sym_struct] = ACTIONS(518),
    [anon_sym_typedef] = ACTIONS(518),
    [anon_sym_typeset] = ACTIONS(518),
    [anon_sym_funcenum] = ACTIONS(518),
    [anon_sym_functag] = ACTIONS(518),
    [anon_sym_methodmap] = ACTIONS(518),
    [anon_sym_void] = ACTIONS(518),
    [anon_sym_bool] = ACTIONS(518),
    [anon_sym_int] = ACTIONS(518),
    [anon_sym_float] = ACTIONS(518),
    [anon_sym_char] = ACTIONS(518),
    [anon_sym__] = ACTIONS(518),
    [anon_sym_Float] = ACTIONS(518),
    [anon_sym_String] = ACTIONS(518),
    [sym_any_type] = ACTIONS(518),
    [anon_sym_while] = ACTIONS(518),
    [anon_sym_else] = ACTIONS(518),
    [anon_sym_case] = ACTIONS(518),
    [anon_sym_default] = ACTIONS(518),
    [anon_sym_SEMI] = ACTIONS(520),
    [anon_sym_DOT] = ACTIONS(518),
    [anon_sym_QMARK] = ACTIONS(520),
    [anon_sym_DASH_DASH] = ACTIONS(520),
    [anon_sym_PLUS_PLUS] = ACTIONS(520),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(520),
  },
  [193] = {
    [sym_preproc_include] = STATE(193),
    [sym_preproc_tryinclude] = STATE(193),
    [sym_preproc_macro] = STATE(193),
    [sym_preproc_define] = STATE(193),
    [sym_preproc_undefine] = STATE(193),
    [sym_preproc_if] = STATE(193),
    [sym_preproc_elseif] = STATE(193),
    [sym_preproc_assert] = STATE(193),
    [sym_preproc_pragma] = STATE(193),
    [sym_preproc_error] = STATE(193),
    [sym_preproc_warning] = STATE(193),
    [ts_builtin_sym_end] = ACTIONS(564),
    [sym_identifier] = ACTIONS(562),
    [anon_sym_DASH] = ACTIONS(562),
    [anon_sym_PLUS] = ACTIONS(562),
    [anon_sym_AMP] = ACTIONS(562),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(564),
    [anon_sym_STAR] = ACTIONS(564),
    [anon_sym_SLASH] = ACTIONS(562),
    [anon_sym_PERCENT] = ACTIONS(564),
    [anon_sym_PIPE_PIPE] = ACTIONS(564),
    [anon_sym_AMP_AMP] = ACTIONS(564),
    [anon_sym_PIPE] = ACTIONS(562),
    [anon_sym_CARET] = ACTIONS(564),
    [anon_sym_EQ_EQ] = ACTIONS(564),
    [anon_sym_BANG_EQ] = ACTIONS(564),
    [anon_sym_GT] = ACTIONS(562),
    [anon_sym_GT_EQ] = ACTIONS(564),
    [anon_sym_LT_EQ] = ACTIONS(564),
    [anon_sym_LT] = ACTIONS(562),
    [anon_sym_LT_LT] = ACTIONS(564),
    [anon_sym_GT_GT] = ACTIONS(562),
    [anon_sym_GT_GT_GT] = ACTIONS(564),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(564),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(564),
    [anon_sym_assert] = ACTIONS(562),
    [anon_sym_static_assert] = ACTIONS(562),
    [anon_sym_forward] = ACTIONS(562),
    [anon_sym_native] = ACTIONS(562),
    [anon_sym_const] = ACTIONS(562),
    [anon_sym_public] = ACTIONS(562),
    [anon_sym_stock] = ACTIONS(562),
    [anon_sym_static] = ACTIONS(562),
    [anon_sym_new] = ACTIONS(562),
    [anon_sym_decl] = ACTIONS(562),
    [anon_sym_enum] = ACTIONS(562),
    [anon_sym_RBRACE] = ACTIONS(564),
    [anon_sym_struct] = ACTIONS(562),
    [anon_sym_typedef] = ACTIONS(562),
    [anon_sym_typeset] = ACTIONS(562),
    [anon_sym_funcenum] = ACTIONS(562),
    [anon_sym_functag] = ACTIONS(562),
    [anon_sym_methodmap] = ACTIONS(562),
    [anon_sym_void] = ACTIONS(562),
    [anon_sym_bool] = ACTIONS(562),
    [anon_sym_int] = ACTIONS(562),
    [anon_sym_float] = ACTIONS(562),
    [anon_sym_char] = ACTIONS(562),
    [anon_sym__] = ACTIONS(562),
    [anon_sym_Float] = ACTIONS(562),
    [anon_sym_String] = ACTIONS(562),
    [sym_any_type] = ACTIONS(562),
    [anon_sym_while] = ACTIONS(562),
    [anon_sym_else] = ACTIONS(562),
    [anon_sym_case] = ACTIONS(562),
    [anon_sym_default] = ACTIONS(562),
    [anon_sym_SEMI] = ACTIONS(564),
    [anon_sym_DOT] = ACTIONS(562),
    [anon_sym_QMARK] = ACTIONS(564),
    [anon_sym_DASH_DASH] = ACTIONS(564),
    [anon_sym_PLUS_PLUS] = ACTIONS(564),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(564),
  },
  [194] = {
    [sym_preproc_include] = STATE(194),
    [sym_preproc_tryinclude] = STATE(194),
    [sym_preproc_macro] = STATE(194),
    [sym_preproc_define] = STATE(194),
    [sym_preproc_undefine] = STATE(194),
    [sym_preproc_if] = STATE(194),
    [sym_preproc_elseif] = STATE(194),
    [sym_preproc_assert] = STATE(194),
    [sym_preproc_pragma] = STATE(194),
    [sym_preproc_error] = STATE(194),
    [sym_preproc_warning] = STATE(194),
    [ts_builtin_sym_end] = ACTIONS(568),
    [sym_identifier] = ACTIONS(566),
    [anon_sym_DASH] = ACTIONS(566),
    [anon_sym_PLUS] = ACTIONS(566),
    [anon_sym_AMP] = ACTIONS(566),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(568),
    [anon_sym_STAR] = ACTIONS(568),
    [anon_sym_SLASH] = ACTIONS(566),
    [anon_sym_PERCENT] = ACTIONS(568),
    [anon_sym_PIPE_PIPE] = ACTIONS(568),
    [anon_sym_AMP_AMP] = ACTIONS(568),
    [anon_sym_PIPE] = ACTIONS(566),
    [anon_sym_CARET] = ACTIONS(568),
    [anon_sym_EQ_EQ] = ACTIONS(568),
    [anon_sym_BANG_EQ] = ACTIONS(568),
    [anon_sym_GT] = ACTIONS(566),
    [anon_sym_GT_EQ] = ACTIONS(568),
    [anon_sym_LT_EQ] = ACTIONS(568),
    [anon_sym_LT] = ACTIONS(566),
    [anon_sym_LT_LT] = ACTIONS(568),
    [anon_sym_GT_GT] = ACTIONS(566),
    [anon_sym_GT_GT_GT] = ACTIONS(568),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(568),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(568),
    [anon_sym_assert] = ACTIONS(566),
    [anon_sym_static_assert] = ACTIONS(566),
    [anon_sym_forward] = ACTIONS(566),
    [anon_sym_native] = ACTIONS(566),
    [anon_sym_const] = ACTIONS(566),
    [anon_sym_public] = ACTIONS(566),
    [anon_sym_stock] = ACTIONS(566),
    [anon_sym_static] = ACTIONS(566),
    [anon_sym_new] = ACTIONS(566),
    [anon_sym_decl] = ACTIONS(566),
    [anon_sym_enum] = ACTIONS(566),
    [anon_sym_RBRACE] = ACTIONS(568),
    [anon_sym_struct] = ACTIONS(566),
    [anon_sym_typedef] = ACTIONS(566),
    [anon_sym_typeset] = ACTIONS(566),
    [anon_sym_funcenum] = ACTIONS(566),
    [anon_sym_functag] = ACTIONS(566),
    [anon_sym_methodmap] = ACTIONS(566),
    [anon_sym_void] = ACTIONS(566),
    [anon_sym_bool] = ACTIONS(566),
    [anon_sym_int] = ACTIONS(566),
    [anon_sym_float] = ACTIONS(566),
    [anon_sym_char] = ACTIONS(566),
    [anon_sym__] = ACTIONS(566),
    [anon_sym_Float] = ACTIONS(566),
    [anon_sym_String] = ACTIONS(566),
    [sym_any_type] = ACTIONS(566),
    [anon_sym_while] = ACTIONS(566),
    [anon_sym_else] = ACTIONS(566),
    [anon_sym_case] = ACTIONS(566),
    [anon_sym_default] = ACTIONS(566),
    [anon_sym_SEMI] = ACTIONS(568),
    [anon_sym_DOT] = ACTIONS(566),
    [anon_sym_QMARK] = ACTIONS(568),
    [anon_sym_DASH_DASH] = ACTIONS(568),
    [anon_sym_PLUS_PLUS] = ACTIONS(568),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(568),
  },
  [195] = {
    [sym_preproc_include] = STATE(195),
    [sym_preproc_tryinclude] = STATE(195),
    [sym_preproc_macro] = STATE(195),
    [sym_preproc_define] = STATE(195),
    [sym_preproc_undefine] = STATE(195),
    [sym_preproc_if] = STATE(195),
    [sym_preproc_elseif] = STATE(195),
    [sym_preproc_assert] = STATE(195),
    [sym_preproc_pragma] = STATE(195),
    [sym_preproc_error] = STATE(195),
    [sym_preproc_warning] = STATE(195),
    [ts_builtin_sym_end] = ACTIONS(246),
    [sym_identifier] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(246),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(246),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(246),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(246),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(246),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(244),
    [anon_sym_static_assert] = ACTIONS(244),
    [anon_sym_forward] = ACTIONS(244),
    [anon_sym_native] = ACTIONS(244),
    [anon_sym_const] = ACTIONS(244),
    [anon_sym_public] = ACTIONS(244),
    [anon_sym_stock] = ACTIONS(244),
    [anon_sym_static] = ACTIONS(244),
    [anon_sym_new] = ACTIONS(244),
    [anon_sym_decl] = ACTIONS(244),
    [anon_sym_enum] = ACTIONS(244),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_struct] = ACTIONS(244),
    [anon_sym_typedef] = ACTIONS(244),
    [anon_sym_typeset] = ACTIONS(244),
    [anon_sym_funcenum] = ACTIONS(244),
    [anon_sym_functag] = ACTIONS(244),
    [anon_sym_methodmap] = ACTIONS(244),
    [anon_sym_void] = ACTIONS(244),
    [anon_sym_bool] = ACTIONS(244),
    [anon_sym_int] = ACTIONS(244),
    [anon_sym_float] = ACTIONS(244),
    [anon_sym_char] = ACTIONS(244),
    [anon_sym__] = ACTIONS(244),
    [anon_sym_Float] = ACTIONS(244),
    [anon_sym_String] = ACTIONS(244),
    [sym_any_type] = ACTIONS(244),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_else] = ACTIONS(244),
    [anon_sym_case] = ACTIONS(244),
    [anon_sym_default] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [196] = {
    [sym_preproc_include] = STATE(196),
    [sym_preproc_tryinclude] = STATE(196),
    [sym_preproc_macro] = STATE(196),
    [sym_preproc_define] = STATE(196),
    [sym_preproc_undefine] = STATE(196),
    [sym_preproc_if] = STATE(196),
    [sym_preproc_elseif] = STATE(196),
    [sym_preproc_assert] = STATE(196),
    [sym_preproc_pragma] = STATE(196),
    [sym_preproc_error] = STATE(196),
    [sym_preproc_warning] = STATE(196),
    [ts_builtin_sym_end] = ACTIONS(580),
    [sym_identifier] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(604),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(612),
    [anon_sym_AMP_AMP] = ACTIONS(614),
    [anon_sym_PIPE] = ACTIONS(616),
    [anon_sym_CARET] = ACTIONS(618),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(580),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(580),
    [anon_sym_assert] = ACTIONS(578),
    [anon_sym_static_assert] = ACTIONS(578),
    [anon_sym_forward] = ACTIONS(578),
    [anon_sym_native] = ACTIONS(578),
    [anon_sym_const] = ACTIONS(578),
    [anon_sym_public] = ACTIONS(578),
    [anon_sym_stock] = ACTIONS(578),
    [anon_sym_static] = ACTIONS(578),
    [anon_sym_new] = ACTIONS(578),
    [anon_sym_decl] = ACTIONS(578),
    [anon_sym_enum] = ACTIONS(578),
    [anon_sym_RBRACE] = ACTIONS(580),
    [anon_sym_struct] = ACTIONS(578),
    [anon_sym_typedef] = ACTIONS(578),
    [anon_sym_typeset] = ACTIONS(578),
    [anon_sym_funcenum] = ACTIONS(578),
    [anon_sym_functag] = ACTIONS(578),
    [anon_sym_methodmap] = ACTIONS(578),
    [anon_sym_void] = ACTIONS(578),
    [anon_sym_bool] = ACTIONS(578),
    [anon_sym_int] = ACTIONS(578),
    [anon_sym_float] = ACTIONS(578),
    [anon_sym_char] = ACTIONS(578),
    [anon_sym__] = ACTIONS(578),
    [anon_sym_Float] = ACTIONS(578),
    [anon_sym_String] = ACTIONS(578),
    [sym_any_type] = ACTIONS(578),
    [anon_sym_while] = ACTIONS(578),
    [anon_sym_else] = ACTIONS(578),
    [anon_sym_case] = ACTIONS(578),
    [anon_sym_default] = ACTIONS(578),
    [anon_sym_SEMI] = ACTIONS(580),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(634),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(580),
  },
  [197] = {
    [sym_preproc_include] = STATE(197),
    [sym_preproc_tryinclude] = STATE(197),
    [sym_preproc_macro] = STATE(197),
    [sym_preproc_define] = STATE(197),
    [sym_preproc_undefine] = STATE(197),
    [sym_preproc_if] = STATE(197),
    [sym_preproc_elseif] = STATE(197),
    [sym_preproc_assert] = STATE(197),
    [sym_preproc_pragma] = STATE(197),
    [sym_preproc_error] = STATE(197),
    [sym_preproc_warning] = STATE(197),
    [ts_builtin_sym_end] = ACTIONS(572),
    [sym_identifier] = ACTIONS(570),
    [anon_sym_DASH] = ACTIONS(570),
    [anon_sym_PLUS] = ACTIONS(570),
    [anon_sym_AMP] = ACTIONS(570),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(572),
    [anon_sym_STAR] = ACTIONS(572),
    [anon_sym_SLASH] = ACTIONS(570),
    [anon_sym_PERCENT] = ACTIONS(572),
    [anon_sym_PIPE_PIPE] = ACTIONS(572),
    [anon_sym_AMP_AMP] = ACTIONS(572),
    [anon_sym_PIPE] = ACTIONS(570),
    [anon_sym_CARET] = ACTIONS(572),
    [anon_sym_EQ_EQ] = ACTIONS(572),
    [anon_sym_BANG_EQ] = ACTIONS(572),
    [anon_sym_GT] = ACTIONS(570),
    [anon_sym_GT_EQ] = ACTIONS(572),
    [anon_sym_LT_EQ] = ACTIONS(572),
    [anon_sym_LT] = ACTIONS(570),
    [anon_sym_LT_LT] = ACTIONS(572),
    [anon_sym_GT_GT] = ACTIONS(570),
    [anon_sym_GT_GT_GT] = ACTIONS(572),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(572),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(572),
    [anon_sym_assert] = ACTIONS(570),
    [anon_sym_static_assert] = ACTIONS(570),
    [anon_sym_forward] = ACTIONS(570),
    [anon_sym_native] = ACTIONS(570),
    [anon_sym_const] = ACTIONS(570),
    [anon_sym_public] = ACTIONS(570),
    [anon_sym_stock] = ACTIONS(570),
    [anon_sym_static] = ACTIONS(570),
    [anon_sym_new] = ACTIONS(570),
    [anon_sym_decl] = ACTIONS(570),
    [anon_sym_enum] = ACTIONS(570),
    [anon_sym_RBRACE] = ACTIONS(572),
    [anon_sym_struct] = ACTIONS(570),
    [anon_sym_typedef] = ACTIONS(570),
    [anon_sym_typeset] = ACTIONS(570),
    [anon_sym_funcenum] = ACTIONS(570),
    [anon_sym_functag] = ACTIONS(570),
    [anon_sym_methodmap] = ACTIONS(570),
    [anon_sym_void] = ACTIONS(570),
    [anon_sym_bool] = ACTIONS(570),
    [anon_sym_int] = ACTIONS(570),
    [anon_sym_float] = ACTIONS(570),
    [anon_sym_char] = ACTIONS(570),
    [anon_sym__] = ACTIONS(570),
    [anon_sym_Float] = ACTIONS(570),
    [anon_sym_String] = ACTIONS(570),
    [sym_any_type] = ACTIONS(570),
    [anon_sym_while] = ACTIONS(570),
    [anon_sym_else] = ACTIONS(570),
    [anon_sym_case] = ACTIONS(570),
    [anon_sym_default] = ACTIONS(570),
    [anon_sym_SEMI] = ACTIONS(572),
    [anon_sym_DOT] = ACTIONS(570),
    [anon_sym_QMARK] = ACTIONS(572),
    [anon_sym_DASH_DASH] = ACTIONS(572),
    [anon_sym_PLUS_PLUS] = ACTIONS(572),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(572),
  },
  [198] = {
    [sym_preproc_include] = STATE(198),
    [sym_preproc_tryinclude] = STATE(198),
    [sym_preproc_macro] = STATE(198),
    [sym_preproc_define] = STATE(198),
    [sym_preproc_undefine] = STATE(198),
    [sym_preproc_if] = STATE(198),
    [sym_preproc_elseif] = STATE(198),
    [sym_preproc_assert] = STATE(198),
    [sym_preproc_pragma] = STATE(198),
    [sym_preproc_error] = STATE(198),
    [sym_preproc_warning] = STATE(198),
    [ts_builtin_sym_end] = ACTIONS(496),
    [sym_identifier] = ACTIONS(494),
    [anon_sym_DASH] = ACTIONS(494),
    [anon_sym_PLUS] = ACTIONS(494),
    [anon_sym_AMP] = ACTIONS(494),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(496),
    [anon_sym_STAR] = ACTIONS(496),
    [anon_sym_SLASH] = ACTIONS(494),
    [anon_sym_PERCENT] = ACTIONS(496),
    [anon_sym_PIPE_PIPE] = ACTIONS(496),
    [anon_sym_AMP_AMP] = ACTIONS(496),
    [anon_sym_PIPE] = ACTIONS(494),
    [anon_sym_CARET] = ACTIONS(496),
    [anon_sym_EQ_EQ] = ACTIONS(496),
    [anon_sym_BANG_EQ] = ACTIONS(496),
    [anon_sym_GT] = ACTIONS(494),
    [anon_sym_GT_EQ] = ACTIONS(496),
    [anon_sym_LT_EQ] = ACTIONS(496),
    [anon_sym_LT] = ACTIONS(494),
    [anon_sym_LT_LT] = ACTIONS(496),
    [anon_sym_GT_GT] = ACTIONS(494),
    [anon_sym_GT_GT_GT] = ACTIONS(496),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(496),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(496),
    [anon_sym_assert] = ACTIONS(494),
    [anon_sym_static_assert] = ACTIONS(494),
    [anon_sym_forward] = ACTIONS(494),
    [anon_sym_native] = ACTIONS(494),
    [anon_sym_const] = ACTIONS(494),
    [anon_sym_public] = ACTIONS(494),
    [anon_sym_stock] = ACTIONS(494),
    [anon_sym_static] = ACTIONS(494),
    [anon_sym_new] = ACTIONS(494),
    [anon_sym_decl] = ACTIONS(494),
    [anon_sym_enum] = ACTIONS(494),
    [anon_sym_RBRACE] = ACTIONS(496),
    [anon_sym_struct] = ACTIONS(494),
    [anon_sym_typedef] = ACTIONS(494),
    [anon_sym_typeset] = ACTIONS(494),
    [anon_sym_funcenum] = ACTIONS(494),
    [anon_sym_functag] = ACTIONS(494),
    [anon_sym_methodmap] = ACTIONS(494),
    [anon_sym_void] = ACTIONS(494),
    [anon_sym_bool] = ACTIONS(494),
    [anon_sym_int] = ACTIONS(494),
    [anon_sym_float] = ACTIONS(494),
    [anon_sym_char] = ACTIONS(494),
    [anon_sym__] = ACTIONS(494),
    [anon_sym_Float] = ACTIONS(494),
    [anon_sym_String] = ACTIONS(494),
    [sym_any_type] = ACTIONS(494),
    [anon_sym_while] = ACTIONS(494),
    [anon_sym_else] = ACTIONS(494),
    [anon_sym_case] = ACTIONS(494),
    [anon_sym_default] = ACTIONS(494),
    [anon_sym_SEMI] = ACTIONS(496),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(496),
    [anon_sym_DASH_DASH] = ACTIONS(496),
    [anon_sym_PLUS_PLUS] = ACTIONS(496),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(496),
  },
  [199] = {
    [sym_preproc_include] = STATE(199),
    [sym_preproc_tryinclude] = STATE(199),
    [sym_preproc_macro] = STATE(199),
    [sym_preproc_define] = STATE(199),
    [sym_preproc_undefine] = STATE(199),
    [sym_preproc_if] = STATE(199),
    [sym_preproc_elseif] = STATE(199),
    [sym_preproc_assert] = STATE(199),
    [sym_preproc_pragma] = STATE(199),
    [sym_preproc_error] = STATE(199),
    [sym_preproc_warning] = STATE(199),
    [ts_builtin_sym_end] = ACTIONS(500),
    [sym_identifier] = ACTIONS(498),
    [anon_sym_DASH] = ACTIONS(498),
    [anon_sym_PLUS] = ACTIONS(498),
    [anon_sym_AMP] = ACTIONS(498),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(500),
    [anon_sym_STAR] = ACTIONS(500),
    [anon_sym_SLASH] = ACTIONS(498),
    [anon_sym_PERCENT] = ACTIONS(500),
    [anon_sym_PIPE_PIPE] = ACTIONS(500),
    [anon_sym_AMP_AMP] = ACTIONS(500),
    [anon_sym_PIPE] = ACTIONS(498),
    [anon_sym_CARET] = ACTIONS(500),
    [anon_sym_EQ_EQ] = ACTIONS(500),
    [anon_sym_BANG_EQ] = ACTIONS(500),
    [anon_sym_GT] = ACTIONS(498),
    [anon_sym_GT_EQ] = ACTIONS(500),
    [anon_sym_LT_EQ] = ACTIONS(500),
    [anon_sym_LT] = ACTIONS(498),
    [anon_sym_LT_LT] = ACTIONS(500),
    [anon_sym_GT_GT] = ACTIONS(498),
    [anon_sym_GT_GT_GT] = ACTIONS(500),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(500),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(500),
    [anon_sym_assert] = ACTIONS(498),
    [anon_sym_static_assert] = ACTIONS(498),
    [anon_sym_forward] = ACTIONS(498),
    [anon_sym_native] = ACTIONS(498),
    [anon_sym_const] = ACTIONS(498),
    [anon_sym_public] = ACTIONS(498),
    [anon_sym_stock] = ACTIONS(498),
    [anon_sym_static] = ACTIONS(498),
    [anon_sym_new] = ACTIONS(498),
    [anon_sym_decl] = ACTIONS(498),
    [anon_sym_enum] = ACTIONS(498),
    [anon_sym_RBRACE] = ACTIONS(500),
    [anon_sym_struct] = ACTIONS(498),
    [anon_sym_typedef] = ACTIONS(498),
    [anon_sym_typeset] = ACTIONS(498),
    [anon_sym_funcenum] = ACTIONS(498),
    [anon_sym_functag] = ACTIONS(498),
    [anon_sym_methodmap] = ACTIONS(498),
    [anon_sym_void] = ACTIONS(498),
    [anon_sym_bool] = ACTIONS(498),
    [anon_sym_int] = ACTIONS(498),
    [anon_sym_float] = ACTIONS(498),
    [anon_sym_char] = ACTIONS(498),
    [anon_sym__] = ACTIONS(498),
    [anon_sym_Float] = ACTIONS(498),
    [anon_sym_String] = ACTIONS(498),
    [sym_any_type] = ACTIONS(498),
    [anon_sym_while] = ACTIONS(498),
    [anon_sym_else] = ACTIONS(498),
    [anon_sym_case] = ACTIONS(498),
    [anon_sym_default] = ACTIONS(498),
    [anon_sym_SEMI] = ACTIONS(500),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(500),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(500),
  },
  [200] = {
    [sym_preproc_include] = STATE(200),
    [sym_preproc_tryinclude] = STATE(200),
    [sym_preproc_macro] = STATE(200),
    [sym_preproc_define] = STATE(200),
    [sym_preproc_undefine] = STATE(200),
    [sym_preproc_if] = STATE(200),
    [sym_preproc_elseif] = STATE(200),
    [sym_preproc_assert] = STATE(200),
    [sym_preproc_pragma] = STATE(200),
    [sym_preproc_error] = STATE(200),
    [sym_preproc_warning] = STATE(200),
    [ts_builtin_sym_end] = ACTIONS(528),
    [sym_identifier] = ACTIONS(526),
    [anon_sym_DASH] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(602),
    [anon_sym_AMP] = ACTIONS(604),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(608),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_PERCENT] = ACTIONS(608),
    [anon_sym_PIPE_PIPE] = ACTIONS(612),
    [anon_sym_AMP_AMP] = ACTIONS(614),
    [anon_sym_PIPE] = ACTIONS(616),
    [anon_sym_CARET] = ACTIONS(618),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_LT_LT] = ACTIONS(626),
    [anon_sym_GT_GT] = ACTIONS(628),
    [anon_sym_GT_GT_GT] = ACTIONS(626),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(528),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(528),
    [anon_sym_assert] = ACTIONS(526),
    [anon_sym_static_assert] = ACTIONS(526),
    [anon_sym_forward] = ACTIONS(526),
    [anon_sym_native] = ACTIONS(526),
    [anon_sym_const] = ACTIONS(526),
    [anon_sym_public] = ACTIONS(526),
    [anon_sym_stock] = ACTIONS(526),
    [anon_sym_static] = ACTIONS(526),
    [anon_sym_new] = ACTIONS(526),
    [anon_sym_decl] = ACTIONS(526),
    [anon_sym_enum] = ACTIONS(526),
    [anon_sym_RBRACE] = ACTIONS(528),
    [anon_sym_struct] = ACTIONS(526),
    [anon_sym_typedef] = ACTIONS(526),
    [anon_sym_typeset] = ACTIONS(526),
    [anon_sym_funcenum] = ACTIONS(526),
    [anon_sym_functag] = ACTIONS(526),
    [anon_sym_methodmap] = ACTIONS(526),
    [anon_sym_void] = ACTIONS(526),
    [anon_sym_bool] = ACTIONS(526),
    [anon_sym_int] = ACTIONS(526),
    [anon_sym_float] = ACTIONS(526),
    [anon_sym_char] = ACTIONS(526),
    [anon_sym__] = ACTIONS(526),
    [anon_sym_Float] = ACTIONS(526),
    [anon_sym_String] = ACTIONS(526),
    [sym_any_type] = ACTIONS(526),
    [anon_sym_while] = ACTIONS(526),
    [anon_sym_else] = ACTIONS(526),
    [anon_sym_case] = ACTIONS(526),
    [anon_sym_default] = ACTIONS(526),
    [anon_sym_SEMI] = ACTIONS(528),
    [anon_sym_DOT] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(634),
    [anon_sym_DASH_DASH] = ACTIONS(636),
    [anon_sym_PLUS_PLUS] = ACTIONS(636),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(528),
  },
  [201] = {
    [sym_preproc_include] = STATE(201),
    [sym_preproc_tryinclude] = STATE(201),
    [sym_preproc_macro] = STATE(201),
    [sym_preproc_define] = STATE(201),
    [sym_preproc_undefine] = STATE(201),
    [sym_preproc_if] = STATE(201),
    [sym_preproc_elseif] = STATE(201),
    [sym_preproc_assert] = STATE(201),
    [sym_preproc_pragma] = STATE(201),
    [sym_preproc_error] = STATE(201),
    [sym_preproc_warning] = STATE(201),
    [ts_builtin_sym_end] = ACTIONS(584),
    [sym_identifier] = ACTIONS(582),
    [anon_sym_DASH] = ACTIONS(582),
    [anon_sym_PLUS] = ACTIONS(582),
    [anon_sym_AMP] = ACTIONS(582),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(584),
    [anon_sym_STAR] = ACTIONS(584),
    [anon_sym_SLASH] = ACTIONS(582),
    [anon_sym_PERCENT] = ACTIONS(584),
    [anon_sym_PIPE_PIPE] = ACTIONS(584),
    [anon_sym_AMP_AMP] = ACTIONS(584),
    [anon_sym_PIPE] = ACTIONS(582),
    [anon_sym_CARET] = ACTIONS(584),
    [anon_sym_EQ_EQ] = ACTIONS(584),
    [anon_sym_BANG_EQ] = ACTIONS(584),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(584),
    [anon_sym_LT_EQ] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_LT] = ACTIONS(584),
    [anon_sym_GT_GT] = ACTIONS(582),
    [anon_sym_GT_GT_GT] = ACTIONS(584),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(584),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(584),
    [anon_sym_assert] = ACTIONS(582),
    [anon_sym_static_assert] = ACTIONS(582),
    [anon_sym_forward] = ACTIONS(582),
    [anon_sym_native] = ACTIONS(582),
    [anon_sym_const] = ACTIONS(582),
    [anon_sym_public] = ACTIONS(582),
    [anon_sym_stock] = ACTIONS(582),
    [anon_sym_static] = ACTIONS(582),
    [anon_sym_new] = ACTIONS(582),
    [anon_sym_decl] = ACTIONS(582),
    [anon_sym_enum] = ACTIONS(582),
    [anon_sym_RBRACE] = ACTIONS(584),
    [anon_sym_struct] = ACTIONS(582),
    [anon_sym_typedef] = ACTIONS(582),
    [anon_sym_typeset] = ACTIONS(582),
    [anon_sym_funcenum] = ACTIONS(582),
    [anon_sym_functag] = ACTIONS(582),
    [anon_sym_methodmap] = ACTIONS(582),
    [anon_sym_void] = ACTIONS(582),
    [anon_sym_bool] = ACTIONS(582),
    [anon_sym_int] = ACTIONS(582),
    [anon_sym_float] = ACTIONS(582),
    [anon_sym_char] = ACTIONS(582),
    [anon_sym__] = ACTIONS(582),
    [anon_sym_Float] = ACTIONS(582),
    [anon_sym_String] = ACTIONS(582),
    [sym_any_type] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_case] = ACTIONS(582),
    [anon_sym_default] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(584),
    [anon_sym_DOT] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(584),
    [anon_sym_DASH_DASH] = ACTIONS(584),
    [anon_sym_PLUS_PLUS] = ACTIONS(584),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(584),
  },
  [202] = {
    [sym_preproc_include] = STATE(202),
    [sym_preproc_tryinclude] = STATE(202),
    [sym_preproc_macro] = STATE(202),
    [sym_preproc_define] = STATE(202),
    [sym_preproc_undefine] = STATE(202),
    [sym_preproc_if] = STATE(202),
    [sym_preproc_elseif] = STATE(202),
    [sym_preproc_assert] = STATE(202),
    [sym_preproc_pragma] = STATE(202),
    [sym_preproc_error] = STATE(202),
    [sym_preproc_warning] = STATE(202),
    [ts_builtin_sym_end] = ACTIONS(588),
    [sym_identifier] = ACTIONS(586),
    [anon_sym_DASH] = ACTIONS(586),
    [anon_sym_PLUS] = ACTIONS(586),
    [anon_sym_AMP] = ACTIONS(586),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(588),
    [anon_sym_STAR] = ACTIONS(588),
    [anon_sym_SLASH] = ACTIONS(586),
    [anon_sym_PERCENT] = ACTIONS(588),
    [anon_sym_PIPE_PIPE] = ACTIONS(588),
    [anon_sym_AMP_AMP] = ACTIONS(588),
    [anon_sym_PIPE] = ACTIONS(586),
    [anon_sym_CARET] = ACTIONS(588),
    [anon_sym_EQ_EQ] = ACTIONS(588),
    [anon_sym_BANG_EQ] = ACTIONS(588),
    [anon_sym_GT] = ACTIONS(586),
    [anon_sym_GT_EQ] = ACTIONS(588),
    [anon_sym_LT_EQ] = ACTIONS(588),
    [anon_sym_LT] = ACTIONS(586),
    [anon_sym_LT_LT] = ACTIONS(588),
    [anon_sym_GT_GT] = ACTIONS(586),
    [anon_sym_GT_GT_GT] = ACTIONS(588),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(588),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(588),
    [anon_sym_assert] = ACTIONS(586),
    [anon_sym_static_assert] = ACTIONS(586),
    [anon_sym_forward] = ACTIONS(586),
    [anon_sym_native] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(586),
    [anon_sym_public] = ACTIONS(586),
    [anon_sym_stock] = ACTIONS(586),
    [anon_sym_static] = ACTIONS(586),
    [anon_sym_new] = ACTIONS(586),
    [anon_sym_decl] = ACTIONS(586),
    [anon_sym_enum] = ACTIONS(586),
    [anon_sym_RBRACE] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(586),
    [anon_sym_typedef] = ACTIONS(586),
    [anon_sym_typeset] = ACTIONS(586),
    [anon_sym_funcenum] = ACTIONS(586),
    [anon_sym_functag] = ACTIONS(586),
    [anon_sym_methodmap] = ACTIONS(586),
    [anon_sym_void] = ACTIONS(586),
    [anon_sym_bool] = ACTIONS(586),
    [anon_sym_int] = ACTIONS(586),
    [anon_sym_float] = ACTIONS(586),
    [anon_sym_char] = ACTIONS(586),
    [anon_sym__] = ACTIONS(586),
    [anon_sym_Float] = ACTIONS(586),
    [anon_sym_String] = ACTIONS(586),
    [sym_any_type] = ACTIONS(586),
    [anon_sym_while] = ACTIONS(586),
    [anon_sym_else] = ACTIONS(586),
    [anon_sym_case] = ACTIONS(586),
    [anon_sym_default] = ACTIONS(586),
    [anon_sym_SEMI] = ACTIONS(588),
    [anon_sym_DOT] = ACTIONS(586),
    [anon_sym_QMARK] = ACTIONS(588),
    [anon_sym_DASH_DASH] = ACTIONS(588),
    [anon_sym_PLUS_PLUS] = ACTIONS(588),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(588),
  },
  [203] = {
    [sym_preproc_include] = STATE(203),
    [sym_preproc_tryinclude] = STATE(203),
    [sym_preproc_macro] = STATE(203),
    [sym_preproc_define] = STATE(203),
    [sym_preproc_undefine] = STATE(203),
    [sym_preproc_if] = STATE(203),
    [sym_preproc_elseif] = STATE(203),
    [sym_preproc_assert] = STATE(203),
    [sym_preproc_pragma] = STATE(203),
    [sym_preproc_error] = STATE(203),
    [sym_preproc_warning] = STATE(203),
    [ts_builtin_sym_end] = ACTIONS(127),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(127),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(127),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(127),
    [anon_sym_assert] = ACTIONS(123),
    [anon_sym_static_assert] = ACTIONS(123),
    [anon_sym_forward] = ACTIONS(123),
    [anon_sym_native] = ACTIONS(123),
    [anon_sym_const] = ACTIONS(123),
    [anon_sym_public] = ACTIONS(123),
    [anon_sym_stock] = ACTIONS(123),
    [anon_sym_static] = ACTIONS(123),
    [anon_sym_new] = ACTIONS(123),
    [anon_sym_decl] = ACTIONS(123),
    [anon_sym_enum] = ACTIONS(123),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_struct] = ACTIONS(123),
    [anon_sym_typedef] = ACTIONS(123),
    [anon_sym_typeset] = ACTIONS(123),
    [anon_sym_funcenum] = ACTIONS(123),
    [anon_sym_functag] = ACTIONS(123),
    [anon_sym_methodmap] = ACTIONS(123),
    [anon_sym_void] = ACTIONS(123),
    [anon_sym_bool] = ACTIONS(123),
    [anon_sym_int] = ACTIONS(123),
    [anon_sym_float] = ACTIONS(123),
    [anon_sym_char] = ACTIONS(123),
    [anon_sym__] = ACTIONS(123),
    [anon_sym_Float] = ACTIONS(123),
    [anon_sym_String] = ACTIONS(123),
    [sym_any_type] = ACTIONS(123),
    [anon_sym_while] = ACTIONS(123),
    [anon_sym_else] = ACTIONS(123),
    [anon_sym_case] = ACTIONS(123),
    [anon_sym_default] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(127),
  },
  [204] = {
    [sym_preproc_include] = STATE(204),
    [sym_preproc_tryinclude] = STATE(204),
    [sym_preproc_macro] = STATE(204),
    [sym_preproc_define] = STATE(204),
    [sym_preproc_undefine] = STATE(204),
    [sym_preproc_if] = STATE(204),
    [sym_preproc_elseif] = STATE(204),
    [sym_preproc_assert] = STATE(204),
    [sym_preproc_pragma] = STATE(204),
    [sym_preproc_error] = STATE(204),
    [sym_preproc_warning] = STATE(204),
    [ts_builtin_sym_end] = ACTIONS(516),
    [sym_identifier] = ACTIONS(514),
    [anon_sym_DASH] = ACTIONS(514),
    [anon_sym_PLUS] = ACTIONS(514),
    [anon_sym_AMP] = ACTIONS(514),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(516),
    [anon_sym_STAR] = ACTIONS(516),
    [anon_sym_SLASH] = ACTIONS(514),
    [anon_sym_PERCENT] = ACTIONS(516),
    [anon_sym_PIPE_PIPE] = ACTIONS(516),
    [anon_sym_AMP_AMP] = ACTIONS(516),
    [anon_sym_PIPE] = ACTIONS(514),
    [anon_sym_CARET] = ACTIONS(516),
    [anon_sym_EQ_EQ] = ACTIONS(516),
    [anon_sym_BANG_EQ] = ACTIONS(516),
    [anon_sym_GT] = ACTIONS(514),
    [anon_sym_GT_EQ] = ACTIONS(516),
    [anon_sym_LT_EQ] = ACTIONS(516),
    [anon_sym_LT] = ACTIONS(514),
    [anon_sym_LT_LT] = ACTIONS(516),
    [anon_sym_GT_GT] = ACTIONS(514),
    [anon_sym_GT_GT_GT] = ACTIONS(516),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(516),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(516),
    [anon_sym_assert] = ACTIONS(514),
    [anon_sym_static_assert] = ACTIONS(514),
    [anon_sym_forward] = ACTIONS(514),
    [anon_sym_native] = ACTIONS(514),
    [anon_sym_const] = ACTIONS(514),
    [anon_sym_public] = ACTIONS(514),
    [anon_sym_stock] = ACTIONS(514),
    [anon_sym_static] = ACTIONS(514),
    [anon_sym_new] = ACTIONS(514),
    [anon_sym_decl] = ACTIONS(514),
    [anon_sym_enum] = ACTIONS(514),
    [anon_sym_RBRACE] = ACTIONS(516),
    [anon_sym_struct] = ACTIONS(514),
    [anon_sym_typedef] = ACTIONS(514),
    [anon_sym_typeset] = ACTIONS(514),
    [anon_sym_funcenum] = ACTIONS(514),
    [anon_sym_functag] = ACTIONS(514),
    [anon_sym_methodmap] = ACTIONS(514),
    [anon_sym_void] = ACTIONS(514),
    [anon_sym_bool] = ACTIONS(514),
    [anon_sym_int] = ACTIONS(514),
    [anon_sym_float] = ACTIONS(514),
    [anon_sym_char] = ACTIONS(514),
    [anon_sym__] = ACTIONS(514),
    [anon_sym_Float] = ACTIONS(514),
    [anon_sym_String] = ACTIONS(514),
    [sym_any_type] = ACTIONS(514),
    [anon_sym_while] = ACTIONS(514),
    [anon_sym_else] = ACTIONS(514),
    [anon_sym_case] = ACTIONS(514),
    [anon_sym_default] = ACTIONS(514),
    [anon_sym_SEMI] = ACTIONS(516),
    [anon_sym_DOT] = ACTIONS(514),
    [anon_sym_QMARK] = ACTIONS(516),
    [anon_sym_DASH_DASH] = ACTIONS(516),
    [anon_sym_PLUS_PLUS] = ACTIONS(516),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(516),
  },
  [205] = {
    [sym_preproc_include] = STATE(205),
    [sym_preproc_tryinclude] = STATE(205),
    [sym_preproc_macro] = STATE(205),
    [sym_preproc_define] = STATE(205),
    [sym_preproc_undefine] = STATE(205),
    [sym_preproc_if] = STATE(205),
    [sym_preproc_elseif] = STATE(205),
    [sym_preproc_assert] = STATE(205),
    [sym_preproc_pragma] = STATE(205),
    [sym_preproc_error] = STATE(205),
    [sym_preproc_warning] = STATE(205),
    [ts_builtin_sym_end] = ACTIONS(552),
    [sym_identifier] = ACTIONS(550),
    [anon_sym_DASH] = ACTIONS(550),
    [anon_sym_PLUS] = ACTIONS(550),
    [anon_sym_AMP] = ACTIONS(550),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(552),
    [anon_sym_STAR] = ACTIONS(552),
    [anon_sym_SLASH] = ACTIONS(550),
    [anon_sym_PERCENT] = ACTIONS(552),
    [anon_sym_PIPE_PIPE] = ACTIONS(552),
    [anon_sym_AMP_AMP] = ACTIONS(552),
    [anon_sym_PIPE] = ACTIONS(550),
    [anon_sym_CARET] = ACTIONS(552),
    [anon_sym_EQ_EQ] = ACTIONS(552),
    [anon_sym_BANG_EQ] = ACTIONS(552),
    [anon_sym_GT] = ACTIONS(550),
    [anon_sym_GT_EQ] = ACTIONS(552),
    [anon_sym_LT_EQ] = ACTIONS(552),
    [anon_sym_LT] = ACTIONS(550),
    [anon_sym_LT_LT] = ACTIONS(552),
    [anon_sym_GT_GT] = ACTIONS(550),
    [anon_sym_GT_GT_GT] = ACTIONS(552),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(552),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(552),
    [anon_sym_assert] = ACTIONS(550),
    [anon_sym_static_assert] = ACTIONS(550),
    [anon_sym_forward] = ACTIONS(550),
    [anon_sym_native] = ACTIONS(550),
    [anon_sym_const] = ACTIONS(550),
    [anon_sym_public] = ACTIONS(550),
    [anon_sym_stock] = ACTIONS(550),
    [anon_sym_static] = ACTIONS(550),
    [anon_sym_new] = ACTIONS(550),
    [anon_sym_decl] = ACTIONS(550),
    [anon_sym_enum] = ACTIONS(550),
    [anon_sym_RBRACE] = ACTIONS(552),
    [anon_sym_struct] = ACTIONS(550),
    [anon_sym_typedef] = ACTIONS(550),
    [anon_sym_typeset] = ACTIONS(550),
    [anon_sym_funcenum] = ACTIONS(550),
    [anon_sym_functag] = ACTIONS(550),
    [anon_sym_methodmap] = ACTIONS(550),
    [anon_sym_void] = ACTIONS(550),
    [anon_sym_bool] = ACTIONS(550),
    [anon_sym_int] = ACTIONS(550),
    [anon_sym_float] = ACTIONS(550),
    [anon_sym_char] = ACTIONS(550),
    [anon_sym__] = ACTIONS(550),
    [anon_sym_Float] = ACTIONS(550),
    [anon_sym_String] = ACTIONS(550),
    [sym_any_type] = ACTIONS(550),
    [anon_sym_while] = ACTIONS(550),
    [anon_sym_else] = ACTIONS(550),
    [anon_sym_case] = ACTIONS(550),
    [anon_sym_default] = ACTIONS(550),
    [anon_sym_SEMI] = ACTIONS(552),
    [anon_sym_DOT] = ACTIONS(550),
    [anon_sym_QMARK] = ACTIONS(552),
    [anon_sym_DASH_DASH] = ACTIONS(552),
    [anon_sym_PLUS_PLUS] = ACTIONS(552),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(552),
  },
  [206] = {
    [sym_preproc_include] = STATE(206),
    [sym_preproc_tryinclude] = STATE(206),
    [sym_preproc_macro] = STATE(206),
    [sym_preproc_define] = STATE(206),
    [sym_preproc_undefine] = STATE(206),
    [sym_preproc_if] = STATE(206),
    [sym_preproc_elseif] = STATE(206),
    [sym_preproc_assert] = STATE(206),
    [sym_preproc_pragma] = STATE(206),
    [sym_preproc_error] = STATE(206),
    [sym_preproc_warning] = STATE(206),
    [ts_builtin_sym_end] = ACTIONS(524),
    [sym_identifier] = ACTIONS(522),
    [anon_sym_DASH] = ACTIONS(522),
    [anon_sym_PLUS] = ACTIONS(522),
    [anon_sym_AMP] = ACTIONS(522),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(524),
    [anon_sym_STAR] = ACTIONS(524),
    [anon_sym_SLASH] = ACTIONS(522),
    [anon_sym_PERCENT] = ACTIONS(524),
    [anon_sym_PIPE_PIPE] = ACTIONS(524),
    [anon_sym_AMP_AMP] = ACTIONS(524),
    [anon_sym_PIPE] = ACTIONS(522),
    [anon_sym_CARET] = ACTIONS(524),
    [anon_sym_EQ_EQ] = ACTIONS(524),
    [anon_sym_BANG_EQ] = ACTIONS(524),
    [anon_sym_GT] = ACTIONS(522),
    [anon_sym_GT_EQ] = ACTIONS(524),
    [anon_sym_LT_EQ] = ACTIONS(524),
    [anon_sym_LT] = ACTIONS(522),
    [anon_sym_LT_LT] = ACTIONS(524),
    [anon_sym_GT_GT] = ACTIONS(522),
    [anon_sym_GT_GT_GT] = ACTIONS(524),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(524),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(524),
    [anon_sym_assert] = ACTIONS(522),
    [anon_sym_static_assert] = ACTIONS(522),
    [anon_sym_forward] = ACTIONS(522),
    [anon_sym_native] = ACTIONS(522),
    [anon_sym_const] = ACTIONS(522),
    [anon_sym_public] = ACTIONS(522),
    [anon_sym_stock] = ACTIONS(522),
    [anon_sym_static] = ACTIONS(522),
    [anon_sym_new] = ACTIONS(522),
    [anon_sym_decl] = ACTIONS(522),
    [anon_sym_enum] = ACTIONS(522),
    [anon_sym_RBRACE] = ACTIONS(524),
    [anon_sym_struct] = ACTIONS(522),
    [anon_sym_typedef] = ACTIONS(522),
    [anon_sym_typeset] = ACTIONS(522),
    [anon_sym_funcenum] = ACTIONS(522),
    [anon_sym_functag] = ACTIONS(522),
    [anon_sym_methodmap] = ACTIONS(522),
    [anon_sym_void] = ACTIONS(522),
    [anon_sym_bool] = ACTIONS(522),
    [anon_sym_int] = ACTIONS(522),
    [anon_sym_float] = ACTIONS(522),
    [anon_sym_char] = ACTIONS(522),
    [anon_sym__] = ACTIONS(522),
    [anon_sym_Float] = ACTIONS(522),
    [anon_sym_String] = ACTIONS(522),
    [sym_any_type] = ACTIONS(522),
    [anon_sym_while] = ACTIONS(522),
    [anon_sym_else] = ACTIONS(522),
    [anon_sym_case] = ACTIONS(522),
    [anon_sym_default] = ACTIONS(522),
    [anon_sym_SEMI] = ACTIONS(524),
    [anon_sym_DOT] = ACTIONS(522),
    [anon_sym_QMARK] = ACTIONS(524),
    [anon_sym_DASH_DASH] = ACTIONS(524),
    [anon_sym_PLUS_PLUS] = ACTIONS(524),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(524),
  },
  [207] = {
    [sym_preproc_include] = STATE(207),
    [sym_preproc_tryinclude] = STATE(207),
    [sym_preproc_macro] = STATE(207),
    [sym_preproc_define] = STATE(207),
    [sym_preproc_undefine] = STATE(207),
    [sym_preproc_if] = STATE(207),
    [sym_preproc_elseif] = STATE(207),
    [sym_preproc_assert] = STATE(207),
    [sym_preproc_pragma] = STATE(207),
    [sym_preproc_error] = STATE(207),
    [sym_preproc_warning] = STATE(207),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(526),
    [sym__semicolon] = STATE(578),
    [sym__expression] = STATE(163),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(521),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_RBRACE] = ACTIONS(364),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_while] = ACTIONS(368),
    [anon_sym_else] = ACTIONS(368),
    [anon_sym_case] = ACTIONS(368),
    [anon_sym_default] = ACTIONS(368),
    [anon_sym_SEMI] = ACTIONS(376),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(378),
  },
  [208] = {
    [sym_preproc_include] = STATE(208),
    [sym_preproc_tryinclude] = STATE(208),
    [sym_preproc_macro] = STATE(208),
    [sym_preproc_define] = STATE(208),
    [sym_preproc_undefine] = STATE(208),
    [sym_preproc_if] = STATE(208),
    [sym_preproc_elseif] = STATE(208),
    [sym_preproc_assert] = STATE(208),
    [sym_preproc_pragma] = STATE(208),
    [sym_preproc_error] = STATE(208),
    [sym_preproc_warning] = STATE(208),
    [sym_hardcoded_symbol] = STATE(653),
    [sym_assertion] = STATE(653),
    [sym_function_definition] = STATE(653),
    [sym_function_declaration] = STATE(653),
    [sym_function_declaration_kind] = STATE(991),
    [sym_alias_declaration] = STATE(653),
    [sym_alias_assignment] = STATE(653),
    [sym_global_variable_declaration] = STATE(653),
    [sym_variable_storage_class] = STATE(984),
    [sym_visibility] = STATE(979),
    [sym_old_global_variable_declaration] = STATE(653),
    [sym_old_variable_declaration] = STATE(1144),
    [sym_enum] = STATE(653),
    [sym_enum_struct] = STATE(653),
    [sym_typedef] = STATE(653),
    [sym_typeset] = STATE(653),
    [sym_funcenum] = STATE(653),
    [sym_functag] = STATE(653),
    [sym_methodmap] = STATE(653),
    [sym_struct] = STATE(653),
    [sym_struct_declaration] = STATE(653),
    [sym_type] = STATE(1149),
    [sym_old_type] = STATE(1386),
    [sym_builtin_type] = STATE(1269),
    [sym_old_builtin_type] = STATE(1579),
    [aux_sym_source_file_repeat1] = STATE(209),
    [ts_builtin_sym_end] = ACTIONS(668),
    [sym_identifier] = ACTIONS(29),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(31),
    [anon_sym_assert] = ACTIONS(33),
    [anon_sym_static_assert] = ACTIONS(33),
    [anon_sym_forward] = ACTIONS(35),
    [anon_sym_native] = ACTIONS(35),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_public] = ACTIONS(39),
    [anon_sym_stock] = ACTIONS(41),
    [anon_sym_static] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_decl] = ACTIONS(45),
    [anon_sym_enum] = ACTIONS(47),
    [anon_sym_struct] = ACTIONS(49),
    [anon_sym_typedef] = ACTIONS(51),
    [anon_sym_typeset] = ACTIONS(53),
    [anon_sym_funcenum] = ACTIONS(55),
    [anon_sym_functag] = ACTIONS(57),
    [anon_sym_methodmap] = ACTIONS(59),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_int] = ACTIONS(61),
    [anon_sym_float] = ACTIONS(61),
    [anon_sym_char] = ACTIONS(61),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(67),
    [sym_comment] = ACTIONS(19),
  },
  [209] = {
    [sym_preproc_include] = STATE(209),
    [sym_preproc_tryinclude] = STATE(209),
    [sym_preproc_macro] = STATE(209),
    [sym_preproc_define] = STATE(209),
    [sym_preproc_undefine] = STATE(209),
    [sym_preproc_if] = STATE(209),
    [sym_preproc_elseif] = STATE(209),
    [sym_preproc_assert] = STATE(209),
    [sym_preproc_pragma] = STATE(209),
    [sym_preproc_error] = STATE(209),
    [sym_preproc_warning] = STATE(209),
    [sym_hardcoded_symbol] = STATE(653),
    [sym_assertion] = STATE(653),
    [sym_function_definition] = STATE(653),
    [sym_function_declaration] = STATE(653),
    [sym_function_declaration_kind] = STATE(991),
    [sym_alias_declaration] = STATE(653),
    [sym_alias_assignment] = STATE(653),
    [sym_global_variable_declaration] = STATE(653),
    [sym_variable_storage_class] = STATE(984),
    [sym_visibility] = STATE(979),
    [sym_old_global_variable_declaration] = STATE(653),
    [sym_old_variable_declaration] = STATE(1144),
    [sym_enum] = STATE(653),
    [sym_enum_struct] = STATE(653),
    [sym_typedef] = STATE(653),
    [sym_typeset] = STATE(653),
    [sym_funcenum] = STATE(653),
    [sym_functag] = STATE(653),
    [sym_methodmap] = STATE(653),
    [sym_struct] = STATE(653),
    [sym_struct_declaration] = STATE(653),
    [sym_type] = STATE(1149),
    [sym_old_type] = STATE(1386),
    [sym_builtin_type] = STATE(1269),
    [sym_old_builtin_type] = STATE(1579),
    [aux_sym_source_file_repeat1] = STATE(209),
    [ts_builtin_sym_end] = ACTIONS(670),
    [sym_identifier] = ACTIONS(672),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(675),
    [anon_sym_assert] = ACTIONS(678),
    [anon_sym_static_assert] = ACTIONS(678),
    [anon_sym_forward] = ACTIONS(681),
    [anon_sym_native] = ACTIONS(681),
    [anon_sym_const] = ACTIONS(684),
    [anon_sym_public] = ACTIONS(687),
    [anon_sym_stock] = ACTIONS(690),
    [anon_sym_static] = ACTIONS(693),
    [anon_sym_new] = ACTIONS(696),
    [anon_sym_decl] = ACTIONS(696),
    [anon_sym_enum] = ACTIONS(699),
    [anon_sym_struct] = ACTIONS(702),
    [anon_sym_typedef] = ACTIONS(705),
    [anon_sym_typeset] = ACTIONS(708),
    [anon_sym_funcenum] = ACTIONS(711),
    [anon_sym_functag] = ACTIONS(714),
    [anon_sym_methodmap] = ACTIONS(717),
    [anon_sym_void] = ACTIONS(720),
    [anon_sym_bool] = ACTIONS(723),
    [anon_sym_int] = ACTIONS(720),
    [anon_sym_float] = ACTIONS(720),
    [anon_sym_char] = ACTIONS(720),
    [anon_sym__] = ACTIONS(726),
    [anon_sym_Float] = ACTIONS(726),
    [anon_sym_String] = ACTIONS(726),
    [sym_any_type] = ACTIONS(729),
    [sym_comment] = ACTIONS(19),
  },
  [210] = {
    [sym__preproc_expression] = STATE(972),
    [sym_preproc_parenthesized_expression] = STATE(929),
    [sym_preproc_unary_expression] = STATE(929),
    [sym_preproc_binary_expression] = STATE(929),
    [sym_preproc_include] = STATE(210),
    [sym_preproc_tryinclude] = STATE(210),
    [sym_preproc_macro] = STATE(210),
    [sym_preproc_define] = STATE(210),
    [sym_preproc_undefine] = STATE(210),
    [sym_preproc_if] = STATE(210),
    [sym_preproc_elseif] = STATE(210),
    [sym_preproc_assert] = STATE(210),
    [sym_preproc_defined_condition] = STATE(929),
    [sym_preproc_pragma] = STATE(210),
    [sym_preproc_error] = STATE(210),
    [sym_preproc_warning] = STATE(210),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(801),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1471),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(827),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(734),
    [anon_sym_BANG] = ACTIONS(736),
    [anon_sym_TILDE] = ACTIONS(736),
    [anon_sym_DASH] = ACTIONS(738),
    [anon_sym_PLUS] = ACTIONS(738),
    [anon_sym_AMP] = ACTIONS(736),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [anon_sym_defined] = ACTIONS(77),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [211] = {
    [sym_preproc_include] = STATE(211),
    [sym_preproc_tryinclude] = STATE(211),
    [sym_preproc_macro] = STATE(211),
    [sym_preproc_define] = STATE(211),
    [sym_preproc_undefine] = STATE(211),
    [sym_preproc_if] = STATE(211),
    [sym_preproc_elseif] = STATE(211),
    [sym_preproc_assert] = STATE(211),
    [sym_preproc_pragma] = STATE(211),
    [sym_preproc_error] = STATE(211),
    [sym_preproc_warning] = STATE(211),
    [sym_dimension] = STATE(230),
    [sym_fixed_dimension] = STATE(230),
    [aux_sym_parameter_declaration_repeat1] = STATE(213),
    [sym_identifier] = ACTIONS(742),
    [anon_sym_LPAREN] = ACTIONS(744),
    [anon_sym_BANG] = ACTIONS(744),
    [anon_sym_TILDE] = ACTIONS(744),
    [anon_sym_DASH] = ACTIONS(742),
    [anon_sym_PLUS] = ACTIONS(742),
    [anon_sym_AMP] = ACTIONS(744),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(744),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(746),
    [anon_sym_const] = ACTIONS(742),
    [anon_sym_public] = ACTIONS(742),
    [anon_sym_stock] = ACTIONS(742),
    [anon_sym_static] = ACTIONS(742),
    [anon_sym_new] = ACTIONS(742),
    [anon_sym_decl] = ACTIONS(742),
    [anon_sym_LBRACE] = ACTIONS(744),
    [anon_sym_RBRACE] = ACTIONS(744),
    [anon_sym_LBRACK] = ACTIONS(748),
    [anon_sym_void] = ACTIONS(742),
    [anon_sym_bool] = ACTIONS(742),
    [anon_sym_int] = ACTIONS(742),
    [anon_sym_float] = ACTIONS(742),
    [anon_sym_char] = ACTIONS(742),
    [anon_sym__] = ACTIONS(742),
    [anon_sym_Float] = ACTIONS(742),
    [anon_sym_String] = ACTIONS(742),
    [sym_any_type] = ACTIONS(742),
    [anon_sym_for] = ACTIONS(742),
    [anon_sym_while] = ACTIONS(742),
    [anon_sym_do] = ACTIONS(742),
    [anon_sym_break] = ACTIONS(742),
    [anon_sym_continue] = ACTIONS(742),
    [anon_sym_if] = ACTIONS(742),
    [anon_sym_else] = ACTIONS(742),
    [anon_sym_switch] = ACTIONS(742),
    [anon_sym_return] = ACTIONS(742),
    [anon_sym_delete] = ACTIONS(742),
    [anon_sym_SEMI] = ACTIONS(744),
    [anon_sym_DASH_DASH] = ACTIONS(744),
    [anon_sym_PLUS_PLUS] = ACTIONS(744),
    [anon_sym_sizeof] = ACTIONS(742),
    [anon_sym_view_as] = ACTIONS(742),
    [sym_int_literal] = ACTIONS(742),
    [sym_float_literal] = ACTIONS(744),
    [anon_sym_SQUOTE] = ACTIONS(744),
    [anon_sym_DQUOTE] = ACTIONS(744),
    [sym_bool_literal] = ACTIONS(742),
    [sym_null] = ACTIONS(742),
    [sym_this] = ACTIONS(742),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(744),
  },
  [212] = {
    [sym__preproc_expression] = STATE(972),
    [sym_preproc_parenthesized_expression] = STATE(929),
    [sym_preproc_unary_expression] = STATE(929),
    [sym_preproc_binary_expression] = STATE(929),
    [sym_preproc_include] = STATE(212),
    [sym_preproc_tryinclude] = STATE(212),
    [sym_preproc_macro] = STATE(212),
    [sym_preproc_define] = STATE(212),
    [sym_preproc_undefine] = STATE(212),
    [sym_preproc_if] = STATE(212),
    [sym_preproc_elseif] = STATE(212),
    [sym_preproc_assert] = STATE(212),
    [sym_preproc_defined_condition] = STATE(929),
    [sym_preproc_pragma] = STATE(212),
    [sym_preproc_error] = STATE(212),
    [sym_preproc_warning] = STATE(212),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(828),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1479),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(827),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(734),
    [anon_sym_BANG] = ACTIONS(736),
    [anon_sym_TILDE] = ACTIONS(736),
    [anon_sym_DASH] = ACTIONS(738),
    [anon_sym_PLUS] = ACTIONS(738),
    [anon_sym_AMP] = ACTIONS(736),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [anon_sym_defined] = ACTIONS(77),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [213] = {
    [sym_preproc_include] = STATE(213),
    [sym_preproc_tryinclude] = STATE(213),
    [sym_preproc_macro] = STATE(213),
    [sym_preproc_define] = STATE(213),
    [sym_preproc_undefine] = STATE(213),
    [sym_preproc_if] = STATE(213),
    [sym_preproc_elseif] = STATE(213),
    [sym_preproc_assert] = STATE(213),
    [sym_preproc_pragma] = STATE(213),
    [sym_preproc_error] = STATE(213),
    [sym_preproc_warning] = STATE(213),
    [sym_dimension] = STATE(230),
    [sym_fixed_dimension] = STATE(230),
    [aux_sym_parameter_declaration_repeat1] = STATE(214),
    [sym_identifier] = ACTIONS(750),
    [anon_sym_LPAREN] = ACTIONS(752),
    [anon_sym_BANG] = ACTIONS(752),
    [anon_sym_TILDE] = ACTIONS(752),
    [anon_sym_DASH] = ACTIONS(750),
    [anon_sym_PLUS] = ACTIONS(750),
    [anon_sym_AMP] = ACTIONS(752),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(752),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(754),
    [anon_sym_const] = ACTIONS(750),
    [anon_sym_public] = ACTIONS(750),
    [anon_sym_stock] = ACTIONS(750),
    [anon_sym_static] = ACTIONS(750),
    [anon_sym_new] = ACTIONS(750),
    [anon_sym_decl] = ACTIONS(750),
    [anon_sym_LBRACE] = ACTIONS(752),
    [anon_sym_RBRACE] = ACTIONS(752),
    [anon_sym_LBRACK] = ACTIONS(748),
    [anon_sym_void] = ACTIONS(750),
    [anon_sym_bool] = ACTIONS(750),
    [anon_sym_int] = ACTIONS(750),
    [anon_sym_float] = ACTIONS(750),
    [anon_sym_char] = ACTIONS(750),
    [anon_sym__] = ACTIONS(750),
    [anon_sym_Float] = ACTIONS(750),
    [anon_sym_String] = ACTIONS(750),
    [sym_any_type] = ACTIONS(750),
    [anon_sym_for] = ACTIONS(750),
    [anon_sym_while] = ACTIONS(750),
    [anon_sym_do] = ACTIONS(750),
    [anon_sym_break] = ACTIONS(750),
    [anon_sym_continue] = ACTIONS(750),
    [anon_sym_if] = ACTIONS(750),
    [anon_sym_else] = ACTIONS(750),
    [anon_sym_switch] = ACTIONS(750),
    [anon_sym_return] = ACTIONS(750),
    [anon_sym_delete] = ACTIONS(750),
    [anon_sym_SEMI] = ACTIONS(752),
    [anon_sym_DASH_DASH] = ACTIONS(752),
    [anon_sym_PLUS_PLUS] = ACTIONS(752),
    [anon_sym_sizeof] = ACTIONS(750),
    [anon_sym_view_as] = ACTIONS(750),
    [sym_int_literal] = ACTIONS(750),
    [sym_float_literal] = ACTIONS(752),
    [anon_sym_SQUOTE] = ACTIONS(752),
    [anon_sym_DQUOTE] = ACTIONS(752),
    [sym_bool_literal] = ACTIONS(750),
    [sym_null] = ACTIONS(750),
    [sym_this] = ACTIONS(750),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(752),
  },
  [214] = {
    [sym_preproc_include] = STATE(214),
    [sym_preproc_tryinclude] = STATE(214),
    [sym_preproc_macro] = STATE(214),
    [sym_preproc_define] = STATE(214),
    [sym_preproc_undefine] = STATE(214),
    [sym_preproc_if] = STATE(214),
    [sym_preproc_elseif] = STATE(214),
    [sym_preproc_assert] = STATE(214),
    [sym_preproc_pragma] = STATE(214),
    [sym_preproc_error] = STATE(214),
    [sym_preproc_warning] = STATE(214),
    [sym_dimension] = STATE(230),
    [sym_fixed_dimension] = STATE(230),
    [aux_sym_parameter_declaration_repeat1] = STATE(214),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_LPAREN] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(758),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_AMP] = ACTIONS(758),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(758),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(758),
    [anon_sym_const] = ACTIONS(756),
    [anon_sym_public] = ACTIONS(756),
    [anon_sym_stock] = ACTIONS(756),
    [anon_sym_static] = ACTIONS(756),
    [anon_sym_new] = ACTIONS(756),
    [anon_sym_decl] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(758),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_LBRACK] = ACTIONS(760),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_bool] = ACTIONS(756),
    [anon_sym_int] = ACTIONS(756),
    [anon_sym_float] = ACTIONS(756),
    [anon_sym_char] = ACTIONS(756),
    [anon_sym__] = ACTIONS(756),
    [anon_sym_Float] = ACTIONS(756),
    [anon_sym_String] = ACTIONS(756),
    [sym_any_type] = ACTIONS(756),
    [anon_sym_for] = ACTIONS(756),
    [anon_sym_while] = ACTIONS(756),
    [anon_sym_do] = ACTIONS(756),
    [anon_sym_break] = ACTIONS(756),
    [anon_sym_continue] = ACTIONS(756),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_else] = ACTIONS(756),
    [anon_sym_switch] = ACTIONS(756),
    [anon_sym_return] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_sizeof] = ACTIONS(756),
    [anon_sym_view_as] = ACTIONS(756),
    [sym_int_literal] = ACTIONS(756),
    [sym_float_literal] = ACTIONS(758),
    [anon_sym_SQUOTE] = ACTIONS(758),
    [anon_sym_DQUOTE] = ACTIONS(758),
    [sym_bool_literal] = ACTIONS(756),
    [sym_null] = ACTIONS(756),
    [sym_this] = ACTIONS(756),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(758),
  },
  [215] = {
    [sym__preproc_expression] = STATE(934),
    [sym_preproc_parenthesized_expression] = STATE(929),
    [sym_preproc_unary_expression] = STATE(929),
    [sym_preproc_binary_expression] = STATE(929),
    [sym_preproc_include] = STATE(215),
    [sym_preproc_tryinclude] = STATE(215),
    [sym_preproc_macro] = STATE(215),
    [sym_preproc_define] = STATE(215),
    [sym_preproc_undefine] = STATE(215),
    [sym_preproc_if] = STATE(215),
    [sym_preproc_elseif] = STATE(215),
    [sym_preproc_assert] = STATE(215),
    [sym_preproc_defined_condition] = STATE(929),
    [sym_preproc_pragma] = STATE(215),
    [sym_preproc_error] = STATE(215),
    [sym_preproc_warning] = STATE(215),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(659),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(827),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(732),
    [anon_sym_LPAREN] = ACTIONS(734),
    [anon_sym_BANG] = ACTIONS(736),
    [anon_sym_TILDE] = ACTIONS(736),
    [anon_sym_DASH] = ACTIONS(738),
    [anon_sym_PLUS] = ACTIONS(738),
    [anon_sym_AMP] = ACTIONS(736),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [anon_sym_defined] = ACTIONS(77),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [216] = {
    [sym__preproc_expression] = STATE(934),
    [sym_preproc_parenthesized_expression] = STATE(929),
    [sym_preproc_unary_expression] = STATE(929),
    [sym_preproc_binary_expression] = STATE(929),
    [sym_preproc_include] = STATE(216),
    [sym_preproc_tryinclude] = STATE(216),
    [sym_preproc_macro] = STATE(216),
    [sym_preproc_define] = STATE(216),
    [sym_preproc_undefine] = STATE(216),
    [sym_preproc_if] = STATE(216),
    [sym_preproc_elseif] = STATE(216),
    [sym_preproc_assert] = STATE(216),
    [sym_preproc_defined_condition] = STATE(929),
    [sym_preproc_pragma] = STATE(216),
    [sym_preproc_error] = STATE(216),
    [sym_preproc_warning] = STATE(216),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(113),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(151),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(763),
    [anon_sym_LPAREN] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(75),
    [anon_sym_PLUS] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [anon_sym_defined] = ACTIONS(77),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [217] = {
    [sym_preproc_include] = STATE(217),
    [sym_preproc_tryinclude] = STATE(217),
    [sym_preproc_macro] = STATE(217),
    [sym_preproc_define] = STATE(217),
    [sym_preproc_undefine] = STATE(217),
    [sym_preproc_if] = STATE(217),
    [sym_preproc_elseif] = STATE(217),
    [sym_preproc_assert] = STATE(217),
    [sym_preproc_pragma] = STATE(217),
    [sym_preproc_error] = STATE(217),
    [sym_preproc_warning] = STATE(217),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(468),
    [aux_sym_global_variable_declaration_repeat1] = STATE(220),
    [sym_identifier] = ACTIONS(765),
    [anon_sym_LPAREN] = ACTIONS(767),
    [anon_sym_BANG] = ACTIONS(767),
    [anon_sym_TILDE] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(765),
    [anon_sym_PLUS] = ACTIONS(765),
    [anon_sym_AMP] = ACTIONS(767),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(769),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(765),
    [anon_sym_public] = ACTIONS(765),
    [anon_sym_stock] = ACTIONS(765),
    [anon_sym_static] = ACTIONS(765),
    [anon_sym_new] = ACTIONS(765),
    [anon_sym_decl] = ACTIONS(765),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_void] = ACTIONS(765),
    [anon_sym_bool] = ACTIONS(765),
    [anon_sym_int] = ACTIONS(765),
    [anon_sym_float] = ACTIONS(765),
    [anon_sym_char] = ACTIONS(765),
    [anon_sym__] = ACTIONS(765),
    [anon_sym_Float] = ACTIONS(765),
    [anon_sym_String] = ACTIONS(765),
    [sym_any_type] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(765),
    [anon_sym_while] = ACTIONS(765),
    [anon_sym_do] = ACTIONS(765),
    [anon_sym_break] = ACTIONS(765),
    [anon_sym_continue] = ACTIONS(765),
    [anon_sym_if] = ACTIONS(765),
    [anon_sym_else] = ACTIONS(765),
    [anon_sym_switch] = ACTIONS(765),
    [anon_sym_return] = ACTIONS(765),
    [anon_sym_delete] = ACTIONS(765),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(767),
    [anon_sym_PLUS_PLUS] = ACTIONS(767),
    [anon_sym_sizeof] = ACTIONS(765),
    [anon_sym_view_as] = ACTIONS(765),
    [sym_int_literal] = ACTIONS(765),
    [sym_float_literal] = ACTIONS(767),
    [anon_sym_SQUOTE] = ACTIONS(767),
    [anon_sym_DQUOTE] = ACTIONS(767),
    [sym_bool_literal] = ACTIONS(765),
    [sym_null] = ACTIONS(765),
    [sym_this] = ACTIONS(765),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [218] = {
    [sym_preproc_include] = STATE(218),
    [sym_preproc_tryinclude] = STATE(218),
    [sym_preproc_macro] = STATE(218),
    [sym_preproc_define] = STATE(218),
    [sym_preproc_undefine] = STATE(218),
    [sym_preproc_if] = STATE(218),
    [sym_preproc_elseif] = STATE(218),
    [sym_preproc_assert] = STATE(218),
    [sym_preproc_pragma] = STATE(218),
    [sym_preproc_error] = STATE(218),
    [sym_preproc_warning] = STATE(218),
    [sym_fixed_dimension] = STATE(248),
    [aux_sym_dynamic_array_repeat1] = STATE(218),
    [sym_identifier] = ACTIONS(396),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym_BANG] = ACTIONS(398),
    [anon_sym_TILDE] = ACTIONS(398),
    [anon_sym_DASH] = ACTIONS(396),
    [anon_sym_PLUS] = ACTIONS(396),
    [anon_sym_AMP] = ACTIONS(398),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(398),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(396),
    [anon_sym_public] = ACTIONS(396),
    [anon_sym_stock] = ACTIONS(396),
    [anon_sym_static] = ACTIONS(396),
    [anon_sym_new] = ACTIONS(396),
    [anon_sym_decl] = ACTIONS(396),
    [anon_sym_LBRACE] = ACTIONS(398),
    [anon_sym_RBRACE] = ACTIONS(398),
    [anon_sym_LBRACK] = ACTIONS(771),
    [anon_sym_void] = ACTIONS(396),
    [anon_sym_bool] = ACTIONS(396),
    [anon_sym_int] = ACTIONS(396),
    [anon_sym_float] = ACTIONS(396),
    [anon_sym_char] = ACTIONS(396),
    [anon_sym__] = ACTIONS(396),
    [anon_sym_Float] = ACTIONS(396),
    [anon_sym_String] = ACTIONS(396),
    [sym_any_type] = ACTIONS(396),
    [anon_sym_for] = ACTIONS(396),
    [anon_sym_while] = ACTIONS(396),
    [anon_sym_do] = ACTIONS(396),
    [anon_sym_break] = ACTIONS(396),
    [anon_sym_continue] = ACTIONS(396),
    [anon_sym_if] = ACTIONS(396),
    [anon_sym_else] = ACTIONS(396),
    [anon_sym_switch] = ACTIONS(396),
    [anon_sym_return] = ACTIONS(396),
    [anon_sym_delete] = ACTIONS(396),
    [anon_sym_SEMI] = ACTIONS(398),
    [anon_sym_DASH_DASH] = ACTIONS(398),
    [anon_sym_PLUS_PLUS] = ACTIONS(398),
    [anon_sym_sizeof] = ACTIONS(396),
    [anon_sym_view_as] = ACTIONS(396),
    [sym_int_literal] = ACTIONS(396),
    [sym_float_literal] = ACTIONS(398),
    [anon_sym_SQUOTE] = ACTIONS(398),
    [anon_sym_DQUOTE] = ACTIONS(398),
    [sym_bool_literal] = ACTIONS(396),
    [sym_null] = ACTIONS(396),
    [sym_this] = ACTIONS(396),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(398),
  },
  [219] = {
    [sym_preproc_include] = STATE(219),
    [sym_preproc_tryinclude] = STATE(219),
    [sym_preproc_macro] = STATE(219),
    [sym_preproc_define] = STATE(219),
    [sym_preproc_undefine] = STATE(219),
    [sym_preproc_if] = STATE(219),
    [sym_preproc_elseif] = STATE(219),
    [sym_preproc_assert] = STATE(219),
    [sym_preproc_pragma] = STATE(219),
    [sym_preproc_error] = STATE(219),
    [sym_preproc_warning] = STATE(219),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(465),
    [aux_sym_global_variable_declaration_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(774),
    [anon_sym_LPAREN] = ACTIONS(776),
    [anon_sym_BANG] = ACTIONS(776),
    [anon_sym_TILDE] = ACTIONS(776),
    [anon_sym_DASH] = ACTIONS(774),
    [anon_sym_PLUS] = ACTIONS(774),
    [anon_sym_AMP] = ACTIONS(776),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(769),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(774),
    [anon_sym_public] = ACTIONS(774),
    [anon_sym_stock] = ACTIONS(774),
    [anon_sym_static] = ACTIONS(774),
    [anon_sym_new] = ACTIONS(774),
    [anon_sym_decl] = ACTIONS(774),
    [anon_sym_LBRACE] = ACTIONS(776),
    [anon_sym_RBRACE] = ACTIONS(776),
    [anon_sym_void] = ACTIONS(774),
    [anon_sym_bool] = ACTIONS(774),
    [anon_sym_int] = ACTIONS(774),
    [anon_sym_float] = ACTIONS(774),
    [anon_sym_char] = ACTIONS(774),
    [anon_sym__] = ACTIONS(774),
    [anon_sym_Float] = ACTIONS(774),
    [anon_sym_String] = ACTIONS(774),
    [sym_any_type] = ACTIONS(774),
    [anon_sym_for] = ACTIONS(774),
    [anon_sym_while] = ACTIONS(774),
    [anon_sym_do] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(774),
    [anon_sym_continue] = ACTIONS(774),
    [anon_sym_if] = ACTIONS(774),
    [anon_sym_else] = ACTIONS(774),
    [anon_sym_switch] = ACTIONS(774),
    [anon_sym_return] = ACTIONS(774),
    [anon_sym_delete] = ACTIONS(774),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(776),
    [anon_sym_PLUS_PLUS] = ACTIONS(776),
    [anon_sym_sizeof] = ACTIONS(774),
    [anon_sym_view_as] = ACTIONS(774),
    [sym_int_literal] = ACTIONS(774),
    [sym_float_literal] = ACTIONS(776),
    [anon_sym_SQUOTE] = ACTIONS(776),
    [anon_sym_DQUOTE] = ACTIONS(776),
    [sym_bool_literal] = ACTIONS(774),
    [sym_null] = ACTIONS(774),
    [sym_this] = ACTIONS(774),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [220] = {
    [sym_preproc_include] = STATE(220),
    [sym_preproc_tryinclude] = STATE(220),
    [sym_preproc_macro] = STATE(220),
    [sym_preproc_define] = STATE(220),
    [sym_preproc_undefine] = STATE(220),
    [sym_preproc_if] = STATE(220),
    [sym_preproc_elseif] = STATE(220),
    [sym_preproc_assert] = STATE(220),
    [sym_preproc_pragma] = STATE(220),
    [sym_preproc_error] = STATE(220),
    [sym_preproc_warning] = STATE(220),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(472),
    [aux_sym_global_variable_declaration_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(780),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_AMP] = ACTIONS(780),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(769),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(778),
    [anon_sym_public] = ACTIONS(778),
    [anon_sym_stock] = ACTIONS(778),
    [anon_sym_static] = ACTIONS(778),
    [anon_sym_new] = ACTIONS(778),
    [anon_sym_decl] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_bool] = ACTIONS(778),
    [anon_sym_int] = ACTIONS(778),
    [anon_sym_float] = ACTIONS(778),
    [anon_sym_char] = ACTIONS(778),
    [anon_sym__] = ACTIONS(778),
    [anon_sym_Float] = ACTIONS(778),
    [anon_sym_String] = ACTIONS(778),
    [sym_any_type] = ACTIONS(778),
    [anon_sym_for] = ACTIONS(778),
    [anon_sym_while] = ACTIONS(778),
    [anon_sym_do] = ACTIONS(778),
    [anon_sym_break] = ACTIONS(778),
    [anon_sym_continue] = ACTIONS(778),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_else] = ACTIONS(778),
    [anon_sym_switch] = ACTIONS(778),
    [anon_sym_return] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_sizeof] = ACTIONS(778),
    [anon_sym_view_as] = ACTIONS(778),
    [sym_int_literal] = ACTIONS(778),
    [sym_float_literal] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [sym_bool_literal] = ACTIONS(778),
    [sym_null] = ACTIONS(778),
    [sym_this] = ACTIONS(778),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [221] = {
    [sym_preproc_include] = STATE(221),
    [sym_preproc_tryinclude] = STATE(221),
    [sym_preproc_macro] = STATE(221),
    [sym_preproc_define] = STATE(221),
    [sym_preproc_undefine] = STATE(221),
    [sym_preproc_if] = STATE(221),
    [sym_preproc_elseif] = STATE(221),
    [sym_preproc_assert] = STATE(221),
    [sym_preproc_pragma] = STATE(221),
    [sym_preproc_error] = STATE(221),
    [sym_preproc_warning] = STATE(221),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(442),
    [aux_sym_global_variable_declaration_repeat1] = STATE(224),
    [sym_identifier] = ACTIONS(782),
    [anon_sym_LPAREN] = ACTIONS(784),
    [anon_sym_BANG] = ACTIONS(784),
    [anon_sym_TILDE] = ACTIONS(784),
    [anon_sym_DASH] = ACTIONS(782),
    [anon_sym_PLUS] = ACTIONS(782),
    [anon_sym_AMP] = ACTIONS(784),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(769),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(782),
    [anon_sym_public] = ACTIONS(782),
    [anon_sym_stock] = ACTIONS(782),
    [anon_sym_static] = ACTIONS(782),
    [anon_sym_new] = ACTIONS(782),
    [anon_sym_decl] = ACTIONS(782),
    [anon_sym_LBRACE] = ACTIONS(784),
    [anon_sym_RBRACE] = ACTIONS(784),
    [anon_sym_void] = ACTIONS(782),
    [anon_sym_bool] = ACTIONS(782),
    [anon_sym_int] = ACTIONS(782),
    [anon_sym_float] = ACTIONS(782),
    [anon_sym_char] = ACTIONS(782),
    [anon_sym__] = ACTIONS(782),
    [anon_sym_Float] = ACTIONS(782),
    [anon_sym_String] = ACTIONS(782),
    [sym_any_type] = ACTIONS(782),
    [anon_sym_for] = ACTIONS(782),
    [anon_sym_while] = ACTIONS(782),
    [anon_sym_do] = ACTIONS(782),
    [anon_sym_break] = ACTIONS(782),
    [anon_sym_continue] = ACTIONS(782),
    [anon_sym_if] = ACTIONS(782),
    [anon_sym_else] = ACTIONS(782),
    [anon_sym_switch] = ACTIONS(782),
    [anon_sym_return] = ACTIONS(782),
    [anon_sym_delete] = ACTIONS(782),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(784),
    [anon_sym_PLUS_PLUS] = ACTIONS(784),
    [anon_sym_sizeof] = ACTIONS(782),
    [anon_sym_view_as] = ACTIONS(782),
    [sym_int_literal] = ACTIONS(782),
    [sym_float_literal] = ACTIONS(784),
    [anon_sym_SQUOTE] = ACTIONS(784),
    [anon_sym_DQUOTE] = ACTIONS(784),
    [sym_bool_literal] = ACTIONS(782),
    [sym_null] = ACTIONS(782),
    [sym_this] = ACTIONS(782),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [222] = {
    [sym_preproc_include] = STATE(222),
    [sym_preproc_tryinclude] = STATE(222),
    [sym_preproc_macro] = STATE(222),
    [sym_preproc_define] = STATE(222),
    [sym_preproc_undefine] = STATE(222),
    [sym_preproc_if] = STATE(222),
    [sym_preproc_elseif] = STATE(222),
    [sym_preproc_assert] = STATE(222),
    [sym_preproc_pragma] = STATE(222),
    [sym_preproc_error] = STATE(222),
    [sym_preproc_warning] = STATE(222),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(471),
    [aux_sym_variable_declaration_statement_repeat1] = STATE(241),
    [sym_identifier] = ACTIONS(786),
    [anon_sym_LPAREN] = ACTIONS(788),
    [anon_sym_BANG] = ACTIONS(788),
    [anon_sym_TILDE] = ACTIONS(788),
    [anon_sym_DASH] = ACTIONS(786),
    [anon_sym_PLUS] = ACTIONS(786),
    [anon_sym_AMP] = ACTIONS(788),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(790),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(786),
    [anon_sym_public] = ACTIONS(786),
    [anon_sym_stock] = ACTIONS(786),
    [anon_sym_static] = ACTIONS(786),
    [anon_sym_new] = ACTIONS(786),
    [anon_sym_decl] = ACTIONS(786),
    [anon_sym_LBRACE] = ACTIONS(788),
    [anon_sym_RBRACE] = ACTIONS(788),
    [anon_sym_void] = ACTIONS(786),
    [anon_sym_bool] = ACTIONS(786),
    [anon_sym_int] = ACTIONS(786),
    [anon_sym_float] = ACTIONS(786),
    [anon_sym_char] = ACTIONS(786),
    [anon_sym__] = ACTIONS(786),
    [anon_sym_Float] = ACTIONS(786),
    [anon_sym_String] = ACTIONS(786),
    [sym_any_type] = ACTIONS(786),
    [anon_sym_for] = ACTIONS(786),
    [anon_sym_while] = ACTIONS(786),
    [anon_sym_do] = ACTIONS(786),
    [anon_sym_break] = ACTIONS(786),
    [anon_sym_continue] = ACTIONS(786),
    [anon_sym_if] = ACTIONS(786),
    [anon_sym_else] = ACTIONS(786),
    [anon_sym_switch] = ACTIONS(786),
    [anon_sym_return] = ACTIONS(786),
    [anon_sym_delete] = ACTIONS(786),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(788),
    [anon_sym_PLUS_PLUS] = ACTIONS(788),
    [anon_sym_sizeof] = ACTIONS(786),
    [anon_sym_view_as] = ACTIONS(786),
    [sym_int_literal] = ACTIONS(786),
    [sym_float_literal] = ACTIONS(788),
    [anon_sym_SQUOTE] = ACTIONS(788),
    [anon_sym_DQUOTE] = ACTIONS(788),
    [sym_bool_literal] = ACTIONS(786),
    [sym_null] = ACTIONS(786),
    [sym_this] = ACTIONS(786),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [223] = {
    [sym_preproc_include] = STATE(223),
    [sym_preproc_tryinclude] = STATE(223),
    [sym_preproc_macro] = STATE(223),
    [sym_preproc_define] = STATE(223),
    [sym_preproc_undefine] = STATE(223),
    [sym_preproc_if] = STATE(223),
    [sym_preproc_elseif] = STATE(223),
    [sym_preproc_assert] = STATE(223),
    [sym_preproc_pragma] = STATE(223),
    [sym_preproc_error] = STATE(223),
    [sym_preproc_warning] = STATE(223),
    [sym_call_arguments] = STATE(169),
    [sym_identifier] = ACTIONS(256),
    [anon_sym_LPAREN] = ACTIONS(333),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(355),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(357),
    [anon_sym_DASH_EQ] = ACTIONS(357),
    [anon_sym_STAR_EQ] = ACTIONS(357),
    [anon_sym_SLASH_EQ] = ACTIONS(357),
    [anon_sym_PIPE_EQ] = ACTIONS(357),
    [anon_sym_AMP_EQ] = ACTIONS(357),
    [anon_sym_CARET_EQ] = ACTIONS(357),
    [anon_sym_TILDE_EQ] = ACTIONS(357),
    [anon_sym_LT_LT_EQ] = ACTIONS(357),
    [anon_sym_GT_GT_EQ] = ACTIONS(357),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_while] = ACTIONS(244),
    [anon_sym_else] = ACTIONS(244),
    [anon_sym_case] = ACTIONS(244),
    [anon_sym_default] = ACTIONS(244),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(357),
    [anon_sym_PERCENT_EQ] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_COLON_COLON] = ACTIONS(337),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(246),
  },
  [224] = {
    [sym_preproc_include] = STATE(224),
    [sym_preproc_tryinclude] = STATE(224),
    [sym_preproc_macro] = STATE(224),
    [sym_preproc_define] = STATE(224),
    [sym_preproc_undefine] = STATE(224),
    [sym_preproc_if] = STATE(224),
    [sym_preproc_elseif] = STATE(224),
    [sym_preproc_assert] = STATE(224),
    [sym_preproc_pragma] = STATE(224),
    [sym_preproc_error] = STATE(224),
    [sym_preproc_warning] = STATE(224),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(453),
    [aux_sym_global_variable_declaration_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(792),
    [anon_sym_LPAREN] = ACTIONS(794),
    [anon_sym_BANG] = ACTIONS(794),
    [anon_sym_TILDE] = ACTIONS(794),
    [anon_sym_DASH] = ACTIONS(792),
    [anon_sym_PLUS] = ACTIONS(792),
    [anon_sym_AMP] = ACTIONS(794),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(769),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(792),
    [anon_sym_public] = ACTIONS(792),
    [anon_sym_stock] = ACTIONS(792),
    [anon_sym_static] = ACTIONS(792),
    [anon_sym_new] = ACTIONS(792),
    [anon_sym_decl] = ACTIONS(792),
    [anon_sym_LBRACE] = ACTIONS(794),
    [anon_sym_RBRACE] = ACTIONS(794),
    [anon_sym_void] = ACTIONS(792),
    [anon_sym_bool] = ACTIONS(792),
    [anon_sym_int] = ACTIONS(792),
    [anon_sym_float] = ACTIONS(792),
    [anon_sym_char] = ACTIONS(792),
    [anon_sym__] = ACTIONS(792),
    [anon_sym_Float] = ACTIONS(792),
    [anon_sym_String] = ACTIONS(792),
    [sym_any_type] = ACTIONS(792),
    [anon_sym_for] = ACTIONS(792),
    [anon_sym_while] = ACTIONS(792),
    [anon_sym_do] = ACTIONS(792),
    [anon_sym_break] = ACTIONS(792),
    [anon_sym_continue] = ACTIONS(792),
    [anon_sym_if] = ACTIONS(792),
    [anon_sym_else] = ACTIONS(792),
    [anon_sym_switch] = ACTIONS(792),
    [anon_sym_return] = ACTIONS(792),
    [anon_sym_delete] = ACTIONS(792),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(794),
    [anon_sym_PLUS_PLUS] = ACTIONS(794),
    [anon_sym_sizeof] = ACTIONS(792),
    [anon_sym_view_as] = ACTIONS(792),
    [sym_int_literal] = ACTIONS(792),
    [sym_float_literal] = ACTIONS(794),
    [anon_sym_SQUOTE] = ACTIONS(794),
    [anon_sym_DQUOTE] = ACTIONS(794),
    [sym_bool_literal] = ACTIONS(792),
    [sym_null] = ACTIONS(792),
    [sym_this] = ACTIONS(792),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [225] = {
    [sym_preproc_include] = STATE(225),
    [sym_preproc_tryinclude] = STATE(225),
    [sym_preproc_macro] = STATE(225),
    [sym_preproc_define] = STATE(225),
    [sym_preproc_undefine] = STATE(225),
    [sym_preproc_if] = STATE(225),
    [sym_preproc_elseif] = STATE(225),
    [sym_preproc_assert] = STATE(225),
    [sym_preproc_pragma] = STATE(225),
    [sym_preproc_error] = STATE(225),
    [sym_preproc_warning] = STATE(225),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(453),
    [aux_sym_variable_declaration_statement_repeat1] = STATE(222),
    [sym_identifier] = ACTIONS(792),
    [anon_sym_LPAREN] = ACTIONS(794),
    [anon_sym_BANG] = ACTIONS(794),
    [anon_sym_TILDE] = ACTIONS(794),
    [anon_sym_DASH] = ACTIONS(792),
    [anon_sym_PLUS] = ACTIONS(792),
    [anon_sym_AMP] = ACTIONS(794),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(790),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(792),
    [anon_sym_public] = ACTIONS(792),
    [anon_sym_stock] = ACTIONS(792),
    [anon_sym_static] = ACTIONS(792),
    [anon_sym_new] = ACTIONS(792),
    [anon_sym_decl] = ACTIONS(792),
    [anon_sym_LBRACE] = ACTIONS(794),
    [anon_sym_RBRACE] = ACTIONS(794),
    [anon_sym_void] = ACTIONS(792),
    [anon_sym_bool] = ACTIONS(792),
    [anon_sym_int] = ACTIONS(792),
    [anon_sym_float] = ACTIONS(792),
    [anon_sym_char] = ACTIONS(792),
    [anon_sym__] = ACTIONS(792),
    [anon_sym_Float] = ACTIONS(792),
    [anon_sym_String] = ACTIONS(792),
    [sym_any_type] = ACTIONS(792),
    [anon_sym_for] = ACTIONS(792),
    [anon_sym_while] = ACTIONS(792),
    [anon_sym_do] = ACTIONS(792),
    [anon_sym_break] = ACTIONS(792),
    [anon_sym_continue] = ACTIONS(792),
    [anon_sym_if] = ACTIONS(792),
    [anon_sym_else] = ACTIONS(792),
    [anon_sym_switch] = ACTIONS(792),
    [anon_sym_return] = ACTIONS(792),
    [anon_sym_delete] = ACTIONS(792),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(794),
    [anon_sym_PLUS_PLUS] = ACTIONS(794),
    [anon_sym_sizeof] = ACTIONS(792),
    [anon_sym_view_as] = ACTIONS(792),
    [sym_int_literal] = ACTIONS(792),
    [sym_float_literal] = ACTIONS(794),
    [anon_sym_SQUOTE] = ACTIONS(794),
    [anon_sym_DQUOTE] = ACTIONS(794),
    [sym_bool_literal] = ACTIONS(792),
    [sym_null] = ACTIONS(792),
    [sym_this] = ACTIONS(792),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [226] = {
    [sym_preproc_include] = STATE(226),
    [sym_preproc_tryinclude] = STATE(226),
    [sym_preproc_macro] = STATE(226),
    [sym_preproc_define] = STATE(226),
    [sym_preproc_undefine] = STATE(226),
    [sym_preproc_if] = STATE(226),
    [sym_preproc_elseif] = STATE(226),
    [sym_preproc_assert] = STATE(226),
    [sym_preproc_pragma] = STATE(226),
    [sym_preproc_error] = STATE(226),
    [sym_preproc_warning] = STATE(226),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(451),
    [aux_sym_global_variable_declaration_repeat1] = STATE(219),
    [sym_identifier] = ACTIONS(796),
    [anon_sym_LPAREN] = ACTIONS(798),
    [anon_sym_BANG] = ACTIONS(798),
    [anon_sym_TILDE] = ACTIONS(798),
    [anon_sym_DASH] = ACTIONS(796),
    [anon_sym_PLUS] = ACTIONS(796),
    [anon_sym_AMP] = ACTIONS(798),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(769),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(796),
    [anon_sym_public] = ACTIONS(796),
    [anon_sym_stock] = ACTIONS(796),
    [anon_sym_static] = ACTIONS(796),
    [anon_sym_new] = ACTIONS(796),
    [anon_sym_decl] = ACTIONS(796),
    [anon_sym_LBRACE] = ACTIONS(798),
    [anon_sym_RBRACE] = ACTIONS(798),
    [anon_sym_void] = ACTIONS(796),
    [anon_sym_bool] = ACTIONS(796),
    [anon_sym_int] = ACTIONS(796),
    [anon_sym_float] = ACTIONS(796),
    [anon_sym_char] = ACTIONS(796),
    [anon_sym__] = ACTIONS(796),
    [anon_sym_Float] = ACTIONS(796),
    [anon_sym_String] = ACTIONS(796),
    [sym_any_type] = ACTIONS(796),
    [anon_sym_for] = ACTIONS(796),
    [anon_sym_while] = ACTIONS(796),
    [anon_sym_do] = ACTIONS(796),
    [anon_sym_break] = ACTIONS(796),
    [anon_sym_continue] = ACTIONS(796),
    [anon_sym_if] = ACTIONS(796),
    [anon_sym_else] = ACTIONS(796),
    [anon_sym_switch] = ACTIONS(796),
    [anon_sym_return] = ACTIONS(796),
    [anon_sym_delete] = ACTIONS(796),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(798),
    [anon_sym_PLUS_PLUS] = ACTIONS(798),
    [anon_sym_sizeof] = ACTIONS(796),
    [anon_sym_view_as] = ACTIONS(796),
    [sym_int_literal] = ACTIONS(796),
    [sym_float_literal] = ACTIONS(798),
    [anon_sym_SQUOTE] = ACTIONS(798),
    [anon_sym_DQUOTE] = ACTIONS(798),
    [sym_bool_literal] = ACTIONS(796),
    [sym_null] = ACTIONS(796),
    [sym_this] = ACTIONS(796),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [227] = {
    [sym_preproc_include] = STATE(227),
    [sym_preproc_tryinclude] = STATE(227),
    [sym_preproc_macro] = STATE(227),
    [sym_preproc_define] = STATE(227),
    [sym_preproc_undefine] = STATE(227),
    [sym_preproc_if] = STATE(227),
    [sym_preproc_elseif] = STATE(227),
    [sym_preproc_assert] = STATE(227),
    [sym_preproc_pragma] = STATE(227),
    [sym_preproc_error] = STATE(227),
    [sym_preproc_warning] = STATE(227),
    [sym_fixed_dimension] = STATE(248),
    [aux_sym_dynamic_array_repeat1] = STATE(218),
    [sym_identifier] = ACTIONS(390),
    [anon_sym_LPAREN] = ACTIONS(392),
    [anon_sym_BANG] = ACTIONS(392),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_DASH] = ACTIONS(390),
    [anon_sym_PLUS] = ACTIONS(390),
    [anon_sym_AMP] = ACTIONS(392),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(390),
    [anon_sym_public] = ACTIONS(390),
    [anon_sym_stock] = ACTIONS(390),
    [anon_sym_static] = ACTIONS(390),
    [anon_sym_new] = ACTIONS(390),
    [anon_sym_decl] = ACTIONS(390),
    [anon_sym_LBRACE] = ACTIONS(392),
    [anon_sym_RBRACE] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(800),
    [anon_sym_void] = ACTIONS(390),
    [anon_sym_bool] = ACTIONS(390),
    [anon_sym_int] = ACTIONS(390),
    [anon_sym_float] = ACTIONS(390),
    [anon_sym_char] = ACTIONS(390),
    [anon_sym__] = ACTIONS(390),
    [anon_sym_Float] = ACTIONS(390),
    [anon_sym_String] = ACTIONS(390),
    [sym_any_type] = ACTIONS(390),
    [anon_sym_for] = ACTIONS(390),
    [anon_sym_while] = ACTIONS(390),
    [anon_sym_do] = ACTIONS(390),
    [anon_sym_break] = ACTIONS(390),
    [anon_sym_continue] = ACTIONS(390),
    [anon_sym_if] = ACTIONS(390),
    [anon_sym_else] = ACTIONS(390),
    [anon_sym_switch] = ACTIONS(390),
    [anon_sym_return] = ACTIONS(390),
    [anon_sym_delete] = ACTIONS(390),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_DASH_DASH] = ACTIONS(392),
    [anon_sym_PLUS_PLUS] = ACTIONS(392),
    [anon_sym_sizeof] = ACTIONS(390),
    [anon_sym_view_as] = ACTIONS(390),
    [sym_int_literal] = ACTIONS(390),
    [sym_float_literal] = ACTIONS(392),
    [anon_sym_SQUOTE] = ACTIONS(392),
    [anon_sym_DQUOTE] = ACTIONS(392),
    [sym_bool_literal] = ACTIONS(390),
    [sym_null] = ACTIONS(390),
    [sym_this] = ACTIONS(390),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(392),
  },
  [228] = {
    [sym_preproc_include] = STATE(228),
    [sym_preproc_tryinclude] = STATE(228),
    [sym_preproc_macro] = STATE(228),
    [sym_preproc_define] = STATE(228),
    [sym_preproc_undefine] = STATE(228),
    [sym_preproc_if] = STATE(228),
    [sym_preproc_elseif] = STATE(228),
    [sym_preproc_assert] = STATE(228),
    [sym_preproc_pragma] = STATE(228),
    [sym_preproc_error] = STATE(228),
    [sym_preproc_warning] = STATE(228),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(751),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_named_arg] = STATE(1303),
    [sym_ignore_argument] = STATE(1303),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(806),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(808),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [229] = {
    [sym_preproc_include] = STATE(229),
    [sym_preproc_tryinclude] = STATE(229),
    [sym_preproc_macro] = STATE(229),
    [sym_preproc_define] = STATE(229),
    [sym_preproc_undefine] = STATE(229),
    [sym_preproc_if] = STATE(229),
    [sym_preproc_elseif] = STATE(229),
    [sym_preproc_assert] = STATE(229),
    [sym_preproc_pragma] = STATE(229),
    [sym_preproc_error] = STATE(229),
    [sym_preproc_warning] = STATE(229),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(759),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_named_arg] = STATE(1307),
    [sym_ignore_argument] = STATE(1307),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(810),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(806),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(808),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [230] = {
    [sym_preproc_include] = STATE(230),
    [sym_preproc_tryinclude] = STATE(230),
    [sym_preproc_macro] = STATE(230),
    [sym_preproc_define] = STATE(230),
    [sym_preproc_undefine] = STATE(230),
    [sym_preproc_if] = STATE(230),
    [sym_preproc_elseif] = STATE(230),
    [sym_preproc_assert] = STATE(230),
    [sym_preproc_pragma] = STATE(230),
    [sym_preproc_error] = STATE(230),
    [sym_preproc_warning] = STATE(230),
    [sym_identifier] = ACTIONS(812),
    [anon_sym_LPAREN] = ACTIONS(814),
    [anon_sym_BANG] = ACTIONS(814),
    [anon_sym_TILDE] = ACTIONS(814),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_PLUS] = ACTIONS(812),
    [anon_sym_AMP] = ACTIONS(814),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(814),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(814),
    [anon_sym_const] = ACTIONS(812),
    [anon_sym_public] = ACTIONS(812),
    [anon_sym_stock] = ACTIONS(812),
    [anon_sym_static] = ACTIONS(812),
    [anon_sym_new] = ACTIONS(812),
    [anon_sym_decl] = ACTIONS(812),
    [anon_sym_LBRACE] = ACTIONS(814),
    [anon_sym_RBRACE] = ACTIONS(814),
    [anon_sym_LBRACK] = ACTIONS(814),
    [anon_sym_void] = ACTIONS(812),
    [anon_sym_bool] = ACTIONS(812),
    [anon_sym_int] = ACTIONS(812),
    [anon_sym_float] = ACTIONS(812),
    [anon_sym_char] = ACTIONS(812),
    [anon_sym__] = ACTIONS(812),
    [anon_sym_Float] = ACTIONS(812),
    [anon_sym_String] = ACTIONS(812),
    [sym_any_type] = ACTIONS(812),
    [anon_sym_for] = ACTIONS(812),
    [anon_sym_while] = ACTIONS(812),
    [anon_sym_do] = ACTIONS(812),
    [anon_sym_break] = ACTIONS(812),
    [anon_sym_continue] = ACTIONS(812),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_else] = ACTIONS(812),
    [anon_sym_switch] = ACTIONS(812),
    [anon_sym_return] = ACTIONS(812),
    [anon_sym_delete] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(814),
    [anon_sym_DASH_DASH] = ACTIONS(814),
    [anon_sym_PLUS_PLUS] = ACTIONS(814),
    [anon_sym_sizeof] = ACTIONS(812),
    [anon_sym_view_as] = ACTIONS(812),
    [sym_int_literal] = ACTIONS(812),
    [sym_float_literal] = ACTIONS(814),
    [anon_sym_SQUOTE] = ACTIONS(814),
    [anon_sym_DQUOTE] = ACTIONS(814),
    [sym_bool_literal] = ACTIONS(812),
    [sym_null] = ACTIONS(812),
    [sym_this] = ACTIONS(812),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(814),
  },
  [231] = {
    [sym_preproc_include] = STATE(231),
    [sym_preproc_tryinclude] = STATE(231),
    [sym_preproc_macro] = STATE(231),
    [sym_preproc_define] = STATE(231),
    [sym_preproc_undefine] = STATE(231),
    [sym_preproc_if] = STATE(231),
    [sym_preproc_elseif] = STATE(231),
    [sym_preproc_assert] = STATE(231),
    [sym_preproc_pragma] = STATE(231),
    [sym_preproc_error] = STATE(231),
    [sym_preproc_warning] = STATE(231),
    [sym_identifier] = ACTIONS(478),
    [anon_sym_LPAREN] = ACTIONS(480),
    [anon_sym_BANG] = ACTIONS(480),
    [anon_sym_TILDE] = ACTIONS(480),
    [anon_sym_DASH] = ACTIONS(478),
    [anon_sym_PLUS] = ACTIONS(478),
    [anon_sym_AMP] = ACTIONS(480),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(480),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(480),
    [anon_sym_const] = ACTIONS(478),
    [anon_sym_public] = ACTIONS(478),
    [anon_sym_stock] = ACTIONS(478),
    [anon_sym_static] = ACTIONS(478),
    [anon_sym_new] = ACTIONS(478),
    [anon_sym_decl] = ACTIONS(478),
    [anon_sym_LBRACE] = ACTIONS(480),
    [anon_sym_RBRACE] = ACTIONS(480),
    [anon_sym_LBRACK] = ACTIONS(480),
    [anon_sym_void] = ACTIONS(478),
    [anon_sym_bool] = ACTIONS(478),
    [anon_sym_int] = ACTIONS(478),
    [anon_sym_float] = ACTIONS(478),
    [anon_sym_char] = ACTIONS(478),
    [anon_sym__] = ACTIONS(478),
    [anon_sym_Float] = ACTIONS(478),
    [anon_sym_String] = ACTIONS(478),
    [sym_any_type] = ACTIONS(478),
    [anon_sym_for] = ACTIONS(478),
    [anon_sym_while] = ACTIONS(478),
    [anon_sym_do] = ACTIONS(478),
    [anon_sym_break] = ACTIONS(478),
    [anon_sym_continue] = ACTIONS(478),
    [anon_sym_if] = ACTIONS(478),
    [anon_sym_else] = ACTIONS(478),
    [anon_sym_switch] = ACTIONS(478),
    [anon_sym_return] = ACTIONS(478),
    [anon_sym_delete] = ACTIONS(478),
    [anon_sym_SEMI] = ACTIONS(480),
    [anon_sym_DASH_DASH] = ACTIONS(480),
    [anon_sym_PLUS_PLUS] = ACTIONS(480),
    [anon_sym_sizeof] = ACTIONS(478),
    [anon_sym_view_as] = ACTIONS(478),
    [sym_int_literal] = ACTIONS(478),
    [sym_float_literal] = ACTIONS(480),
    [anon_sym_SQUOTE] = ACTIONS(480),
    [anon_sym_DQUOTE] = ACTIONS(480),
    [sym_bool_literal] = ACTIONS(478),
    [sym_null] = ACTIONS(478),
    [sym_this] = ACTIONS(478),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(480),
  },
  [232] = {
    [sym_preproc_include] = STATE(232),
    [sym_preproc_tryinclude] = STATE(232),
    [sym_preproc_macro] = STATE(232),
    [sym_preproc_define] = STATE(232),
    [sym_preproc_undefine] = STATE(232),
    [sym_preproc_if] = STATE(232),
    [sym_preproc_elseif] = STATE(232),
    [sym_preproc_assert] = STATE(232),
    [sym_preproc_pragma] = STATE(232),
    [sym_preproc_error] = STATE(232),
    [sym_preproc_warning] = STATE(232),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(757),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_named_arg] = STATE(1282),
    [sym_ignore_argument] = STATE(1282),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(816),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(806),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(808),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [233] = {
    [sym_preproc_include] = STATE(233),
    [sym_preproc_tryinclude] = STATE(233),
    [sym_preproc_macro] = STATE(233),
    [sym_preproc_define] = STATE(233),
    [sym_preproc_undefine] = STATE(233),
    [sym_preproc_if] = STATE(233),
    [sym_preproc_elseif] = STATE(233),
    [sym_preproc_assert] = STATE(233),
    [sym_preproc_pragma] = STATE(233),
    [sym_preproc_error] = STATE(233),
    [sym_preproc_warning] = STATE(233),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(753),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_named_arg] = STATE(1314),
    [sym_ignore_argument] = STATE(1314),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(818),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(806),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(808),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [234] = {
    [sym_preproc_include] = STATE(234),
    [sym_preproc_tryinclude] = STATE(234),
    [sym_preproc_macro] = STATE(234),
    [sym_preproc_define] = STATE(234),
    [sym_preproc_undefine] = STATE(234),
    [sym_preproc_if] = STATE(234),
    [sym_preproc_elseif] = STATE(234),
    [sym_preproc_assert] = STATE(234),
    [sym_preproc_pragma] = STATE(234),
    [sym_preproc_error] = STATE(234),
    [sym_preproc_warning] = STATE(234),
    [sym_identifier] = ACTIONS(474),
    [anon_sym_LPAREN] = ACTIONS(476),
    [anon_sym_BANG] = ACTIONS(476),
    [anon_sym_TILDE] = ACTIONS(476),
    [anon_sym_DASH] = ACTIONS(474),
    [anon_sym_PLUS] = ACTIONS(474),
    [anon_sym_AMP] = ACTIONS(476),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(476),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(476),
    [anon_sym_const] = ACTIONS(474),
    [anon_sym_public] = ACTIONS(474),
    [anon_sym_stock] = ACTIONS(474),
    [anon_sym_static] = ACTIONS(474),
    [anon_sym_new] = ACTIONS(474),
    [anon_sym_decl] = ACTIONS(474),
    [anon_sym_LBRACE] = ACTIONS(476),
    [anon_sym_RBRACE] = ACTIONS(476),
    [anon_sym_LBRACK] = ACTIONS(476),
    [anon_sym_void] = ACTIONS(474),
    [anon_sym_bool] = ACTIONS(474),
    [anon_sym_int] = ACTIONS(474),
    [anon_sym_float] = ACTIONS(474),
    [anon_sym_char] = ACTIONS(474),
    [anon_sym__] = ACTIONS(474),
    [anon_sym_Float] = ACTIONS(474),
    [anon_sym_String] = ACTIONS(474),
    [sym_any_type] = ACTIONS(474),
    [anon_sym_for] = ACTIONS(474),
    [anon_sym_while] = ACTIONS(474),
    [anon_sym_do] = ACTIONS(474),
    [anon_sym_break] = ACTIONS(474),
    [anon_sym_continue] = ACTIONS(474),
    [anon_sym_if] = ACTIONS(474),
    [anon_sym_else] = ACTIONS(474),
    [anon_sym_switch] = ACTIONS(474),
    [anon_sym_return] = ACTIONS(474),
    [anon_sym_delete] = ACTIONS(474),
    [anon_sym_SEMI] = ACTIONS(476),
    [anon_sym_DASH_DASH] = ACTIONS(476),
    [anon_sym_PLUS_PLUS] = ACTIONS(476),
    [anon_sym_sizeof] = ACTIONS(474),
    [anon_sym_view_as] = ACTIONS(474),
    [sym_int_literal] = ACTIONS(474),
    [sym_float_literal] = ACTIONS(476),
    [anon_sym_SQUOTE] = ACTIONS(476),
    [anon_sym_DQUOTE] = ACTIONS(476),
    [sym_bool_literal] = ACTIONS(474),
    [sym_null] = ACTIONS(474),
    [sym_this] = ACTIONS(474),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(476),
  },
  [235] = {
    [sym_preproc_include] = STATE(235),
    [sym_preproc_tryinclude] = STATE(235),
    [sym_preproc_macro] = STATE(235),
    [sym_preproc_define] = STATE(235),
    [sym_preproc_undefine] = STATE(235),
    [sym_preproc_if] = STATE(235),
    [sym_preproc_elseif] = STATE(235),
    [sym_preproc_assert] = STATE(235),
    [sym_preproc_pragma] = STATE(235),
    [sym_preproc_error] = STATE(235),
    [sym_preproc_warning] = STATE(235),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(755),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_named_arg] = STATE(1346),
    [sym_ignore_argument] = STATE(1346),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(820),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(806),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(808),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [236] = {
    [sym_preproc_include] = STATE(236),
    [sym_preproc_tryinclude] = STATE(236),
    [sym_preproc_macro] = STATE(236),
    [sym_preproc_define] = STATE(236),
    [sym_preproc_undefine] = STATE(236),
    [sym_preproc_if] = STATE(236),
    [sym_preproc_elseif] = STATE(236),
    [sym_preproc_assert] = STATE(236),
    [sym_preproc_pragma] = STATE(236),
    [sym_preproc_error] = STATE(236),
    [sym_preproc_warning] = STATE(236),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(440),
    [sym_identifier] = ACTIONS(418),
    [anon_sym_LPAREN] = ACTIONS(420),
    [anon_sym_BANG] = ACTIONS(420),
    [anon_sym_TILDE] = ACTIONS(420),
    [anon_sym_DASH] = ACTIONS(418),
    [anon_sym_PLUS] = ACTIONS(418),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(418),
    [anon_sym_public] = ACTIONS(418),
    [anon_sym_stock] = ACTIONS(418),
    [anon_sym_static] = ACTIONS(418),
    [anon_sym_new] = ACTIONS(418),
    [anon_sym_decl] = ACTIONS(418),
    [anon_sym_LBRACE] = ACTIONS(420),
    [anon_sym_RBRACE] = ACTIONS(420),
    [anon_sym_void] = ACTIONS(418),
    [anon_sym_bool] = ACTIONS(418),
    [anon_sym_int] = ACTIONS(418),
    [anon_sym_float] = ACTIONS(418),
    [anon_sym_char] = ACTIONS(418),
    [anon_sym__] = ACTIONS(418),
    [anon_sym_Float] = ACTIONS(418),
    [anon_sym_String] = ACTIONS(418),
    [sym_any_type] = ACTIONS(418),
    [anon_sym_for] = ACTIONS(418),
    [anon_sym_while] = ACTIONS(418),
    [anon_sym_do] = ACTIONS(418),
    [anon_sym_break] = ACTIONS(418),
    [anon_sym_continue] = ACTIONS(418),
    [anon_sym_if] = ACTIONS(418),
    [anon_sym_else] = ACTIONS(418),
    [anon_sym_switch] = ACTIONS(418),
    [anon_sym_return] = ACTIONS(418),
    [anon_sym_delete] = ACTIONS(418),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(420),
    [anon_sym_PLUS_PLUS] = ACTIONS(420),
    [anon_sym_sizeof] = ACTIONS(418),
    [anon_sym_view_as] = ACTIONS(418),
    [sym_int_literal] = ACTIONS(418),
    [sym_float_literal] = ACTIONS(420),
    [anon_sym_SQUOTE] = ACTIONS(420),
    [anon_sym_DQUOTE] = ACTIONS(420),
    [sym_bool_literal] = ACTIONS(418),
    [sym_null] = ACTIONS(418),
    [sym_this] = ACTIONS(418),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [237] = {
    [sym_preproc_include] = STATE(237),
    [sym_preproc_tryinclude] = STATE(237),
    [sym_preproc_macro] = STATE(237),
    [sym_preproc_define] = STATE(237),
    [sym_preproc_undefine] = STATE(237),
    [sym_preproc_if] = STATE(237),
    [sym_preproc_elseif] = STATE(237),
    [sym_preproc_assert] = STATE(237),
    [sym_preproc_pragma] = STATE(237),
    [sym_preproc_error] = STATE(237),
    [sym_preproc_warning] = STATE(237),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(790),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(760),
    [sym_array_indexed_access] = STATE(495),
    [sym_parenthesized_expression] = STATE(760),
    [sym_comma_expression] = STATE(1616),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(488),
    [sym_scope_access] = STATE(514),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym__sizeof_call_expression] = STATE(1519),
    [sym_array_scope_access] = STATE(665),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(760),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(822),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(824),
    [sym_comment] = ACTIONS(19),
  },
  [238] = {
    [sym_preproc_include] = STATE(238),
    [sym_preproc_tryinclude] = STATE(238),
    [sym_preproc_macro] = STATE(238),
    [sym_preproc_define] = STATE(238),
    [sym_preproc_undefine] = STATE(238),
    [sym_preproc_if] = STATE(238),
    [sym_preproc_elseif] = STATE(238),
    [sym_preproc_assert] = STATE(238),
    [sym_preproc_pragma] = STATE(238),
    [sym_preproc_error] = STATE(238),
    [sym_preproc_warning] = STATE(238),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(457),
    [sym_identifier] = ACTIONS(826),
    [anon_sym_LPAREN] = ACTIONS(828),
    [anon_sym_BANG] = ACTIONS(828),
    [anon_sym_TILDE] = ACTIONS(828),
    [anon_sym_DASH] = ACTIONS(826),
    [anon_sym_PLUS] = ACTIONS(826),
    [anon_sym_AMP] = ACTIONS(828),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(826),
    [anon_sym_public] = ACTIONS(826),
    [anon_sym_stock] = ACTIONS(826),
    [anon_sym_static] = ACTIONS(826),
    [anon_sym_new] = ACTIONS(826),
    [anon_sym_decl] = ACTIONS(826),
    [anon_sym_LBRACE] = ACTIONS(828),
    [anon_sym_RBRACE] = ACTIONS(828),
    [anon_sym_void] = ACTIONS(826),
    [anon_sym_bool] = ACTIONS(826),
    [anon_sym_int] = ACTIONS(826),
    [anon_sym_float] = ACTIONS(826),
    [anon_sym_char] = ACTIONS(826),
    [anon_sym__] = ACTIONS(826),
    [anon_sym_Float] = ACTIONS(826),
    [anon_sym_String] = ACTIONS(826),
    [sym_any_type] = ACTIONS(826),
    [anon_sym_for] = ACTIONS(826),
    [anon_sym_while] = ACTIONS(826),
    [anon_sym_do] = ACTIONS(826),
    [anon_sym_break] = ACTIONS(826),
    [anon_sym_continue] = ACTIONS(826),
    [anon_sym_if] = ACTIONS(826),
    [anon_sym_else] = ACTIONS(826),
    [anon_sym_switch] = ACTIONS(826),
    [anon_sym_return] = ACTIONS(826),
    [anon_sym_delete] = ACTIONS(826),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(828),
    [anon_sym_PLUS_PLUS] = ACTIONS(828),
    [anon_sym_sizeof] = ACTIONS(826),
    [anon_sym_view_as] = ACTIONS(826),
    [sym_int_literal] = ACTIONS(826),
    [sym_float_literal] = ACTIONS(828),
    [anon_sym_SQUOTE] = ACTIONS(828),
    [anon_sym_DQUOTE] = ACTIONS(828),
    [sym_bool_literal] = ACTIONS(826),
    [sym_null] = ACTIONS(826),
    [sym_this] = ACTIONS(826),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [239] = {
    [sym_preproc_include] = STATE(239),
    [sym_preproc_tryinclude] = STATE(239),
    [sym_preproc_macro] = STATE(239),
    [sym_preproc_define] = STATE(239),
    [sym_preproc_undefine] = STATE(239),
    [sym_preproc_if] = STATE(239),
    [sym_preproc_elseif] = STATE(239),
    [sym_preproc_assert] = STATE(239),
    [sym_preproc_pragma] = STATE(239),
    [sym_preproc_error] = STATE(239),
    [sym_preproc_warning] = STATE(239),
    [sym_dimension] = STATE(621),
    [sym_call_arguments] = STATE(632),
    [aux_sym_function_definition_repeat1] = STATE(612),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(832),
    [anon_sym_RBRACK] = ACTIONS(127),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_COLON_COLON] = ACTIONS(834),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [sym_comment] = ACTIONS(19),
  },
  [240] = {
    [sym_preproc_include] = STATE(240),
    [sym_preproc_tryinclude] = STATE(240),
    [sym_preproc_macro] = STATE(240),
    [sym_preproc_define] = STATE(240),
    [sym_preproc_undefine] = STATE(240),
    [sym_preproc_if] = STATE(240),
    [sym_preproc_elseif] = STATE(240),
    [sym_preproc_assert] = STATE(240),
    [sym_preproc_pragma] = STATE(240),
    [sym_preproc_error] = STATE(240),
    [sym_preproc_warning] = STATE(240),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(450),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_LPAREN] = ACTIONS(838),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_AMP] = ACTIONS(838),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(836),
    [anon_sym_public] = ACTIONS(836),
    [anon_sym_stock] = ACTIONS(836),
    [anon_sym_static] = ACTIONS(836),
    [anon_sym_new] = ACTIONS(836),
    [anon_sym_decl] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_RBRACE] = ACTIONS(838),
    [anon_sym_void] = ACTIONS(836),
    [anon_sym_bool] = ACTIONS(836),
    [anon_sym_int] = ACTIONS(836),
    [anon_sym_float] = ACTIONS(836),
    [anon_sym_char] = ACTIONS(836),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_Float] = ACTIONS(836),
    [anon_sym_String] = ACTIONS(836),
    [sym_any_type] = ACTIONS(836),
    [anon_sym_for] = ACTIONS(836),
    [anon_sym_while] = ACTIONS(836),
    [anon_sym_do] = ACTIONS(836),
    [anon_sym_break] = ACTIONS(836),
    [anon_sym_continue] = ACTIONS(836),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_switch] = ACTIONS(836),
    [anon_sym_return] = ACTIONS(836),
    [anon_sym_delete] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(838),
    [anon_sym_PLUS_PLUS] = ACTIONS(838),
    [anon_sym_sizeof] = ACTIONS(836),
    [anon_sym_view_as] = ACTIONS(836),
    [sym_int_literal] = ACTIONS(836),
    [sym_float_literal] = ACTIONS(838),
    [anon_sym_SQUOTE] = ACTIONS(838),
    [anon_sym_DQUOTE] = ACTIONS(838),
    [sym_bool_literal] = ACTIONS(836),
    [sym_null] = ACTIONS(836),
    [sym_this] = ACTIONS(836),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [241] = {
    [sym_preproc_include] = STATE(241),
    [sym_preproc_tryinclude] = STATE(241),
    [sym_preproc_macro] = STATE(241),
    [sym_preproc_define] = STATE(241),
    [sym_preproc_undefine] = STATE(241),
    [sym_preproc_if] = STATE(241),
    [sym_preproc_elseif] = STATE(241),
    [sym_preproc_assert] = STATE(241),
    [sym_preproc_pragma] = STATE(241),
    [sym_preproc_error] = STATE(241),
    [sym_preproc_warning] = STATE(241),
    [aux_sym_variable_declaration_statement_repeat1] = STATE(241),
    [sym_identifier] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(842),
    [anon_sym_BANG] = ACTIONS(842),
    [anon_sym_TILDE] = ACTIONS(842),
    [anon_sym_DASH] = ACTIONS(840),
    [anon_sym_PLUS] = ACTIONS(840),
    [anon_sym_AMP] = ACTIONS(842),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(844),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(840),
    [anon_sym_public] = ACTIONS(840),
    [anon_sym_stock] = ACTIONS(840),
    [anon_sym_static] = ACTIONS(840),
    [anon_sym_new] = ACTIONS(840),
    [anon_sym_decl] = ACTIONS(840),
    [anon_sym_LBRACE] = ACTIONS(842),
    [anon_sym_RBRACE] = ACTIONS(842),
    [anon_sym_void] = ACTIONS(840),
    [anon_sym_bool] = ACTIONS(840),
    [anon_sym_int] = ACTIONS(840),
    [anon_sym_float] = ACTIONS(840),
    [anon_sym_char] = ACTIONS(840),
    [anon_sym__] = ACTIONS(840),
    [anon_sym_Float] = ACTIONS(840),
    [anon_sym_String] = ACTIONS(840),
    [sym_any_type] = ACTIONS(840),
    [anon_sym_for] = ACTIONS(840),
    [anon_sym_while] = ACTIONS(840),
    [anon_sym_do] = ACTIONS(840),
    [anon_sym_break] = ACTIONS(840),
    [anon_sym_continue] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(840),
    [anon_sym_else] = ACTIONS(840),
    [anon_sym_switch] = ACTIONS(840),
    [anon_sym_return] = ACTIONS(840),
    [anon_sym_delete] = ACTIONS(840),
    [anon_sym_SEMI] = ACTIONS(842),
    [anon_sym_DASH_DASH] = ACTIONS(842),
    [anon_sym_PLUS_PLUS] = ACTIONS(842),
    [anon_sym_sizeof] = ACTIONS(840),
    [anon_sym_view_as] = ACTIONS(840),
    [sym_int_literal] = ACTIONS(840),
    [sym_float_literal] = ACTIONS(842),
    [anon_sym_SQUOTE] = ACTIONS(842),
    [anon_sym_DQUOTE] = ACTIONS(842),
    [sym_bool_literal] = ACTIONS(840),
    [sym_null] = ACTIONS(840),
    [sym_this] = ACTIONS(840),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(842),
  },
  [242] = {
    [sym_preproc_include] = STATE(242),
    [sym_preproc_tryinclude] = STATE(242),
    [sym_preproc_macro] = STATE(242),
    [sym_preproc_define] = STATE(242),
    [sym_preproc_undefine] = STATE(242),
    [sym_preproc_if] = STATE(242),
    [sym_preproc_elseif] = STATE(242),
    [sym_preproc_assert] = STATE(242),
    [sym_preproc_pragma] = STATE(242),
    [sym_preproc_error] = STATE(242),
    [sym_preproc_warning] = STATE(242),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(466),
    [sym_identifier] = ACTIONS(458),
    [anon_sym_LPAREN] = ACTIONS(460),
    [anon_sym_BANG] = ACTIONS(460),
    [anon_sym_TILDE] = ACTIONS(460),
    [anon_sym_DASH] = ACTIONS(458),
    [anon_sym_PLUS] = ACTIONS(458),
    [anon_sym_AMP] = ACTIONS(460),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_public] = ACTIONS(458),
    [anon_sym_stock] = ACTIONS(458),
    [anon_sym_static] = ACTIONS(458),
    [anon_sym_new] = ACTIONS(458),
    [anon_sym_decl] = ACTIONS(458),
    [anon_sym_LBRACE] = ACTIONS(460),
    [anon_sym_RBRACE] = ACTIONS(460),
    [anon_sym_void] = ACTIONS(458),
    [anon_sym_bool] = ACTIONS(458),
    [anon_sym_int] = ACTIONS(458),
    [anon_sym_float] = ACTIONS(458),
    [anon_sym_char] = ACTIONS(458),
    [anon_sym__] = ACTIONS(458),
    [anon_sym_Float] = ACTIONS(458),
    [anon_sym_String] = ACTIONS(458),
    [sym_any_type] = ACTIONS(458),
    [anon_sym_for] = ACTIONS(458),
    [anon_sym_while] = ACTIONS(458),
    [anon_sym_do] = ACTIONS(458),
    [anon_sym_break] = ACTIONS(458),
    [anon_sym_continue] = ACTIONS(458),
    [anon_sym_if] = ACTIONS(458),
    [anon_sym_else] = ACTIONS(458),
    [anon_sym_switch] = ACTIONS(458),
    [anon_sym_return] = ACTIONS(458),
    [anon_sym_delete] = ACTIONS(458),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(460),
    [anon_sym_PLUS_PLUS] = ACTIONS(460),
    [anon_sym_sizeof] = ACTIONS(458),
    [anon_sym_view_as] = ACTIONS(458),
    [sym_int_literal] = ACTIONS(458),
    [sym_float_literal] = ACTIONS(460),
    [anon_sym_SQUOTE] = ACTIONS(460),
    [anon_sym_DQUOTE] = ACTIONS(460),
    [sym_bool_literal] = ACTIONS(458),
    [sym_null] = ACTIONS(458),
    [sym_this] = ACTIONS(458),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [243] = {
    [sym_preproc_include] = STATE(243),
    [sym_preproc_tryinclude] = STATE(243),
    [sym_preproc_macro] = STATE(243),
    [sym_preproc_define] = STATE(243),
    [sym_preproc_undefine] = STATE(243),
    [sym_preproc_if] = STATE(243),
    [sym_preproc_elseif] = STATE(243),
    [sym_preproc_assert] = STATE(243),
    [sym_preproc_pragma] = STATE(243),
    [sym_preproc_error] = STATE(243),
    [sym_preproc_warning] = STATE(243),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(810),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(760),
    [sym_array_indexed_access] = STATE(495),
    [sym_parenthesized_expression] = STATE(760),
    [sym_comma_expression] = STATE(1522),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(488),
    [sym_scope_access] = STATE(514),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym__sizeof_call_expression] = STATE(1532),
    [sym_array_scope_access] = STATE(665),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(760),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(822),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(824),
    [sym_comment] = ACTIONS(19),
  },
  [244] = {
    [sym_preproc_include] = STATE(244),
    [sym_preproc_tryinclude] = STATE(244),
    [sym_preproc_macro] = STATE(244),
    [sym_preproc_define] = STATE(244),
    [sym_preproc_undefine] = STATE(244),
    [sym_preproc_if] = STATE(244),
    [sym_preproc_elseif] = STATE(244),
    [sym_preproc_assert] = STATE(244),
    [sym_preproc_pragma] = STATE(244),
    [sym_preproc_error] = STATE(244),
    [sym_preproc_warning] = STATE(244),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(801),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(760),
    [sym_array_indexed_access] = STATE(495),
    [sym_parenthesized_expression] = STATE(760),
    [sym_comma_expression] = STATE(1471),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(488),
    [sym_scope_access] = STATE(514),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym__sizeof_call_expression] = STATE(1483),
    [sym_array_scope_access] = STATE(665),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(760),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(822),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(824),
    [sym_comment] = ACTIONS(19),
  },
  [245] = {
    [sym_preproc_include] = STATE(245),
    [sym_preproc_tryinclude] = STATE(245),
    [sym_preproc_macro] = STATE(245),
    [sym_preproc_define] = STATE(245),
    [sym_preproc_undefine] = STATE(245),
    [sym_preproc_if] = STATE(245),
    [sym_preproc_elseif] = STATE(245),
    [sym_preproc_assert] = STATE(245),
    [sym_preproc_pragma] = STATE(245),
    [sym_preproc_error] = STATE(245),
    [sym_preproc_warning] = STATE(245),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(828),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(760),
    [sym_array_indexed_access] = STATE(495),
    [sym_parenthesized_expression] = STATE(760),
    [sym_comma_expression] = STATE(1479),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(488),
    [sym_scope_access] = STATE(514),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym__sizeof_call_expression] = STATE(1631),
    [sym_array_scope_access] = STATE(665),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(760),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(822),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(824),
    [sym_comment] = ACTIONS(19),
  },
  [246] = {
    [sym_preproc_include] = STATE(246),
    [sym_preproc_tryinclude] = STATE(246),
    [sym_preproc_macro] = STATE(246),
    [sym_preproc_define] = STATE(246),
    [sym_preproc_undefine] = STATE(246),
    [sym_preproc_if] = STATE(246),
    [sym_preproc_elseif] = STATE(246),
    [sym_preproc_assert] = STATE(246),
    [sym_preproc_pragma] = STATE(246),
    [sym_preproc_error] = STATE(246),
    [sym_preproc_warning] = STATE(246),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(828),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(760),
    [sym_array_indexed_access] = STATE(495),
    [sym_parenthesized_expression] = STATE(760),
    [sym_comma_expression] = STATE(1479),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(488),
    [sym_scope_access] = STATE(514),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym__sizeof_call_expression] = STATE(1560),
    [sym_array_scope_access] = STATE(665),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(760),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(822),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(824),
    [sym_comment] = ACTIONS(19),
  },
  [247] = {
    [sym_preproc_include] = STATE(247),
    [sym_preproc_tryinclude] = STATE(247),
    [sym_preproc_macro] = STATE(247),
    [sym_preproc_define] = STATE(247),
    [sym_preproc_undefine] = STATE(247),
    [sym_preproc_if] = STATE(247),
    [sym_preproc_elseif] = STATE(247),
    [sym_preproc_assert] = STATE(247),
    [sym_preproc_pragma] = STATE(247),
    [sym_preproc_error] = STATE(247),
    [sym_preproc_warning] = STATE(247),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(788),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_named_arg] = STATE(1362),
    [sym_ignore_argument] = STATE(1362),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(806),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DOT] = ACTIONS(808),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [248] = {
    [sym_preproc_include] = STATE(248),
    [sym_preproc_tryinclude] = STATE(248),
    [sym_preproc_macro] = STATE(248),
    [sym_preproc_define] = STATE(248),
    [sym_preproc_undefine] = STATE(248),
    [sym_preproc_if] = STATE(248),
    [sym_preproc_elseif] = STATE(248),
    [sym_preproc_assert] = STATE(248),
    [sym_preproc_pragma] = STATE(248),
    [sym_preproc_error] = STATE(248),
    [sym_preproc_warning] = STATE(248),
    [sym_identifier] = ACTIONS(462),
    [anon_sym_LPAREN] = ACTIONS(464),
    [anon_sym_BANG] = ACTIONS(464),
    [anon_sym_TILDE] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(462),
    [anon_sym_PLUS] = ACTIONS(462),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(464),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(462),
    [anon_sym_public] = ACTIONS(462),
    [anon_sym_stock] = ACTIONS(462),
    [anon_sym_static] = ACTIONS(462),
    [anon_sym_new] = ACTIONS(462),
    [anon_sym_decl] = ACTIONS(462),
    [anon_sym_LBRACE] = ACTIONS(464),
    [anon_sym_RBRACE] = ACTIONS(464),
    [anon_sym_LBRACK] = ACTIONS(464),
    [anon_sym_void] = ACTIONS(462),
    [anon_sym_bool] = ACTIONS(462),
    [anon_sym_int] = ACTIONS(462),
    [anon_sym_float] = ACTIONS(462),
    [anon_sym_char] = ACTIONS(462),
    [anon_sym__] = ACTIONS(462),
    [anon_sym_Float] = ACTIONS(462),
    [anon_sym_String] = ACTIONS(462),
    [sym_any_type] = ACTIONS(462),
    [anon_sym_for] = ACTIONS(462),
    [anon_sym_while] = ACTIONS(462),
    [anon_sym_do] = ACTIONS(462),
    [anon_sym_break] = ACTIONS(462),
    [anon_sym_continue] = ACTIONS(462),
    [anon_sym_if] = ACTIONS(462),
    [anon_sym_else] = ACTIONS(462),
    [anon_sym_switch] = ACTIONS(462),
    [anon_sym_return] = ACTIONS(462),
    [anon_sym_delete] = ACTIONS(462),
    [anon_sym_SEMI] = ACTIONS(464),
    [anon_sym_DASH_DASH] = ACTIONS(464),
    [anon_sym_PLUS_PLUS] = ACTIONS(464),
    [anon_sym_sizeof] = ACTIONS(462),
    [anon_sym_view_as] = ACTIONS(462),
    [sym_int_literal] = ACTIONS(462),
    [sym_float_literal] = ACTIONS(464),
    [anon_sym_SQUOTE] = ACTIONS(464),
    [anon_sym_DQUOTE] = ACTIONS(464),
    [sym_bool_literal] = ACTIONS(462),
    [sym_null] = ACTIONS(462),
    [sym_this] = ACTIONS(462),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(464),
  },
  [249] = {
    [sym_preproc_include] = STATE(249),
    [sym_preproc_tryinclude] = STATE(249),
    [sym_preproc_macro] = STATE(249),
    [sym_preproc_define] = STATE(249),
    [sym_preproc_undefine] = STATE(249),
    [sym_preproc_if] = STATE(249),
    [sym_preproc_elseif] = STATE(249),
    [sym_preproc_assert] = STATE(249),
    [sym_preproc_pragma] = STATE(249),
    [sym_preproc_error] = STATE(249),
    [sym_preproc_warning] = STATE(249),
    [aux_sym_global_variable_declaration_repeat1] = STATE(249),
    [sym_identifier] = ACTIONS(847),
    [anon_sym_LPAREN] = ACTIONS(849),
    [anon_sym_BANG] = ACTIONS(849),
    [anon_sym_TILDE] = ACTIONS(849),
    [anon_sym_DASH] = ACTIONS(847),
    [anon_sym_PLUS] = ACTIONS(847),
    [anon_sym_AMP] = ACTIONS(849),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(851),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(847),
    [anon_sym_public] = ACTIONS(847),
    [anon_sym_stock] = ACTIONS(847),
    [anon_sym_static] = ACTIONS(847),
    [anon_sym_new] = ACTIONS(847),
    [anon_sym_decl] = ACTIONS(847),
    [anon_sym_LBRACE] = ACTIONS(849),
    [anon_sym_RBRACE] = ACTIONS(849),
    [anon_sym_void] = ACTIONS(847),
    [anon_sym_bool] = ACTIONS(847),
    [anon_sym_int] = ACTIONS(847),
    [anon_sym_float] = ACTIONS(847),
    [anon_sym_char] = ACTIONS(847),
    [anon_sym__] = ACTIONS(847),
    [anon_sym_Float] = ACTIONS(847),
    [anon_sym_String] = ACTIONS(847),
    [sym_any_type] = ACTIONS(847),
    [anon_sym_for] = ACTIONS(847),
    [anon_sym_while] = ACTIONS(847),
    [anon_sym_do] = ACTIONS(847),
    [anon_sym_break] = ACTIONS(847),
    [anon_sym_continue] = ACTIONS(847),
    [anon_sym_if] = ACTIONS(847),
    [anon_sym_else] = ACTIONS(847),
    [anon_sym_switch] = ACTIONS(847),
    [anon_sym_return] = ACTIONS(847),
    [anon_sym_delete] = ACTIONS(847),
    [anon_sym_SEMI] = ACTIONS(849),
    [anon_sym_DASH_DASH] = ACTIONS(849),
    [anon_sym_PLUS_PLUS] = ACTIONS(849),
    [anon_sym_sizeof] = ACTIONS(847),
    [anon_sym_view_as] = ACTIONS(847),
    [sym_int_literal] = ACTIONS(847),
    [sym_float_literal] = ACTIONS(849),
    [anon_sym_SQUOTE] = ACTIONS(849),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_bool_literal] = ACTIONS(847),
    [sym_null] = ACTIONS(847),
    [sym_this] = ACTIONS(847),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(849),
  },
  [250] = {
    [sym_preproc_include] = STATE(250),
    [sym_preproc_tryinclude] = STATE(250),
    [sym_preproc_macro] = STATE(250),
    [sym_preproc_define] = STATE(250),
    [sym_preproc_undefine] = STATE(250),
    [sym_preproc_if] = STATE(250),
    [sym_preproc_elseif] = STATE(250),
    [sym_preproc_assert] = STATE(250),
    [sym_preproc_pragma] = STATE(250),
    [sym_preproc_error] = STATE(250),
    [sym_preproc_warning] = STATE(250),
    [sym__manual_semicolon] = STATE(460),
    [sym__semicolon] = STATE(449),
    [sym_identifier] = ACTIONS(854),
    [anon_sym_LPAREN] = ACTIONS(856),
    [anon_sym_BANG] = ACTIONS(856),
    [anon_sym_TILDE] = ACTIONS(856),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_AMP] = ACTIONS(856),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(854),
    [anon_sym_public] = ACTIONS(854),
    [anon_sym_stock] = ACTIONS(854),
    [anon_sym_static] = ACTIONS(854),
    [anon_sym_new] = ACTIONS(854),
    [anon_sym_decl] = ACTIONS(854),
    [anon_sym_LBRACE] = ACTIONS(856),
    [anon_sym_RBRACE] = ACTIONS(856),
    [anon_sym_void] = ACTIONS(854),
    [anon_sym_bool] = ACTIONS(854),
    [anon_sym_int] = ACTIONS(854),
    [anon_sym_float] = ACTIONS(854),
    [anon_sym_char] = ACTIONS(854),
    [anon_sym__] = ACTIONS(854),
    [anon_sym_Float] = ACTIONS(854),
    [anon_sym_String] = ACTIONS(854),
    [sym_any_type] = ACTIONS(854),
    [anon_sym_for] = ACTIONS(854),
    [anon_sym_while] = ACTIONS(854),
    [anon_sym_do] = ACTIONS(854),
    [anon_sym_break] = ACTIONS(854),
    [anon_sym_continue] = ACTIONS(854),
    [anon_sym_if] = ACTIONS(854),
    [anon_sym_else] = ACTIONS(854),
    [anon_sym_switch] = ACTIONS(854),
    [anon_sym_return] = ACTIONS(854),
    [anon_sym_delete] = ACTIONS(854),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(856),
    [anon_sym_PLUS_PLUS] = ACTIONS(856),
    [anon_sym_sizeof] = ACTIONS(854),
    [anon_sym_view_as] = ACTIONS(854),
    [sym_int_literal] = ACTIONS(854),
    [sym_float_literal] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(856),
    [anon_sym_DQUOTE] = ACTIONS(856),
    [sym_bool_literal] = ACTIONS(854),
    [sym_null] = ACTIONS(854),
    [sym_this] = ACTIONS(854),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(388),
  },
  [251] = {
    [sym_preproc_include] = STATE(251),
    [sym_preproc_tryinclude] = STATE(251),
    [sym_preproc_macro] = STATE(251),
    [sym_preproc_define] = STATE(251),
    [sym_preproc_undefine] = STATE(251),
    [sym_preproc_if] = STATE(251),
    [sym_preproc_elseif] = STATE(251),
    [sym_preproc_assert] = STATE(251),
    [sym_preproc_pragma] = STATE(251),
    [sym_preproc_error] = STATE(251),
    [sym_preproc_warning] = STATE(251),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(258),
    [sym__expression] = STATE(818),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [252] = {
    [sym_preproc_include] = STATE(252),
    [sym_preproc_tryinclude] = STATE(252),
    [sym_preproc_macro] = STATE(252),
    [sym_preproc_define] = STATE(252),
    [sym_preproc_undefine] = STATE(252),
    [sym_preproc_if] = STATE(252),
    [sym_preproc_elseif] = STATE(252),
    [sym_preproc_assert] = STATE(252),
    [sym_preproc_pragma] = STATE(252),
    [sym_preproc_error] = STATE(252),
    [sym_preproc_warning] = STATE(252),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(902),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(663),
    [sym_array_indexed_access] = STATE(444),
    [sym_parenthesized_expression] = STATE(663),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(454),
    [sym_scope_access] = STATE(497),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym__sizeof_call_expression] = STATE(664),
    [sym_array_scope_access] = STATE(665),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(663),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(858),
    [anon_sym_LPAREN] = ACTIONS(860),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(862),
    [sym_comment] = ACTIONS(19),
  },
  [253] = {
    [sym_preproc_include] = STATE(253),
    [sym_preproc_tryinclude] = STATE(253),
    [sym_preproc_macro] = STATE(253),
    [sym_preproc_define] = STATE(253),
    [sym_preproc_undefine] = STATE(253),
    [sym_preproc_if] = STATE(253),
    [sym_preproc_elseif] = STATE(253),
    [sym_preproc_assert] = STATE(253),
    [sym_preproc_pragma] = STATE(253),
    [sym_preproc_error] = STATE(253),
    [sym_preproc_warning] = STATE(253),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(284),
    [sym__expression] = STATE(781),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [254] = {
    [sym_preproc_include] = STATE(254),
    [sym_preproc_tryinclude] = STATE(254),
    [sym_preproc_macro] = STATE(254),
    [sym_preproc_define] = STATE(254),
    [sym_preproc_undefine] = STATE(254),
    [sym_preproc_if] = STATE(254),
    [sym_preproc_elseif] = STATE(254),
    [sym_preproc_assert] = STATE(254),
    [sym_preproc_pragma] = STATE(254),
    [sym_preproc_error] = STATE(254),
    [sym_preproc_warning] = STATE(254),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(794),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1590),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(864),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [255] = {
    [sym_preproc_include] = STATE(255),
    [sym_preproc_tryinclude] = STATE(255),
    [sym_preproc_macro] = STATE(255),
    [sym_preproc_define] = STATE(255),
    [sym_preproc_undefine] = STATE(255),
    [sym_preproc_if] = STATE(255),
    [sym_preproc_elseif] = STATE(255),
    [sym_preproc_assert] = STATE(255),
    [sym_preproc_pragma] = STATE(255),
    [sym_preproc_error] = STATE(255),
    [sym_preproc_warning] = STATE(255),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(795),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1608),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(866),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [256] = {
    [sym_preproc_include] = STATE(256),
    [sym_preproc_tryinclude] = STATE(256),
    [sym_preproc_macro] = STATE(256),
    [sym_preproc_define] = STATE(256),
    [sym_preproc_undefine] = STATE(256),
    [sym_preproc_if] = STATE(256),
    [sym_preproc_elseif] = STATE(256),
    [sym_preproc_assert] = STATE(256),
    [sym_preproc_pragma] = STATE(256),
    [sym_preproc_error] = STATE(256),
    [sym_preproc_warning] = STATE(256),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(796),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1613),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(868),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [257] = {
    [sym_preproc_include] = STATE(257),
    [sym_preproc_tryinclude] = STATE(257),
    [sym_preproc_macro] = STATE(257),
    [sym_preproc_define] = STATE(257),
    [sym_preproc_undefine] = STATE(257),
    [sym_preproc_if] = STATE(257),
    [sym_preproc_elseif] = STATE(257),
    [sym_preproc_assert] = STATE(257),
    [sym_preproc_pragma] = STATE(257),
    [sym_preproc_error] = STATE(257),
    [sym_preproc_warning] = STATE(257),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(797),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1622),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [258] = {
    [sym_preproc_include] = STATE(258),
    [sym_preproc_tryinclude] = STATE(258),
    [sym_preproc_macro] = STATE(258),
    [sym_preproc_define] = STATE(258),
    [sym_preproc_undefine] = STATE(258),
    [sym_preproc_if] = STATE(258),
    [sym_preproc_elseif] = STATE(258),
    [sym_preproc_assert] = STATE(258),
    [sym_preproc_pragma] = STATE(258),
    [sym_preproc_error] = STATE(258),
    [sym_preproc_warning] = STATE(258),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(798),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1623),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(872),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [259] = {
    [sym_preproc_include] = STATE(259),
    [sym_preproc_tryinclude] = STATE(259),
    [sym_preproc_macro] = STATE(259),
    [sym_preproc_define] = STATE(259),
    [sym_preproc_undefine] = STATE(259),
    [sym_preproc_if] = STATE(259),
    [sym_preproc_elseif] = STATE(259),
    [sym_preproc_assert] = STATE(259),
    [sym_preproc_pragma] = STATE(259),
    [sym_preproc_error] = STATE(259),
    [sym_preproc_warning] = STATE(259),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(799),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1653),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [260] = {
    [sym_preproc_include] = STATE(260),
    [sym_preproc_tryinclude] = STATE(260),
    [sym_preproc_macro] = STATE(260),
    [sym_preproc_define] = STATE(260),
    [sym_preproc_undefine] = STATE(260),
    [sym_preproc_if] = STATE(260),
    [sym_preproc_elseif] = STATE(260),
    [sym_preproc_assert] = STATE(260),
    [sym_preproc_pragma] = STATE(260),
    [sym_preproc_error] = STATE(260),
    [sym_preproc_warning] = STATE(260),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(274),
    [sym__expression] = STATE(812),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [261] = {
    [sym_preproc_include] = STATE(261),
    [sym_preproc_tryinclude] = STATE(261),
    [sym_preproc_macro] = STATE(261),
    [sym_preproc_define] = STATE(261),
    [sym_preproc_undefine] = STATE(261),
    [sym_preproc_if] = STATE(261),
    [sym_preproc_elseif] = STATE(261),
    [sym_preproc_assert] = STATE(261),
    [sym_preproc_pragma] = STATE(261),
    [sym_preproc_error] = STATE(261),
    [sym_preproc_warning] = STATE(261),
    [sym_identifier] = ACTIONS(582),
    [anon_sym_LPAREN] = ACTIONS(584),
    [anon_sym_BANG] = ACTIONS(584),
    [anon_sym_TILDE] = ACTIONS(584),
    [anon_sym_DASH] = ACTIONS(582),
    [anon_sym_PLUS] = ACTIONS(582),
    [anon_sym_AMP] = ACTIONS(584),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(584),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(582),
    [anon_sym_public] = ACTIONS(582),
    [anon_sym_stock] = ACTIONS(582),
    [anon_sym_static] = ACTIONS(582),
    [anon_sym_new] = ACTIONS(582),
    [anon_sym_decl] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(584),
    [anon_sym_RBRACE] = ACTIONS(584),
    [anon_sym_void] = ACTIONS(582),
    [anon_sym_bool] = ACTIONS(582),
    [anon_sym_int] = ACTIONS(582),
    [anon_sym_float] = ACTIONS(582),
    [anon_sym_char] = ACTIONS(582),
    [anon_sym__] = ACTIONS(582),
    [anon_sym_Float] = ACTIONS(582),
    [anon_sym_String] = ACTIONS(582),
    [sym_any_type] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_do] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_delete] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(584),
    [anon_sym_DASH_DASH] = ACTIONS(584),
    [anon_sym_PLUS_PLUS] = ACTIONS(584),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_view_as] = ACTIONS(582),
    [sym_int_literal] = ACTIONS(582),
    [sym_float_literal] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_DQUOTE] = ACTIONS(584),
    [sym_bool_literal] = ACTIONS(582),
    [sym_null] = ACTIONS(582),
    [sym_this] = ACTIONS(582),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(584),
  },
  [262] = {
    [sym_preproc_include] = STATE(262),
    [sym_preproc_tryinclude] = STATE(262),
    [sym_preproc_macro] = STATE(262),
    [sym_preproc_define] = STATE(262),
    [sym_preproc_undefine] = STATE(262),
    [sym_preproc_if] = STATE(262),
    [sym_preproc_elseif] = STATE(262),
    [sym_preproc_assert] = STATE(262),
    [sym_preproc_pragma] = STATE(262),
    [sym_preproc_error] = STATE(262),
    [sym_preproc_warning] = STATE(262),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(923),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(145),
    [sym_array_indexed_access] = STATE(12),
    [sym_parenthesized_expression] = STATE(145),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(67),
    [sym_scope_access] = STATE(81),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym__sizeof_call_expression] = STATE(125),
    [sym_array_scope_access] = STATE(150),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(145),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(876),
    [anon_sym_LPAREN] = ACTIONS(878),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(880),
    [sym_comment] = ACTIONS(19),
  },
  [263] = {
    [sym_preproc_include] = STATE(263),
    [sym_preproc_tryinclude] = STATE(263),
    [sym_preproc_macro] = STATE(263),
    [sym_preproc_define] = STATE(263),
    [sym_preproc_undefine] = STATE(263),
    [sym_preproc_if] = STATE(263),
    [sym_preproc_elseif] = STATE(263),
    [sym_preproc_assert] = STATE(263),
    [sym_preproc_pragma] = STATE(263),
    [sym_preproc_error] = STATE(263),
    [sym_preproc_warning] = STATE(263),
    [sym_identifier] = ACTIONS(586),
    [anon_sym_LPAREN] = ACTIONS(588),
    [anon_sym_BANG] = ACTIONS(588),
    [anon_sym_TILDE] = ACTIONS(588),
    [anon_sym_DASH] = ACTIONS(586),
    [anon_sym_PLUS] = ACTIONS(586),
    [anon_sym_AMP] = ACTIONS(588),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(588),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(586),
    [anon_sym_public] = ACTIONS(586),
    [anon_sym_stock] = ACTIONS(586),
    [anon_sym_static] = ACTIONS(586),
    [anon_sym_new] = ACTIONS(586),
    [anon_sym_decl] = ACTIONS(586),
    [anon_sym_LBRACE] = ACTIONS(588),
    [anon_sym_RBRACE] = ACTIONS(588),
    [anon_sym_void] = ACTIONS(586),
    [anon_sym_bool] = ACTIONS(586),
    [anon_sym_int] = ACTIONS(586),
    [anon_sym_float] = ACTIONS(586),
    [anon_sym_char] = ACTIONS(586),
    [anon_sym__] = ACTIONS(586),
    [anon_sym_Float] = ACTIONS(586),
    [anon_sym_String] = ACTIONS(586),
    [sym_any_type] = ACTIONS(586),
    [anon_sym_for] = ACTIONS(586),
    [anon_sym_while] = ACTIONS(586),
    [anon_sym_do] = ACTIONS(586),
    [anon_sym_break] = ACTIONS(586),
    [anon_sym_continue] = ACTIONS(586),
    [anon_sym_if] = ACTIONS(586),
    [anon_sym_else] = ACTIONS(586),
    [anon_sym_switch] = ACTIONS(586),
    [anon_sym_return] = ACTIONS(586),
    [anon_sym_delete] = ACTIONS(586),
    [anon_sym_SEMI] = ACTIONS(588),
    [anon_sym_DASH_DASH] = ACTIONS(588),
    [anon_sym_PLUS_PLUS] = ACTIONS(588),
    [anon_sym_sizeof] = ACTIONS(586),
    [anon_sym_view_as] = ACTIONS(586),
    [sym_int_literal] = ACTIONS(586),
    [sym_float_literal] = ACTIONS(588),
    [anon_sym_SQUOTE] = ACTIONS(588),
    [anon_sym_DQUOTE] = ACTIONS(588),
    [sym_bool_literal] = ACTIONS(586),
    [sym_null] = ACTIONS(586),
    [sym_this] = ACTIONS(586),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(588),
  },
  [264] = {
    [sym_preproc_include] = STATE(264),
    [sym_preproc_tryinclude] = STATE(264),
    [sym_preproc_macro] = STATE(264),
    [sym_preproc_define] = STATE(264),
    [sym_preproc_undefine] = STATE(264),
    [sym_preproc_if] = STATE(264),
    [sym_preproc_elseif] = STATE(264),
    [sym_preproc_assert] = STATE(264),
    [sym_preproc_pragma] = STATE(264),
    [sym_preproc_error] = STATE(264),
    [sym_preproc_warning] = STATE(264),
    [sym_identifier] = ACTIONS(882),
    [anon_sym_LPAREN] = ACTIONS(884),
    [anon_sym_BANG] = ACTIONS(884),
    [anon_sym_TILDE] = ACTIONS(884),
    [anon_sym_DASH] = ACTIONS(882),
    [anon_sym_PLUS] = ACTIONS(882),
    [anon_sym_AMP] = ACTIONS(884),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(884),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(882),
    [anon_sym_public] = ACTIONS(882),
    [anon_sym_stock] = ACTIONS(882),
    [anon_sym_static] = ACTIONS(882),
    [anon_sym_new] = ACTIONS(882),
    [anon_sym_decl] = ACTIONS(882),
    [anon_sym_LBRACE] = ACTIONS(884),
    [anon_sym_RBRACE] = ACTIONS(884),
    [anon_sym_void] = ACTIONS(882),
    [anon_sym_bool] = ACTIONS(882),
    [anon_sym_int] = ACTIONS(882),
    [anon_sym_float] = ACTIONS(882),
    [anon_sym_char] = ACTIONS(882),
    [anon_sym__] = ACTIONS(882),
    [anon_sym_Float] = ACTIONS(882),
    [anon_sym_String] = ACTIONS(882),
    [sym_any_type] = ACTIONS(882),
    [anon_sym_for] = ACTIONS(882),
    [anon_sym_while] = ACTIONS(882),
    [anon_sym_do] = ACTIONS(882),
    [anon_sym_break] = ACTIONS(882),
    [anon_sym_continue] = ACTIONS(882),
    [anon_sym_if] = ACTIONS(882),
    [anon_sym_else] = ACTIONS(882),
    [anon_sym_switch] = ACTIONS(882),
    [anon_sym_return] = ACTIONS(882),
    [anon_sym_delete] = ACTIONS(882),
    [anon_sym_SEMI] = ACTIONS(884),
    [anon_sym_DASH_DASH] = ACTIONS(884),
    [anon_sym_PLUS_PLUS] = ACTIONS(884),
    [anon_sym_sizeof] = ACTIONS(882),
    [anon_sym_view_as] = ACTIONS(882),
    [sym_int_literal] = ACTIONS(882),
    [sym_float_literal] = ACTIONS(884),
    [anon_sym_SQUOTE] = ACTIONS(884),
    [anon_sym_DQUOTE] = ACTIONS(884),
    [sym_bool_literal] = ACTIONS(882),
    [sym_null] = ACTIONS(882),
    [sym_this] = ACTIONS(882),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(884),
  },
  [265] = {
    [sym_preproc_include] = STATE(265),
    [sym_preproc_tryinclude] = STATE(265),
    [sym_preproc_macro] = STATE(265),
    [sym_preproc_define] = STATE(265),
    [sym_preproc_undefine] = STATE(265),
    [sym_preproc_if] = STATE(265),
    [sym_preproc_elseif] = STATE(265),
    [sym_preproc_assert] = STATE(265),
    [sym_preproc_pragma] = STATE(265),
    [sym_preproc_error] = STATE(265),
    [sym_preproc_warning] = STATE(265),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(803),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1498),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(886),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [266] = {
    [sym_preproc_include] = STATE(266),
    [sym_preproc_tryinclude] = STATE(266),
    [sym_preproc_macro] = STATE(266),
    [sym_preproc_define] = STATE(266),
    [sym_preproc_undefine] = STATE(266),
    [sym_preproc_if] = STATE(266),
    [sym_preproc_elseif] = STATE(266),
    [sym_preproc_assert] = STATE(266),
    [sym_preproc_pragma] = STATE(266),
    [sym_preproc_error] = STATE(266),
    [sym_preproc_warning] = STATE(266),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(804),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1501),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(888),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [267] = {
    [sym_preproc_include] = STATE(267),
    [sym_preproc_tryinclude] = STATE(267),
    [sym_preproc_macro] = STATE(267),
    [sym_preproc_define] = STATE(267),
    [sym_preproc_undefine] = STATE(267),
    [sym_preproc_if] = STATE(267),
    [sym_preproc_elseif] = STATE(267),
    [sym_preproc_assert] = STATE(267),
    [sym_preproc_pragma] = STATE(267),
    [sym_preproc_error] = STATE(267),
    [sym_preproc_warning] = STATE(267),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(770),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1600),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(890),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [268] = {
    [sym_preproc_include] = STATE(268),
    [sym_preproc_tryinclude] = STATE(268),
    [sym_preproc_macro] = STATE(268),
    [sym_preproc_define] = STATE(268),
    [sym_preproc_undefine] = STATE(268),
    [sym_preproc_if] = STATE(268),
    [sym_preproc_elseif] = STATE(268),
    [sym_preproc_assert] = STATE(268),
    [sym_preproc_pragma] = STATE(268),
    [sym_preproc_error] = STATE(268),
    [sym_preproc_warning] = STATE(268),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(806),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1507),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(892),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [269] = {
    [sym_preproc_include] = STATE(269),
    [sym_preproc_tryinclude] = STATE(269),
    [sym_preproc_macro] = STATE(269),
    [sym_preproc_define] = STATE(269),
    [sym_preproc_undefine] = STATE(269),
    [sym_preproc_if] = STATE(269),
    [sym_preproc_elseif] = STATE(269),
    [sym_preproc_assert] = STATE(269),
    [sym_preproc_pragma] = STATE(269),
    [sym_preproc_error] = STATE(269),
    [sym_preproc_warning] = STATE(269),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(807),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1508),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(894),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [270] = {
    [sym_preproc_include] = STATE(270),
    [sym_preproc_tryinclude] = STATE(270),
    [sym_preproc_macro] = STATE(270),
    [sym_preproc_define] = STATE(270),
    [sym_preproc_undefine] = STATE(270),
    [sym_preproc_if] = STATE(270),
    [sym_preproc_elseif] = STATE(270),
    [sym_preproc_assert] = STATE(270),
    [sym_preproc_pragma] = STATE(270),
    [sym_preproc_error] = STATE(270),
    [sym_preproc_warning] = STATE(270),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(808),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1511),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(896),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [271] = {
    [sym_preproc_include] = STATE(271),
    [sym_preproc_tryinclude] = STATE(271),
    [sym_preproc_macro] = STATE(271),
    [sym_preproc_define] = STATE(271),
    [sym_preproc_undefine] = STATE(271),
    [sym_preproc_if] = STATE(271),
    [sym_preproc_elseif] = STATE(271),
    [sym_preproc_assert] = STATE(271),
    [sym_preproc_pragma] = STATE(271),
    [sym_preproc_error] = STATE(271),
    [sym_preproc_warning] = STATE(271),
    [sym_identifier] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(842),
    [anon_sym_BANG] = ACTIONS(842),
    [anon_sym_TILDE] = ACTIONS(842),
    [anon_sym_DASH] = ACTIONS(840),
    [anon_sym_PLUS] = ACTIONS(840),
    [anon_sym_AMP] = ACTIONS(842),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(842),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(840),
    [anon_sym_public] = ACTIONS(840),
    [anon_sym_stock] = ACTIONS(840),
    [anon_sym_static] = ACTIONS(840),
    [anon_sym_new] = ACTIONS(840),
    [anon_sym_decl] = ACTIONS(840),
    [anon_sym_LBRACE] = ACTIONS(842),
    [anon_sym_RBRACE] = ACTIONS(842),
    [anon_sym_void] = ACTIONS(840),
    [anon_sym_bool] = ACTIONS(840),
    [anon_sym_int] = ACTIONS(840),
    [anon_sym_float] = ACTIONS(840),
    [anon_sym_char] = ACTIONS(840),
    [anon_sym__] = ACTIONS(840),
    [anon_sym_Float] = ACTIONS(840),
    [anon_sym_String] = ACTIONS(840),
    [sym_any_type] = ACTIONS(840),
    [anon_sym_for] = ACTIONS(840),
    [anon_sym_while] = ACTIONS(840),
    [anon_sym_do] = ACTIONS(840),
    [anon_sym_break] = ACTIONS(840),
    [anon_sym_continue] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(840),
    [anon_sym_else] = ACTIONS(840),
    [anon_sym_switch] = ACTIONS(840),
    [anon_sym_return] = ACTIONS(840),
    [anon_sym_delete] = ACTIONS(840),
    [anon_sym_SEMI] = ACTIONS(842),
    [anon_sym_DASH_DASH] = ACTIONS(842),
    [anon_sym_PLUS_PLUS] = ACTIONS(842),
    [anon_sym_sizeof] = ACTIONS(840),
    [anon_sym_view_as] = ACTIONS(840),
    [sym_int_literal] = ACTIONS(840),
    [sym_float_literal] = ACTIONS(842),
    [anon_sym_SQUOTE] = ACTIONS(842),
    [anon_sym_DQUOTE] = ACTIONS(842),
    [sym_bool_literal] = ACTIONS(840),
    [sym_null] = ACTIONS(840),
    [sym_this] = ACTIONS(840),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(842),
  },
  [272] = {
    [sym_preproc_include] = STATE(272),
    [sym_preproc_tryinclude] = STATE(272),
    [sym_preproc_macro] = STATE(272),
    [sym_preproc_define] = STATE(272),
    [sym_preproc_undefine] = STATE(272),
    [sym_preproc_if] = STATE(272),
    [sym_preproc_elseif] = STATE(272),
    [sym_preproc_assert] = STATE(272),
    [sym_preproc_pragma] = STATE(272),
    [sym_preproc_error] = STATE(272),
    [sym_preproc_warning] = STATE(272),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(899),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(846),
    [sym_array_indexed_access] = STATE(498),
    [sym_parenthesized_expression] = STATE(846),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(500),
    [sym_scope_access] = STATE(522),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym__sizeof_call_expression] = STATE(841),
    [sym_array_scope_access] = STATE(842),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(846),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(898),
    [anon_sym_LPAREN] = ACTIONS(900),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(912),
    [sym_comment] = ACTIONS(19),
  },
  [273] = {
    [sym_preproc_include] = STATE(273),
    [sym_preproc_tryinclude] = STATE(273),
    [sym_preproc_macro] = STATE(273),
    [sym_preproc_define] = STATE(273),
    [sym_preproc_undefine] = STATE(273),
    [sym_preproc_if] = STATE(273),
    [sym_preproc_elseif] = STATE(273),
    [sym_preproc_assert] = STATE(273),
    [sym_preproc_pragma] = STATE(273),
    [sym_preproc_error] = STATE(273),
    [sym_preproc_warning] = STATE(273),
    [sym_identifier] = ACTIONS(847),
    [anon_sym_LPAREN] = ACTIONS(849),
    [anon_sym_BANG] = ACTIONS(849),
    [anon_sym_TILDE] = ACTIONS(849),
    [anon_sym_DASH] = ACTIONS(847),
    [anon_sym_PLUS] = ACTIONS(847),
    [anon_sym_AMP] = ACTIONS(849),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(849),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(847),
    [anon_sym_public] = ACTIONS(847),
    [anon_sym_stock] = ACTIONS(847),
    [anon_sym_static] = ACTIONS(847),
    [anon_sym_new] = ACTIONS(847),
    [anon_sym_decl] = ACTIONS(847),
    [anon_sym_LBRACE] = ACTIONS(849),
    [anon_sym_RBRACE] = ACTIONS(849),
    [anon_sym_void] = ACTIONS(847),
    [anon_sym_bool] = ACTIONS(847),
    [anon_sym_int] = ACTIONS(847),
    [anon_sym_float] = ACTIONS(847),
    [anon_sym_char] = ACTIONS(847),
    [anon_sym__] = ACTIONS(847),
    [anon_sym_Float] = ACTIONS(847),
    [anon_sym_String] = ACTIONS(847),
    [sym_any_type] = ACTIONS(847),
    [anon_sym_for] = ACTIONS(847),
    [anon_sym_while] = ACTIONS(847),
    [anon_sym_do] = ACTIONS(847),
    [anon_sym_break] = ACTIONS(847),
    [anon_sym_continue] = ACTIONS(847),
    [anon_sym_if] = ACTIONS(847),
    [anon_sym_else] = ACTIONS(847),
    [anon_sym_switch] = ACTIONS(847),
    [anon_sym_return] = ACTIONS(847),
    [anon_sym_delete] = ACTIONS(847),
    [anon_sym_SEMI] = ACTIONS(849),
    [anon_sym_DASH_DASH] = ACTIONS(849),
    [anon_sym_PLUS_PLUS] = ACTIONS(849),
    [anon_sym_sizeof] = ACTIONS(847),
    [anon_sym_view_as] = ACTIONS(847),
    [sym_int_literal] = ACTIONS(847),
    [sym_float_literal] = ACTIONS(849),
    [anon_sym_SQUOTE] = ACTIONS(849),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [sym_bool_literal] = ACTIONS(847),
    [sym_null] = ACTIONS(847),
    [sym_this] = ACTIONS(847),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(849),
  },
  [274] = {
    [sym_preproc_include] = STATE(274),
    [sym_preproc_tryinclude] = STATE(274),
    [sym_preproc_macro] = STATE(274),
    [sym_preproc_define] = STATE(274),
    [sym_preproc_undefine] = STATE(274),
    [sym_preproc_if] = STATE(274),
    [sym_preproc_elseif] = STATE(274),
    [sym_preproc_assert] = STATE(274),
    [sym_preproc_pragma] = STATE(274),
    [sym_preproc_error] = STATE(274),
    [sym_preproc_warning] = STATE(274),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(782),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1599),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(914),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [275] = {
    [sym_preproc_include] = STATE(275),
    [sym_preproc_tryinclude] = STATE(275),
    [sym_preproc_macro] = STATE(275),
    [sym_preproc_define] = STATE(275),
    [sym_preproc_undefine] = STATE(275),
    [sym_preproc_if] = STATE(275),
    [sym_preproc_elseif] = STATE(275),
    [sym_preproc_assert] = STATE(275),
    [sym_preproc_pragma] = STATE(275),
    [sym_preproc_error] = STATE(275),
    [sym_preproc_warning] = STATE(275),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(902),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(773),
    [sym_array_indexed_access] = STATE(493),
    [sym_parenthesized_expression] = STATE(773),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(491),
    [sym_scope_access] = STATE(510),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym__sizeof_call_expression] = STATE(954),
    [sym_array_scope_access] = STATE(955),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(773),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(916),
    [anon_sym_LPAREN] = ACTIONS(918),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(920),
    [sym_comment] = ACTIONS(19),
  },
  [276] = {
    [sym_preproc_include] = STATE(276),
    [sym_preproc_tryinclude] = STATE(276),
    [sym_preproc_macro] = STATE(276),
    [sym_preproc_define] = STATE(276),
    [sym_preproc_undefine] = STATE(276),
    [sym_preproc_if] = STATE(276),
    [sym_preproc_elseif] = STATE(276),
    [sym_preproc_assert] = STATE(276),
    [sym_preproc_pragma] = STATE(276),
    [sym_preproc_error] = STATE(276),
    [sym_preproc_warning] = STATE(276),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(279),
    [sym__expression] = STATE(779),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [277] = {
    [sym_preproc_include] = STATE(277),
    [sym_preproc_tryinclude] = STATE(277),
    [sym_preproc_macro] = STATE(277),
    [sym_preproc_define] = STATE(277),
    [sym_preproc_undefine] = STATE(277),
    [sym_preproc_if] = STATE(277),
    [sym_preproc_elseif] = STATE(277),
    [sym_preproc_assert] = STATE(277),
    [sym_preproc_pragma] = STATE(277),
    [sym_preproc_error] = STATE(277),
    [sym_preproc_warning] = STATE(277),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(254),
    [sym__expression] = STATE(815),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [278] = {
    [sym_preproc_include] = STATE(278),
    [sym_preproc_tryinclude] = STATE(278),
    [sym_preproc_macro] = STATE(278),
    [sym_preproc_define] = STATE(278),
    [sym_preproc_undefine] = STATE(278),
    [sym_preproc_if] = STATE(278),
    [sym_preproc_elseif] = STATE(278),
    [sym_preproc_assert] = STATE(278),
    [sym_preproc_pragma] = STATE(278),
    [sym_preproc_error] = STATE(278),
    [sym_preproc_warning] = STATE(278),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(255),
    [sym__expression] = STATE(817),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [279] = {
    [sym_preproc_include] = STATE(279),
    [sym_preproc_tryinclude] = STATE(279),
    [sym_preproc_macro] = STATE(279),
    [sym_preproc_define] = STATE(279),
    [sym_preproc_undefine] = STATE(279),
    [sym_preproc_if] = STATE(279),
    [sym_preproc_elseif] = STATE(279),
    [sym_preproc_assert] = STATE(279),
    [sym_preproc_pragma] = STATE(279),
    [sym_preproc_error] = STATE(279),
    [sym_preproc_warning] = STATE(279),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(778),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1517),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(922),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [280] = {
    [sym_preproc_include] = STATE(280),
    [sym_preproc_tryinclude] = STATE(280),
    [sym_preproc_macro] = STATE(280),
    [sym_preproc_define] = STATE(280),
    [sym_preproc_undefine] = STATE(280),
    [sym_preproc_if] = STATE(280),
    [sym_preproc_elseif] = STATE(280),
    [sym_preproc_assert] = STATE(280),
    [sym_preproc_pragma] = STATE(280),
    [sym_preproc_error] = STATE(280),
    [sym_preproc_warning] = STATE(280),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(265),
    [sym__expression] = STATE(821),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [281] = {
    [sym_preproc_include] = STATE(281),
    [sym_preproc_tryinclude] = STATE(281),
    [sym_preproc_macro] = STATE(281),
    [sym_preproc_define] = STATE(281),
    [sym_preproc_undefine] = STATE(281),
    [sym_preproc_if] = STATE(281),
    [sym_preproc_elseif] = STATE(281),
    [sym_preproc_assert] = STATE(281),
    [sym_preproc_pragma] = STATE(281),
    [sym_preproc_error] = STATE(281),
    [sym_preproc_warning] = STATE(281),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(266),
    [sym__expression] = STATE(822),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [282] = {
    [sym_preproc_include] = STATE(282),
    [sym_preproc_tryinclude] = STATE(282),
    [sym_preproc_macro] = STATE(282),
    [sym_preproc_define] = STATE(282),
    [sym_preproc_undefine] = STATE(282),
    [sym_preproc_if] = STATE(282),
    [sym_preproc_elseif] = STATE(282),
    [sym_preproc_assert] = STATE(282),
    [sym_preproc_pragma] = STATE(282),
    [sym_preproc_error] = STATE(282),
    [sym_preproc_warning] = STATE(282),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__manual_semicolon] = STATE(269),
    [sym__expression] = STATE(823),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [283] = {
    [sym_preproc_include] = STATE(283),
    [sym_preproc_tryinclude] = STATE(283),
    [sym_preproc_macro] = STATE(283),
    [sym_preproc_define] = STATE(283),
    [sym_preproc_undefine] = STATE(283),
    [sym_preproc_if] = STATE(283),
    [sym_preproc_elseif] = STATE(283),
    [sym_preproc_assert] = STATE(283),
    [sym_preproc_pragma] = STATE(283),
    [sym_preproc_error] = STATE(283),
    [sym_preproc_warning] = STATE(283),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(922),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(203),
    [sym_array_indexed_access] = STATE(85),
    [sym_parenthesized_expression] = STATE(203),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(86),
    [sym_scope_access] = STATE(94),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym__sizeof_call_expression] = STATE(206),
    [sym_array_scope_access] = STATE(168),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(203),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(924),
    [anon_sym_LPAREN] = ACTIONS(926),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(928),
    [sym_comment] = ACTIONS(19),
  },
  [284] = {
    [sym_preproc_include] = STATE(284),
    [sym_preproc_tryinclude] = STATE(284),
    [sym_preproc_macro] = STATE(284),
    [sym_preproc_define] = STATE(284),
    [sym_preproc_undefine] = STATE(284),
    [sym_preproc_if] = STATE(284),
    [sym_preproc_elseif] = STATE(284),
    [sym_preproc_assert] = STATE(284),
    [sym_preproc_pragma] = STATE(284),
    [sym_preproc_error] = STATE(284),
    [sym_preproc_warning] = STATE(284),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(819),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1585),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(930),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [285] = {
    [sym_preproc_include] = STATE(285),
    [sym_preproc_tryinclude] = STATE(285),
    [sym_preproc_macro] = STATE(285),
    [sym_preproc_define] = STATE(285),
    [sym_preproc_undefine] = STATE(285),
    [sym_preproc_if] = STATE(285),
    [sym_preproc_elseif] = STATE(285),
    [sym_preproc_assert] = STATE(285),
    [sym_preproc_pragma] = STATE(285),
    [sym_preproc_error] = STATE(285),
    [sym_preproc_warning] = STATE(285),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(780),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1566),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(932),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [286] = {
    [sym_preproc_include] = STATE(286),
    [sym_preproc_tryinclude] = STATE(286),
    [sym_preproc_macro] = STATE(286),
    [sym_preproc_define] = STATE(286),
    [sym_preproc_undefine] = STATE(286),
    [sym_preproc_if] = STATE(286),
    [sym_preproc_elseif] = STATE(286),
    [sym_preproc_assert] = STATE(286),
    [sym_preproc_pragma] = STATE(286),
    [sym_preproc_error] = STATE(286),
    [sym_preproc_warning] = STATE(286),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(811),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1558),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(934),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [287] = {
    [sym_preproc_include] = STATE(287),
    [sym_preproc_tryinclude] = STATE(287),
    [sym_preproc_macro] = STATE(287),
    [sym_preproc_define] = STATE(287),
    [sym_preproc_undefine] = STATE(287),
    [sym_preproc_if] = STATE(287),
    [sym_preproc_elseif] = STATE(287),
    [sym_preproc_assert] = STATE(287),
    [sym_preproc_pragma] = STATE(287),
    [sym_preproc_error] = STATE(287),
    [sym_preproc_warning] = STATE(287),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(805),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1504),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(936),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [288] = {
    [sym_preproc_include] = STATE(288),
    [sym_preproc_tryinclude] = STATE(288),
    [sym_preproc_macro] = STATE(288),
    [sym_preproc_define] = STATE(288),
    [sym_preproc_undefine] = STATE(288),
    [sym_preproc_if] = STATE(288),
    [sym_preproc_elseif] = STATE(288),
    [sym_preproc_assert] = STATE(288),
    [sym_preproc_pragma] = STATE(288),
    [sym_preproc_error] = STATE(288),
    [sym_preproc_warning] = STATE(288),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(813),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1551),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [289] = {
    [sym_preproc_include] = STATE(289),
    [sym_preproc_tryinclude] = STATE(289),
    [sym_preproc_macro] = STATE(289),
    [sym_preproc_define] = STATE(289),
    [sym_preproc_undefine] = STATE(289),
    [sym_preproc_if] = STATE(289),
    [sym_preproc_elseif] = STATE(289),
    [sym_preproc_assert] = STATE(289),
    [sym_preproc_pragma] = STATE(289),
    [sym_preproc_error] = STATE(289),
    [sym_preproc_warning] = STATE(289),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(801),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1471),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [290] = {
    [sym_preproc_include] = STATE(290),
    [sym_preproc_tryinclude] = STATE(290),
    [sym_preproc_macro] = STATE(290),
    [sym_preproc_define] = STATE(290),
    [sym_preproc_undefine] = STATE(290),
    [sym_preproc_if] = STATE(290),
    [sym_preproc_elseif] = STATE(290),
    [sym_preproc_assert] = STATE(290),
    [sym_preproc_pragma] = STATE(290),
    [sym_preproc_error] = STATE(290),
    [sym_preproc_warning] = STATE(290),
    [sym_identifier] = ACTIONS(938),
    [anon_sym_LPAREN] = ACTIONS(940),
    [anon_sym_RPAREN] = ACTIONS(940),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(938),
    [anon_sym_AMP] = ACTIONS(940),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(940),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(940),
    [anon_sym_const] = ACTIONS(938),
    [anon_sym_public] = ACTIONS(938),
    [anon_sym_stock] = ACTIONS(938),
    [anon_sym_static] = ACTIONS(938),
    [anon_sym_new] = ACTIONS(938),
    [anon_sym_decl] = ACTIONS(938),
    [anon_sym_LBRACE] = ACTIONS(940),
    [anon_sym_RBRACE] = ACTIONS(940),
    [anon_sym_void] = ACTIONS(938),
    [anon_sym_bool] = ACTIONS(938),
    [anon_sym_int] = ACTIONS(938),
    [anon_sym_float] = ACTIONS(938),
    [anon_sym_char] = ACTIONS(938),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_Float] = ACTIONS(938),
    [anon_sym_String] = ACTIONS(938),
    [sym_any_type] = ACTIONS(938),
    [anon_sym_for] = ACTIONS(938),
    [anon_sym_while] = ACTIONS(938),
    [anon_sym_do] = ACTIONS(938),
    [anon_sym_break] = ACTIONS(938),
    [anon_sym_continue] = ACTIONS(938),
    [anon_sym_if] = ACTIONS(938),
    [anon_sym_switch] = ACTIONS(938),
    [anon_sym_return] = ACTIONS(938),
    [anon_sym_delete] = ACTIONS(938),
    [anon_sym_DASH_DASH] = ACTIONS(940),
    [anon_sym_PLUS_PLUS] = ACTIONS(940),
    [anon_sym_sizeof] = ACTIONS(938),
    [anon_sym_view_as] = ACTIONS(938),
    [sym_int_literal] = ACTIONS(938),
    [sym_float_literal] = ACTIONS(940),
    [anon_sym_SQUOTE] = ACTIONS(940),
    [anon_sym_DQUOTE] = ACTIONS(940),
    [sym_bool_literal] = ACTIONS(938),
    [sym_null] = ACTIONS(938),
    [sym_this] = ACTIONS(938),
    [sym_comment] = ACTIONS(19),
  },
  [291] = {
    [sym_preproc_include] = STATE(291),
    [sym_preproc_tryinclude] = STATE(291),
    [sym_preproc_macro] = STATE(291),
    [sym_preproc_define] = STATE(291),
    [sym_preproc_undefine] = STATE(291),
    [sym_preproc_if] = STATE(291),
    [sym_preproc_elseif] = STATE(291),
    [sym_preproc_assert] = STATE(291),
    [sym_preproc_pragma] = STATE(291),
    [sym_preproc_error] = STATE(291),
    [sym_preproc_warning] = STATE(291),
    [sym_identifier] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(944),
    [anon_sym_RPAREN] = ACTIONS(944),
    [anon_sym_BANG] = ACTIONS(944),
    [anon_sym_TILDE] = ACTIONS(944),
    [anon_sym_DASH] = ACTIONS(942),
    [anon_sym_PLUS] = ACTIONS(942),
    [anon_sym_AMP] = ACTIONS(944),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(942),
    [anon_sym_public] = ACTIONS(942),
    [anon_sym_stock] = ACTIONS(942),
    [anon_sym_static] = ACTIONS(942),
    [anon_sym_new] = ACTIONS(942),
    [anon_sym_decl] = ACTIONS(942),
    [anon_sym_LBRACE] = ACTIONS(944),
    [anon_sym_RBRACE] = ACTIONS(944),
    [anon_sym_void] = ACTIONS(942),
    [anon_sym_bool] = ACTIONS(942),
    [anon_sym_int] = ACTIONS(942),
    [anon_sym_float] = ACTIONS(942),
    [anon_sym_char] = ACTIONS(942),
    [anon_sym__] = ACTIONS(942),
    [anon_sym_Float] = ACTIONS(942),
    [anon_sym_String] = ACTIONS(942),
    [sym_any_type] = ACTIONS(942),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_while] = ACTIONS(942),
    [anon_sym_do] = ACTIONS(942),
    [anon_sym_break] = ACTIONS(942),
    [anon_sym_continue] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(942),
    [anon_sym_else] = ACTIONS(942),
    [anon_sym_switch] = ACTIONS(942),
    [anon_sym_return] = ACTIONS(942),
    [anon_sym_delete] = ACTIONS(942),
    [anon_sym_SEMI] = ACTIONS(944),
    [anon_sym_DASH_DASH] = ACTIONS(944),
    [anon_sym_PLUS_PLUS] = ACTIONS(944),
    [anon_sym_sizeof] = ACTIONS(942),
    [anon_sym_view_as] = ACTIONS(942),
    [sym_int_literal] = ACTIONS(942),
    [sym_float_literal] = ACTIONS(944),
    [anon_sym_SQUOTE] = ACTIONS(944),
    [anon_sym_DQUOTE] = ACTIONS(944),
    [sym_bool_literal] = ACTIONS(942),
    [sym_null] = ACTIONS(942),
    [sym_this] = ACTIONS(942),
    [sym_comment] = ACTIONS(19),
  },
  [292] = {
    [sym_preproc_include] = STATE(292),
    [sym_preproc_tryinclude] = STATE(292),
    [sym_preproc_macro] = STATE(292),
    [sym_preproc_define] = STATE(292),
    [sym_preproc_undefine] = STATE(292),
    [sym_preproc_if] = STATE(292),
    [sym_preproc_elseif] = STATE(292),
    [sym_preproc_assert] = STATE(292),
    [sym_preproc_pragma] = STATE(292),
    [sym_preproc_error] = STATE(292),
    [sym_preproc_warning] = STATE(292),
    [sym_identifier] = ACTIONS(946),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_RPAREN] = ACTIONS(948),
    [anon_sym_BANG] = ACTIONS(948),
    [anon_sym_TILDE] = ACTIONS(948),
    [anon_sym_DASH] = ACTIONS(946),
    [anon_sym_PLUS] = ACTIONS(946),
    [anon_sym_AMP] = ACTIONS(948),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(948),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(948),
    [anon_sym_const] = ACTIONS(946),
    [anon_sym_public] = ACTIONS(946),
    [anon_sym_stock] = ACTIONS(946),
    [anon_sym_static] = ACTIONS(946),
    [anon_sym_new] = ACTIONS(946),
    [anon_sym_decl] = ACTIONS(946),
    [anon_sym_LBRACE] = ACTIONS(948),
    [anon_sym_RBRACE] = ACTIONS(948),
    [anon_sym_void] = ACTIONS(946),
    [anon_sym_bool] = ACTIONS(946),
    [anon_sym_int] = ACTIONS(946),
    [anon_sym_float] = ACTIONS(946),
    [anon_sym_char] = ACTIONS(946),
    [anon_sym__] = ACTIONS(946),
    [anon_sym_Float] = ACTIONS(946),
    [anon_sym_String] = ACTIONS(946),
    [sym_any_type] = ACTIONS(946),
    [anon_sym_for] = ACTIONS(946),
    [anon_sym_while] = ACTIONS(946),
    [anon_sym_do] = ACTIONS(946),
    [anon_sym_break] = ACTIONS(946),
    [anon_sym_continue] = ACTIONS(946),
    [anon_sym_if] = ACTIONS(946),
    [anon_sym_switch] = ACTIONS(946),
    [anon_sym_return] = ACTIONS(946),
    [anon_sym_delete] = ACTIONS(946),
    [anon_sym_DASH_DASH] = ACTIONS(948),
    [anon_sym_PLUS_PLUS] = ACTIONS(948),
    [anon_sym_sizeof] = ACTIONS(946),
    [anon_sym_view_as] = ACTIONS(946),
    [sym_int_literal] = ACTIONS(946),
    [sym_float_literal] = ACTIONS(948),
    [anon_sym_SQUOTE] = ACTIONS(948),
    [anon_sym_DQUOTE] = ACTIONS(948),
    [sym_bool_literal] = ACTIONS(946),
    [sym_null] = ACTIONS(946),
    [sym_this] = ACTIONS(946),
    [sym_comment] = ACTIONS(19),
  },
  [293] = {
    [sym_preproc_include] = STATE(293),
    [sym_preproc_tryinclude] = STATE(293),
    [sym_preproc_macro] = STATE(293),
    [sym_preproc_define] = STATE(293),
    [sym_preproc_undefine] = STATE(293),
    [sym_preproc_if] = STATE(293),
    [sym_preproc_elseif] = STATE(293),
    [sym_preproc_assert] = STATE(293),
    [sym_preproc_pragma] = STATE(293),
    [sym_preproc_error] = STATE(293),
    [sym_preproc_warning] = STATE(293),
    [sym_dynamic_array] = STATE(119),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(112),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(950),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [294] = {
    [sym_preproc_include] = STATE(294),
    [sym_preproc_tryinclude] = STATE(294),
    [sym_preproc_macro] = STATE(294),
    [sym_preproc_define] = STATE(294),
    [sym_preproc_undefine] = STATE(294),
    [sym_preproc_if] = STATE(294),
    [sym_preproc_elseif] = STATE(294),
    [sym_preproc_assert] = STATE(294),
    [sym_preproc_pragma] = STATE(294),
    [sym_preproc_error] = STATE(294),
    [sym_preproc_warning] = STATE(294),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(828),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1479),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [295] = {
    [sym_preproc_include] = STATE(295),
    [sym_preproc_tryinclude] = STATE(295),
    [sym_preproc_macro] = STATE(295),
    [sym_preproc_define] = STATE(295),
    [sym_preproc_undefine] = STATE(295),
    [sym_preproc_if] = STATE(295),
    [sym_preproc_elseif] = STATE(295),
    [sym_preproc_assert] = STATE(295),
    [sym_preproc_pragma] = STATE(295),
    [sym_preproc_error] = STATE(295),
    [sym_preproc_warning] = STATE(295),
    [sym_identifier] = ACTIONS(574),
    [anon_sym_LPAREN] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_AMP] = ACTIONS(576),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(574),
    [anon_sym_public] = ACTIONS(574),
    [anon_sym_stock] = ACTIONS(574),
    [anon_sym_static] = ACTIONS(574),
    [anon_sym_new] = ACTIONS(574),
    [anon_sym_decl] = ACTIONS(574),
    [anon_sym_LBRACE] = ACTIONS(576),
    [anon_sym_RBRACE] = ACTIONS(576),
    [anon_sym_void] = ACTIONS(574),
    [anon_sym_bool] = ACTIONS(574),
    [anon_sym_int] = ACTIONS(574),
    [anon_sym_float] = ACTIONS(574),
    [anon_sym_char] = ACTIONS(574),
    [anon_sym__] = ACTIONS(574),
    [anon_sym_Float] = ACTIONS(574),
    [anon_sym_String] = ACTIONS(574),
    [sym_any_type] = ACTIONS(574),
    [anon_sym_for] = ACTIONS(574),
    [anon_sym_while] = ACTIONS(574),
    [anon_sym_do] = ACTIONS(574),
    [anon_sym_break] = ACTIONS(574),
    [anon_sym_continue] = ACTIONS(574),
    [anon_sym_if] = ACTIONS(574),
    [anon_sym_else] = ACTIONS(574),
    [anon_sym_switch] = ACTIONS(574),
    [anon_sym_return] = ACTIONS(574),
    [anon_sym_delete] = ACTIONS(574),
    [anon_sym_SEMI] = ACTIONS(576),
    [anon_sym_DASH_DASH] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(576),
    [anon_sym_sizeof] = ACTIONS(574),
    [anon_sym_view_as] = ACTIONS(574),
    [sym_int_literal] = ACTIONS(574),
    [sym_float_literal] = ACTIONS(576),
    [anon_sym_SQUOTE] = ACTIONS(576),
    [anon_sym_DQUOTE] = ACTIONS(576),
    [sym_bool_literal] = ACTIONS(574),
    [sym_null] = ACTIONS(574),
    [sym_this] = ACTIONS(574),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(576),
  },
  [296] = {
    [sym_preproc_include] = STATE(296),
    [sym_preproc_tryinclude] = STATE(296),
    [sym_preproc_macro] = STATE(296),
    [sym_preproc_define] = STATE(296),
    [sym_preproc_undefine] = STATE(296),
    [sym_preproc_if] = STATE(296),
    [sym_preproc_elseif] = STATE(296),
    [sym_preproc_assert] = STATE(296),
    [sym_preproc_pragma] = STATE(296),
    [sym_preproc_error] = STATE(296),
    [sym_preproc_warning] = STATE(296),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(172),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_comma_expression] = STATE(541),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [297] = {
    [sym_preproc_include] = STATE(297),
    [sym_preproc_tryinclude] = STATE(297),
    [sym_preproc_macro] = STATE(297),
    [sym_preproc_define] = STATE(297),
    [sym_preproc_undefine] = STATE(297),
    [sym_preproc_if] = STATE(297),
    [sym_preproc_elseif] = STATE(297),
    [sym_preproc_assert] = STATE(297),
    [sym_preproc_pragma] = STATE(297),
    [sym_preproc_error] = STATE(297),
    [sym_preproc_warning] = STATE(297),
    [sym_dynamic_array] = STATE(178),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(179),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(952),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [298] = {
    [sym_preproc_include] = STATE(298),
    [sym_preproc_tryinclude] = STATE(298),
    [sym_preproc_macro] = STATE(298),
    [sym_preproc_define] = STATE(298),
    [sym_preproc_undefine] = STATE(298),
    [sym_preproc_if] = STATE(298),
    [sym_preproc_elseif] = STATE(298),
    [sym_preproc_assert] = STATE(298),
    [sym_preproc_pragma] = STATE(298),
    [sym_preproc_error] = STATE(298),
    [sym_preproc_warning] = STATE(298),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(857),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_RBRACK] = ACTIONS(954),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [299] = {
    [sym_preproc_include] = STATE(299),
    [sym_preproc_tryinclude] = STATE(299),
    [sym_preproc_macro] = STATE(299),
    [sym_preproc_define] = STATE(299),
    [sym_preproc_undefine] = STATE(299),
    [sym_preproc_if] = STATE(299),
    [sym_preproc_elseif] = STATE(299),
    [sym_preproc_assert] = STATE(299),
    [sym_preproc_pragma] = STATE(299),
    [sym_preproc_error] = STATE(299),
    [sym_preproc_warning] = STATE(299),
    [sym_dynamic_array] = STATE(867),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(853),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(964),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [300] = {
    [sym_preproc_include] = STATE(300),
    [sym_preproc_tryinclude] = STATE(300),
    [sym_preproc_macro] = STATE(300),
    [sym_preproc_define] = STATE(300),
    [sym_preproc_undefine] = STATE(300),
    [sym_preproc_if] = STATE(300),
    [sym_preproc_elseif] = STATE(300),
    [sym_preproc_assert] = STATE(300),
    [sym_preproc_pragma] = STATE(300),
    [sym_preproc_error] = STATE(300),
    [sym_preproc_warning] = STATE(300),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(771),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1586),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [301] = {
    [sym_preproc_include] = STATE(301),
    [sym_preproc_tryinclude] = STATE(301),
    [sym_preproc_macro] = STATE(301),
    [sym_preproc_define] = STATE(301),
    [sym_preproc_undefine] = STATE(301),
    [sym_preproc_if] = STATE(301),
    [sym_preproc_elseif] = STATE(301),
    [sym_preproc_assert] = STATE(301),
    [sym_preproc_pragma] = STATE(301),
    [sym_preproc_error] = STATE(301),
    [sym_preproc_warning] = STATE(301),
    [sym_identifier] = ACTIONS(974),
    [anon_sym_LPAREN] = ACTIONS(976),
    [anon_sym_RPAREN] = ACTIONS(976),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(974),
    [anon_sym_AMP] = ACTIONS(976),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(976),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(976),
    [anon_sym_const] = ACTIONS(974),
    [anon_sym_public] = ACTIONS(974),
    [anon_sym_stock] = ACTIONS(974),
    [anon_sym_static] = ACTIONS(974),
    [anon_sym_new] = ACTIONS(974),
    [anon_sym_decl] = ACTIONS(974),
    [anon_sym_LBRACE] = ACTIONS(976),
    [anon_sym_RBRACE] = ACTIONS(976),
    [anon_sym_void] = ACTIONS(974),
    [anon_sym_bool] = ACTIONS(974),
    [anon_sym_int] = ACTIONS(974),
    [anon_sym_float] = ACTIONS(974),
    [anon_sym_char] = ACTIONS(974),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_Float] = ACTIONS(974),
    [anon_sym_String] = ACTIONS(974),
    [sym_any_type] = ACTIONS(974),
    [anon_sym_for] = ACTIONS(974),
    [anon_sym_while] = ACTIONS(974),
    [anon_sym_do] = ACTIONS(974),
    [anon_sym_break] = ACTIONS(974),
    [anon_sym_continue] = ACTIONS(974),
    [anon_sym_if] = ACTIONS(974),
    [anon_sym_switch] = ACTIONS(974),
    [anon_sym_return] = ACTIONS(974),
    [anon_sym_delete] = ACTIONS(974),
    [anon_sym_DASH_DASH] = ACTIONS(976),
    [anon_sym_PLUS_PLUS] = ACTIONS(976),
    [anon_sym_sizeof] = ACTIONS(974),
    [anon_sym_view_as] = ACTIONS(974),
    [sym_int_literal] = ACTIONS(974),
    [sym_float_literal] = ACTIONS(976),
    [anon_sym_SQUOTE] = ACTIONS(976),
    [anon_sym_DQUOTE] = ACTIONS(976),
    [sym_bool_literal] = ACTIONS(974),
    [sym_null] = ACTIONS(974),
    [sym_this] = ACTIONS(974),
    [sym_comment] = ACTIONS(19),
  },
  [302] = {
    [sym_preproc_include] = STATE(302),
    [sym_preproc_tryinclude] = STATE(302),
    [sym_preproc_macro] = STATE(302),
    [sym_preproc_define] = STATE(302),
    [sym_preproc_undefine] = STATE(302),
    [sym_preproc_if] = STATE(302),
    [sym_preproc_elseif] = STATE(302),
    [sym_preproc_assert] = STATE(302),
    [sym_preproc_pragma] = STATE(302),
    [sym_preproc_error] = STATE(302),
    [sym_preproc_warning] = STATE(302),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(894),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_RBRACK] = ACTIONS(978),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [303] = {
    [sym_preproc_include] = STATE(303),
    [sym_preproc_tryinclude] = STATE(303),
    [sym_preproc_macro] = STATE(303),
    [sym_preproc_define] = STATE(303),
    [sym_preproc_undefine] = STATE(303),
    [sym_preproc_if] = STATE(303),
    [sym_preproc_elseif] = STATE(303),
    [sym_preproc_assert] = STATE(303),
    [sym_preproc_pragma] = STATE(303),
    [sym_preproc_error] = STATE(303),
    [sym_preproc_warning] = STATE(303),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(877),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_RBRACK] = ACTIONS(978),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [304] = {
    [sym_preproc_include] = STATE(304),
    [sym_preproc_tryinclude] = STATE(304),
    [sym_preproc_macro] = STATE(304),
    [sym_preproc_define] = STATE(304),
    [sym_preproc_undefine] = STATE(304),
    [sym_preproc_if] = STATE(304),
    [sym_preproc_elseif] = STATE(304),
    [sym_preproc_assert] = STATE(304),
    [sym_preproc_pragma] = STATE(304),
    [sym_preproc_error] = STATE(304),
    [sym_preproc_warning] = STATE(304),
    [sym_call_arguments] = STATE(632),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_RPAREN] = ACTIONS(246),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_LBRACK] = ACTIONS(980),
    [anon_sym_RBRACK] = ACTIONS(246),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_COLON_COLON] = ACTIONS(834),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
  },
  [305] = {
    [sym_preproc_include] = STATE(305),
    [sym_preproc_tryinclude] = STATE(305),
    [sym_preproc_macro] = STATE(305),
    [sym_preproc_define] = STATE(305),
    [sym_preproc_undefine] = STATE(305),
    [sym_preproc_if] = STATE(305),
    [sym_preproc_elseif] = STATE(305),
    [sym_preproc_assert] = STATE(305),
    [sym_preproc_pragma] = STATE(305),
    [sym_preproc_error] = STATE(305),
    [sym_preproc_warning] = STATE(305),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(886),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_RBRACK] = ACTIONS(954),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [306] = {
    [sym_preproc_include] = STATE(306),
    [sym_preproc_tryinclude] = STATE(306),
    [sym_preproc_macro] = STATE(306),
    [sym_preproc_define] = STATE(306),
    [sym_preproc_undefine] = STATE(306),
    [sym_preproc_if] = STATE(306),
    [sym_preproc_elseif] = STATE(306),
    [sym_preproc_assert] = STATE(306),
    [sym_preproc_pragma] = STATE(306),
    [sym_preproc_error] = STATE(306),
    [sym_preproc_warning] = STATE(306),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(144),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_comma_expression] = STATE(295),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [307] = {
    [sym_preproc_include] = STATE(307),
    [sym_preproc_tryinclude] = STATE(307),
    [sym_preproc_macro] = STATE(307),
    [sym_preproc_define] = STATE(307),
    [sym_preproc_undefine] = STATE(307),
    [sym_preproc_if] = STATE(307),
    [sym_preproc_elseif] = STATE(307),
    [sym_preproc_assert] = STATE(307),
    [sym_preproc_pragma] = STATE(307),
    [sym_preproc_error] = STATE(307),
    [sym_preproc_warning] = STATE(307),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(848),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_RBRACK] = ACTIONS(982),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [308] = {
    [sym_preproc_include] = STATE(308),
    [sym_preproc_tryinclude] = STATE(308),
    [sym_preproc_macro] = STATE(308),
    [sym_preproc_define] = STATE(308),
    [sym_preproc_undefine] = STATE(308),
    [sym_preproc_if] = STATE(308),
    [sym_preproc_elseif] = STATE(308),
    [sym_preproc_assert] = STATE(308),
    [sym_preproc_pragma] = STATE(308),
    [sym_preproc_error] = STATE(308),
    [sym_preproc_warning] = STATE(308),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(845),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_RBRACK] = ACTIONS(984),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [309] = {
    [sym_preproc_include] = STATE(309),
    [sym_preproc_tryinclude] = STATE(309),
    [sym_preproc_macro] = STATE(309),
    [sym_preproc_define] = STATE(309),
    [sym_preproc_undefine] = STATE(309),
    [sym_preproc_if] = STATE(309),
    [sym_preproc_elseif] = STATE(309),
    [sym_preproc_assert] = STATE(309),
    [sym_preproc_pragma] = STATE(309),
    [sym_preproc_error] = STATE(309),
    [sym_preproc_warning] = STATE(309),
    [sym_dynamic_array] = STATE(701),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(702),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [310] = {
    [sym_preproc_include] = STATE(310),
    [sym_preproc_tryinclude] = STATE(310),
    [sym_preproc_macro] = STATE(310),
    [sym_preproc_define] = STATE(310),
    [sym_preproc_undefine] = STATE(310),
    [sym_preproc_if] = STATE(310),
    [sym_preproc_elseif] = STATE(310),
    [sym_preproc_assert] = STATE(310),
    [sym_preproc_pragma] = STATE(310),
    [sym_preproc_error] = STATE(310),
    [sym_preproc_warning] = STATE(310),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(869),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_RBRACK] = ACTIONS(988),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [311] = {
    [sym_preproc_include] = STATE(311),
    [sym_preproc_tryinclude] = STATE(311),
    [sym_preproc_macro] = STATE(311),
    [sym_preproc_define] = STATE(311),
    [sym_preproc_undefine] = STATE(311),
    [sym_preproc_if] = STATE(311),
    [sym_preproc_elseif] = STATE(311),
    [sym_preproc_assert] = STATE(311),
    [sym_preproc_pragma] = STATE(311),
    [sym_preproc_error] = STATE(311),
    [sym_preproc_warning] = STATE(311),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(857),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_RBRACK] = ACTIONS(990),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [312] = {
    [sym_preproc_include] = STATE(312),
    [sym_preproc_tryinclude] = STATE(312),
    [sym_preproc_macro] = STATE(312),
    [sym_preproc_define] = STATE(312),
    [sym_preproc_undefine] = STATE(312),
    [sym_preproc_if] = STATE(312),
    [sym_preproc_elseif] = STATE(312),
    [sym_preproc_assert] = STATE(312),
    [sym_preproc_pragma] = STATE(312),
    [sym_preproc_error] = STATE(312),
    [sym_preproc_warning] = STATE(312),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(790),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1616),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [313] = {
    [sym_preproc_include] = STATE(313),
    [sym_preproc_tryinclude] = STATE(313),
    [sym_preproc_macro] = STATE(313),
    [sym_preproc_define] = STATE(313),
    [sym_preproc_undefine] = STATE(313),
    [sym_preproc_if] = STATE(313),
    [sym_preproc_elseif] = STATE(313),
    [sym_preproc_assert] = STATE(313),
    [sym_preproc_pragma] = STATE(313),
    [sym_preproc_error] = STATE(313),
    [sym_preproc_warning] = STATE(313),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(810),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_comma_expression] = STATE(1522),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [314] = {
    [sym_preproc_include] = STATE(314),
    [sym_preproc_tryinclude] = STATE(314),
    [sym_preproc_macro] = STATE(314),
    [sym_preproc_define] = STATE(314),
    [sym_preproc_undefine] = STATE(314),
    [sym_preproc_if] = STATE(314),
    [sym_preproc_elseif] = STATE(314),
    [sym_preproc_assert] = STATE(314),
    [sym_preproc_pragma] = STATE(314),
    [sym_preproc_error] = STATE(314),
    [sym_preproc_warning] = STATE(314),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(772),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [315] = {
    [sym_preproc_include] = STATE(315),
    [sym_preproc_tryinclude] = STATE(315),
    [sym_preproc_macro] = STATE(315),
    [sym_preproc_define] = STATE(315),
    [sym_preproc_undefine] = STATE(315),
    [sym_preproc_if] = STATE(315),
    [sym_preproc_elseif] = STATE(315),
    [sym_preproc_assert] = STATE(315),
    [sym_preproc_pragma] = STATE(315),
    [sym_preproc_error] = STATE(315),
    [sym_preproc_warning] = STATE(315),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(895),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [316] = {
    [sym_preproc_include] = STATE(316),
    [sym_preproc_tryinclude] = STATE(316),
    [sym_preproc_macro] = STATE(316),
    [sym_preproc_define] = STATE(316),
    [sym_preproc_undefine] = STATE(316),
    [sym_preproc_if] = STATE(316),
    [sym_preproc_elseif] = STATE(316),
    [sym_preproc_assert] = STATE(316),
    [sym_preproc_pragma] = STATE(316),
    [sym_preproc_error] = STATE(316),
    [sym_preproc_warning] = STATE(316),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(109),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [317] = {
    [sym_preproc_include] = STATE(317),
    [sym_preproc_tryinclude] = STATE(317),
    [sym_preproc_macro] = STATE(317),
    [sym_preproc_define] = STATE(317),
    [sym_preproc_undefine] = STATE(317),
    [sym_preproc_if] = STATE(317),
    [sym_preproc_elseif] = STATE(317),
    [sym_preproc_assert] = STATE(317),
    [sym_preproc_pragma] = STATE(317),
    [sym_preproc_error] = STATE(317),
    [sym_preproc_warning] = STATE(317),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(792),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [318] = {
    [sym_preproc_include] = STATE(318),
    [sym_preproc_tryinclude] = STATE(318),
    [sym_preproc_macro] = STATE(318),
    [sym_preproc_define] = STATE(318),
    [sym_preproc_undefine] = STATE(318),
    [sym_preproc_if] = STATE(318),
    [sym_preproc_elseif] = STATE(318),
    [sym_preproc_assert] = STATE(318),
    [sym_preproc_pragma] = STATE(318),
    [sym_preproc_error] = STATE(318),
    [sym_preproc_warning] = STATE(318),
    [sym_dimension] = STATE(621),
    [sym_call_arguments] = STATE(632),
    [aux_sym_function_definition_repeat1] = STATE(612),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(832),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_COLON_COLON] = ACTIONS(834),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
  },
  [319] = {
    [sym_preproc_include] = STATE(319),
    [sym_preproc_tryinclude] = STATE(319),
    [sym_preproc_macro] = STATE(319),
    [sym_preproc_define] = STATE(319),
    [sym_preproc_undefine] = STATE(319),
    [sym_preproc_if] = STATE(319),
    [sym_preproc_elseif] = STATE(319),
    [sym_preproc_assert] = STATE(319),
    [sym_preproc_pragma] = STATE(319),
    [sym_preproc_error] = STATE(319),
    [sym_preproc_warning] = STATE(319),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(115),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [320] = {
    [sym_preproc_include] = STATE(320),
    [sym_preproc_tryinclude] = STATE(320),
    [sym_preproc_macro] = STATE(320),
    [sym_preproc_define] = STATE(320),
    [sym_preproc_undefine] = STATE(320),
    [sym_preproc_if] = STATE(320),
    [sym_preproc_elseif] = STATE(320),
    [sym_preproc_assert] = STATE(320),
    [sym_preproc_pragma] = STATE(320),
    [sym_preproc_error] = STATE(320),
    [sym_preproc_warning] = STATE(320),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(116),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [321] = {
    [sym_preproc_include] = STATE(321),
    [sym_preproc_tryinclude] = STATE(321),
    [sym_preproc_macro] = STATE(321),
    [sym_preproc_define] = STATE(321),
    [sym_preproc_undefine] = STATE(321),
    [sym_preproc_if] = STATE(321),
    [sym_preproc_elseif] = STATE(321),
    [sym_preproc_assert] = STATE(321),
    [sym_preproc_pragma] = STATE(321),
    [sym_preproc_error] = STATE(321),
    [sym_preproc_warning] = STATE(321),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(120),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [322] = {
    [sym_preproc_include] = STATE(322),
    [sym_preproc_tryinclude] = STATE(322),
    [sym_preproc_macro] = STATE(322),
    [sym_preproc_define] = STATE(322),
    [sym_preproc_undefine] = STATE(322),
    [sym_preproc_if] = STATE(322),
    [sym_preproc_elseif] = STATE(322),
    [sym_preproc_assert] = STATE(322),
    [sym_preproc_pragma] = STATE(322),
    [sym_preproc_error] = STATE(322),
    [sym_preproc_warning] = STATE(322),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(121),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [323] = {
    [sym_preproc_include] = STATE(323),
    [sym_preproc_tryinclude] = STATE(323),
    [sym_preproc_macro] = STATE(323),
    [sym_preproc_define] = STATE(323),
    [sym_preproc_undefine] = STATE(323),
    [sym_preproc_if] = STATE(323),
    [sym_preproc_elseif] = STATE(323),
    [sym_preproc_assert] = STATE(323),
    [sym_preproc_pragma] = STATE(323),
    [sym_preproc_error] = STATE(323),
    [sym_preproc_warning] = STATE(323),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(124),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [324] = {
    [sym_preproc_include] = STATE(324),
    [sym_preproc_tryinclude] = STATE(324),
    [sym_preproc_macro] = STATE(324),
    [sym_preproc_define] = STATE(324),
    [sym_preproc_undefine] = STATE(324),
    [sym_preproc_if] = STATE(324),
    [sym_preproc_elseif] = STATE(324),
    [sym_preproc_assert] = STATE(324),
    [sym_preproc_pragma] = STATE(324),
    [sym_preproc_error] = STATE(324),
    [sym_preproc_warning] = STATE(324),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(132),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [325] = {
    [sym_preproc_include] = STATE(325),
    [sym_preproc_tryinclude] = STATE(325),
    [sym_preproc_macro] = STATE(325),
    [sym_preproc_define] = STATE(325),
    [sym_preproc_undefine] = STATE(325),
    [sym_preproc_if] = STATE(325),
    [sym_preproc_elseif] = STATE(325),
    [sym_preproc_assert] = STATE(325),
    [sym_preproc_pragma] = STATE(325),
    [sym_preproc_error] = STATE(325),
    [sym_preproc_warning] = STATE(325),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(133),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [326] = {
    [sym_preproc_include] = STATE(326),
    [sym_preproc_tryinclude] = STATE(326),
    [sym_preproc_macro] = STATE(326),
    [sym_preproc_define] = STATE(326),
    [sym_preproc_undefine] = STATE(326),
    [sym_preproc_if] = STATE(326),
    [sym_preproc_elseif] = STATE(326),
    [sym_preproc_assert] = STATE(326),
    [sym_preproc_pragma] = STATE(326),
    [sym_preproc_error] = STATE(326),
    [sym_preproc_warning] = STATE(326),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(135),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [327] = {
    [sym_preproc_include] = STATE(327),
    [sym_preproc_tryinclude] = STATE(327),
    [sym_preproc_macro] = STATE(327),
    [sym_preproc_define] = STATE(327),
    [sym_preproc_undefine] = STATE(327),
    [sym_preproc_if] = STATE(327),
    [sym_preproc_elseif] = STATE(327),
    [sym_preproc_assert] = STATE(327),
    [sym_preproc_pragma] = STATE(327),
    [sym_preproc_error] = STATE(327),
    [sym_preproc_warning] = STATE(327),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(141),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [328] = {
    [sym_preproc_include] = STATE(328),
    [sym_preproc_tryinclude] = STATE(328),
    [sym_preproc_macro] = STATE(328),
    [sym_preproc_define] = STATE(328),
    [sym_preproc_undefine] = STATE(328),
    [sym_preproc_if] = STATE(328),
    [sym_preproc_elseif] = STATE(328),
    [sym_preproc_assert] = STATE(328),
    [sym_preproc_pragma] = STATE(328),
    [sym_preproc_error] = STATE(328),
    [sym_preproc_warning] = STATE(328),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(142),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [329] = {
    [sym_preproc_include] = STATE(329),
    [sym_preproc_tryinclude] = STATE(329),
    [sym_preproc_macro] = STATE(329),
    [sym_preproc_define] = STATE(329),
    [sym_preproc_undefine] = STATE(329),
    [sym_preproc_if] = STATE(329),
    [sym_preproc_elseif] = STATE(329),
    [sym_preproc_assert] = STATE(329),
    [sym_preproc_pragma] = STATE(329),
    [sym_preproc_error] = STATE(329),
    [sym_preproc_warning] = STATE(329),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(170),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [330] = {
    [sym_preproc_include] = STATE(330),
    [sym_preproc_tryinclude] = STATE(330),
    [sym_preproc_macro] = STATE(330),
    [sym_preproc_define] = STATE(330),
    [sym_preproc_undefine] = STATE(330),
    [sym_preproc_if] = STATE(330),
    [sym_preproc_elseif] = STATE(330),
    [sym_preproc_assert] = STATE(330),
    [sym_preproc_pragma] = STATE(330),
    [sym_preproc_error] = STATE(330),
    [sym_preproc_warning] = STATE(330),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(831),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [331] = {
    [sym_preproc_include] = STATE(331),
    [sym_preproc_tryinclude] = STATE(331),
    [sym_preproc_macro] = STATE(331),
    [sym_preproc_define] = STATE(331),
    [sym_preproc_undefine] = STATE(331),
    [sym_preproc_if] = STATE(331),
    [sym_preproc_elseif] = STATE(331),
    [sym_preproc_assert] = STATE(331),
    [sym_preproc_pragma] = STATE(331),
    [sym_preproc_error] = STATE(331),
    [sym_preproc_warning] = STATE(331),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(863),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [332] = {
    [sym_preproc_include] = STATE(332),
    [sym_preproc_tryinclude] = STATE(332),
    [sym_preproc_macro] = STATE(332),
    [sym_preproc_define] = STATE(332),
    [sym_preproc_undefine] = STATE(332),
    [sym_preproc_if] = STATE(332),
    [sym_preproc_elseif] = STATE(332),
    [sym_preproc_assert] = STATE(332),
    [sym_preproc_pragma] = STATE(332),
    [sym_preproc_error] = STATE(332),
    [sym_preproc_warning] = STATE(332),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(832),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [333] = {
    [sym_preproc_include] = STATE(333),
    [sym_preproc_tryinclude] = STATE(333),
    [sym_preproc_macro] = STATE(333),
    [sym_preproc_define] = STATE(333),
    [sym_preproc_undefine] = STATE(333),
    [sym_preproc_if] = STATE(333),
    [sym_preproc_elseif] = STATE(333),
    [sym_preproc_assert] = STATE(333),
    [sym_preproc_pragma] = STATE(333),
    [sym_preproc_error] = STATE(333),
    [sym_preproc_warning] = STATE(333),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(166),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [334] = {
    [sym_preproc_include] = STATE(334),
    [sym_preproc_tryinclude] = STATE(334),
    [sym_preproc_macro] = STATE(334),
    [sym_preproc_define] = STATE(334),
    [sym_preproc_undefine] = STATE(334),
    [sym_preproc_if] = STATE(334),
    [sym_preproc_elseif] = STATE(334),
    [sym_preproc_assert] = STATE(334),
    [sym_preproc_pragma] = STATE(334),
    [sym_preproc_error] = STATE(334),
    [sym_preproc_warning] = STATE(334),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(762),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [335] = {
    [sym_preproc_include] = STATE(335),
    [sym_preproc_tryinclude] = STATE(335),
    [sym_preproc_macro] = STATE(335),
    [sym_preproc_define] = STATE(335),
    [sym_preproc_undefine] = STATE(335),
    [sym_preproc_if] = STATE(335),
    [sym_preproc_elseif] = STATE(335),
    [sym_preproc_assert] = STATE(335),
    [sym_preproc_pragma] = STATE(335),
    [sym_preproc_error] = STATE(335),
    [sym_preproc_warning] = STATE(335),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(886),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [336] = {
    [sym_preproc_include] = STATE(336),
    [sym_preproc_tryinclude] = STATE(336),
    [sym_preproc_macro] = STATE(336),
    [sym_preproc_define] = STATE(336),
    [sym_preproc_undefine] = STATE(336),
    [sym_preproc_if] = STATE(336),
    [sym_preproc_elseif] = STATE(336),
    [sym_preproc_assert] = STATE(336),
    [sym_preproc_pragma] = STATE(336),
    [sym_preproc_error] = STATE(336),
    [sym_preproc_warning] = STATE(336),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(146),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [337] = {
    [sym_preproc_include] = STATE(337),
    [sym_preproc_tryinclude] = STATE(337),
    [sym_preproc_macro] = STATE(337),
    [sym_preproc_define] = STATE(337),
    [sym_preproc_undefine] = STATE(337),
    [sym_preproc_if] = STATE(337),
    [sym_preproc_elseif] = STATE(337),
    [sym_preproc_assert] = STATE(337),
    [sym_preproc_pragma] = STATE(337),
    [sym_preproc_error] = STATE(337),
    [sym_preproc_warning] = STATE(337),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(756),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [338] = {
    [sym_preproc_include] = STATE(338),
    [sym_preproc_tryinclude] = STATE(338),
    [sym_preproc_macro] = STATE(338),
    [sym_preproc_define] = STATE(338),
    [sym_preproc_undefine] = STATE(338),
    [sym_preproc_if] = STATE(338),
    [sym_preproc_elseif] = STATE(338),
    [sym_preproc_assert] = STATE(338),
    [sym_preproc_pragma] = STATE(338),
    [sym_preproc_error] = STATE(338),
    [sym_preproc_warning] = STATE(338),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(764),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [339] = {
    [sym_preproc_include] = STATE(339),
    [sym_preproc_tryinclude] = STATE(339),
    [sym_preproc_macro] = STATE(339),
    [sym_preproc_define] = STATE(339),
    [sym_preproc_undefine] = STATE(339),
    [sym_preproc_if] = STATE(339),
    [sym_preproc_elseif] = STATE(339),
    [sym_preproc_assert] = STATE(339),
    [sym_preproc_pragma] = STATE(339),
    [sym_preproc_error] = STATE(339),
    [sym_preproc_warning] = STATE(339),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(837),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [340] = {
    [sym_preproc_include] = STATE(340),
    [sym_preproc_tryinclude] = STATE(340),
    [sym_preproc_macro] = STATE(340),
    [sym_preproc_define] = STATE(340),
    [sym_preproc_undefine] = STATE(340),
    [sym_preproc_if] = STATE(340),
    [sym_preproc_elseif] = STATE(340),
    [sym_preproc_assert] = STATE(340),
    [sym_preproc_pragma] = STATE(340),
    [sym_preproc_error] = STATE(340),
    [sym_preproc_warning] = STATE(340),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(659),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [341] = {
    [sym_preproc_include] = STATE(341),
    [sym_preproc_tryinclude] = STATE(341),
    [sym_preproc_macro] = STATE(341),
    [sym_preproc_define] = STATE(341),
    [sym_preproc_undefine] = STATE(341),
    [sym_preproc_if] = STATE(341),
    [sym_preproc_elseif] = STATE(341),
    [sym_preproc_assert] = STATE(341),
    [sym_preproc_pragma] = STATE(341),
    [sym_preproc_error] = STATE(341),
    [sym_preproc_warning] = STATE(341),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(754),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [342] = {
    [sym_preproc_include] = STATE(342),
    [sym_preproc_tryinclude] = STATE(342),
    [sym_preproc_macro] = STATE(342),
    [sym_preproc_define] = STATE(342),
    [sym_preproc_undefine] = STATE(342),
    [sym_preproc_if] = STATE(342),
    [sym_preproc_elseif] = STATE(342),
    [sym_preproc_assert] = STATE(342),
    [sym_preproc_pragma] = STATE(342),
    [sym_preproc_error] = STATE(342),
    [sym_preproc_warning] = STATE(342),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(176),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [343] = {
    [sym_preproc_include] = STATE(343),
    [sym_preproc_tryinclude] = STATE(343),
    [sym_preproc_macro] = STATE(343),
    [sym_preproc_define] = STATE(343),
    [sym_preproc_undefine] = STATE(343),
    [sym_preproc_if] = STATE(343),
    [sym_preproc_elseif] = STATE(343),
    [sym_preproc_assert] = STATE(343),
    [sym_preproc_pragma] = STATE(343),
    [sym_preproc_error] = STATE(343),
    [sym_preproc_warning] = STATE(343),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(758),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [344] = {
    [sym_preproc_include] = STATE(344),
    [sym_preproc_tryinclude] = STATE(344),
    [sym_preproc_macro] = STATE(344),
    [sym_preproc_define] = STATE(344),
    [sym_preproc_undefine] = STATE(344),
    [sym_preproc_if] = STATE(344),
    [sym_preproc_elseif] = STATE(344),
    [sym_preproc_assert] = STATE(344),
    [sym_preproc_pragma] = STATE(344),
    [sym_preproc_error] = STATE(344),
    [sym_preproc_warning] = STATE(344),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(820),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [345] = {
    [sym_preproc_include] = STATE(345),
    [sym_preproc_tryinclude] = STATE(345),
    [sym_preproc_macro] = STATE(345),
    [sym_preproc_define] = STATE(345),
    [sym_preproc_undefine] = STATE(345),
    [sym_preproc_if] = STATE(345),
    [sym_preproc_elseif] = STATE(345),
    [sym_preproc_assert] = STATE(345),
    [sym_preproc_pragma] = STATE(345),
    [sym_preproc_error] = STATE(345),
    [sym_preproc_warning] = STATE(345),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(180),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [346] = {
    [sym_preproc_include] = STATE(346),
    [sym_preproc_tryinclude] = STATE(346),
    [sym_preproc_macro] = STATE(346),
    [sym_preproc_define] = STATE(346),
    [sym_preproc_undefine] = STATE(346),
    [sym_preproc_if] = STATE(346),
    [sym_preproc_elseif] = STATE(346),
    [sym_preproc_assert] = STATE(346),
    [sym_preproc_pragma] = STATE(346),
    [sym_preproc_error] = STATE(346),
    [sym_preproc_warning] = STATE(346),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(181),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [347] = {
    [sym_preproc_include] = STATE(347),
    [sym_preproc_tryinclude] = STATE(347),
    [sym_preproc_macro] = STATE(347),
    [sym_preproc_define] = STATE(347),
    [sym_preproc_undefine] = STATE(347),
    [sym_preproc_if] = STATE(347),
    [sym_preproc_elseif] = STATE(347),
    [sym_preproc_assert] = STATE(347),
    [sym_preproc_pragma] = STATE(347),
    [sym_preproc_error] = STATE(347),
    [sym_preproc_warning] = STATE(347),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(182),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [348] = {
    [sym_preproc_include] = STATE(348),
    [sym_preproc_tryinclude] = STATE(348),
    [sym_preproc_macro] = STATE(348),
    [sym_preproc_define] = STATE(348),
    [sym_preproc_undefine] = STATE(348),
    [sym_preproc_if] = STATE(348),
    [sym_preproc_elseif] = STATE(348),
    [sym_preproc_assert] = STATE(348),
    [sym_preproc_pragma] = STATE(348),
    [sym_preproc_error] = STATE(348),
    [sym_preproc_warning] = STATE(348),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(183),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [349] = {
    [sym_preproc_include] = STATE(349),
    [sym_preproc_tryinclude] = STATE(349),
    [sym_preproc_macro] = STATE(349),
    [sym_preproc_define] = STATE(349),
    [sym_preproc_undefine] = STATE(349),
    [sym_preproc_if] = STATE(349),
    [sym_preproc_elseif] = STATE(349),
    [sym_preproc_assert] = STATE(349),
    [sym_preproc_pragma] = STATE(349),
    [sym_preproc_error] = STATE(349),
    [sym_preproc_warning] = STATE(349),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(839),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [350] = {
    [sym_preproc_include] = STATE(350),
    [sym_preproc_tryinclude] = STATE(350),
    [sym_preproc_macro] = STATE(350),
    [sym_preproc_define] = STATE(350),
    [sym_preproc_undefine] = STATE(350),
    [sym_preproc_if] = STATE(350),
    [sym_preproc_elseif] = STATE(350),
    [sym_preproc_assert] = STATE(350),
    [sym_preproc_pragma] = STATE(350),
    [sym_preproc_error] = STATE(350),
    [sym_preproc_warning] = STATE(350),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(184),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [351] = {
    [sym_preproc_include] = STATE(351),
    [sym_preproc_tryinclude] = STATE(351),
    [sym_preproc_macro] = STATE(351),
    [sym_preproc_define] = STATE(351),
    [sym_preproc_undefine] = STATE(351),
    [sym_preproc_if] = STATE(351),
    [sym_preproc_elseif] = STATE(351),
    [sym_preproc_assert] = STATE(351),
    [sym_preproc_pragma] = STATE(351),
    [sym_preproc_error] = STATE(351),
    [sym_preproc_warning] = STATE(351),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(185),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [352] = {
    [sym_preproc_include] = STATE(352),
    [sym_preproc_tryinclude] = STATE(352),
    [sym_preproc_macro] = STATE(352),
    [sym_preproc_define] = STATE(352),
    [sym_preproc_undefine] = STATE(352),
    [sym_preproc_if] = STATE(352),
    [sym_preproc_elseif] = STATE(352),
    [sym_preproc_assert] = STATE(352),
    [sym_preproc_pragma] = STATE(352),
    [sym_preproc_error] = STATE(352),
    [sym_preproc_warning] = STATE(352),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(186),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [353] = {
    [sym_preproc_include] = STATE(353),
    [sym_preproc_tryinclude] = STATE(353),
    [sym_preproc_macro] = STATE(353),
    [sym_preproc_define] = STATE(353),
    [sym_preproc_undefine] = STATE(353),
    [sym_preproc_if] = STATE(353),
    [sym_preproc_elseif] = STATE(353),
    [sym_preproc_assert] = STATE(353),
    [sym_preproc_pragma] = STATE(353),
    [sym_preproc_error] = STATE(353),
    [sym_preproc_warning] = STATE(353),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(187),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [354] = {
    [sym_preproc_include] = STATE(354),
    [sym_preproc_tryinclude] = STATE(354),
    [sym_preproc_macro] = STATE(354),
    [sym_preproc_define] = STATE(354),
    [sym_preproc_undefine] = STATE(354),
    [sym_preproc_if] = STATE(354),
    [sym_preproc_elseif] = STATE(354),
    [sym_preproc_assert] = STATE(354),
    [sym_preproc_pragma] = STATE(354),
    [sym_preproc_error] = STATE(354),
    [sym_preproc_warning] = STATE(354),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(188),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [355] = {
    [sym_preproc_include] = STATE(355),
    [sym_preproc_tryinclude] = STATE(355),
    [sym_preproc_macro] = STATE(355),
    [sym_preproc_define] = STATE(355),
    [sym_preproc_undefine] = STATE(355),
    [sym_preproc_if] = STATE(355),
    [sym_preproc_elseif] = STATE(355),
    [sym_preproc_assert] = STATE(355),
    [sym_preproc_pragma] = STATE(355),
    [sym_preproc_error] = STATE(355),
    [sym_preproc_warning] = STATE(355),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(189),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [356] = {
    [sym_preproc_include] = STATE(356),
    [sym_preproc_tryinclude] = STATE(356),
    [sym_preproc_macro] = STATE(356),
    [sym_preproc_define] = STATE(356),
    [sym_preproc_undefine] = STATE(356),
    [sym_preproc_if] = STATE(356),
    [sym_preproc_elseif] = STATE(356),
    [sym_preproc_assert] = STATE(356),
    [sym_preproc_pragma] = STATE(356),
    [sym_preproc_error] = STATE(356),
    [sym_preproc_warning] = STATE(356),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(854),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [357] = {
    [sym_preproc_include] = STATE(357),
    [sym_preproc_tryinclude] = STATE(357),
    [sym_preproc_macro] = STATE(357),
    [sym_preproc_define] = STATE(357),
    [sym_preproc_undefine] = STATE(357),
    [sym_preproc_if] = STATE(357),
    [sym_preproc_elseif] = STATE(357),
    [sym_preproc_assert] = STATE(357),
    [sym_preproc_pragma] = STATE(357),
    [sym_preproc_error] = STATE(357),
    [sym_preproc_warning] = STATE(357),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(856),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [358] = {
    [sym_preproc_include] = STATE(358),
    [sym_preproc_tryinclude] = STATE(358),
    [sym_preproc_macro] = STATE(358),
    [sym_preproc_define] = STATE(358),
    [sym_preproc_undefine] = STATE(358),
    [sym_preproc_if] = STATE(358),
    [sym_preproc_elseif] = STATE(358),
    [sym_preproc_assert] = STATE(358),
    [sym_preproc_pragma] = STATE(358),
    [sym_preproc_error] = STATE(358),
    [sym_preproc_warning] = STATE(358),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(858),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [359] = {
    [sym_preproc_include] = STATE(359),
    [sym_preproc_tryinclude] = STATE(359),
    [sym_preproc_macro] = STATE(359),
    [sym_preproc_define] = STATE(359),
    [sym_preproc_undefine] = STATE(359),
    [sym_preproc_if] = STATE(359),
    [sym_preproc_elseif] = STATE(359),
    [sym_preproc_assert] = STATE(359),
    [sym_preproc_pragma] = STATE(359),
    [sym_preproc_error] = STATE(359),
    [sym_preproc_warning] = STATE(359),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(859),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [360] = {
    [sym_preproc_include] = STATE(360),
    [sym_preproc_tryinclude] = STATE(360),
    [sym_preproc_macro] = STATE(360),
    [sym_preproc_define] = STATE(360),
    [sym_preproc_undefine] = STATE(360),
    [sym_preproc_if] = STATE(360),
    [sym_preproc_elseif] = STATE(360),
    [sym_preproc_assert] = STATE(360),
    [sym_preproc_pragma] = STATE(360),
    [sym_preproc_error] = STATE(360),
    [sym_preproc_warning] = STATE(360),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(829),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [361] = {
    [sym_preproc_include] = STATE(361),
    [sym_preproc_tryinclude] = STATE(361),
    [sym_preproc_macro] = STATE(361),
    [sym_preproc_define] = STATE(361),
    [sym_preproc_undefine] = STATE(361),
    [sym_preproc_if] = STATE(361),
    [sym_preproc_elseif] = STATE(361),
    [sym_preproc_assert] = STATE(361),
    [sym_preproc_pragma] = STATE(361),
    [sym_preproc_error] = STATE(361),
    [sym_preproc_warning] = STATE(361),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(866),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [362] = {
    [sym_preproc_include] = STATE(362),
    [sym_preproc_tryinclude] = STATE(362),
    [sym_preproc_macro] = STATE(362),
    [sym_preproc_define] = STATE(362),
    [sym_preproc_undefine] = STATE(362),
    [sym_preproc_if] = STATE(362),
    [sym_preproc_elseif] = STATE(362),
    [sym_preproc_assert] = STATE(362),
    [sym_preproc_pragma] = STATE(362),
    [sym_preproc_error] = STATE(362),
    [sym_preproc_warning] = STATE(362),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(868),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [363] = {
    [sym_preproc_include] = STATE(363),
    [sym_preproc_tryinclude] = STATE(363),
    [sym_preproc_macro] = STATE(363),
    [sym_preproc_define] = STATE(363),
    [sym_preproc_undefine] = STATE(363),
    [sym_preproc_if] = STATE(363),
    [sym_preproc_elseif] = STATE(363),
    [sym_preproc_assert] = STATE(363),
    [sym_preproc_pragma] = STATE(363),
    [sym_preproc_error] = STATE(363),
    [sym_preproc_warning] = STATE(363),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(875),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [364] = {
    [sym_preproc_include] = STATE(364),
    [sym_preproc_tryinclude] = STATE(364),
    [sym_preproc_macro] = STATE(364),
    [sym_preproc_define] = STATE(364),
    [sym_preproc_undefine] = STATE(364),
    [sym_preproc_if] = STATE(364),
    [sym_preproc_elseif] = STATE(364),
    [sym_preproc_assert] = STATE(364),
    [sym_preproc_pragma] = STATE(364),
    [sym_preproc_error] = STATE(364),
    [sym_preproc_warning] = STATE(364),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(881),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [365] = {
    [sym_preproc_include] = STATE(365),
    [sym_preproc_tryinclude] = STATE(365),
    [sym_preproc_macro] = STATE(365),
    [sym_preproc_define] = STATE(365),
    [sym_preproc_undefine] = STATE(365),
    [sym_preproc_if] = STATE(365),
    [sym_preproc_elseif] = STATE(365),
    [sym_preproc_assert] = STATE(365),
    [sym_preproc_pragma] = STATE(365),
    [sym_preproc_error] = STATE(365),
    [sym_preproc_warning] = STATE(365),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(883),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [366] = {
    [sym_preproc_include] = STATE(366),
    [sym_preproc_tryinclude] = STATE(366),
    [sym_preproc_macro] = STATE(366),
    [sym_preproc_define] = STATE(366),
    [sym_preproc_undefine] = STATE(366),
    [sym_preproc_if] = STATE(366),
    [sym_preproc_elseif] = STATE(366),
    [sym_preproc_assert] = STATE(366),
    [sym_preproc_pragma] = STATE(366),
    [sym_preproc_error] = STATE(366),
    [sym_preproc_warning] = STATE(366),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(777),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [367] = {
    [sym_preproc_include] = STATE(367),
    [sym_preproc_tryinclude] = STATE(367),
    [sym_preproc_macro] = STATE(367),
    [sym_preproc_define] = STATE(367),
    [sym_preproc_undefine] = STATE(367),
    [sym_preproc_if] = STATE(367),
    [sym_preproc_elseif] = STATE(367),
    [sym_preproc_assert] = STATE(367),
    [sym_preproc_pragma] = STATE(367),
    [sym_preproc_error] = STATE(367),
    [sym_preproc_warning] = STATE(367),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(889),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [368] = {
    [sym_preproc_include] = STATE(368),
    [sym_preproc_tryinclude] = STATE(368),
    [sym_preproc_macro] = STATE(368),
    [sym_preproc_define] = STATE(368),
    [sym_preproc_undefine] = STATE(368),
    [sym_preproc_if] = STATE(368),
    [sym_preproc_elseif] = STATE(368),
    [sym_preproc_assert] = STATE(368),
    [sym_preproc_pragma] = STATE(368),
    [sym_preproc_error] = STATE(368),
    [sym_preproc_warning] = STATE(368),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(879),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [369] = {
    [sym_preproc_include] = STATE(369),
    [sym_preproc_tryinclude] = STATE(369),
    [sym_preproc_macro] = STATE(369),
    [sym_preproc_define] = STATE(369),
    [sym_preproc_undefine] = STATE(369),
    [sym_preproc_if] = STATE(369),
    [sym_preproc_elseif] = STATE(369),
    [sym_preproc_assert] = STATE(369),
    [sym_preproc_pragma] = STATE(369),
    [sym_preproc_error] = STATE(369),
    [sym_preproc_warning] = STATE(369),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(783),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [370] = {
    [sym_preproc_include] = STATE(370),
    [sym_preproc_tryinclude] = STATE(370),
    [sym_preproc_macro] = STATE(370),
    [sym_preproc_define] = STATE(370),
    [sym_preproc_undefine] = STATE(370),
    [sym_preproc_if] = STATE(370),
    [sym_preproc_elseif] = STATE(370),
    [sym_preproc_assert] = STATE(370),
    [sym_preproc_pragma] = STATE(370),
    [sym_preproc_error] = STATE(370),
    [sym_preproc_warning] = STATE(370),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(785),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [371] = {
    [sym_preproc_include] = STATE(371),
    [sym_preproc_tryinclude] = STATE(371),
    [sym_preproc_macro] = STATE(371),
    [sym_preproc_define] = STATE(371),
    [sym_preproc_undefine] = STATE(371),
    [sym_preproc_if] = STATE(371),
    [sym_preproc_elseif] = STATE(371),
    [sym_preproc_assert] = STATE(371),
    [sym_preproc_pragma] = STATE(371),
    [sym_preproc_error] = STATE(371),
    [sym_preproc_warning] = STATE(371),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(789),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [372] = {
    [sym_preproc_include] = STATE(372),
    [sym_preproc_tryinclude] = STATE(372),
    [sym_preproc_macro] = STATE(372),
    [sym_preproc_define] = STATE(372),
    [sym_preproc_undefine] = STATE(372),
    [sym_preproc_if] = STATE(372),
    [sym_preproc_elseif] = STATE(372),
    [sym_preproc_assert] = STATE(372),
    [sym_preproc_pragma] = STATE(372),
    [sym_preproc_error] = STATE(372),
    [sym_preproc_warning] = STATE(372),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(793),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [373] = {
    [sym_preproc_include] = STATE(373),
    [sym_preproc_tryinclude] = STATE(373),
    [sym_preproc_macro] = STATE(373),
    [sym_preproc_define] = STATE(373),
    [sym_preproc_undefine] = STATE(373),
    [sym_preproc_if] = STATE(373),
    [sym_preproc_elseif] = STATE(373),
    [sym_preproc_assert] = STATE(373),
    [sym_preproc_pragma] = STATE(373),
    [sym_preproc_error] = STATE(373),
    [sym_preproc_warning] = STATE(373),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(662),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [374] = {
    [sym_preproc_include] = STATE(374),
    [sym_preproc_tryinclude] = STATE(374),
    [sym_preproc_macro] = STATE(374),
    [sym_preproc_define] = STATE(374),
    [sym_preproc_undefine] = STATE(374),
    [sym_preproc_if] = STATE(374),
    [sym_preproc_elseif] = STATE(374),
    [sym_preproc_assert] = STATE(374),
    [sym_preproc_pragma] = STATE(374),
    [sym_preproc_error] = STATE(374),
    [sym_preproc_warning] = STATE(374),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(816),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [375] = {
    [sym_preproc_include] = STATE(375),
    [sym_preproc_tryinclude] = STATE(375),
    [sym_preproc_macro] = STATE(375),
    [sym_preproc_define] = STATE(375),
    [sym_preproc_undefine] = STATE(375),
    [sym_preproc_if] = STATE(375),
    [sym_preproc_elseif] = STATE(375),
    [sym_preproc_assert] = STATE(375),
    [sym_preproc_pragma] = STATE(375),
    [sym_preproc_error] = STATE(375),
    [sym_preproc_warning] = STATE(375),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(752),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [376] = {
    [sym_preproc_include] = STATE(376),
    [sym_preproc_tryinclude] = STATE(376),
    [sym_preproc_macro] = STATE(376),
    [sym_preproc_define] = STATE(376),
    [sym_preproc_undefine] = STATE(376),
    [sym_preproc_if] = STATE(376),
    [sym_preproc_elseif] = STATE(376),
    [sym_preproc_assert] = STATE(376),
    [sym_preproc_pragma] = STATE(376),
    [sym_preproc_error] = STATE(376),
    [sym_preproc_warning] = STATE(376),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(721),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [377] = {
    [sym_preproc_include] = STATE(377),
    [sym_preproc_tryinclude] = STATE(377),
    [sym_preproc_macro] = STATE(377),
    [sym_preproc_define] = STATE(377),
    [sym_preproc_undefine] = STATE(377),
    [sym_preproc_if] = STATE(377),
    [sym_preproc_elseif] = STATE(377),
    [sym_preproc_assert] = STATE(377),
    [sym_preproc_pragma] = STATE(377),
    [sym_preproc_error] = STATE(377),
    [sym_preproc_warning] = STATE(377),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(786),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [378] = {
    [sym_preproc_include] = STATE(378),
    [sym_preproc_tryinclude] = STATE(378),
    [sym_preproc_macro] = STATE(378),
    [sym_preproc_define] = STATE(378),
    [sym_preproc_undefine] = STATE(378),
    [sym_preproc_if] = STATE(378),
    [sym_preproc_elseif] = STATE(378),
    [sym_preproc_assert] = STATE(378),
    [sym_preproc_pragma] = STATE(378),
    [sym_preproc_error] = STATE(378),
    [sym_preproc_warning] = STATE(378),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(824),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [379] = {
    [sym_preproc_include] = STATE(379),
    [sym_preproc_tryinclude] = STATE(379),
    [sym_preproc_macro] = STATE(379),
    [sym_preproc_define] = STATE(379),
    [sym_preproc_undefine] = STATE(379),
    [sym_preproc_if] = STATE(379),
    [sym_preproc_elseif] = STATE(379),
    [sym_preproc_assert] = STATE(379),
    [sym_preproc_pragma] = STATE(379),
    [sym_preproc_error] = STATE(379),
    [sym_preproc_warning] = STATE(379),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(825),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [380] = {
    [sym_preproc_include] = STATE(380),
    [sym_preproc_tryinclude] = STATE(380),
    [sym_preproc_macro] = STATE(380),
    [sym_preproc_define] = STATE(380),
    [sym_preproc_undefine] = STATE(380),
    [sym_preproc_if] = STATE(380),
    [sym_preproc_elseif] = STATE(380),
    [sym_preproc_assert] = STATE(380),
    [sym_preproc_pragma] = STATE(380),
    [sym_preproc_error] = STATE(380),
    [sym_preproc_warning] = STATE(380),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(761),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [381] = {
    [sym_preproc_include] = STATE(381),
    [sym_preproc_tryinclude] = STATE(381),
    [sym_preproc_macro] = STATE(381),
    [sym_preproc_define] = STATE(381),
    [sym_preproc_undefine] = STATE(381),
    [sym_preproc_if] = STATE(381),
    [sym_preproc_elseif] = STATE(381),
    [sym_preproc_assert] = STATE(381),
    [sym_preproc_pragma] = STATE(381),
    [sym_preproc_error] = STATE(381),
    [sym_preproc_warning] = STATE(381),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(766),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [382] = {
    [sym_preproc_include] = STATE(382),
    [sym_preproc_tryinclude] = STATE(382),
    [sym_preproc_macro] = STATE(382),
    [sym_preproc_define] = STATE(382),
    [sym_preproc_undefine] = STATE(382),
    [sym_preproc_if] = STATE(382),
    [sym_preproc_elseif] = STATE(382),
    [sym_preproc_assert] = STATE(382),
    [sym_preproc_pragma] = STATE(382),
    [sym_preproc_error] = STATE(382),
    [sym_preproc_warning] = STATE(382),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(767),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [383] = {
    [sym_preproc_include] = STATE(383),
    [sym_preproc_tryinclude] = STATE(383),
    [sym_preproc_macro] = STATE(383),
    [sym_preproc_define] = STATE(383),
    [sym_preproc_undefine] = STATE(383),
    [sym_preproc_if] = STATE(383),
    [sym_preproc_elseif] = STATE(383),
    [sym_preproc_assert] = STATE(383),
    [sym_preproc_pragma] = STATE(383),
    [sym_preproc_error] = STATE(383),
    [sym_preproc_warning] = STATE(383),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(768),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [384] = {
    [sym_preproc_include] = STATE(384),
    [sym_preproc_tryinclude] = STATE(384),
    [sym_preproc_macro] = STATE(384),
    [sym_preproc_define] = STATE(384),
    [sym_preproc_undefine] = STATE(384),
    [sym_preproc_if] = STATE(384),
    [sym_preproc_elseif] = STATE(384),
    [sym_preproc_assert] = STATE(384),
    [sym_preproc_pragma] = STATE(384),
    [sym_preproc_error] = STATE(384),
    [sym_preproc_warning] = STATE(384),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(902),
    [sym_assignment_expression] = STATE(784),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [385] = {
    [sym_preproc_include] = STATE(385),
    [sym_preproc_tryinclude] = STATE(385),
    [sym_preproc_macro] = STATE(385),
    [sym_preproc_define] = STATE(385),
    [sym_preproc_undefine] = STATE(385),
    [sym_preproc_if] = STATE(385),
    [sym_preproc_elseif] = STATE(385),
    [sym_preproc_assert] = STATE(385),
    [sym_preproc_pragma] = STATE(385),
    [sym_preproc_error] = STATE(385),
    [sym_preproc_warning] = STATE(385),
    [sym_dimension] = STATE(908),
    [sym_call_arguments] = STATE(632),
    [aux_sym_function_definition_repeat1] = STATE(769),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(994),
    [anon_sym_COLON2] = ACTIONS(123),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_COLON_COLON] = ACTIONS(834),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
  },
  [386] = {
    [sym_preproc_include] = STATE(386),
    [sym_preproc_tryinclude] = STATE(386),
    [sym_preproc_macro] = STATE(386),
    [sym_preproc_define] = STATE(386),
    [sym_preproc_undefine] = STATE(386),
    [sym_preproc_if] = STATE(386),
    [sym_preproc_elseif] = STATE(386),
    [sym_preproc_assert] = STATE(386),
    [sym_preproc_pragma] = STATE(386),
    [sym_preproc_error] = STATE(386),
    [sym_preproc_warning] = STATE(386),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(871),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [387] = {
    [sym_preproc_include] = STATE(387),
    [sym_preproc_tryinclude] = STATE(387),
    [sym_preproc_macro] = STATE(387),
    [sym_preproc_define] = STATE(387),
    [sym_preproc_undefine] = STATE(387),
    [sym_preproc_if] = STATE(387),
    [sym_preproc_elseif] = STATE(387),
    [sym_preproc_assert] = STATE(387),
    [sym_preproc_pragma] = STATE(387),
    [sym_preproc_error] = STATE(387),
    [sym_preproc_warning] = STATE(387),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(809),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [388] = {
    [sym_preproc_include] = STATE(388),
    [sym_preproc_tryinclude] = STATE(388),
    [sym_preproc_macro] = STATE(388),
    [sym_preproc_define] = STATE(388),
    [sym_preproc_undefine] = STATE(388),
    [sym_preproc_if] = STATE(388),
    [sym_preproc_elseif] = STATE(388),
    [sym_preproc_assert] = STATE(388),
    [sym_preproc_pragma] = STATE(388),
    [sym_preproc_error] = STATE(388),
    [sym_preproc_warning] = STATE(388),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(198),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [389] = {
    [sym_preproc_include] = STATE(389),
    [sym_preproc_tryinclude] = STATE(389),
    [sym_preproc_macro] = STATE(389),
    [sym_preproc_define] = STATE(389),
    [sym_preproc_undefine] = STATE(389),
    [sym_preproc_if] = STATE(389),
    [sym_preproc_elseif] = STATE(389),
    [sym_preproc_assert] = STATE(389),
    [sym_preproc_pragma] = STATE(389),
    [sym_preproc_error] = STATE(389),
    [sym_preproc_warning] = STATE(389),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(199),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [390] = {
    [sym_preproc_include] = STATE(390),
    [sym_preproc_tryinclude] = STATE(390),
    [sym_preproc_macro] = STATE(390),
    [sym_preproc_define] = STATE(390),
    [sym_preproc_undefine] = STATE(390),
    [sym_preproc_if] = STATE(390),
    [sym_preproc_elseif] = STATE(390),
    [sym_preproc_assert] = STATE(390),
    [sym_preproc_pragma] = STATE(390),
    [sym_preproc_error] = STATE(390),
    [sym_preproc_warning] = STATE(390),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(800),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [391] = {
    [sym_preproc_include] = STATE(391),
    [sym_preproc_tryinclude] = STATE(391),
    [sym_preproc_macro] = STATE(391),
    [sym_preproc_define] = STATE(391),
    [sym_preproc_undefine] = STATE(391),
    [sym_preproc_if] = STATE(391),
    [sym_preproc_elseif] = STATE(391),
    [sym_preproc_assert] = STATE(391),
    [sym_preproc_pragma] = STATE(391),
    [sym_preproc_error] = STATE(391),
    [sym_preproc_warning] = STATE(391),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(105),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [392] = {
    [sym_preproc_include] = STATE(392),
    [sym_preproc_tryinclude] = STATE(392),
    [sym_preproc_macro] = STATE(392),
    [sym_preproc_define] = STATE(392),
    [sym_preproc_undefine] = STATE(392),
    [sym_preproc_if] = STATE(392),
    [sym_preproc_elseif] = STATE(392),
    [sym_preproc_assert] = STATE(392),
    [sym_preproc_pragma] = STATE(392),
    [sym_preproc_error] = STATE(392),
    [sym_preproc_warning] = STATE(392),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(126),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [393] = {
    [sym_preproc_include] = STATE(393),
    [sym_preproc_tryinclude] = STATE(393),
    [sym_preproc_macro] = STATE(393),
    [sym_preproc_define] = STATE(393),
    [sym_preproc_undefine] = STATE(393),
    [sym_preproc_if] = STATE(393),
    [sym_preproc_elseif] = STATE(393),
    [sym_preproc_assert] = STATE(393),
    [sym_preproc_pragma] = STATE(393),
    [sym_preproc_error] = STATE(393),
    [sym_preproc_warning] = STATE(393),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(877),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [394] = {
    [sym_preproc_include] = STATE(394),
    [sym_preproc_tryinclude] = STATE(394),
    [sym_preproc_macro] = STATE(394),
    [sym_preproc_define] = STATE(394),
    [sym_preproc_undefine] = STATE(394),
    [sym_preproc_if] = STATE(394),
    [sym_preproc_elseif] = STATE(394),
    [sym_preproc_assert] = STATE(394),
    [sym_preproc_pragma] = STATE(394),
    [sym_preproc_error] = STATE(394),
    [sym_preproc_warning] = STATE(394),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(892),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [395] = {
    [sym_preproc_include] = STATE(395),
    [sym_preproc_tryinclude] = STATE(395),
    [sym_preproc_macro] = STATE(395),
    [sym_preproc_define] = STATE(395),
    [sym_preproc_undefine] = STATE(395),
    [sym_preproc_if] = STATE(395),
    [sym_preproc_elseif] = STATE(395),
    [sym_preproc_assert] = STATE(395),
    [sym_preproc_pragma] = STATE(395),
    [sym_preproc_error] = STATE(395),
    [sym_preproc_warning] = STATE(395),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(826),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [396] = {
    [sym_preproc_include] = STATE(396),
    [sym_preproc_tryinclude] = STATE(396),
    [sym_preproc_macro] = STATE(396),
    [sym_preproc_define] = STATE(396),
    [sym_preproc_undefine] = STATE(396),
    [sym_preproc_if] = STATE(396),
    [sym_preproc_elseif] = STATE(396),
    [sym_preproc_assert] = STATE(396),
    [sym_preproc_pragma] = STATE(396),
    [sym_preproc_error] = STATE(396),
    [sym_preproc_warning] = STATE(396),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(196),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [397] = {
    [sym_preproc_include] = STATE(397),
    [sym_preproc_tryinclude] = STATE(397),
    [sym_preproc_macro] = STATE(397),
    [sym_preproc_define] = STATE(397),
    [sym_preproc_undefine] = STATE(397),
    [sym_preproc_if] = STATE(397),
    [sym_preproc_elseif] = STATE(397),
    [sym_preproc_assert] = STATE(397),
    [sym_preproc_pragma] = STATE(397),
    [sym_preproc_error] = STATE(397),
    [sym_preproc_warning] = STATE(397),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(110),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [398] = {
    [sym_preproc_include] = STATE(398),
    [sym_preproc_tryinclude] = STATE(398),
    [sym_preproc_macro] = STATE(398),
    [sym_preproc_define] = STATE(398),
    [sym_preproc_undefine] = STATE(398),
    [sym_preproc_if] = STATE(398),
    [sym_preproc_elseif] = STATE(398),
    [sym_preproc_assert] = STATE(398),
    [sym_preproc_pragma] = STATE(398),
    [sym_preproc_error] = STATE(398),
    [sym_preproc_warning] = STATE(398),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(765),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [399] = {
    [sym_preproc_include] = STATE(399),
    [sym_preproc_tryinclude] = STATE(399),
    [sym_preproc_macro] = STATE(399),
    [sym_preproc_define] = STATE(399),
    [sym_preproc_undefine] = STATE(399),
    [sym_preproc_if] = STATE(399),
    [sym_preproc_elseif] = STATE(399),
    [sym_preproc_assert] = STATE(399),
    [sym_preproc_pragma] = STATE(399),
    [sym_preproc_error] = STATE(399),
    [sym_preproc_warning] = STATE(399),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(774),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [400] = {
    [sym_preproc_include] = STATE(400),
    [sym_preproc_tryinclude] = STATE(400),
    [sym_preproc_macro] = STATE(400),
    [sym_preproc_define] = STATE(400),
    [sym_preproc_undefine] = STATE(400),
    [sym_preproc_if] = STATE(400),
    [sym_preproc_elseif] = STATE(400),
    [sym_preproc_assert] = STATE(400),
    [sym_preproc_pragma] = STATE(400),
    [sym_preproc_error] = STATE(400),
    [sym_preproc_warning] = STATE(400),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(775),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [401] = {
    [sym_preproc_include] = STATE(401),
    [sym_preproc_tryinclude] = STATE(401),
    [sym_preproc_macro] = STATE(401),
    [sym_preproc_define] = STATE(401),
    [sym_preproc_undefine] = STATE(401),
    [sym_preproc_if] = STATE(401),
    [sym_preproc_elseif] = STATE(401),
    [sym_preproc_assert] = STATE(401),
    [sym_preproc_pragma] = STATE(401),
    [sym_preproc_error] = STATE(401),
    [sym_preproc_warning] = STATE(401),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(776),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [402] = {
    [sym_preproc_include] = STATE(402),
    [sym_preproc_tryinclude] = STATE(402),
    [sym_preproc_macro] = STATE(402),
    [sym_preproc_define] = STATE(402),
    [sym_preproc_undefine] = STATE(402),
    [sym_preproc_if] = STATE(402),
    [sym_preproc_elseif] = STATE(402),
    [sym_preproc_assert] = STATE(402),
    [sym_preproc_pragma] = STATE(402),
    [sym_preproc_error] = STATE(402),
    [sym_preproc_warning] = STATE(402),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(893),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [403] = {
    [sym_preproc_include] = STATE(403),
    [sym_preproc_tryinclude] = STATE(403),
    [sym_preproc_macro] = STATE(403),
    [sym_preproc_define] = STATE(403),
    [sym_preproc_undefine] = STATE(403),
    [sym_preproc_if] = STATE(403),
    [sym_preproc_elseif] = STATE(403),
    [sym_preproc_assert] = STATE(403),
    [sym_preproc_pragma] = STATE(403),
    [sym_preproc_error] = STATE(403),
    [sym_preproc_warning] = STATE(403),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(114),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [404] = {
    [sym_preproc_include] = STATE(404),
    [sym_preproc_tryinclude] = STATE(404),
    [sym_preproc_macro] = STATE(404),
    [sym_preproc_define] = STATE(404),
    [sym_preproc_undefine] = STATE(404),
    [sym_preproc_if] = STATE(404),
    [sym_preproc_elseif] = STATE(404),
    [sym_preproc_assert] = STATE(404),
    [sym_preproc_pragma] = STATE(404),
    [sym_preproc_error] = STATE(404),
    [sym_preproc_warning] = STATE(404),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(857),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [405] = {
    [sym_preproc_include] = STATE(405),
    [sym_preproc_tryinclude] = STATE(405),
    [sym_preproc_macro] = STATE(405),
    [sym_preproc_define] = STATE(405),
    [sym_preproc_undefine] = STATE(405),
    [sym_preproc_if] = STATE(405),
    [sym_preproc_elseif] = STATE(405),
    [sym_preproc_assert] = STATE(405),
    [sym_preproc_pragma] = STATE(405),
    [sym_preproc_error] = STATE(405),
    [sym_preproc_warning] = STATE(405),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(667),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [406] = {
    [sym_preproc_include] = STATE(406),
    [sym_preproc_tryinclude] = STATE(406),
    [sym_preproc_macro] = STATE(406),
    [sym_preproc_define] = STATE(406),
    [sym_preproc_undefine] = STATE(406),
    [sym_preproc_if] = STATE(406),
    [sym_preproc_elseif] = STATE(406),
    [sym_preproc_assert] = STATE(406),
    [sym_preproc_pragma] = STATE(406),
    [sym_preproc_error] = STATE(406),
    [sym_preproc_warning] = STATE(406),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(703),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [407] = {
    [sym_preproc_include] = STATE(407),
    [sym_preproc_tryinclude] = STATE(407),
    [sym_preproc_macro] = STATE(407),
    [sym_preproc_define] = STATE(407),
    [sym_preproc_undefine] = STATE(407),
    [sym_preproc_if] = STATE(407),
    [sym_preproc_elseif] = STATE(407),
    [sym_preproc_assert] = STATE(407),
    [sym_preproc_pragma] = STATE(407),
    [sym_preproc_error] = STATE(407),
    [sym_preproc_warning] = STATE(407),
    [sym_new_expression] = STATE(111),
    [sym_old_type] = STATE(316),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(113),
    [sym_assignment_expression] = STATE(111),
    [sym_call_expression] = STATE(111),
    [sym_array_indexed_access] = STATE(73),
    [sym_parenthesized_expression] = STATE(111),
    [sym_ternary_expression] = STATE(111),
    [sym_field_access] = STATE(64),
    [sym_scope_access] = STATE(77),
    [sym_unary_expression] = STATE(111),
    [sym_binary_expression] = STATE(111),
    [sym_update_expression] = STATE(111),
    [sym_sizeof_expression] = STATE(111),
    [sym_view_as] = STATE(77),
    [sym_old_type_cast] = STATE(111),
    [sym_array_literal] = STATE(123),
    [sym__literal] = STATE(111),
    [sym_char_literal] = STATE(123),
    [sym_string_literal] = STATE(123),
    [sym_identifier] = ACTIONS(380),
    [anon_sym_LPAREN] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(143),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(382),
    [anon_sym_LBRACE] = ACTIONS(384),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(105),
    [anon_sym_PLUS_PLUS] = ACTIONS(105),
    [anon_sym_sizeof] = ACTIONS(107),
    [anon_sym_view_as] = ACTIONS(109),
    [sym_int_literal] = ACTIONS(111),
    [sym_float_literal] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(117),
    [sym_bool_literal] = ACTIONS(111),
    [sym_null] = ACTIONS(111),
    [sym_this] = ACTIONS(119),
    [sym_comment] = ACTIONS(19),
  },
  [408] = {
    [sym_preproc_include] = STATE(408),
    [sym_preproc_tryinclude] = STATE(408),
    [sym_preproc_macro] = STATE(408),
    [sym_preproc_define] = STATE(408),
    [sym_preproc_undefine] = STATE(408),
    [sym_preproc_if] = STATE(408),
    [sym_preproc_elseif] = STATE(408),
    [sym_preproc_assert] = STATE(408),
    [sym_preproc_pragma] = STATE(408),
    [sym_preproc_error] = STATE(408),
    [sym_preproc_warning] = STATE(408),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(830),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [409] = {
    [sym_preproc_include] = STATE(409),
    [sym_preproc_tryinclude] = STATE(409),
    [sym_preproc_macro] = STATE(409),
    [sym_preproc_define] = STATE(409),
    [sym_preproc_undefine] = STATE(409),
    [sym_preproc_if] = STATE(409),
    [sym_preproc_elseif] = STATE(409),
    [sym_preproc_assert] = STATE(409),
    [sym_preproc_pragma] = STATE(409),
    [sym_preproc_error] = STATE(409),
    [sym_preproc_warning] = STATE(409),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(704),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [410] = {
    [sym_preproc_include] = STATE(410),
    [sym_preproc_tryinclude] = STATE(410),
    [sym_preproc_macro] = STATE(410),
    [sym_preproc_define] = STATE(410),
    [sym_preproc_undefine] = STATE(410),
    [sym_preproc_if] = STATE(410),
    [sym_preproc_elseif] = STATE(410),
    [sym_preproc_assert] = STATE(410),
    [sym_preproc_pragma] = STATE(410),
    [sym_preproc_error] = STATE(410),
    [sym_preproc_warning] = STATE(410),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(705),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [411] = {
    [sym_preproc_include] = STATE(411),
    [sym_preproc_tryinclude] = STATE(411),
    [sym_preproc_macro] = STATE(411),
    [sym_preproc_define] = STATE(411),
    [sym_preproc_undefine] = STATE(411),
    [sym_preproc_if] = STATE(411),
    [sym_preproc_elseif] = STATE(411),
    [sym_preproc_assert] = STATE(411),
    [sym_preproc_pragma] = STATE(411),
    [sym_preproc_error] = STATE(411),
    [sym_preproc_warning] = STATE(411),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(706),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [412] = {
    [sym_preproc_include] = STATE(412),
    [sym_preproc_tryinclude] = STATE(412),
    [sym_preproc_macro] = STATE(412),
    [sym_preproc_define] = STATE(412),
    [sym_preproc_undefine] = STATE(412),
    [sym_preproc_if] = STATE(412),
    [sym_preproc_elseif] = STATE(412),
    [sym_preproc_assert] = STATE(412),
    [sym_preproc_pragma] = STATE(412),
    [sym_preproc_error] = STATE(412),
    [sym_preproc_warning] = STATE(412),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(884),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [413] = {
    [sym_preproc_include] = STATE(413),
    [sym_preproc_tryinclude] = STATE(413),
    [sym_preproc_macro] = STATE(413),
    [sym_preproc_define] = STATE(413),
    [sym_preproc_undefine] = STATE(413),
    [sym_preproc_if] = STATE(413),
    [sym_preproc_elseif] = STATE(413),
    [sym_preproc_assert] = STATE(413),
    [sym_preproc_pragma] = STATE(413),
    [sym_preproc_error] = STATE(413),
    [sym_preproc_warning] = STATE(413),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(894),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [414] = {
    [sym_preproc_include] = STATE(414),
    [sym_preproc_tryinclude] = STATE(414),
    [sym_preproc_macro] = STATE(414),
    [sym_preproc_define] = STATE(414),
    [sym_preproc_undefine] = STATE(414),
    [sym_preproc_if] = STATE(414),
    [sym_preproc_elseif] = STATE(414),
    [sym_preproc_assert] = STATE(414),
    [sym_preproc_pragma] = STATE(414),
    [sym_preproc_error] = STATE(414),
    [sym_preproc_warning] = STATE(414),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(896),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [415] = {
    [sym_preproc_include] = STATE(415),
    [sym_preproc_tryinclude] = STATE(415),
    [sym_preproc_macro] = STATE(415),
    [sym_preproc_define] = STATE(415),
    [sym_preproc_undefine] = STATE(415),
    [sym_preproc_if] = STATE(415),
    [sym_preproc_elseif] = STATE(415),
    [sym_preproc_assert] = STATE(415),
    [sym_preproc_pragma] = STATE(415),
    [sym_preproc_error] = STATE(415),
    [sym_preproc_warning] = STATE(415),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(897),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [416] = {
    [sym_preproc_include] = STATE(416),
    [sym_preproc_tryinclude] = STATE(416),
    [sym_preproc_macro] = STATE(416),
    [sym_preproc_define] = STATE(416),
    [sym_preproc_undefine] = STATE(416),
    [sym_preproc_if] = STATE(416),
    [sym_preproc_elseif] = STATE(416),
    [sym_preproc_assert] = STATE(416),
    [sym_preproc_pragma] = STATE(416),
    [sym_preproc_error] = STATE(416),
    [sym_preproc_warning] = STATE(416),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(864),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [417] = {
    [sym_preproc_include] = STATE(417),
    [sym_preproc_tryinclude] = STATE(417),
    [sym_preproc_macro] = STATE(417),
    [sym_preproc_define] = STATE(417),
    [sym_preproc_undefine] = STATE(417),
    [sym_preproc_if] = STATE(417),
    [sym_preproc_elseif] = STATE(417),
    [sym_preproc_assert] = STATE(417),
    [sym_preproc_pragma] = STATE(417),
    [sym_preproc_error] = STATE(417),
    [sym_preproc_warning] = STATE(417),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(865),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [418] = {
    [sym_preproc_include] = STATE(418),
    [sym_preproc_tryinclude] = STATE(418),
    [sym_preproc_macro] = STATE(418),
    [sym_preproc_define] = STATE(418),
    [sym_preproc_undefine] = STATE(418),
    [sym_preproc_if] = STATE(418),
    [sym_preproc_elseif] = STATE(418),
    [sym_preproc_assert] = STATE(418),
    [sym_preproc_pragma] = STATE(418),
    [sym_preproc_error] = STATE(418),
    [sym_preproc_warning] = STATE(418),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(707),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [419] = {
    [sym_preproc_include] = STATE(419),
    [sym_preproc_tryinclude] = STATE(419),
    [sym_preproc_macro] = STATE(419),
    [sym_preproc_define] = STATE(419),
    [sym_preproc_undefine] = STATE(419),
    [sym_preproc_if] = STATE(419),
    [sym_preproc_elseif] = STATE(419),
    [sym_preproc_assert] = STATE(419),
    [sym_preproc_pragma] = STATE(419),
    [sym_preproc_error] = STATE(419),
    [sym_preproc_warning] = STATE(419),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(833),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [420] = {
    [sym_preproc_include] = STATE(420),
    [sym_preproc_tryinclude] = STATE(420),
    [sym_preproc_macro] = STATE(420),
    [sym_preproc_define] = STATE(420),
    [sym_preproc_undefine] = STATE(420),
    [sym_preproc_if] = STATE(420),
    [sym_preproc_elseif] = STATE(420),
    [sym_preproc_assert] = STATE(420),
    [sym_preproc_pragma] = STATE(420),
    [sym_preproc_error] = STATE(420),
    [sym_preproc_warning] = STATE(420),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(834),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [421] = {
    [sym_preproc_include] = STATE(421),
    [sym_preproc_tryinclude] = STATE(421),
    [sym_preproc_macro] = STATE(421),
    [sym_preproc_define] = STATE(421),
    [sym_preproc_undefine] = STATE(421),
    [sym_preproc_if] = STATE(421),
    [sym_preproc_elseif] = STATE(421),
    [sym_preproc_assert] = STATE(421),
    [sym_preproc_pragma] = STATE(421),
    [sym_preproc_error] = STATE(421),
    [sym_preproc_warning] = STATE(421),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(708),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [422] = {
    [sym_preproc_include] = STATE(422),
    [sym_preproc_tryinclude] = STATE(422),
    [sym_preproc_macro] = STATE(422),
    [sym_preproc_define] = STATE(422),
    [sym_preproc_undefine] = STATE(422),
    [sym_preproc_if] = STATE(422),
    [sym_preproc_elseif] = STATE(422),
    [sym_preproc_assert] = STATE(422),
    [sym_preproc_pragma] = STATE(422),
    [sym_preproc_error] = STATE(422),
    [sym_preproc_warning] = STATE(422),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(861),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [423] = {
    [sym_preproc_include] = STATE(423),
    [sym_preproc_tryinclude] = STATE(423),
    [sym_preproc_macro] = STATE(423),
    [sym_preproc_define] = STATE(423),
    [sym_preproc_undefine] = STATE(423),
    [sym_preproc_if] = STATE(423),
    [sym_preproc_elseif] = STATE(423),
    [sym_preproc_assert] = STATE(423),
    [sym_preproc_pragma] = STATE(423),
    [sym_preproc_error] = STATE(423),
    [sym_preproc_warning] = STATE(423),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(848),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [424] = {
    [sym_preproc_include] = STATE(424),
    [sym_preproc_tryinclude] = STATE(424),
    [sym_preproc_macro] = STATE(424),
    [sym_preproc_define] = STATE(424),
    [sym_preproc_undefine] = STATE(424),
    [sym_preproc_if] = STATE(424),
    [sym_preproc_elseif] = STATE(424),
    [sym_preproc_assert] = STATE(424),
    [sym_preproc_pragma] = STATE(424),
    [sym_preproc_error] = STATE(424),
    [sym_preproc_warning] = STATE(424),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(849),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [425] = {
    [sym_preproc_include] = STATE(425),
    [sym_preproc_tryinclude] = STATE(425),
    [sym_preproc_macro] = STATE(425),
    [sym_preproc_define] = STATE(425),
    [sym_preproc_undefine] = STATE(425),
    [sym_preproc_if] = STATE(425),
    [sym_preproc_elseif] = STATE(425),
    [sym_preproc_assert] = STATE(425),
    [sym_preproc_pragma] = STATE(425),
    [sym_preproc_error] = STATE(425),
    [sym_preproc_warning] = STATE(425),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(874),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [426] = {
    [sym_preproc_include] = STATE(426),
    [sym_preproc_tryinclude] = STATE(426),
    [sym_preproc_macro] = STATE(426),
    [sym_preproc_define] = STATE(426),
    [sym_preproc_undefine] = STATE(426),
    [sym_preproc_if] = STATE(426),
    [sym_preproc_elseif] = STATE(426),
    [sym_preproc_assert] = STATE(426),
    [sym_preproc_pragma] = STATE(426),
    [sym_preproc_error] = STATE(426),
    [sym_preproc_warning] = STATE(426),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(850),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [427] = {
    [sym_preproc_include] = STATE(427),
    [sym_preproc_tryinclude] = STATE(427),
    [sym_preproc_macro] = STATE(427),
    [sym_preproc_define] = STATE(427),
    [sym_preproc_undefine] = STATE(427),
    [sym_preproc_if] = STATE(427),
    [sym_preproc_elseif] = STATE(427),
    [sym_preproc_assert] = STATE(427),
    [sym_preproc_pragma] = STATE(427),
    [sym_preproc_error] = STATE(427),
    [sym_preproc_warning] = STATE(427),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(851),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [428] = {
    [sym_preproc_include] = STATE(428),
    [sym_preproc_tryinclude] = STATE(428),
    [sym_preproc_macro] = STATE(428),
    [sym_preproc_define] = STATE(428),
    [sym_preproc_undefine] = STATE(428),
    [sym_preproc_if] = STATE(428),
    [sym_preproc_elseif] = STATE(428),
    [sym_preproc_assert] = STATE(428),
    [sym_preproc_pragma] = STATE(428),
    [sym_preproc_error] = STATE(428),
    [sym_preproc_warning] = STATE(428),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(855),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [429] = {
    [sym_preproc_include] = STATE(429),
    [sym_preproc_tryinclude] = STATE(429),
    [sym_preproc_macro] = STATE(429),
    [sym_preproc_define] = STATE(429),
    [sym_preproc_undefine] = STATE(429),
    [sym_preproc_if] = STATE(429),
    [sym_preproc_elseif] = STATE(429),
    [sym_preproc_assert] = STATE(429),
    [sym_preproc_pragma] = STATE(429),
    [sym_preproc_error] = STATE(429),
    [sym_preproc_warning] = STATE(429),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(709),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [430] = {
    [sym_preproc_include] = STATE(430),
    [sym_preproc_tryinclude] = STATE(430),
    [sym_preproc_macro] = STATE(430),
    [sym_preproc_define] = STATE(430),
    [sym_preproc_undefine] = STATE(430),
    [sym_preproc_if] = STATE(430),
    [sym_preproc_elseif] = STATE(430),
    [sym_preproc_assert] = STATE(430),
    [sym_preproc_pragma] = STATE(430),
    [sym_preproc_error] = STATE(430),
    [sym_preproc_warning] = STATE(430),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(869),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [431] = {
    [sym_preproc_include] = STATE(431),
    [sym_preproc_tryinclude] = STATE(431),
    [sym_preproc_macro] = STATE(431),
    [sym_preproc_define] = STATE(431),
    [sym_preproc_undefine] = STATE(431),
    [sym_preproc_if] = STATE(431),
    [sym_preproc_elseif] = STATE(431),
    [sym_preproc_assert] = STATE(431),
    [sym_preproc_pragma] = STATE(431),
    [sym_preproc_error] = STATE(431),
    [sym_preproc_warning] = STATE(431),
    [sym_new_expression] = STATE(885),
    [sym_old_type] = STATE(349),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(870),
    [sym_assignment_expression] = STATE(885),
    [sym_call_expression] = STATE(885),
    [sym_array_indexed_access] = STATE(513),
    [sym_parenthesized_expression] = STATE(885),
    [sym_ternary_expression] = STATE(885),
    [sym_field_access] = STATE(499),
    [sym_scope_access] = STATE(524),
    [sym_unary_expression] = STATE(885),
    [sym_binary_expression] = STATE(885),
    [sym_update_expression] = STATE(885),
    [sym_sizeof_expression] = STATE(885),
    [sym_view_as] = STATE(524),
    [sym_old_type_cast] = STATE(885),
    [sym_array_literal] = STATE(835),
    [sym__literal] = STATE(885),
    [sym_char_literal] = STATE(835),
    [sym_string_literal] = STATE(835),
    [sym_identifier] = ACTIONS(956),
    [anon_sym_LPAREN] = ACTIONS(958),
    [anon_sym_BANG] = ACTIONS(960),
    [anon_sym_TILDE] = ACTIONS(960),
    [anon_sym_DASH] = ACTIONS(962),
    [anon_sym_PLUS] = ACTIONS(962),
    [anon_sym_AMP] = ACTIONS(960),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(992),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(966),
    [anon_sym_PLUS_PLUS] = ACTIONS(966),
    [anon_sym_sizeof] = ACTIONS(968),
    [anon_sym_view_as] = ACTIONS(970),
    [sym_int_literal] = ACTIONS(904),
    [sym_float_literal] = ACTIONS(906),
    [anon_sym_SQUOTE] = ACTIONS(908),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [sym_bool_literal] = ACTIONS(904),
    [sym_null] = ACTIONS(904),
    [sym_this] = ACTIONS(972),
    [sym_comment] = ACTIONS(19),
  },
  [432] = {
    [sym_preproc_include] = STATE(432),
    [sym_preproc_tryinclude] = STATE(432),
    [sym_preproc_macro] = STATE(432),
    [sym_preproc_define] = STATE(432),
    [sym_preproc_undefine] = STATE(432),
    [sym_preproc_if] = STATE(432),
    [sym_preproc_elseif] = STATE(432),
    [sym_preproc_assert] = STATE(432),
    [sym_preproc_pragma] = STATE(432),
    [sym_preproc_error] = STATE(432),
    [sym_preproc_warning] = STATE(432),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(845),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [433] = {
    [sym_preproc_include] = STATE(433),
    [sym_preproc_tryinclude] = STATE(433),
    [sym_preproc_macro] = STATE(433),
    [sym_preproc_define] = STATE(433),
    [sym_preproc_undefine] = STATE(433),
    [sym_preproc_if] = STATE(433),
    [sym_preproc_elseif] = STATE(433),
    [sym_preproc_assert] = STATE(433),
    [sym_preproc_pragma] = STATE(433),
    [sym_preproc_error] = STATE(433),
    [sym_preproc_warning] = STATE(433),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(872),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [434] = {
    [sym_preproc_include] = STATE(434),
    [sym_preproc_tryinclude] = STATE(434),
    [sym_preproc_macro] = STATE(434),
    [sym_preproc_define] = STATE(434),
    [sym_preproc_undefine] = STATE(434),
    [sym_preproc_if] = STATE(434),
    [sym_preproc_elseif] = STATE(434),
    [sym_preproc_assert] = STATE(434),
    [sym_preproc_pragma] = STATE(434),
    [sym_preproc_error] = STATE(434),
    [sym_preproc_warning] = STATE(434),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(710),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [435] = {
    [sym_preproc_include] = STATE(435),
    [sym_preproc_tryinclude] = STATE(435),
    [sym_preproc_macro] = STATE(435),
    [sym_preproc_define] = STATE(435),
    [sym_preproc_undefine] = STATE(435),
    [sym_preproc_if] = STATE(435),
    [sym_preproc_elseif] = STATE(435),
    [sym_preproc_assert] = STATE(435),
    [sym_preproc_pragma] = STATE(435),
    [sym_preproc_error] = STATE(435),
    [sym_preproc_warning] = STATE(435),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(878),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [436] = {
    [sym_preproc_include] = STATE(436),
    [sym_preproc_tryinclude] = STATE(436),
    [sym_preproc_macro] = STATE(436),
    [sym_preproc_define] = STATE(436),
    [sym_preproc_undefine] = STATE(436),
    [sym_preproc_if] = STATE(436),
    [sym_preproc_elseif] = STATE(436),
    [sym_preproc_assert] = STATE(436),
    [sym_preproc_pragma] = STATE(436),
    [sym_preproc_error] = STATE(436),
    [sym_preproc_warning] = STATE(436),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(711),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [437] = {
    [sym_preproc_include] = STATE(437),
    [sym_preproc_tryinclude] = STATE(437),
    [sym_preproc_macro] = STATE(437),
    [sym_preproc_define] = STATE(437),
    [sym_preproc_undefine] = STATE(437),
    [sym_preproc_if] = STATE(437),
    [sym_preproc_elseif] = STATE(437),
    [sym_preproc_assert] = STATE(437),
    [sym_preproc_pragma] = STATE(437),
    [sym_preproc_error] = STATE(437),
    [sym_preproc_warning] = STATE(437),
    [sym_new_expression] = STATE(729),
    [sym_old_type] = STATE(405),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(712),
    [sym_assignment_expression] = STATE(729),
    [sym_call_expression] = STATE(729),
    [sym_array_indexed_access] = STATE(485),
    [sym_parenthesized_expression] = STATE(729),
    [sym_ternary_expression] = STATE(729),
    [sym_field_access] = STATE(445),
    [sym_scope_access] = STATE(496),
    [sym_unary_expression] = STATE(729),
    [sym_binary_expression] = STATE(729),
    [sym_update_expression] = STATE(729),
    [sym_sizeof_expression] = STATE(729),
    [sym_view_as] = STATE(496),
    [sym_old_type_cast] = STATE(729),
    [sym_array_literal] = STATE(634),
    [sym__literal] = STATE(729),
    [sym_char_literal] = STATE(634),
    [sym_string_literal] = STATE(634),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_AMP] = ACTIONS(642),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(650),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(652),
    [anon_sym_PLUS_PLUS] = ACTIONS(652),
    [anon_sym_sizeof] = ACTIONS(654),
    [anon_sym_view_as] = ACTIONS(656),
    [sym_int_literal] = ACTIONS(658),
    [sym_float_literal] = ACTIONS(660),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym_bool_literal] = ACTIONS(658),
    [sym_null] = ACTIONS(658),
    [sym_this] = ACTIONS(666),
    [sym_comment] = ACTIONS(19),
  },
  [438] = {
    [sym_preproc_include] = STATE(438),
    [sym_preproc_tryinclude] = STATE(438),
    [sym_preproc_macro] = STATE(438),
    [sym_preproc_define] = STATE(438),
    [sym_preproc_undefine] = STATE(438),
    [sym_preproc_if] = STATE(438),
    [sym_preproc_elseif] = STATE(438),
    [sym_preproc_assert] = STATE(438),
    [sym_preproc_pragma] = STATE(438),
    [sym_preproc_error] = STATE(438),
    [sym_preproc_warning] = STATE(438),
    [sym_new_expression] = STATE(195),
    [sym_old_type] = STATE(329),
    [sym_old_builtin_type] = STATE(1531),
    [sym__expression] = STATE(200),
    [sym_assignment_expression] = STATE(195),
    [sym_call_expression] = STATE(195),
    [sym_array_indexed_access] = STATE(88),
    [sym_parenthesized_expression] = STATE(195),
    [sym_ternary_expression] = STATE(195),
    [sym_field_access] = STATE(84),
    [sym_scope_access] = STATE(93),
    [sym_unary_expression] = STATE(195),
    [sym_binary_expression] = STATE(195),
    [sym_update_expression] = STATE(195),
    [sym_sizeof_expression] = STATE(195),
    [sym_view_as] = STATE(93),
    [sym_old_type_cast] = STATE(195),
    [sym_array_literal] = STATE(192),
    [sym__literal] = STATE(195),
    [sym_char_literal] = STATE(192),
    [sym_string_literal] = STATE(192),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_TILDE] = ACTIONS(271),
    [anon_sym_DASH] = ACTIONS(273),
    [anon_sym_PLUS] = ACTIONS(273),
    [anon_sym_AMP] = ACTIONS(271),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_new] = ACTIONS(370),
    [anon_sym_LBRACE] = ACTIONS(372),
    [anon_sym_bool] = ACTIONS(65),
    [anon_sym__] = ACTIONS(65),
    [anon_sym_Float] = ACTIONS(65),
    [anon_sym_String] = ACTIONS(65),
    [sym_any_type] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(299),
    [anon_sym_PLUS_PLUS] = ACTIONS(299),
    [anon_sym_sizeof] = ACTIONS(301),
    [anon_sym_view_as] = ACTIONS(303),
    [sym_int_literal] = ACTIONS(305),
    [sym_float_literal] = ACTIONS(307),
    [anon_sym_SQUOTE] = ACTIONS(309),
    [anon_sym_DQUOTE] = ACTIONS(311),
    [sym_bool_literal] = ACTIONS(305),
    [sym_null] = ACTIONS(305),
    [sym_this] = ACTIONS(313),
    [sym_comment] = ACTIONS(19),
  },
  [439] = {
    [sym_preproc_include] = STATE(439),
    [sym_preproc_tryinclude] = STATE(439),
    [sym_preproc_macro] = STATE(439),
    [sym_preproc_define] = STATE(439),
    [sym_preproc_undefine] = STATE(439),
    [sym_preproc_if] = STATE(439),
    [sym_preproc_elseif] = STATE(439),
    [sym_preproc_assert] = STATE(439),
    [sym_preproc_pragma] = STATE(439),
    [sym_preproc_error] = STATE(439),
    [sym_preproc_warning] = STATE(439),
    [sym_identifier] = ACTIONS(996),
    [anon_sym_LPAREN] = ACTIONS(998),
    [anon_sym_BANG] = ACTIONS(998),
    [anon_sym_TILDE] = ACTIONS(998),
    [anon_sym_DASH] = ACTIONS(996),
    [anon_sym_PLUS] = ACTIONS(996),
    [anon_sym_AMP] = ACTIONS(998),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(996),
    [anon_sym_public] = ACTIONS(996),
    [anon_sym_stock] = ACTIONS(996),
    [anon_sym_static] = ACTIONS(996),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_decl] = ACTIONS(996),
    [anon_sym_LBRACE] = ACTIONS(998),
    [anon_sym_RBRACE] = ACTIONS(998),
    [anon_sym_void] = ACTIONS(996),
    [anon_sym_bool] = ACTIONS(996),
    [anon_sym_int] = ACTIONS(996),
    [anon_sym_float] = ACTIONS(996),
    [anon_sym_char] = ACTIONS(996),
    [anon_sym__] = ACTIONS(996),
    [anon_sym_Float] = ACTIONS(996),
    [anon_sym_String] = ACTIONS(996),
    [sym_any_type] = ACTIONS(996),
    [anon_sym_for] = ACTIONS(996),
    [anon_sym_while] = ACTIONS(996),
    [anon_sym_do] = ACTIONS(996),
    [anon_sym_break] = ACTIONS(996),
    [anon_sym_continue] = ACTIONS(996),
    [anon_sym_if] = ACTIONS(996),
    [anon_sym_else] = ACTIONS(996),
    [anon_sym_switch] = ACTIONS(996),
    [anon_sym_return] = ACTIONS(996),
    [anon_sym_delete] = ACTIONS(996),
    [anon_sym_DASH_DASH] = ACTIONS(998),
    [anon_sym_PLUS_PLUS] = ACTIONS(998),
    [anon_sym_sizeof] = ACTIONS(996),
    [anon_sym_view_as] = ACTIONS(996),
    [sym_int_literal] = ACTIONS(996),
    [sym_float_literal] = ACTIONS(998),
    [anon_sym_SQUOTE] = ACTIONS(998),
    [anon_sym_DQUOTE] = ACTIONS(998),
    [sym_bool_literal] = ACTIONS(996),
    [sym_null] = ACTIONS(996),
    [sym_this] = ACTIONS(996),
    [sym_comment] = ACTIONS(19),
  },
  [440] = {
    [sym_preproc_include] = STATE(440),
    [sym_preproc_tryinclude] = STATE(440),
    [sym_preproc_macro] = STATE(440),
    [sym_preproc_define] = STATE(440),
    [sym_preproc_undefine] = STATE(440),
    [sym_preproc_if] = STATE(440),
    [sym_preproc_elseif] = STATE(440),
    [sym_preproc_assert] = STATE(440),
    [sym_preproc_pragma] = STATE(440),
    [sym_preproc_error] = STATE(440),
    [sym_preproc_warning] = STATE(440),
    [sym_identifier] = ACTIONS(1000),
    [anon_sym_LPAREN] = ACTIONS(1002),
    [anon_sym_BANG] = ACTIONS(1002),
    [anon_sym_TILDE] = ACTIONS(1002),
    [anon_sym_DASH] = ACTIONS(1000),
    [anon_sym_PLUS] = ACTIONS(1000),
    [anon_sym_AMP] = ACTIONS(1002),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1000),
    [anon_sym_public] = ACTIONS(1000),
    [anon_sym_stock] = ACTIONS(1000),
    [anon_sym_static] = ACTIONS(1000),
    [anon_sym_new] = ACTIONS(1000),
    [anon_sym_decl] = ACTIONS(1000),
    [anon_sym_LBRACE] = ACTIONS(1002),
    [anon_sym_RBRACE] = ACTIONS(1002),
    [anon_sym_void] = ACTIONS(1000),
    [anon_sym_bool] = ACTIONS(1000),
    [anon_sym_int] = ACTIONS(1000),
    [anon_sym_float] = ACTIONS(1000),
    [anon_sym_char] = ACTIONS(1000),
    [anon_sym__] = ACTIONS(1000),
    [anon_sym_Float] = ACTIONS(1000),
    [anon_sym_String] = ACTIONS(1000),
    [sym_any_type] = ACTIONS(1000),
    [anon_sym_for] = ACTIONS(1000),
    [anon_sym_while] = ACTIONS(1000),
    [anon_sym_do] = ACTIONS(1000),
    [anon_sym_break] = ACTIONS(1000),
    [anon_sym_continue] = ACTIONS(1000),
    [anon_sym_if] = ACTIONS(1000),
    [anon_sym_else] = ACTIONS(1000),
    [anon_sym_switch] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1000),
    [anon_sym_delete] = ACTIONS(1000),
    [anon_sym_DASH_DASH] = ACTIONS(1002),
    [anon_sym_PLUS_PLUS] = ACTIONS(1002),
    [anon_sym_sizeof] = ACTIONS(1000),
    [anon_sym_view_as] = ACTIONS(1000),
    [sym_int_literal] = ACTIONS(1000),
    [sym_float_literal] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1002),
    [anon_sym_DQUOTE] = ACTIONS(1002),
    [sym_bool_literal] = ACTIONS(1000),
    [sym_null] = ACTIONS(1000),
    [sym_this] = ACTIONS(1000),
    [sym_comment] = ACTIONS(19),
  },
  [441] = {
    [sym_preproc_include] = STATE(441),
    [sym_preproc_tryinclude] = STATE(441),
    [sym_preproc_macro] = STATE(441),
    [sym_preproc_define] = STATE(441),
    [sym_preproc_undefine] = STATE(441),
    [sym_preproc_if] = STATE(441),
    [sym_preproc_elseif] = STATE(441),
    [sym_preproc_assert] = STATE(441),
    [sym_preproc_pragma] = STATE(441),
    [sym_preproc_error] = STATE(441),
    [sym_preproc_warning] = STATE(441),
    [sym_identifier] = ACTIONS(1004),
    [anon_sym_LPAREN] = ACTIONS(1006),
    [anon_sym_BANG] = ACTIONS(1006),
    [anon_sym_TILDE] = ACTIONS(1006),
    [anon_sym_DASH] = ACTIONS(1004),
    [anon_sym_PLUS] = ACTIONS(1004),
    [anon_sym_AMP] = ACTIONS(1006),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1004),
    [anon_sym_public] = ACTIONS(1004),
    [anon_sym_stock] = ACTIONS(1004),
    [anon_sym_static] = ACTIONS(1004),
    [anon_sym_new] = ACTIONS(1004),
    [anon_sym_decl] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1006),
    [anon_sym_RBRACE] = ACTIONS(1006),
    [anon_sym_void] = ACTIONS(1004),
    [anon_sym_bool] = ACTIONS(1004),
    [anon_sym_int] = ACTIONS(1004),
    [anon_sym_float] = ACTIONS(1004),
    [anon_sym_char] = ACTIONS(1004),
    [anon_sym__] = ACTIONS(1004),
    [anon_sym_Float] = ACTIONS(1004),
    [anon_sym_String] = ACTIONS(1004),
    [sym_any_type] = ACTIONS(1004),
    [anon_sym_for] = ACTIONS(1004),
    [anon_sym_while] = ACTIONS(1004),
    [anon_sym_do] = ACTIONS(1004),
    [anon_sym_break] = ACTIONS(1004),
    [anon_sym_continue] = ACTIONS(1004),
    [anon_sym_if] = ACTIONS(1004),
    [anon_sym_else] = ACTIONS(1004),
    [anon_sym_switch] = ACTIONS(1004),
    [anon_sym_return] = ACTIONS(1004),
    [anon_sym_delete] = ACTIONS(1004),
    [anon_sym_DASH_DASH] = ACTIONS(1006),
    [anon_sym_PLUS_PLUS] = ACTIONS(1006),
    [anon_sym_sizeof] = ACTIONS(1004),
    [anon_sym_view_as] = ACTIONS(1004),
    [sym_int_literal] = ACTIONS(1004),
    [sym_float_literal] = ACTIONS(1006),
    [anon_sym_SQUOTE] = ACTIONS(1006),
    [anon_sym_DQUOTE] = ACTIONS(1006),
    [sym_bool_literal] = ACTIONS(1004),
    [sym_null] = ACTIONS(1004),
    [sym_this] = ACTIONS(1004),
    [sym_comment] = ACTIONS(19),
  },
  [442] = {
    [sym_preproc_include] = STATE(442),
    [sym_preproc_tryinclude] = STATE(442),
    [sym_preproc_macro] = STATE(442),
    [sym_preproc_define] = STATE(442),
    [sym_preproc_undefine] = STATE(442),
    [sym_preproc_if] = STATE(442),
    [sym_preproc_elseif] = STATE(442),
    [sym_preproc_assert] = STATE(442),
    [sym_preproc_pragma] = STATE(442),
    [sym_preproc_error] = STATE(442),
    [sym_preproc_warning] = STATE(442),
    [sym_identifier] = ACTIONS(792),
    [anon_sym_LPAREN] = ACTIONS(794),
    [anon_sym_BANG] = ACTIONS(794),
    [anon_sym_TILDE] = ACTIONS(794),
    [anon_sym_DASH] = ACTIONS(792),
    [anon_sym_PLUS] = ACTIONS(792),
    [anon_sym_AMP] = ACTIONS(794),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(792),
    [anon_sym_public] = ACTIONS(792),
    [anon_sym_stock] = ACTIONS(792),
    [anon_sym_static] = ACTIONS(792),
    [anon_sym_new] = ACTIONS(792),
    [anon_sym_decl] = ACTIONS(792),
    [anon_sym_LBRACE] = ACTIONS(794),
    [anon_sym_RBRACE] = ACTIONS(794),
    [anon_sym_void] = ACTIONS(792),
    [anon_sym_bool] = ACTIONS(792),
    [anon_sym_int] = ACTIONS(792),
    [anon_sym_float] = ACTIONS(792),
    [anon_sym_char] = ACTIONS(792),
    [anon_sym__] = ACTIONS(792),
    [anon_sym_Float] = ACTIONS(792),
    [anon_sym_String] = ACTIONS(792),
    [sym_any_type] = ACTIONS(792),
    [anon_sym_for] = ACTIONS(792),
    [anon_sym_while] = ACTIONS(792),
    [anon_sym_do] = ACTIONS(792),
    [anon_sym_break] = ACTIONS(792),
    [anon_sym_continue] = ACTIONS(792),
    [anon_sym_if] = ACTIONS(792),
    [anon_sym_else] = ACTIONS(792),
    [anon_sym_switch] = ACTIONS(792),
    [anon_sym_return] = ACTIONS(792),
    [anon_sym_delete] = ACTIONS(792),
    [anon_sym_DASH_DASH] = ACTIONS(794),
    [anon_sym_PLUS_PLUS] = ACTIONS(794),
    [anon_sym_sizeof] = ACTIONS(792),
    [anon_sym_view_as] = ACTIONS(792),
    [sym_int_literal] = ACTIONS(792),
    [sym_float_literal] = ACTIONS(794),
    [anon_sym_SQUOTE] = ACTIONS(794),
    [anon_sym_DQUOTE] = ACTIONS(794),
    [sym_bool_literal] = ACTIONS(792),
    [sym_null] = ACTIONS(792),
    [sym_this] = ACTIONS(792),
    [sym_comment] = ACTIONS(19),
  },
  [443] = {
    [sym_preproc_include] = STATE(443),
    [sym_preproc_tryinclude] = STATE(443),
    [sym_preproc_macro] = STATE(443),
    [sym_preproc_define] = STATE(443),
    [sym_preproc_undefine] = STATE(443),
    [sym_preproc_if] = STATE(443),
    [sym_preproc_elseif] = STATE(443),
    [sym_preproc_assert] = STATE(443),
    [sym_preproc_pragma] = STATE(443),
    [sym_preproc_error] = STATE(443),
    [sym_preproc_warning] = STATE(443),
    [sym_identifier] = ACTIONS(1008),
    [anon_sym_LPAREN] = ACTIONS(1010),
    [anon_sym_BANG] = ACTIONS(1010),
    [anon_sym_TILDE] = ACTIONS(1010),
    [anon_sym_DASH] = ACTIONS(1008),
    [anon_sym_PLUS] = ACTIONS(1008),
    [anon_sym_AMP] = ACTIONS(1010),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1008),
    [anon_sym_public] = ACTIONS(1008),
    [anon_sym_stock] = ACTIONS(1008),
    [anon_sym_static] = ACTIONS(1008),
    [anon_sym_new] = ACTIONS(1008),
    [anon_sym_decl] = ACTIONS(1008),
    [anon_sym_LBRACE] = ACTIONS(1010),
    [anon_sym_RBRACE] = ACTIONS(1010),
    [anon_sym_void] = ACTIONS(1008),
    [anon_sym_bool] = ACTIONS(1008),
    [anon_sym_int] = ACTIONS(1008),
    [anon_sym_float] = ACTIONS(1008),
    [anon_sym_char] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1008),
    [anon_sym_Float] = ACTIONS(1008),
    [anon_sym_String] = ACTIONS(1008),
    [sym_any_type] = ACTIONS(1008),
    [anon_sym_for] = ACTIONS(1008),
    [anon_sym_while] = ACTIONS(1008),
    [anon_sym_do] = ACTIONS(1008),
    [anon_sym_break] = ACTIONS(1008),
    [anon_sym_continue] = ACTIONS(1008),
    [anon_sym_if] = ACTIONS(1008),
    [anon_sym_else] = ACTIONS(1008),
    [anon_sym_switch] = ACTIONS(1008),
    [anon_sym_return] = ACTIONS(1008),
    [anon_sym_delete] = ACTIONS(1008),
    [anon_sym_DASH_DASH] = ACTIONS(1010),
    [anon_sym_PLUS_PLUS] = ACTIONS(1010),
    [anon_sym_sizeof] = ACTIONS(1008),
    [anon_sym_view_as] = ACTIONS(1008),
    [sym_int_literal] = ACTIONS(1008),
    [sym_float_literal] = ACTIONS(1010),
    [anon_sym_SQUOTE] = ACTIONS(1010),
    [anon_sym_DQUOTE] = ACTIONS(1010),
    [sym_bool_literal] = ACTIONS(1008),
    [sym_null] = ACTIONS(1008),
    [sym_this] = ACTIONS(1008),
    [sym_comment] = ACTIONS(19),
  },
  [444] = {
    [sym_preproc_include] = STATE(444),
    [sym_preproc_tryinclude] = STATE(444),
    [sym_preproc_macro] = STATE(444),
    [sym_preproc_define] = STATE(444),
    [sym_preproc_undefine] = STATE(444),
    [sym_preproc_if] = STATE(444),
    [sym_preproc_elseif] = STATE(444),
    [sym_preproc_assert] = STATE(444),
    [sym_preproc_pragma] = STATE(444),
    [sym_preproc_error] = STATE(444),
    [sym_preproc_warning] = STATE(444),
    [sym_dimension] = STATE(621),
    [aux_sym_function_definition_repeat1] = STATE(614),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(832),
    [anon_sym_RBRACK] = ACTIONS(127),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [sym_comment] = ACTIONS(19),
  },
  [445] = {
    [sym_preproc_include] = STATE(445),
    [sym_preproc_tryinclude] = STATE(445),
    [sym_preproc_macro] = STATE(445),
    [sym_preproc_define] = STATE(445),
    [sym_preproc_undefine] = STATE(445),
    [sym_preproc_if] = STATE(445),
    [sym_preproc_elseif] = STATE(445),
    [sym_preproc_assert] = STATE(445),
    [sym_preproc_pragma] = STATE(445),
    [sym_preproc_error] = STATE(445),
    [sym_preproc_warning] = STATE(445),
    [sym_call_arguments] = STATE(632),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_RPAREN] = ACTIONS(246),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_LBRACK] = ACTIONS(980),
    [anon_sym_RBRACK] = ACTIONS(246),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
  },
  [446] = {
    [sym_preproc_include] = STATE(446),
    [sym_preproc_tryinclude] = STATE(446),
    [sym_preproc_macro] = STATE(446),
    [sym_preproc_define] = STATE(446),
    [sym_preproc_undefine] = STATE(446),
    [sym_preproc_if] = STATE(446),
    [sym_preproc_elseif] = STATE(446),
    [sym_preproc_assert] = STATE(446),
    [sym_preproc_pragma] = STATE(446),
    [sym_preproc_error] = STATE(446),
    [sym_preproc_warning] = STATE(446),
    [sym_identifier] = ACTIONS(1012),
    [anon_sym_LPAREN] = ACTIONS(1014),
    [anon_sym_BANG] = ACTIONS(1014),
    [anon_sym_TILDE] = ACTIONS(1014),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_AMP] = ACTIONS(1014),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1012),
    [anon_sym_public] = ACTIONS(1012),
    [anon_sym_stock] = ACTIONS(1012),
    [anon_sym_static] = ACTIONS(1012),
    [anon_sym_new] = ACTIONS(1012),
    [anon_sym_decl] = ACTIONS(1012),
    [anon_sym_LBRACE] = ACTIONS(1014),
    [anon_sym_RBRACE] = ACTIONS(1014),
    [anon_sym_void] = ACTIONS(1012),
    [anon_sym_bool] = ACTIONS(1012),
    [anon_sym_int] = ACTIONS(1012),
    [anon_sym_float] = ACTIONS(1012),
    [anon_sym_char] = ACTIONS(1012),
    [anon_sym__] = ACTIONS(1012),
    [anon_sym_Float] = ACTIONS(1012),
    [anon_sym_String] = ACTIONS(1012),
    [sym_any_type] = ACTIONS(1012),
    [anon_sym_for] = ACTIONS(1012),
    [anon_sym_while] = ACTIONS(1012),
    [anon_sym_do] = ACTIONS(1012),
    [anon_sym_break] = ACTIONS(1012),
    [anon_sym_continue] = ACTIONS(1012),
    [anon_sym_if] = ACTIONS(1012),
    [anon_sym_else] = ACTIONS(1012),
    [anon_sym_switch] = ACTIONS(1012),
    [anon_sym_return] = ACTIONS(1012),
    [anon_sym_delete] = ACTIONS(1012),
    [anon_sym_DASH_DASH] = ACTIONS(1014),
    [anon_sym_PLUS_PLUS] = ACTIONS(1014),
    [anon_sym_sizeof] = ACTIONS(1012),
    [anon_sym_view_as] = ACTIONS(1012),
    [sym_int_literal] = ACTIONS(1012),
    [sym_float_literal] = ACTIONS(1014),
    [anon_sym_SQUOTE] = ACTIONS(1014),
    [anon_sym_DQUOTE] = ACTIONS(1014),
    [sym_bool_literal] = ACTIONS(1012),
    [sym_null] = ACTIONS(1012),
    [sym_this] = ACTIONS(1012),
    [sym_comment] = ACTIONS(19),
  },
  [447] = {
    [sym_preproc_include] = STATE(447),
    [sym_preproc_tryinclude] = STATE(447),
    [sym_preproc_macro] = STATE(447),
    [sym_preproc_define] = STATE(447),
    [sym_preproc_undefine] = STATE(447),
    [sym_preproc_if] = STATE(447),
    [sym_preproc_elseif] = STATE(447),
    [sym_preproc_assert] = STATE(447),
    [sym_preproc_pragma] = STATE(447),
    [sym_preproc_error] = STATE(447),
    [sym_preproc_warning] = STATE(447),
    [sym_identifier] = ACTIONS(1016),
    [anon_sym_LPAREN] = ACTIONS(1018),
    [anon_sym_BANG] = ACTIONS(1018),
    [anon_sym_TILDE] = ACTIONS(1018),
    [anon_sym_DASH] = ACTIONS(1016),
    [anon_sym_PLUS] = ACTIONS(1016),
    [anon_sym_AMP] = ACTIONS(1018),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1016),
    [anon_sym_public] = ACTIONS(1016),
    [anon_sym_stock] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1016),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_decl] = ACTIONS(1016),
    [anon_sym_LBRACE] = ACTIONS(1018),
    [anon_sym_RBRACE] = ACTIONS(1018),
    [anon_sym_void] = ACTIONS(1016),
    [anon_sym_bool] = ACTIONS(1016),
    [anon_sym_int] = ACTIONS(1016),
    [anon_sym_float] = ACTIONS(1016),
    [anon_sym_char] = ACTIONS(1016),
    [anon_sym__] = ACTIONS(1016),
    [anon_sym_Float] = ACTIONS(1016),
    [anon_sym_String] = ACTIONS(1016),
    [sym_any_type] = ACTIONS(1016),
    [anon_sym_for] = ACTIONS(1016),
    [anon_sym_while] = ACTIONS(1016),
    [anon_sym_do] = ACTIONS(1016),
    [anon_sym_break] = ACTIONS(1016),
    [anon_sym_continue] = ACTIONS(1016),
    [anon_sym_if] = ACTIONS(1016),
    [anon_sym_else] = ACTIONS(1016),
    [anon_sym_switch] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1016),
    [anon_sym_delete] = ACTIONS(1016),
    [anon_sym_DASH_DASH] = ACTIONS(1018),
    [anon_sym_PLUS_PLUS] = ACTIONS(1018),
    [anon_sym_sizeof] = ACTIONS(1016),
    [anon_sym_view_as] = ACTIONS(1016),
    [sym_int_literal] = ACTIONS(1016),
    [sym_float_literal] = ACTIONS(1018),
    [anon_sym_SQUOTE] = ACTIONS(1018),
    [anon_sym_DQUOTE] = ACTIONS(1018),
    [sym_bool_literal] = ACTIONS(1016),
    [sym_null] = ACTIONS(1016),
    [sym_this] = ACTIONS(1016),
    [sym_comment] = ACTIONS(19),
  },
  [448] = {
    [sym_preproc_include] = STATE(448),
    [sym_preproc_tryinclude] = STATE(448),
    [sym_preproc_macro] = STATE(448),
    [sym_preproc_define] = STATE(448),
    [sym_preproc_undefine] = STATE(448),
    [sym_preproc_if] = STATE(448),
    [sym_preproc_elseif] = STATE(448),
    [sym_preproc_assert] = STATE(448),
    [sym_preproc_pragma] = STATE(448),
    [sym_preproc_error] = STATE(448),
    [sym_preproc_warning] = STATE(448),
    [sym_identifier] = ACTIONS(1020),
    [anon_sym_LPAREN] = ACTIONS(1022),
    [anon_sym_BANG] = ACTIONS(1022),
    [anon_sym_TILDE] = ACTIONS(1022),
    [anon_sym_DASH] = ACTIONS(1020),
    [anon_sym_PLUS] = ACTIONS(1020),
    [anon_sym_AMP] = ACTIONS(1022),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1020),
    [anon_sym_public] = ACTIONS(1020),
    [anon_sym_stock] = ACTIONS(1020),
    [anon_sym_static] = ACTIONS(1020),
    [anon_sym_new] = ACTIONS(1020),
    [anon_sym_decl] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1022),
    [anon_sym_RBRACE] = ACTIONS(1022),
    [anon_sym_void] = ACTIONS(1020),
    [anon_sym_bool] = ACTIONS(1020),
    [anon_sym_int] = ACTIONS(1020),
    [anon_sym_float] = ACTIONS(1020),
    [anon_sym_char] = ACTIONS(1020),
    [anon_sym__] = ACTIONS(1020),
    [anon_sym_Float] = ACTIONS(1020),
    [anon_sym_String] = ACTIONS(1020),
    [sym_any_type] = ACTIONS(1020),
    [anon_sym_for] = ACTIONS(1020),
    [anon_sym_while] = ACTIONS(1020),
    [anon_sym_do] = ACTIONS(1020),
    [anon_sym_break] = ACTIONS(1020),
    [anon_sym_continue] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1020),
    [anon_sym_else] = ACTIONS(1020),
    [anon_sym_switch] = ACTIONS(1020),
    [anon_sym_return] = ACTIONS(1020),
    [anon_sym_delete] = ACTIONS(1020),
    [anon_sym_DASH_DASH] = ACTIONS(1022),
    [anon_sym_PLUS_PLUS] = ACTIONS(1022),
    [anon_sym_sizeof] = ACTIONS(1020),
    [anon_sym_view_as] = ACTIONS(1020),
    [sym_int_literal] = ACTIONS(1020),
    [sym_float_literal] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1022),
    [anon_sym_DQUOTE] = ACTIONS(1022),
    [sym_bool_literal] = ACTIONS(1020),
    [sym_null] = ACTIONS(1020),
    [sym_this] = ACTIONS(1020),
    [sym_comment] = ACTIONS(19),
  },
  [449] = {
    [sym_preproc_include] = STATE(449),
    [sym_preproc_tryinclude] = STATE(449),
    [sym_preproc_macro] = STATE(449),
    [sym_preproc_define] = STATE(449),
    [sym_preproc_undefine] = STATE(449),
    [sym_preproc_if] = STATE(449),
    [sym_preproc_elseif] = STATE(449),
    [sym_preproc_assert] = STATE(449),
    [sym_preproc_pragma] = STATE(449),
    [sym_preproc_error] = STATE(449),
    [sym_preproc_warning] = STATE(449),
    [sym_identifier] = ACTIONS(1024),
    [anon_sym_LPAREN] = ACTIONS(1026),
    [anon_sym_BANG] = ACTIONS(1026),
    [anon_sym_TILDE] = ACTIONS(1026),
    [anon_sym_DASH] = ACTIONS(1024),
    [anon_sym_PLUS] = ACTIONS(1024),
    [anon_sym_AMP] = ACTIONS(1026),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1024),
    [anon_sym_public] = ACTIONS(1024),
    [anon_sym_stock] = ACTIONS(1024),
    [anon_sym_static] = ACTIONS(1024),
    [anon_sym_new] = ACTIONS(1024),
    [anon_sym_decl] = ACTIONS(1024),
    [anon_sym_LBRACE] = ACTIONS(1026),
    [anon_sym_RBRACE] = ACTIONS(1026),
    [anon_sym_void] = ACTIONS(1024),
    [anon_sym_bool] = ACTIONS(1024),
    [anon_sym_int] = ACTIONS(1024),
    [anon_sym_float] = ACTIONS(1024),
    [anon_sym_char] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1024),
    [anon_sym_Float] = ACTIONS(1024),
    [anon_sym_String] = ACTIONS(1024),
    [sym_any_type] = ACTIONS(1024),
    [anon_sym_for] = ACTIONS(1024),
    [anon_sym_while] = ACTIONS(1024),
    [anon_sym_do] = ACTIONS(1024),
    [anon_sym_break] = ACTIONS(1024),
    [anon_sym_continue] = ACTIONS(1024),
    [anon_sym_if] = ACTIONS(1024),
    [anon_sym_else] = ACTIONS(1024),
    [anon_sym_switch] = ACTIONS(1024),
    [anon_sym_return] = ACTIONS(1024),
    [anon_sym_delete] = ACTIONS(1024),
    [anon_sym_DASH_DASH] = ACTIONS(1026),
    [anon_sym_PLUS_PLUS] = ACTIONS(1026),
    [anon_sym_sizeof] = ACTIONS(1024),
    [anon_sym_view_as] = ACTIONS(1024),
    [sym_int_literal] = ACTIONS(1024),
    [sym_float_literal] = ACTIONS(1026),
    [anon_sym_SQUOTE] = ACTIONS(1026),
    [anon_sym_DQUOTE] = ACTIONS(1026),
    [sym_bool_literal] = ACTIONS(1024),
    [sym_null] = ACTIONS(1024),
    [sym_this] = ACTIONS(1024),
    [sym_comment] = ACTIONS(19),
  },
  [450] = {
    [sym_preproc_include] = STATE(450),
    [sym_preproc_tryinclude] = STATE(450),
    [sym_preproc_macro] = STATE(450),
    [sym_preproc_define] = STATE(450),
    [sym_preproc_undefine] = STATE(450),
    [sym_preproc_if] = STATE(450),
    [sym_preproc_elseif] = STATE(450),
    [sym_preproc_assert] = STATE(450),
    [sym_preproc_pragma] = STATE(450),
    [sym_preproc_error] = STATE(450),
    [sym_preproc_warning] = STATE(450),
    [sym_identifier] = ACTIONS(1028),
    [anon_sym_LPAREN] = ACTIONS(1030),
    [anon_sym_BANG] = ACTIONS(1030),
    [anon_sym_TILDE] = ACTIONS(1030),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_AMP] = ACTIONS(1030),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1028),
    [anon_sym_public] = ACTIONS(1028),
    [anon_sym_stock] = ACTIONS(1028),
    [anon_sym_static] = ACTIONS(1028),
    [anon_sym_new] = ACTIONS(1028),
    [anon_sym_decl] = ACTIONS(1028),
    [anon_sym_LBRACE] = ACTIONS(1030),
    [anon_sym_RBRACE] = ACTIONS(1030),
    [anon_sym_void] = ACTIONS(1028),
    [anon_sym_bool] = ACTIONS(1028),
    [anon_sym_int] = ACTIONS(1028),
    [anon_sym_float] = ACTIONS(1028),
    [anon_sym_char] = ACTIONS(1028),
    [anon_sym__] = ACTIONS(1028),
    [anon_sym_Float] = ACTIONS(1028),
    [anon_sym_String] = ACTIONS(1028),
    [sym_any_type] = ACTIONS(1028),
    [anon_sym_for] = ACTIONS(1028),
    [anon_sym_while] = ACTIONS(1028),
    [anon_sym_do] = ACTIONS(1028),
    [anon_sym_break] = ACTIONS(1028),
    [anon_sym_continue] = ACTIONS(1028),
    [anon_sym_if] = ACTIONS(1028),
    [anon_sym_else] = ACTIONS(1028),
    [anon_sym_switch] = ACTIONS(1028),
    [anon_sym_return] = ACTIONS(1028),
    [anon_sym_delete] = ACTIONS(1028),
    [anon_sym_DASH_DASH] = ACTIONS(1030),
    [anon_sym_PLUS_PLUS] = ACTIONS(1030),
    [anon_sym_sizeof] = ACTIONS(1028),
    [anon_sym_view_as] = ACTIONS(1028),
    [sym_int_literal] = ACTIONS(1028),
    [sym_float_literal] = ACTIONS(1030),
    [anon_sym_SQUOTE] = ACTIONS(1030),
    [anon_sym_DQUOTE] = ACTIONS(1030),
    [sym_bool_literal] = ACTIONS(1028),
    [sym_null] = ACTIONS(1028),
    [sym_this] = ACTIONS(1028),
    [sym_comment] = ACTIONS(19),
  },
  [451] = {
    [sym_preproc_include] = STATE(451),
    [sym_preproc_tryinclude] = STATE(451),
    [sym_preproc_macro] = STATE(451),
    [sym_preproc_define] = STATE(451),
    [sym_preproc_undefine] = STATE(451),
    [sym_preproc_if] = STATE(451),
    [sym_preproc_elseif] = STATE(451),
    [sym_preproc_assert] = STATE(451),
    [sym_preproc_pragma] = STATE(451),
    [sym_preproc_error] = STATE(451),
    [sym_preproc_warning] = STATE(451),
    [sym_identifier] = ACTIONS(774),
    [anon_sym_LPAREN] = ACTIONS(776),
    [anon_sym_BANG] = ACTIONS(776),
    [anon_sym_TILDE] = ACTIONS(776),
    [anon_sym_DASH] = ACTIONS(774),
    [anon_sym_PLUS] = ACTIONS(774),
    [anon_sym_AMP] = ACTIONS(776),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(774),
    [anon_sym_public] = ACTIONS(774),
    [anon_sym_stock] = ACTIONS(774),
    [anon_sym_static] = ACTIONS(774),
    [anon_sym_new] = ACTIONS(774),
    [anon_sym_decl] = ACTIONS(774),
    [anon_sym_LBRACE] = ACTIONS(776),
    [anon_sym_RBRACE] = ACTIONS(776),
    [anon_sym_void] = ACTIONS(774),
    [anon_sym_bool] = ACTIONS(774),
    [anon_sym_int] = ACTIONS(774),
    [anon_sym_float] = ACTIONS(774),
    [anon_sym_char] = ACTIONS(774),
    [anon_sym__] = ACTIONS(774),
    [anon_sym_Float] = ACTIONS(774),
    [anon_sym_String] = ACTIONS(774),
    [sym_any_type] = ACTIONS(774),
    [anon_sym_for] = ACTIONS(774),
    [anon_sym_while] = ACTIONS(774),
    [anon_sym_do] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(774),
    [anon_sym_continue] = ACTIONS(774),
    [anon_sym_if] = ACTIONS(774),
    [anon_sym_else] = ACTIONS(774),
    [anon_sym_switch] = ACTIONS(774),
    [anon_sym_return] = ACTIONS(774),
    [anon_sym_delete] = ACTIONS(774),
    [anon_sym_DASH_DASH] = ACTIONS(776),
    [anon_sym_PLUS_PLUS] = ACTIONS(776),
    [anon_sym_sizeof] = ACTIONS(774),
    [anon_sym_view_as] = ACTIONS(774),
    [sym_int_literal] = ACTIONS(774),
    [sym_float_literal] = ACTIONS(776),
    [anon_sym_SQUOTE] = ACTIONS(776),
    [anon_sym_DQUOTE] = ACTIONS(776),
    [sym_bool_literal] = ACTIONS(774),
    [sym_null] = ACTIONS(774),
    [sym_this] = ACTIONS(774),
    [sym_comment] = ACTIONS(19),
  },
  [452] = {
    [sym_preproc_include] = STATE(452),
    [sym_preproc_tryinclude] = STATE(452),
    [sym_preproc_macro] = STATE(452),
    [sym_preproc_define] = STATE(452),
    [sym_preproc_undefine] = STATE(452),
    [sym_preproc_if] = STATE(452),
    [sym_preproc_elseif] = STATE(452),
    [sym_preproc_assert] = STATE(452),
    [sym_preproc_pragma] = STATE(452),
    [sym_preproc_error] = STATE(452),
    [sym_preproc_warning] = STATE(452),
    [sym_identifier] = ACTIONS(1032),
    [anon_sym_LPAREN] = ACTIONS(1034),
    [anon_sym_BANG] = ACTIONS(1034),
    [anon_sym_TILDE] = ACTIONS(1034),
    [anon_sym_DASH] = ACTIONS(1032),
    [anon_sym_PLUS] = ACTIONS(1032),
    [anon_sym_AMP] = ACTIONS(1034),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1032),
    [anon_sym_public] = ACTIONS(1032),
    [anon_sym_stock] = ACTIONS(1032),
    [anon_sym_static] = ACTIONS(1032),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_decl] = ACTIONS(1032),
    [anon_sym_LBRACE] = ACTIONS(1034),
    [anon_sym_RBRACE] = ACTIONS(1034),
    [anon_sym_void] = ACTIONS(1032),
    [anon_sym_bool] = ACTIONS(1032),
    [anon_sym_int] = ACTIONS(1032),
    [anon_sym_float] = ACTIONS(1032),
    [anon_sym_char] = ACTIONS(1032),
    [anon_sym__] = ACTIONS(1032),
    [anon_sym_Float] = ACTIONS(1032),
    [anon_sym_String] = ACTIONS(1032),
    [sym_any_type] = ACTIONS(1032),
    [anon_sym_for] = ACTIONS(1032),
    [anon_sym_while] = ACTIONS(1032),
    [anon_sym_do] = ACTIONS(1032),
    [anon_sym_break] = ACTIONS(1032),
    [anon_sym_continue] = ACTIONS(1032),
    [anon_sym_if] = ACTIONS(1032),
    [anon_sym_else] = ACTIONS(1032),
    [anon_sym_switch] = ACTIONS(1032),
    [anon_sym_return] = ACTIONS(1032),
    [anon_sym_delete] = ACTIONS(1032),
    [anon_sym_DASH_DASH] = ACTIONS(1034),
    [anon_sym_PLUS_PLUS] = ACTIONS(1034),
    [anon_sym_sizeof] = ACTIONS(1032),
    [anon_sym_view_as] = ACTIONS(1032),
    [sym_int_literal] = ACTIONS(1032),
    [sym_float_literal] = ACTIONS(1034),
    [anon_sym_SQUOTE] = ACTIONS(1034),
    [anon_sym_DQUOTE] = ACTIONS(1034),
    [sym_bool_literal] = ACTIONS(1032),
    [sym_null] = ACTIONS(1032),
    [sym_this] = ACTIONS(1032),
    [sym_comment] = ACTIONS(19),
  },
  [453] = {
    [sym_preproc_include] = STATE(453),
    [sym_preproc_tryinclude] = STATE(453),
    [sym_preproc_macro] = STATE(453),
    [sym_preproc_define] = STATE(453),
    [sym_preproc_undefine] = STATE(453),
    [sym_preproc_if] = STATE(453),
    [sym_preproc_elseif] = STATE(453),
    [sym_preproc_assert] = STATE(453),
    [sym_preproc_pragma] = STATE(453),
    [sym_preproc_error] = STATE(453),
    [sym_preproc_warning] = STATE(453),
    [sym_identifier] = ACTIONS(786),
    [anon_sym_LPAREN] = ACTIONS(788),
    [anon_sym_BANG] = ACTIONS(788),
    [anon_sym_TILDE] = ACTIONS(788),
    [anon_sym_DASH] = ACTIONS(786),
    [anon_sym_PLUS] = ACTIONS(786),
    [anon_sym_AMP] = ACTIONS(788),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(786),
    [anon_sym_public] = ACTIONS(786),
    [anon_sym_stock] = ACTIONS(786),
    [anon_sym_static] = ACTIONS(786),
    [anon_sym_new] = ACTIONS(786),
    [anon_sym_decl] = ACTIONS(786),
    [anon_sym_LBRACE] = ACTIONS(788),
    [anon_sym_RBRACE] = ACTIONS(788),
    [anon_sym_void] = ACTIONS(786),
    [anon_sym_bool] = ACTIONS(786),
    [anon_sym_int] = ACTIONS(786),
    [anon_sym_float] = ACTIONS(786),
    [anon_sym_char] = ACTIONS(786),
    [anon_sym__] = ACTIONS(786),
    [anon_sym_Float] = ACTIONS(786),
    [anon_sym_String] = ACTIONS(786),
    [sym_any_type] = ACTIONS(786),
    [anon_sym_for] = ACTIONS(786),
    [anon_sym_while] = ACTIONS(786),
    [anon_sym_do] = ACTIONS(786),
    [anon_sym_break] = ACTIONS(786),
    [anon_sym_continue] = ACTIONS(786),
    [anon_sym_if] = ACTIONS(786),
    [anon_sym_else] = ACTIONS(786),
    [anon_sym_switch] = ACTIONS(786),
    [anon_sym_return] = ACTIONS(786),
    [anon_sym_delete] = ACTIONS(786),
    [anon_sym_DASH_DASH] = ACTIONS(788),
    [anon_sym_PLUS_PLUS] = ACTIONS(788),
    [anon_sym_sizeof] = ACTIONS(786),
    [anon_sym_view_as] = ACTIONS(786),
    [sym_int_literal] = ACTIONS(786),
    [sym_float_literal] = ACTIONS(788),
    [anon_sym_SQUOTE] = ACTIONS(788),
    [anon_sym_DQUOTE] = ACTIONS(788),
    [sym_bool_literal] = ACTIONS(786),
    [sym_null] = ACTIONS(786),
    [sym_this] = ACTIONS(786),
    [sym_comment] = ACTIONS(19),
  },
  [454] = {
    [sym_preproc_include] = STATE(454),
    [sym_preproc_tryinclude] = STATE(454),
    [sym_preproc_macro] = STATE(454),
    [sym_preproc_define] = STATE(454),
    [sym_preproc_undefine] = STATE(454),
    [sym_preproc_if] = STATE(454),
    [sym_preproc_elseif] = STATE(454),
    [sym_preproc_assert] = STATE(454),
    [sym_preproc_pragma] = STATE(454),
    [sym_preproc_error] = STATE(454),
    [sym_preproc_warning] = STATE(454),
    [sym_call_arguments] = STATE(632),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(980),
    [anon_sym_RBRACK] = ACTIONS(127),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [sym_comment] = ACTIONS(19),
  },
  [455] = {
    [sym_preproc_include] = STATE(455),
    [sym_preproc_tryinclude] = STATE(455),
    [sym_preproc_macro] = STATE(455),
    [sym_preproc_define] = STATE(455),
    [sym_preproc_undefine] = STATE(455),
    [sym_preproc_if] = STATE(455),
    [sym_preproc_elseif] = STATE(455),
    [sym_preproc_assert] = STATE(455),
    [sym_preproc_pragma] = STATE(455),
    [sym_preproc_error] = STATE(455),
    [sym_preproc_warning] = STATE(455),
    [sym_identifier] = ACTIONS(1036),
    [anon_sym_LPAREN] = ACTIONS(1038),
    [anon_sym_BANG] = ACTIONS(1038),
    [anon_sym_TILDE] = ACTIONS(1038),
    [anon_sym_DASH] = ACTIONS(1036),
    [anon_sym_PLUS] = ACTIONS(1036),
    [anon_sym_AMP] = ACTIONS(1038),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1036),
    [anon_sym_public] = ACTIONS(1036),
    [anon_sym_stock] = ACTIONS(1036),
    [anon_sym_static] = ACTIONS(1036),
    [anon_sym_new] = ACTIONS(1036),
    [anon_sym_decl] = ACTIONS(1036),
    [anon_sym_LBRACE] = ACTIONS(1038),
    [anon_sym_RBRACE] = ACTIONS(1038),
    [anon_sym_void] = ACTIONS(1036),
    [anon_sym_bool] = ACTIONS(1036),
    [anon_sym_int] = ACTIONS(1036),
    [anon_sym_float] = ACTIONS(1036),
    [anon_sym_char] = ACTIONS(1036),
    [anon_sym__] = ACTIONS(1036),
    [anon_sym_Float] = ACTIONS(1036),
    [anon_sym_String] = ACTIONS(1036),
    [sym_any_type] = ACTIONS(1036),
    [anon_sym_for] = ACTIONS(1036),
    [anon_sym_while] = ACTIONS(1036),
    [anon_sym_do] = ACTIONS(1036),
    [anon_sym_break] = ACTIONS(1036),
    [anon_sym_continue] = ACTIONS(1036),
    [anon_sym_if] = ACTIONS(1036),
    [anon_sym_else] = ACTIONS(1036),
    [anon_sym_switch] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1036),
    [anon_sym_delete] = ACTIONS(1036),
    [anon_sym_DASH_DASH] = ACTIONS(1038),
    [anon_sym_PLUS_PLUS] = ACTIONS(1038),
    [anon_sym_sizeof] = ACTIONS(1036),
    [anon_sym_view_as] = ACTIONS(1036),
    [sym_int_literal] = ACTIONS(1036),
    [sym_float_literal] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1038),
    [anon_sym_DQUOTE] = ACTIONS(1038),
    [sym_bool_literal] = ACTIONS(1036),
    [sym_null] = ACTIONS(1036),
    [sym_this] = ACTIONS(1036),
    [sym_comment] = ACTIONS(19),
  },
  [456] = {
    [sym_preproc_include] = STATE(456),
    [sym_preproc_tryinclude] = STATE(456),
    [sym_preproc_macro] = STATE(456),
    [sym_preproc_define] = STATE(456),
    [sym_preproc_undefine] = STATE(456),
    [sym_preproc_if] = STATE(456),
    [sym_preproc_elseif] = STATE(456),
    [sym_preproc_assert] = STATE(456),
    [sym_preproc_pragma] = STATE(456),
    [sym_preproc_error] = STATE(456),
    [sym_preproc_warning] = STATE(456),
    [sym_identifier] = ACTIONS(1040),
    [anon_sym_LPAREN] = ACTIONS(1042),
    [anon_sym_BANG] = ACTIONS(1042),
    [anon_sym_TILDE] = ACTIONS(1042),
    [anon_sym_DASH] = ACTIONS(1040),
    [anon_sym_PLUS] = ACTIONS(1040),
    [anon_sym_AMP] = ACTIONS(1042),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1040),
    [anon_sym_public] = ACTIONS(1040),
    [anon_sym_stock] = ACTIONS(1040),
    [anon_sym_static] = ACTIONS(1040),
    [anon_sym_new] = ACTIONS(1040),
    [anon_sym_decl] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1042),
    [anon_sym_RBRACE] = ACTIONS(1042),
    [anon_sym_void] = ACTIONS(1040),
    [anon_sym_bool] = ACTIONS(1040),
    [anon_sym_int] = ACTIONS(1040),
    [anon_sym_float] = ACTIONS(1040),
    [anon_sym_char] = ACTIONS(1040),
    [anon_sym__] = ACTIONS(1040),
    [anon_sym_Float] = ACTIONS(1040),
    [anon_sym_String] = ACTIONS(1040),
    [sym_any_type] = ACTIONS(1040),
    [anon_sym_for] = ACTIONS(1040),
    [anon_sym_while] = ACTIONS(1040),
    [anon_sym_do] = ACTIONS(1040),
    [anon_sym_break] = ACTIONS(1040),
    [anon_sym_continue] = ACTIONS(1040),
    [anon_sym_if] = ACTIONS(1040),
    [anon_sym_else] = ACTIONS(1040),
    [anon_sym_switch] = ACTIONS(1040),
    [anon_sym_return] = ACTIONS(1040),
    [anon_sym_delete] = ACTIONS(1040),
    [anon_sym_DASH_DASH] = ACTIONS(1042),
    [anon_sym_PLUS_PLUS] = ACTIONS(1042),
    [anon_sym_sizeof] = ACTIONS(1040),
    [anon_sym_view_as] = ACTIONS(1040),
    [sym_int_literal] = ACTIONS(1040),
    [sym_float_literal] = ACTIONS(1042),
    [anon_sym_SQUOTE] = ACTIONS(1042),
    [anon_sym_DQUOTE] = ACTIONS(1042),
    [sym_bool_literal] = ACTIONS(1040),
    [sym_null] = ACTIONS(1040),
    [sym_this] = ACTIONS(1040),
    [sym_comment] = ACTIONS(19),
  },
  [457] = {
    [sym_preproc_include] = STATE(457),
    [sym_preproc_tryinclude] = STATE(457),
    [sym_preproc_macro] = STATE(457),
    [sym_preproc_define] = STATE(457),
    [sym_preproc_undefine] = STATE(457),
    [sym_preproc_if] = STATE(457),
    [sym_preproc_elseif] = STATE(457),
    [sym_preproc_assert] = STATE(457),
    [sym_preproc_pragma] = STATE(457),
    [sym_preproc_error] = STATE(457),
    [sym_preproc_warning] = STATE(457),
    [sym_identifier] = ACTIONS(1044),
    [anon_sym_LPAREN] = ACTIONS(1046),
    [anon_sym_BANG] = ACTIONS(1046),
    [anon_sym_TILDE] = ACTIONS(1046),
    [anon_sym_DASH] = ACTIONS(1044),
    [anon_sym_PLUS] = ACTIONS(1044),
    [anon_sym_AMP] = ACTIONS(1046),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1044),
    [anon_sym_public] = ACTIONS(1044),
    [anon_sym_stock] = ACTIONS(1044),
    [anon_sym_static] = ACTIONS(1044),
    [anon_sym_new] = ACTIONS(1044),
    [anon_sym_decl] = ACTIONS(1044),
    [anon_sym_LBRACE] = ACTIONS(1046),
    [anon_sym_RBRACE] = ACTIONS(1046),
    [anon_sym_void] = ACTIONS(1044),
    [anon_sym_bool] = ACTIONS(1044),
    [anon_sym_int] = ACTIONS(1044),
    [anon_sym_float] = ACTIONS(1044),
    [anon_sym_char] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1044),
    [anon_sym_Float] = ACTIONS(1044),
    [anon_sym_String] = ACTIONS(1044),
    [sym_any_type] = ACTIONS(1044),
    [anon_sym_for] = ACTIONS(1044),
    [anon_sym_while] = ACTIONS(1044),
    [anon_sym_do] = ACTIONS(1044),
    [anon_sym_break] = ACTIONS(1044),
    [anon_sym_continue] = ACTIONS(1044),
    [anon_sym_if] = ACTIONS(1044),
    [anon_sym_else] = ACTIONS(1044),
    [anon_sym_switch] = ACTIONS(1044),
    [anon_sym_return] = ACTIONS(1044),
    [anon_sym_delete] = ACTIONS(1044),
    [anon_sym_DASH_DASH] = ACTIONS(1046),
    [anon_sym_PLUS_PLUS] = ACTIONS(1046),
    [anon_sym_sizeof] = ACTIONS(1044),
    [anon_sym_view_as] = ACTIONS(1044),
    [sym_int_literal] = ACTIONS(1044),
    [sym_float_literal] = ACTIONS(1046),
    [anon_sym_SQUOTE] = ACTIONS(1046),
    [anon_sym_DQUOTE] = ACTIONS(1046),
    [sym_bool_literal] = ACTIONS(1044),
    [sym_null] = ACTIONS(1044),
    [sym_this] = ACTIONS(1044),
    [sym_comment] = ACTIONS(19),
  },
  [458] = {
    [sym_preproc_include] = STATE(458),
    [sym_preproc_tryinclude] = STATE(458),
    [sym_preproc_macro] = STATE(458),
    [sym_preproc_define] = STATE(458),
    [sym_preproc_undefine] = STATE(458),
    [sym_preproc_if] = STATE(458),
    [sym_preproc_elseif] = STATE(458),
    [sym_preproc_assert] = STATE(458),
    [sym_preproc_pragma] = STATE(458),
    [sym_preproc_error] = STATE(458),
    [sym_preproc_warning] = STATE(458),
    [sym_identifier] = ACTIONS(1048),
    [anon_sym_LPAREN] = ACTIONS(1050),
    [anon_sym_BANG] = ACTIONS(1050),
    [anon_sym_TILDE] = ACTIONS(1050),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_AMP] = ACTIONS(1050),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1048),
    [anon_sym_public] = ACTIONS(1048),
    [anon_sym_stock] = ACTIONS(1048),
    [anon_sym_static] = ACTIONS(1048),
    [anon_sym_new] = ACTIONS(1048),
    [anon_sym_decl] = ACTIONS(1048),
    [anon_sym_LBRACE] = ACTIONS(1050),
    [anon_sym_RBRACE] = ACTIONS(1050),
    [anon_sym_void] = ACTIONS(1048),
    [anon_sym_bool] = ACTIONS(1048),
    [anon_sym_int] = ACTIONS(1048),
    [anon_sym_float] = ACTIONS(1048),
    [anon_sym_char] = ACTIONS(1048),
    [anon_sym__] = ACTIONS(1048),
    [anon_sym_Float] = ACTIONS(1048),
    [anon_sym_String] = ACTIONS(1048),
    [sym_any_type] = ACTIONS(1048),
    [anon_sym_for] = ACTIONS(1048),
    [anon_sym_while] = ACTIONS(1048),
    [anon_sym_do] = ACTIONS(1048),
    [anon_sym_break] = ACTIONS(1048),
    [anon_sym_continue] = ACTIONS(1048),
    [anon_sym_if] = ACTIONS(1048),
    [anon_sym_else] = ACTIONS(1048),
    [anon_sym_switch] = ACTIONS(1048),
    [anon_sym_return] = ACTIONS(1048),
    [anon_sym_delete] = ACTIONS(1048),
    [anon_sym_DASH_DASH] = ACTIONS(1050),
    [anon_sym_PLUS_PLUS] = ACTIONS(1050),
    [anon_sym_sizeof] = ACTIONS(1048),
    [anon_sym_view_as] = ACTIONS(1048),
    [sym_int_literal] = ACTIONS(1048),
    [sym_float_literal] = ACTIONS(1050),
    [anon_sym_SQUOTE] = ACTIONS(1050),
    [anon_sym_DQUOTE] = ACTIONS(1050),
    [sym_bool_literal] = ACTIONS(1048),
    [sym_null] = ACTIONS(1048),
    [sym_this] = ACTIONS(1048),
    [sym_comment] = ACTIONS(19),
  },
  [459] = {
    [sym_preproc_include] = STATE(459),
    [sym_preproc_tryinclude] = STATE(459),
    [sym_preproc_macro] = STATE(459),
    [sym_preproc_define] = STATE(459),
    [sym_preproc_undefine] = STATE(459),
    [sym_preproc_if] = STATE(459),
    [sym_preproc_elseif] = STATE(459),
    [sym_preproc_assert] = STATE(459),
    [sym_preproc_pragma] = STATE(459),
    [sym_preproc_error] = STATE(459),
    [sym_preproc_warning] = STATE(459),
    [sym_identifier] = ACTIONS(1052),
    [anon_sym_LPAREN] = ACTIONS(1054),
    [anon_sym_BANG] = ACTIONS(1054),
    [anon_sym_TILDE] = ACTIONS(1054),
    [anon_sym_DASH] = ACTIONS(1052),
    [anon_sym_PLUS] = ACTIONS(1052),
    [anon_sym_AMP] = ACTIONS(1054),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1052),
    [anon_sym_public] = ACTIONS(1052),
    [anon_sym_stock] = ACTIONS(1052),
    [anon_sym_static] = ACTIONS(1052),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_decl] = ACTIONS(1052),
    [anon_sym_LBRACE] = ACTIONS(1054),
    [anon_sym_RBRACE] = ACTIONS(1054),
    [anon_sym_void] = ACTIONS(1052),
    [anon_sym_bool] = ACTIONS(1052),
    [anon_sym_int] = ACTIONS(1052),
    [anon_sym_float] = ACTIONS(1052),
    [anon_sym_char] = ACTIONS(1052),
    [anon_sym__] = ACTIONS(1052),
    [anon_sym_Float] = ACTIONS(1052),
    [anon_sym_String] = ACTIONS(1052),
    [sym_any_type] = ACTIONS(1052),
    [anon_sym_for] = ACTIONS(1052),
    [anon_sym_while] = ACTIONS(1052),
    [anon_sym_do] = ACTIONS(1052),
    [anon_sym_break] = ACTIONS(1052),
    [anon_sym_continue] = ACTIONS(1052),
    [anon_sym_if] = ACTIONS(1052),
    [anon_sym_else] = ACTIONS(1052),
    [anon_sym_switch] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1052),
    [anon_sym_delete] = ACTIONS(1052),
    [anon_sym_DASH_DASH] = ACTIONS(1054),
    [anon_sym_PLUS_PLUS] = ACTIONS(1054),
    [anon_sym_sizeof] = ACTIONS(1052),
    [anon_sym_view_as] = ACTIONS(1052),
    [sym_int_literal] = ACTIONS(1052),
    [sym_float_literal] = ACTIONS(1054),
    [anon_sym_SQUOTE] = ACTIONS(1054),
    [anon_sym_DQUOTE] = ACTIONS(1054),
    [sym_bool_literal] = ACTIONS(1052),
    [sym_null] = ACTIONS(1052),
    [sym_this] = ACTIONS(1052),
    [sym_comment] = ACTIONS(19),
  },
  [460] = {
    [sym_preproc_include] = STATE(460),
    [sym_preproc_tryinclude] = STATE(460),
    [sym_preproc_macro] = STATE(460),
    [sym_preproc_define] = STATE(460),
    [sym_preproc_undefine] = STATE(460),
    [sym_preproc_if] = STATE(460),
    [sym_preproc_elseif] = STATE(460),
    [sym_preproc_assert] = STATE(460),
    [sym_preproc_pragma] = STATE(460),
    [sym_preproc_error] = STATE(460),
    [sym_preproc_warning] = STATE(460),
    [sym_identifier] = ACTIONS(1056),
    [anon_sym_LPAREN] = ACTIONS(1058),
    [anon_sym_BANG] = ACTIONS(1058),
    [anon_sym_TILDE] = ACTIONS(1058),
    [anon_sym_DASH] = ACTIONS(1056),
    [anon_sym_PLUS] = ACTIONS(1056),
    [anon_sym_AMP] = ACTIONS(1058),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1056),
    [anon_sym_public] = ACTIONS(1056),
    [anon_sym_stock] = ACTIONS(1056),
    [anon_sym_static] = ACTIONS(1056),
    [anon_sym_new] = ACTIONS(1056),
    [anon_sym_decl] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1058),
    [anon_sym_RBRACE] = ACTIONS(1058),
    [anon_sym_void] = ACTIONS(1056),
    [anon_sym_bool] = ACTIONS(1056),
    [anon_sym_int] = ACTIONS(1056),
    [anon_sym_float] = ACTIONS(1056),
    [anon_sym_char] = ACTIONS(1056),
    [anon_sym__] = ACTIONS(1056),
    [anon_sym_Float] = ACTIONS(1056),
    [anon_sym_String] = ACTIONS(1056),
    [sym_any_type] = ACTIONS(1056),
    [anon_sym_for] = ACTIONS(1056),
    [anon_sym_while] = ACTIONS(1056),
    [anon_sym_do] = ACTIONS(1056),
    [anon_sym_break] = ACTIONS(1056),
    [anon_sym_continue] = ACTIONS(1056),
    [anon_sym_if] = ACTIONS(1056),
    [anon_sym_else] = ACTIONS(1056),
    [anon_sym_switch] = ACTIONS(1056),
    [anon_sym_return] = ACTIONS(1056),
    [anon_sym_delete] = ACTIONS(1056),
    [anon_sym_DASH_DASH] = ACTIONS(1058),
    [anon_sym_PLUS_PLUS] = ACTIONS(1058),
    [anon_sym_sizeof] = ACTIONS(1056),
    [anon_sym_view_as] = ACTIONS(1056),
    [sym_int_literal] = ACTIONS(1056),
    [sym_float_literal] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1058),
    [anon_sym_DQUOTE] = ACTIONS(1058),
    [sym_bool_literal] = ACTIONS(1056),
    [sym_null] = ACTIONS(1056),
    [sym_this] = ACTIONS(1056),
    [sym_comment] = ACTIONS(19),
  },
  [461] = {
    [sym_preproc_include] = STATE(461),
    [sym_preproc_tryinclude] = STATE(461),
    [sym_preproc_macro] = STATE(461),
    [sym_preproc_define] = STATE(461),
    [sym_preproc_undefine] = STATE(461),
    [sym_preproc_if] = STATE(461),
    [sym_preproc_elseif] = STATE(461),
    [sym_preproc_assert] = STATE(461),
    [sym_preproc_pragma] = STATE(461),
    [sym_preproc_error] = STATE(461),
    [sym_preproc_warning] = STATE(461),
    [sym_identifier] = ACTIONS(1060),
    [anon_sym_LPAREN] = ACTIONS(1062),
    [anon_sym_BANG] = ACTIONS(1062),
    [anon_sym_TILDE] = ACTIONS(1062),
    [anon_sym_DASH] = ACTIONS(1060),
    [anon_sym_PLUS] = ACTIONS(1060),
    [anon_sym_AMP] = ACTIONS(1062),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1060),
    [anon_sym_public] = ACTIONS(1060),
    [anon_sym_stock] = ACTIONS(1060),
    [anon_sym_static] = ACTIONS(1060),
    [anon_sym_new] = ACTIONS(1060),
    [anon_sym_decl] = ACTIONS(1060),
    [anon_sym_LBRACE] = ACTIONS(1062),
    [anon_sym_RBRACE] = ACTIONS(1062),
    [anon_sym_void] = ACTIONS(1060),
    [anon_sym_bool] = ACTIONS(1060),
    [anon_sym_int] = ACTIONS(1060),
    [anon_sym_float] = ACTIONS(1060),
    [anon_sym_char] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1060),
    [anon_sym_Float] = ACTIONS(1060),
    [anon_sym_String] = ACTIONS(1060),
    [sym_any_type] = ACTIONS(1060),
    [anon_sym_for] = ACTIONS(1060),
    [anon_sym_while] = ACTIONS(1060),
    [anon_sym_do] = ACTIONS(1060),
    [anon_sym_break] = ACTIONS(1060),
    [anon_sym_continue] = ACTIONS(1060),
    [anon_sym_if] = ACTIONS(1060),
    [anon_sym_else] = ACTIONS(1060),
    [anon_sym_switch] = ACTIONS(1060),
    [anon_sym_return] = ACTIONS(1060),
    [anon_sym_delete] = ACTIONS(1060),
    [anon_sym_DASH_DASH] = ACTIONS(1062),
    [anon_sym_PLUS_PLUS] = ACTIONS(1062),
    [anon_sym_sizeof] = ACTIONS(1060),
    [anon_sym_view_as] = ACTIONS(1060),
    [sym_int_literal] = ACTIONS(1060),
    [sym_float_literal] = ACTIONS(1062),
    [anon_sym_SQUOTE] = ACTIONS(1062),
    [anon_sym_DQUOTE] = ACTIONS(1062),
    [sym_bool_literal] = ACTIONS(1060),
    [sym_null] = ACTIONS(1060),
    [sym_this] = ACTIONS(1060),
    [sym_comment] = ACTIONS(19),
  },
  [462] = {
    [sym_preproc_include] = STATE(462),
    [sym_preproc_tryinclude] = STATE(462),
    [sym_preproc_macro] = STATE(462),
    [sym_preproc_define] = STATE(462),
    [sym_preproc_undefine] = STATE(462),
    [sym_preproc_if] = STATE(462),
    [sym_preproc_elseif] = STATE(462),
    [sym_preproc_assert] = STATE(462),
    [sym_preproc_pragma] = STATE(462),
    [sym_preproc_error] = STATE(462),
    [sym_preproc_warning] = STATE(462),
    [sym_identifier] = ACTIONS(1064),
    [anon_sym_LPAREN] = ACTIONS(1066),
    [anon_sym_BANG] = ACTIONS(1066),
    [anon_sym_TILDE] = ACTIONS(1066),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_AMP] = ACTIONS(1066),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1064),
    [anon_sym_public] = ACTIONS(1064),
    [anon_sym_stock] = ACTIONS(1064),
    [anon_sym_static] = ACTIONS(1064),
    [anon_sym_new] = ACTIONS(1064),
    [anon_sym_decl] = ACTIONS(1064),
    [anon_sym_LBRACE] = ACTIONS(1066),
    [anon_sym_RBRACE] = ACTIONS(1066),
    [anon_sym_void] = ACTIONS(1064),
    [anon_sym_bool] = ACTIONS(1064),
    [anon_sym_int] = ACTIONS(1064),
    [anon_sym_float] = ACTIONS(1064),
    [anon_sym_char] = ACTIONS(1064),
    [anon_sym__] = ACTIONS(1064),
    [anon_sym_Float] = ACTIONS(1064),
    [anon_sym_String] = ACTIONS(1064),
    [sym_any_type] = ACTIONS(1064),
    [anon_sym_for] = ACTIONS(1064),
    [anon_sym_while] = ACTIONS(1064),
    [anon_sym_do] = ACTIONS(1064),
    [anon_sym_break] = ACTIONS(1064),
    [anon_sym_continue] = ACTIONS(1064),
    [anon_sym_if] = ACTIONS(1064),
    [anon_sym_else] = ACTIONS(1064),
    [anon_sym_switch] = ACTIONS(1064),
    [anon_sym_return] = ACTIONS(1064),
    [anon_sym_delete] = ACTIONS(1064),
    [anon_sym_DASH_DASH] = ACTIONS(1066),
    [anon_sym_PLUS_PLUS] = ACTIONS(1066),
    [anon_sym_sizeof] = ACTIONS(1064),
    [anon_sym_view_as] = ACTIONS(1064),
    [sym_int_literal] = ACTIONS(1064),
    [sym_float_literal] = ACTIONS(1066),
    [anon_sym_SQUOTE] = ACTIONS(1066),
    [anon_sym_DQUOTE] = ACTIONS(1066),
    [sym_bool_literal] = ACTIONS(1064),
    [sym_null] = ACTIONS(1064),
    [sym_this] = ACTIONS(1064),
    [sym_comment] = ACTIONS(19),
  },
  [463] = {
    [sym_preproc_include] = STATE(463),
    [sym_preproc_tryinclude] = STATE(463),
    [sym_preproc_macro] = STATE(463),
    [sym_preproc_define] = STATE(463),
    [sym_preproc_undefine] = STATE(463),
    [sym_preproc_if] = STATE(463),
    [sym_preproc_elseif] = STATE(463),
    [sym_preproc_assert] = STATE(463),
    [sym_preproc_pragma] = STATE(463),
    [sym_preproc_error] = STATE(463),
    [sym_preproc_warning] = STATE(463),
    [sym_identifier] = ACTIONS(1068),
    [anon_sym_LPAREN] = ACTIONS(1070),
    [anon_sym_BANG] = ACTIONS(1070),
    [anon_sym_TILDE] = ACTIONS(1070),
    [anon_sym_DASH] = ACTIONS(1068),
    [anon_sym_PLUS] = ACTIONS(1068),
    [anon_sym_AMP] = ACTIONS(1070),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1068),
    [anon_sym_public] = ACTIONS(1068),
    [anon_sym_stock] = ACTIONS(1068),
    [anon_sym_static] = ACTIONS(1068),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_decl] = ACTIONS(1068),
    [anon_sym_LBRACE] = ACTIONS(1070),
    [anon_sym_RBRACE] = ACTIONS(1070),
    [anon_sym_void] = ACTIONS(1068),
    [anon_sym_bool] = ACTIONS(1068),
    [anon_sym_int] = ACTIONS(1068),
    [anon_sym_float] = ACTIONS(1068),
    [anon_sym_char] = ACTIONS(1068),
    [anon_sym__] = ACTIONS(1068),
    [anon_sym_Float] = ACTIONS(1068),
    [anon_sym_String] = ACTIONS(1068),
    [sym_any_type] = ACTIONS(1068),
    [anon_sym_for] = ACTIONS(1068),
    [anon_sym_while] = ACTIONS(1068),
    [anon_sym_do] = ACTIONS(1068),
    [anon_sym_break] = ACTIONS(1068),
    [anon_sym_continue] = ACTIONS(1068),
    [anon_sym_if] = ACTIONS(1068),
    [anon_sym_else] = ACTIONS(1068),
    [anon_sym_switch] = ACTIONS(1068),
    [anon_sym_return] = ACTIONS(1068),
    [anon_sym_delete] = ACTIONS(1068),
    [anon_sym_DASH_DASH] = ACTIONS(1070),
    [anon_sym_PLUS_PLUS] = ACTIONS(1070),
    [anon_sym_sizeof] = ACTIONS(1068),
    [anon_sym_view_as] = ACTIONS(1068),
    [sym_int_literal] = ACTIONS(1068),
    [sym_float_literal] = ACTIONS(1070),
    [anon_sym_SQUOTE] = ACTIONS(1070),
    [anon_sym_DQUOTE] = ACTIONS(1070),
    [sym_bool_literal] = ACTIONS(1068),
    [sym_null] = ACTIONS(1068),
    [sym_this] = ACTIONS(1068),
    [sym_comment] = ACTIONS(19),
  },
  [464] = {
    [sym_preproc_include] = STATE(464),
    [sym_preproc_tryinclude] = STATE(464),
    [sym_preproc_macro] = STATE(464),
    [sym_preproc_define] = STATE(464),
    [sym_preproc_undefine] = STATE(464),
    [sym_preproc_if] = STATE(464),
    [sym_preproc_elseif] = STATE(464),
    [sym_preproc_assert] = STATE(464),
    [sym_preproc_pragma] = STATE(464),
    [sym_preproc_error] = STATE(464),
    [sym_preproc_warning] = STATE(464),
    [sym_identifier] = ACTIONS(1072),
    [anon_sym_LPAREN] = ACTIONS(1074),
    [anon_sym_BANG] = ACTIONS(1074),
    [anon_sym_TILDE] = ACTIONS(1074),
    [anon_sym_DASH] = ACTIONS(1072),
    [anon_sym_PLUS] = ACTIONS(1072),
    [anon_sym_AMP] = ACTIONS(1074),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1072),
    [anon_sym_public] = ACTIONS(1072),
    [anon_sym_stock] = ACTIONS(1072),
    [anon_sym_static] = ACTIONS(1072),
    [anon_sym_new] = ACTIONS(1072),
    [anon_sym_decl] = ACTIONS(1072),
    [anon_sym_LBRACE] = ACTIONS(1074),
    [anon_sym_RBRACE] = ACTIONS(1074),
    [anon_sym_void] = ACTIONS(1072),
    [anon_sym_bool] = ACTIONS(1072),
    [anon_sym_int] = ACTIONS(1072),
    [anon_sym_float] = ACTIONS(1072),
    [anon_sym_char] = ACTIONS(1072),
    [anon_sym__] = ACTIONS(1072),
    [anon_sym_Float] = ACTIONS(1072),
    [anon_sym_String] = ACTIONS(1072),
    [sym_any_type] = ACTIONS(1072),
    [anon_sym_for] = ACTIONS(1072),
    [anon_sym_while] = ACTIONS(1072),
    [anon_sym_do] = ACTIONS(1072),
    [anon_sym_break] = ACTIONS(1072),
    [anon_sym_continue] = ACTIONS(1072),
    [anon_sym_if] = ACTIONS(1072),
    [anon_sym_else] = ACTIONS(1076),
    [anon_sym_switch] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1072),
    [anon_sym_delete] = ACTIONS(1072),
    [anon_sym_DASH_DASH] = ACTIONS(1074),
    [anon_sym_PLUS_PLUS] = ACTIONS(1074),
    [anon_sym_sizeof] = ACTIONS(1072),
    [anon_sym_view_as] = ACTIONS(1072),
    [sym_int_literal] = ACTIONS(1072),
    [sym_float_literal] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1074),
    [anon_sym_DQUOTE] = ACTIONS(1074),
    [sym_bool_literal] = ACTIONS(1072),
    [sym_null] = ACTIONS(1072),
    [sym_this] = ACTIONS(1072),
    [sym_comment] = ACTIONS(19),
  },
  [465] = {
    [sym_preproc_include] = STATE(465),
    [sym_preproc_tryinclude] = STATE(465),
    [sym_preproc_macro] = STATE(465),
    [sym_preproc_define] = STATE(465),
    [sym_preproc_undefine] = STATE(465),
    [sym_preproc_if] = STATE(465),
    [sym_preproc_elseif] = STATE(465),
    [sym_preproc_assert] = STATE(465),
    [sym_preproc_pragma] = STATE(465),
    [sym_preproc_error] = STATE(465),
    [sym_preproc_warning] = STATE(465),
    [sym_identifier] = ACTIONS(1078),
    [anon_sym_LPAREN] = ACTIONS(1080),
    [anon_sym_BANG] = ACTIONS(1080),
    [anon_sym_TILDE] = ACTIONS(1080),
    [anon_sym_DASH] = ACTIONS(1078),
    [anon_sym_PLUS] = ACTIONS(1078),
    [anon_sym_AMP] = ACTIONS(1080),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1078),
    [anon_sym_public] = ACTIONS(1078),
    [anon_sym_stock] = ACTIONS(1078),
    [anon_sym_static] = ACTIONS(1078),
    [anon_sym_new] = ACTIONS(1078),
    [anon_sym_decl] = ACTIONS(1078),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym_RBRACE] = ACTIONS(1080),
    [anon_sym_void] = ACTIONS(1078),
    [anon_sym_bool] = ACTIONS(1078),
    [anon_sym_int] = ACTIONS(1078),
    [anon_sym_float] = ACTIONS(1078),
    [anon_sym_char] = ACTIONS(1078),
    [anon_sym__] = ACTIONS(1078),
    [anon_sym_Float] = ACTIONS(1078),
    [anon_sym_String] = ACTIONS(1078),
    [sym_any_type] = ACTIONS(1078),
    [anon_sym_for] = ACTIONS(1078),
    [anon_sym_while] = ACTIONS(1078),
    [anon_sym_do] = ACTIONS(1078),
    [anon_sym_break] = ACTIONS(1078),
    [anon_sym_continue] = ACTIONS(1078),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_else] = ACTIONS(1078),
    [anon_sym_switch] = ACTIONS(1078),
    [anon_sym_return] = ACTIONS(1078),
    [anon_sym_delete] = ACTIONS(1078),
    [anon_sym_DASH_DASH] = ACTIONS(1080),
    [anon_sym_PLUS_PLUS] = ACTIONS(1080),
    [anon_sym_sizeof] = ACTIONS(1078),
    [anon_sym_view_as] = ACTIONS(1078),
    [sym_int_literal] = ACTIONS(1078),
    [sym_float_literal] = ACTIONS(1080),
    [anon_sym_SQUOTE] = ACTIONS(1080),
    [anon_sym_DQUOTE] = ACTIONS(1080),
    [sym_bool_literal] = ACTIONS(1078),
    [sym_null] = ACTIONS(1078),
    [sym_this] = ACTIONS(1078),
    [sym_comment] = ACTIONS(19),
  },
  [466] = {
    [sym_preproc_include] = STATE(466),
    [sym_preproc_tryinclude] = STATE(466),
    [sym_preproc_macro] = STATE(466),
    [sym_preproc_define] = STATE(466),
    [sym_preproc_undefine] = STATE(466),
    [sym_preproc_if] = STATE(466),
    [sym_preproc_elseif] = STATE(466),
    [sym_preproc_assert] = STATE(466),
    [sym_preproc_pragma] = STATE(466),
    [sym_preproc_error] = STATE(466),
    [sym_preproc_warning] = STATE(466),
    [sym_identifier] = ACTIONS(1082),
    [anon_sym_LPAREN] = ACTIONS(1084),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1082),
    [anon_sym_AMP] = ACTIONS(1084),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1082),
    [anon_sym_public] = ACTIONS(1082),
    [anon_sym_stock] = ACTIONS(1082),
    [anon_sym_static] = ACTIONS(1082),
    [anon_sym_new] = ACTIONS(1082),
    [anon_sym_decl] = ACTIONS(1082),
    [anon_sym_LBRACE] = ACTIONS(1084),
    [anon_sym_RBRACE] = ACTIONS(1084),
    [anon_sym_void] = ACTIONS(1082),
    [anon_sym_bool] = ACTIONS(1082),
    [anon_sym_int] = ACTIONS(1082),
    [anon_sym_float] = ACTIONS(1082),
    [anon_sym_char] = ACTIONS(1082),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_Float] = ACTIONS(1082),
    [anon_sym_String] = ACTIONS(1082),
    [sym_any_type] = ACTIONS(1082),
    [anon_sym_for] = ACTIONS(1082),
    [anon_sym_while] = ACTIONS(1082),
    [anon_sym_do] = ACTIONS(1082),
    [anon_sym_break] = ACTIONS(1082),
    [anon_sym_continue] = ACTIONS(1082),
    [anon_sym_if] = ACTIONS(1082),
    [anon_sym_else] = ACTIONS(1082),
    [anon_sym_switch] = ACTIONS(1082),
    [anon_sym_return] = ACTIONS(1082),
    [anon_sym_delete] = ACTIONS(1082),
    [anon_sym_DASH_DASH] = ACTIONS(1084),
    [anon_sym_PLUS_PLUS] = ACTIONS(1084),
    [anon_sym_sizeof] = ACTIONS(1082),
    [anon_sym_view_as] = ACTIONS(1082),
    [sym_int_literal] = ACTIONS(1082),
    [sym_float_literal] = ACTIONS(1084),
    [anon_sym_SQUOTE] = ACTIONS(1084),
    [anon_sym_DQUOTE] = ACTIONS(1084),
    [sym_bool_literal] = ACTIONS(1082),
    [sym_null] = ACTIONS(1082),
    [sym_this] = ACTIONS(1082),
    [sym_comment] = ACTIONS(19),
  },
  [467] = {
    [sym_preproc_include] = STATE(467),
    [sym_preproc_tryinclude] = STATE(467),
    [sym_preproc_macro] = STATE(467),
    [sym_preproc_define] = STATE(467),
    [sym_preproc_undefine] = STATE(467),
    [sym_preproc_if] = STATE(467),
    [sym_preproc_elseif] = STATE(467),
    [sym_preproc_assert] = STATE(467),
    [sym_preproc_pragma] = STATE(467),
    [sym_preproc_error] = STATE(467),
    [sym_preproc_warning] = STATE(467),
    [sym_identifier] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1088),
    [anon_sym_BANG] = ACTIONS(1088),
    [anon_sym_TILDE] = ACTIONS(1088),
    [anon_sym_DASH] = ACTIONS(1086),
    [anon_sym_PLUS] = ACTIONS(1086),
    [anon_sym_AMP] = ACTIONS(1088),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1086),
    [anon_sym_public] = ACTIONS(1086),
    [anon_sym_stock] = ACTIONS(1086),
    [anon_sym_static] = ACTIONS(1086),
    [anon_sym_new] = ACTIONS(1086),
    [anon_sym_decl] = ACTIONS(1086),
    [anon_sym_LBRACE] = ACTIONS(1088),
    [anon_sym_RBRACE] = ACTIONS(1088),
    [anon_sym_void] = ACTIONS(1086),
    [anon_sym_bool] = ACTIONS(1086),
    [anon_sym_int] = ACTIONS(1086),
    [anon_sym_float] = ACTIONS(1086),
    [anon_sym_char] = ACTIONS(1086),
    [anon_sym__] = ACTIONS(1086),
    [anon_sym_Float] = ACTIONS(1086),
    [anon_sym_String] = ACTIONS(1086),
    [sym_any_type] = ACTIONS(1086),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_while] = ACTIONS(1086),
    [anon_sym_do] = ACTIONS(1086),
    [anon_sym_break] = ACTIONS(1086),
    [anon_sym_continue] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1086),
    [anon_sym_else] = ACTIONS(1086),
    [anon_sym_switch] = ACTIONS(1086),
    [anon_sym_return] = ACTIONS(1086),
    [anon_sym_delete] = ACTIONS(1086),
    [anon_sym_DASH_DASH] = ACTIONS(1088),
    [anon_sym_PLUS_PLUS] = ACTIONS(1088),
    [anon_sym_sizeof] = ACTIONS(1086),
    [anon_sym_view_as] = ACTIONS(1086),
    [sym_int_literal] = ACTIONS(1086),
    [sym_float_literal] = ACTIONS(1088),
    [anon_sym_SQUOTE] = ACTIONS(1088),
    [anon_sym_DQUOTE] = ACTIONS(1088),
    [sym_bool_literal] = ACTIONS(1086),
    [sym_null] = ACTIONS(1086),
    [sym_this] = ACTIONS(1086),
    [sym_comment] = ACTIONS(19),
  },
  [468] = {
    [sym_preproc_include] = STATE(468),
    [sym_preproc_tryinclude] = STATE(468),
    [sym_preproc_macro] = STATE(468),
    [sym_preproc_define] = STATE(468),
    [sym_preproc_undefine] = STATE(468),
    [sym_preproc_if] = STATE(468),
    [sym_preproc_elseif] = STATE(468),
    [sym_preproc_assert] = STATE(468),
    [sym_preproc_pragma] = STATE(468),
    [sym_preproc_error] = STATE(468),
    [sym_preproc_warning] = STATE(468),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(780),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_AMP] = ACTIONS(780),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(778),
    [anon_sym_public] = ACTIONS(778),
    [anon_sym_stock] = ACTIONS(778),
    [anon_sym_static] = ACTIONS(778),
    [anon_sym_new] = ACTIONS(778),
    [anon_sym_decl] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_bool] = ACTIONS(778),
    [anon_sym_int] = ACTIONS(778),
    [anon_sym_float] = ACTIONS(778),
    [anon_sym_char] = ACTIONS(778),
    [anon_sym__] = ACTIONS(778),
    [anon_sym_Float] = ACTIONS(778),
    [anon_sym_String] = ACTIONS(778),
    [sym_any_type] = ACTIONS(778),
    [anon_sym_for] = ACTIONS(778),
    [anon_sym_while] = ACTIONS(778),
    [anon_sym_do] = ACTIONS(778),
    [anon_sym_break] = ACTIONS(778),
    [anon_sym_continue] = ACTIONS(778),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_else] = ACTIONS(778),
    [anon_sym_switch] = ACTIONS(778),
    [anon_sym_return] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_sizeof] = ACTIONS(778),
    [anon_sym_view_as] = ACTIONS(778),
    [sym_int_literal] = ACTIONS(778),
    [sym_float_literal] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [sym_bool_literal] = ACTIONS(778),
    [sym_null] = ACTIONS(778),
    [sym_this] = ACTIONS(778),
    [sym_comment] = ACTIONS(19),
  },
  [469] = {
    [sym_preproc_include] = STATE(469),
    [sym_preproc_tryinclude] = STATE(469),
    [sym_preproc_macro] = STATE(469),
    [sym_preproc_define] = STATE(469),
    [sym_preproc_undefine] = STATE(469),
    [sym_preproc_if] = STATE(469),
    [sym_preproc_elseif] = STATE(469),
    [sym_preproc_assert] = STATE(469),
    [sym_preproc_pragma] = STATE(469),
    [sym_preproc_error] = STATE(469),
    [sym_preproc_warning] = STATE(469),
    [sym_identifier] = ACTIONS(1090),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_BANG] = ACTIONS(1092),
    [anon_sym_TILDE] = ACTIONS(1092),
    [anon_sym_DASH] = ACTIONS(1090),
    [anon_sym_PLUS] = ACTIONS(1090),
    [anon_sym_AMP] = ACTIONS(1092),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1090),
    [anon_sym_public] = ACTIONS(1090),
    [anon_sym_stock] = ACTIONS(1090),
    [anon_sym_static] = ACTIONS(1090),
    [anon_sym_new] = ACTIONS(1090),
    [anon_sym_decl] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(1092),
    [anon_sym_RBRACE] = ACTIONS(1092),
    [anon_sym_void] = ACTIONS(1090),
    [anon_sym_bool] = ACTIONS(1090),
    [anon_sym_int] = ACTIONS(1090),
    [anon_sym_float] = ACTIONS(1090),
    [anon_sym_char] = ACTIONS(1090),
    [anon_sym__] = ACTIONS(1090),
    [anon_sym_Float] = ACTIONS(1090),
    [anon_sym_String] = ACTIONS(1090),
    [sym_any_type] = ACTIONS(1090),
    [anon_sym_for] = ACTIONS(1090),
    [anon_sym_while] = ACTIONS(1090),
    [anon_sym_do] = ACTIONS(1090),
    [anon_sym_break] = ACTIONS(1090),
    [anon_sym_continue] = ACTIONS(1090),
    [anon_sym_if] = ACTIONS(1090),
    [anon_sym_else] = ACTIONS(1090),
    [anon_sym_switch] = ACTIONS(1090),
    [anon_sym_return] = ACTIONS(1090),
    [anon_sym_delete] = ACTIONS(1090),
    [anon_sym_DASH_DASH] = ACTIONS(1092),
    [anon_sym_PLUS_PLUS] = ACTIONS(1092),
    [anon_sym_sizeof] = ACTIONS(1090),
    [anon_sym_view_as] = ACTIONS(1090),
    [sym_int_literal] = ACTIONS(1090),
    [sym_float_literal] = ACTIONS(1092),
    [anon_sym_SQUOTE] = ACTIONS(1092),
    [anon_sym_DQUOTE] = ACTIONS(1092),
    [sym_bool_literal] = ACTIONS(1090),
    [sym_null] = ACTIONS(1090),
    [sym_this] = ACTIONS(1090),
    [sym_comment] = ACTIONS(19),
  },
  [470] = {
    [sym_preproc_include] = STATE(470),
    [sym_preproc_tryinclude] = STATE(470),
    [sym_preproc_macro] = STATE(470),
    [sym_preproc_define] = STATE(470),
    [sym_preproc_undefine] = STATE(470),
    [sym_preproc_if] = STATE(470),
    [sym_preproc_elseif] = STATE(470),
    [sym_preproc_assert] = STATE(470),
    [sym_preproc_pragma] = STATE(470),
    [sym_preproc_error] = STATE(470),
    [sym_preproc_warning] = STATE(470),
    [sym_dimension] = STATE(787),
    [sym_call_arguments] = STATE(843),
    [aux_sym_function_definition_repeat1] = STATE(746),
    [anon_sym_LPAREN] = ACTIONS(1094),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(1096),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_COLON_COLON] = ACTIONS(1098),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [sym_comment] = ACTIONS(19),
    [sym__ternary_colon] = ACTIONS(127),
  },
  [471] = {
    [sym_preproc_include] = STATE(471),
    [sym_preproc_tryinclude] = STATE(471),
    [sym_preproc_macro] = STATE(471),
    [sym_preproc_define] = STATE(471),
    [sym_preproc_undefine] = STATE(471),
    [sym_preproc_if] = STATE(471),
    [sym_preproc_elseif] = STATE(471),
    [sym_preproc_assert] = STATE(471),
    [sym_preproc_pragma] = STATE(471),
    [sym_preproc_error] = STATE(471),
    [sym_preproc_warning] = STATE(471),
    [sym_identifier] = ACTIONS(1100),
    [anon_sym_LPAREN] = ACTIONS(1102),
    [anon_sym_BANG] = ACTIONS(1102),
    [anon_sym_TILDE] = ACTIONS(1102),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_AMP] = ACTIONS(1102),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1100),
    [anon_sym_public] = ACTIONS(1100),
    [anon_sym_stock] = ACTIONS(1100),
    [anon_sym_static] = ACTIONS(1100),
    [anon_sym_new] = ACTIONS(1100),
    [anon_sym_decl] = ACTIONS(1100),
    [anon_sym_LBRACE] = ACTIONS(1102),
    [anon_sym_RBRACE] = ACTIONS(1102),
    [anon_sym_void] = ACTIONS(1100),
    [anon_sym_bool] = ACTIONS(1100),
    [anon_sym_int] = ACTIONS(1100),
    [anon_sym_float] = ACTIONS(1100),
    [anon_sym_char] = ACTIONS(1100),
    [anon_sym__] = ACTIONS(1100),
    [anon_sym_Float] = ACTIONS(1100),
    [anon_sym_String] = ACTIONS(1100),
    [sym_any_type] = ACTIONS(1100),
    [anon_sym_for] = ACTIONS(1100),
    [anon_sym_while] = ACTIONS(1100),
    [anon_sym_do] = ACTIONS(1100),
    [anon_sym_break] = ACTIONS(1100),
    [anon_sym_continue] = ACTIONS(1100),
    [anon_sym_if] = ACTIONS(1100),
    [anon_sym_else] = ACTIONS(1100),
    [anon_sym_switch] = ACTIONS(1100),
    [anon_sym_return] = ACTIONS(1100),
    [anon_sym_delete] = ACTIONS(1100),
    [anon_sym_DASH_DASH] = ACTIONS(1102),
    [anon_sym_PLUS_PLUS] = ACTIONS(1102),
    [anon_sym_sizeof] = ACTIONS(1100),
    [anon_sym_view_as] = ACTIONS(1100),
    [sym_int_literal] = ACTIONS(1100),
    [sym_float_literal] = ACTIONS(1102),
    [anon_sym_SQUOTE] = ACTIONS(1102),
    [anon_sym_DQUOTE] = ACTIONS(1102),
    [sym_bool_literal] = ACTIONS(1100),
    [sym_null] = ACTIONS(1100),
    [sym_this] = ACTIONS(1100),
    [sym_comment] = ACTIONS(19),
  },
  [472] = {
    [sym_preproc_include] = STATE(472),
    [sym_preproc_tryinclude] = STATE(472),
    [sym_preproc_macro] = STATE(472),
    [sym_preproc_define] = STATE(472),
    [sym_preproc_undefine] = STATE(472),
    [sym_preproc_if] = STATE(472),
    [sym_preproc_elseif] = STATE(472),
    [sym_preproc_assert] = STATE(472),
    [sym_preproc_pragma] = STATE(472),
    [sym_preproc_error] = STATE(472),
    [sym_preproc_warning] = STATE(472),
    [sym_identifier] = ACTIONS(1104),
    [anon_sym_LPAREN] = ACTIONS(1106),
    [anon_sym_BANG] = ACTIONS(1106),
    [anon_sym_TILDE] = ACTIONS(1106),
    [anon_sym_DASH] = ACTIONS(1104),
    [anon_sym_PLUS] = ACTIONS(1104),
    [anon_sym_AMP] = ACTIONS(1106),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1104),
    [anon_sym_public] = ACTIONS(1104),
    [anon_sym_stock] = ACTIONS(1104),
    [anon_sym_static] = ACTIONS(1104),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_decl] = ACTIONS(1104),
    [anon_sym_LBRACE] = ACTIONS(1106),
    [anon_sym_RBRACE] = ACTIONS(1106),
    [anon_sym_void] = ACTIONS(1104),
    [anon_sym_bool] = ACTIONS(1104),
    [anon_sym_int] = ACTIONS(1104),
    [anon_sym_float] = ACTIONS(1104),
    [anon_sym_char] = ACTIONS(1104),
    [anon_sym__] = ACTIONS(1104),
    [anon_sym_Float] = ACTIONS(1104),
    [anon_sym_String] = ACTIONS(1104),
    [sym_any_type] = ACTIONS(1104),
    [anon_sym_for] = ACTIONS(1104),
    [anon_sym_while] = ACTIONS(1104),
    [anon_sym_do] = ACTIONS(1104),
    [anon_sym_break] = ACTIONS(1104),
    [anon_sym_continue] = ACTIONS(1104),
    [anon_sym_if] = ACTIONS(1104),
    [anon_sym_else] = ACTIONS(1104),
    [anon_sym_switch] = ACTIONS(1104),
    [anon_sym_return] = ACTIONS(1104),
    [anon_sym_delete] = ACTIONS(1104),
    [anon_sym_DASH_DASH] = ACTIONS(1106),
    [anon_sym_PLUS_PLUS] = ACTIONS(1106),
    [anon_sym_sizeof] = ACTIONS(1104),
    [anon_sym_view_as] = ACTIONS(1104),
    [sym_int_literal] = ACTIONS(1104),
    [sym_float_literal] = ACTIONS(1106),
    [anon_sym_SQUOTE] = ACTIONS(1106),
    [anon_sym_DQUOTE] = ACTIONS(1106),
    [sym_bool_literal] = ACTIONS(1104),
    [sym_null] = ACTIONS(1104),
    [sym_this] = ACTIONS(1104),
    [sym_comment] = ACTIONS(19),
  },
  [473] = {
    [sym_preproc_include] = STATE(473),
    [sym_preproc_tryinclude] = STATE(473),
    [sym_preproc_macro] = STATE(473),
    [sym_preproc_define] = STATE(473),
    [sym_preproc_undefine] = STATE(473),
    [sym_preproc_if] = STATE(473),
    [sym_preproc_elseif] = STATE(473),
    [sym_preproc_assert] = STATE(473),
    [sym_preproc_pragma] = STATE(473),
    [sym_preproc_error] = STATE(473),
    [sym_preproc_warning] = STATE(473),
    [sym_identifier] = ACTIONS(1108),
    [anon_sym_LPAREN] = ACTIONS(1110),
    [anon_sym_BANG] = ACTIONS(1110),
    [anon_sym_TILDE] = ACTIONS(1110),
    [anon_sym_DASH] = ACTIONS(1108),
    [anon_sym_PLUS] = ACTIONS(1108),
    [anon_sym_AMP] = ACTIONS(1110),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1108),
    [anon_sym_public] = ACTIONS(1108),
    [anon_sym_stock] = ACTIONS(1108),
    [anon_sym_static] = ACTIONS(1108),
    [anon_sym_new] = ACTIONS(1108),
    [anon_sym_decl] = ACTIONS(1108),
    [anon_sym_LBRACE] = ACTIONS(1110),
    [anon_sym_RBRACE] = ACTIONS(1110),
    [anon_sym_void] = ACTIONS(1108),
    [anon_sym_bool] = ACTIONS(1108),
    [anon_sym_int] = ACTIONS(1108),
    [anon_sym_float] = ACTIONS(1108),
    [anon_sym_char] = ACTIONS(1108),
    [anon_sym__] = ACTIONS(1108),
    [anon_sym_Float] = ACTIONS(1108),
    [anon_sym_String] = ACTIONS(1108),
    [sym_any_type] = ACTIONS(1108),
    [anon_sym_for] = ACTIONS(1108),
    [anon_sym_while] = ACTIONS(1108),
    [anon_sym_do] = ACTIONS(1108),
    [anon_sym_break] = ACTIONS(1108),
    [anon_sym_continue] = ACTIONS(1108),
    [anon_sym_if] = ACTIONS(1108),
    [anon_sym_else] = ACTIONS(1108),
    [anon_sym_switch] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1108),
    [anon_sym_delete] = ACTIONS(1108),
    [anon_sym_DASH_DASH] = ACTIONS(1110),
    [anon_sym_PLUS_PLUS] = ACTIONS(1110),
    [anon_sym_sizeof] = ACTIONS(1108),
    [anon_sym_view_as] = ACTIONS(1108),
    [sym_int_literal] = ACTIONS(1108),
    [sym_float_literal] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1110),
    [anon_sym_DQUOTE] = ACTIONS(1110),
    [sym_bool_literal] = ACTIONS(1108),
    [sym_null] = ACTIONS(1108),
    [sym_this] = ACTIONS(1108),
    [sym_comment] = ACTIONS(19),
  },
  [474] = {
    [sym_preproc_include] = STATE(474),
    [sym_preproc_tryinclude] = STATE(474),
    [sym_preproc_macro] = STATE(474),
    [sym_preproc_define] = STATE(474),
    [sym_preproc_undefine] = STATE(474),
    [sym_preproc_if] = STATE(474),
    [sym_preproc_elseif] = STATE(474),
    [sym_preproc_assert] = STATE(474),
    [sym_preproc_pragma] = STATE(474),
    [sym_preproc_error] = STATE(474),
    [sym_preproc_warning] = STATE(474),
    [sym_identifier] = ACTIONS(1112),
    [anon_sym_LPAREN] = ACTIONS(1114),
    [anon_sym_BANG] = ACTIONS(1114),
    [anon_sym_TILDE] = ACTIONS(1114),
    [anon_sym_DASH] = ACTIONS(1112),
    [anon_sym_PLUS] = ACTIONS(1112),
    [anon_sym_AMP] = ACTIONS(1114),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1112),
    [anon_sym_public] = ACTIONS(1112),
    [anon_sym_stock] = ACTIONS(1112),
    [anon_sym_static] = ACTIONS(1112),
    [anon_sym_new] = ACTIONS(1112),
    [anon_sym_decl] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1114),
    [anon_sym_RBRACE] = ACTIONS(1114),
    [anon_sym_void] = ACTIONS(1112),
    [anon_sym_bool] = ACTIONS(1112),
    [anon_sym_int] = ACTIONS(1112),
    [anon_sym_float] = ACTIONS(1112),
    [anon_sym_char] = ACTIONS(1112),
    [anon_sym__] = ACTIONS(1112),
    [anon_sym_Float] = ACTIONS(1112),
    [anon_sym_String] = ACTIONS(1112),
    [sym_any_type] = ACTIONS(1112),
    [anon_sym_for] = ACTIONS(1112),
    [anon_sym_while] = ACTIONS(1112),
    [anon_sym_do] = ACTIONS(1112),
    [anon_sym_break] = ACTIONS(1112),
    [anon_sym_continue] = ACTIONS(1112),
    [anon_sym_if] = ACTIONS(1112),
    [anon_sym_else] = ACTIONS(1112),
    [anon_sym_switch] = ACTIONS(1112),
    [anon_sym_return] = ACTIONS(1112),
    [anon_sym_delete] = ACTIONS(1112),
    [anon_sym_DASH_DASH] = ACTIONS(1114),
    [anon_sym_PLUS_PLUS] = ACTIONS(1114),
    [anon_sym_sizeof] = ACTIONS(1112),
    [anon_sym_view_as] = ACTIONS(1112),
    [sym_int_literal] = ACTIONS(1112),
    [sym_float_literal] = ACTIONS(1114),
    [anon_sym_SQUOTE] = ACTIONS(1114),
    [anon_sym_DQUOTE] = ACTIONS(1114),
    [sym_bool_literal] = ACTIONS(1112),
    [sym_null] = ACTIONS(1112),
    [sym_this] = ACTIONS(1112),
    [sym_comment] = ACTIONS(19),
  },
  [475] = {
    [sym_preproc_include] = STATE(475),
    [sym_preproc_tryinclude] = STATE(475),
    [sym_preproc_macro] = STATE(475),
    [sym_preproc_define] = STATE(475),
    [sym_preproc_undefine] = STATE(475),
    [sym_preproc_if] = STATE(475),
    [sym_preproc_elseif] = STATE(475),
    [sym_preproc_assert] = STATE(475),
    [sym_preproc_pragma] = STATE(475),
    [sym_preproc_error] = STATE(475),
    [sym_preproc_warning] = STATE(475),
    [sym_identifier] = ACTIONS(1116),
    [anon_sym_LPAREN] = ACTIONS(1118),
    [anon_sym_BANG] = ACTIONS(1118),
    [anon_sym_TILDE] = ACTIONS(1118),
    [anon_sym_DASH] = ACTIONS(1116),
    [anon_sym_PLUS] = ACTIONS(1116),
    [anon_sym_AMP] = ACTIONS(1118),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1116),
    [anon_sym_public] = ACTIONS(1116),
    [anon_sym_stock] = ACTIONS(1116),
    [anon_sym_static] = ACTIONS(1116),
    [anon_sym_new] = ACTIONS(1116),
    [anon_sym_decl] = ACTIONS(1116),
    [anon_sym_LBRACE] = ACTIONS(1118),
    [anon_sym_RBRACE] = ACTIONS(1118),
    [anon_sym_void] = ACTIONS(1116),
    [anon_sym_bool] = ACTIONS(1116),
    [anon_sym_int] = ACTIONS(1116),
    [anon_sym_float] = ACTIONS(1116),
    [anon_sym_char] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1116),
    [anon_sym_Float] = ACTIONS(1116),
    [anon_sym_String] = ACTIONS(1116),
    [sym_any_type] = ACTIONS(1116),
    [anon_sym_for] = ACTIONS(1116),
    [anon_sym_while] = ACTIONS(1116),
    [anon_sym_do] = ACTIONS(1116),
    [anon_sym_break] = ACTIONS(1116),
    [anon_sym_continue] = ACTIONS(1116),
    [anon_sym_if] = ACTIONS(1116),
    [anon_sym_else] = ACTIONS(1116),
    [anon_sym_switch] = ACTIONS(1116),
    [anon_sym_return] = ACTIONS(1116),
    [anon_sym_delete] = ACTIONS(1116),
    [anon_sym_DASH_DASH] = ACTIONS(1118),
    [anon_sym_PLUS_PLUS] = ACTIONS(1118),
    [anon_sym_sizeof] = ACTIONS(1116),
    [anon_sym_view_as] = ACTIONS(1116),
    [sym_int_literal] = ACTIONS(1116),
    [sym_float_literal] = ACTIONS(1118),
    [anon_sym_SQUOTE] = ACTIONS(1118),
    [anon_sym_DQUOTE] = ACTIONS(1118),
    [sym_bool_literal] = ACTIONS(1116),
    [sym_null] = ACTIONS(1116),
    [sym_this] = ACTIONS(1116),
    [sym_comment] = ACTIONS(19),
  },
  [476] = {
    [sym_preproc_include] = STATE(476),
    [sym_preproc_tryinclude] = STATE(476),
    [sym_preproc_macro] = STATE(476),
    [sym_preproc_define] = STATE(476),
    [sym_preproc_undefine] = STATE(476),
    [sym_preproc_if] = STATE(476),
    [sym_preproc_elseif] = STATE(476),
    [sym_preproc_assert] = STATE(476),
    [sym_preproc_pragma] = STATE(476),
    [sym_preproc_error] = STATE(476),
    [sym_preproc_warning] = STATE(476),
    [sym_identifier] = ACTIONS(1120),
    [anon_sym_LPAREN] = ACTIONS(1122),
    [anon_sym_BANG] = ACTIONS(1122),
    [anon_sym_TILDE] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_AMP] = ACTIONS(1122),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1120),
    [anon_sym_public] = ACTIONS(1120),
    [anon_sym_stock] = ACTIONS(1120),
    [anon_sym_static] = ACTIONS(1120),
    [anon_sym_new] = ACTIONS(1120),
    [anon_sym_decl] = ACTIONS(1120),
    [anon_sym_LBRACE] = ACTIONS(1122),
    [anon_sym_RBRACE] = ACTIONS(1122),
    [anon_sym_void] = ACTIONS(1120),
    [anon_sym_bool] = ACTIONS(1120),
    [anon_sym_int] = ACTIONS(1120),
    [anon_sym_float] = ACTIONS(1120),
    [anon_sym_char] = ACTIONS(1120),
    [anon_sym__] = ACTIONS(1120),
    [anon_sym_Float] = ACTIONS(1120),
    [anon_sym_String] = ACTIONS(1120),
    [sym_any_type] = ACTIONS(1120),
    [anon_sym_for] = ACTIONS(1120),
    [anon_sym_while] = ACTIONS(1120),
    [anon_sym_do] = ACTIONS(1120),
    [anon_sym_break] = ACTIONS(1120),
    [anon_sym_continue] = ACTIONS(1120),
    [anon_sym_if] = ACTIONS(1120),
    [anon_sym_else] = ACTIONS(1120),
    [anon_sym_switch] = ACTIONS(1120),
    [anon_sym_return] = ACTIONS(1120),
    [anon_sym_delete] = ACTIONS(1120),
    [anon_sym_DASH_DASH] = ACTIONS(1122),
    [anon_sym_PLUS_PLUS] = ACTIONS(1122),
    [anon_sym_sizeof] = ACTIONS(1120),
    [anon_sym_view_as] = ACTIONS(1120),
    [sym_int_literal] = ACTIONS(1120),
    [sym_float_literal] = ACTIONS(1122),
    [anon_sym_SQUOTE] = ACTIONS(1122),
    [anon_sym_DQUOTE] = ACTIONS(1122),
    [sym_bool_literal] = ACTIONS(1120),
    [sym_null] = ACTIONS(1120),
    [sym_this] = ACTIONS(1120),
    [sym_comment] = ACTIONS(19),
  },
  [477] = {
    [sym_preproc_include] = STATE(477),
    [sym_preproc_tryinclude] = STATE(477),
    [sym_preproc_macro] = STATE(477),
    [sym_preproc_define] = STATE(477),
    [sym_preproc_undefine] = STATE(477),
    [sym_preproc_if] = STATE(477),
    [sym_preproc_elseif] = STATE(477),
    [sym_preproc_assert] = STATE(477),
    [sym_preproc_pragma] = STATE(477),
    [sym_preproc_error] = STATE(477),
    [sym_preproc_warning] = STATE(477),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_RPAREN] = ACTIONS(327),
    [anon_sym_DASH] = ACTIONS(325),
    [anon_sym_PLUS] = ACTIONS(325),
    [anon_sym_AMP] = ACTIONS(325),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(327),
    [anon_sym_STAR] = ACTIONS(325),
    [anon_sym_SLASH] = ACTIONS(325),
    [anon_sym_PERCENT] = ACTIONS(325),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(325),
    [anon_sym_CARET] = ACTIONS(325),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_GT] = ACTIONS(325),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_LT] = ACTIONS(325),
    [anon_sym_LT_LT] = ACTIONS(325),
    [anon_sym_GT_GT] = ACTIONS(325),
    [anon_sym_GT_GT_GT] = ACTIONS(325),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(327),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(325),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_SLASH_EQ] = ACTIONS(327),
    [anon_sym_PIPE_EQ] = ACTIONS(327),
    [anon_sym_AMP_EQ] = ACTIONS(327),
    [anon_sym_CARET_EQ] = ACTIONS(327),
    [anon_sym_TILDE_EQ] = ACTIONS(327),
    [anon_sym_LT_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_GT_EQ] = ACTIONS(327),
    [anon_sym_RBRACE] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(327),
    [anon_sym_RBRACK] = ACTIONS(327),
    [anon_sym_COLON2] = ACTIONS(327),
    [anon_sym_SEMI] = ACTIONS(327),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(327),
    [anon_sym_PERCENT_EQ] = ACTIONS(327),
    [anon_sym_DOT] = ACTIONS(325),
    [anon_sym_QMARK] = ACTIONS(327),
    [anon_sym_DASH_DASH] = ACTIONS(327),
    [anon_sym_PLUS_PLUS] = ACTIONS(327),
    [sym_comment] = ACTIONS(19),
  },
  [478] = {
    [sym_preproc_include] = STATE(478),
    [sym_preproc_tryinclude] = STATE(478),
    [sym_preproc_macro] = STATE(478),
    [sym_preproc_define] = STATE(478),
    [sym_preproc_undefine] = STATE(478),
    [sym_preproc_if] = STATE(478),
    [sym_preproc_elseif] = STATE(478),
    [sym_preproc_assert] = STATE(478),
    [sym_preproc_pragma] = STATE(478),
    [sym_preproc_error] = STATE(478),
    [sym_preproc_warning] = STATE(478),
    [sym_identifier] = ACTIONS(1124),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(1126),
    [anon_sym_TILDE] = ACTIONS(1126),
    [anon_sym_DASH] = ACTIONS(1124),
    [anon_sym_PLUS] = ACTIONS(1124),
    [anon_sym_AMP] = ACTIONS(1126),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1124),
    [anon_sym_public] = ACTIONS(1124),
    [anon_sym_stock] = ACTIONS(1124),
    [anon_sym_static] = ACTIONS(1124),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_decl] = ACTIONS(1124),
    [anon_sym_LBRACE] = ACTIONS(1126),
    [anon_sym_RBRACE] = ACTIONS(1126),
    [anon_sym_void] = ACTIONS(1124),
    [anon_sym_bool] = ACTIONS(1124),
    [anon_sym_int] = ACTIONS(1124),
    [anon_sym_float] = ACTIONS(1124),
    [anon_sym_char] = ACTIONS(1124),
    [anon_sym__] = ACTIONS(1124),
    [anon_sym_Float] = ACTIONS(1124),
    [anon_sym_String] = ACTIONS(1124),
    [sym_any_type] = ACTIONS(1124),
    [anon_sym_for] = ACTIONS(1124),
    [anon_sym_while] = ACTIONS(1124),
    [anon_sym_do] = ACTIONS(1124),
    [anon_sym_break] = ACTIONS(1124),
    [anon_sym_continue] = ACTIONS(1124),
    [anon_sym_if] = ACTIONS(1124),
    [anon_sym_else] = ACTIONS(1124),
    [anon_sym_switch] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1124),
    [anon_sym_delete] = ACTIONS(1124),
    [anon_sym_DASH_DASH] = ACTIONS(1126),
    [anon_sym_PLUS_PLUS] = ACTIONS(1126),
    [anon_sym_sizeof] = ACTIONS(1124),
    [anon_sym_view_as] = ACTIONS(1124),
    [sym_int_literal] = ACTIONS(1124),
    [sym_float_literal] = ACTIONS(1126),
    [anon_sym_SQUOTE] = ACTIONS(1126),
    [anon_sym_DQUOTE] = ACTIONS(1126),
    [sym_bool_literal] = ACTIONS(1124),
    [sym_null] = ACTIONS(1124),
    [sym_this] = ACTIONS(1124),
    [sym_comment] = ACTIONS(19),
  },
  [479] = {
    [sym_preproc_include] = STATE(479),
    [sym_preproc_tryinclude] = STATE(479),
    [sym_preproc_macro] = STATE(479),
    [sym_preproc_define] = STATE(479),
    [sym_preproc_undefine] = STATE(479),
    [sym_preproc_if] = STATE(479),
    [sym_preproc_elseif] = STATE(479),
    [sym_preproc_assert] = STATE(479),
    [sym_preproc_pragma] = STATE(479),
    [sym_preproc_error] = STATE(479),
    [sym_preproc_warning] = STATE(479),
    [sym_identifier] = ACTIONS(1128),
    [anon_sym_LPAREN] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1128),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1128),
    [anon_sym_public] = ACTIONS(1128),
    [anon_sym_stock] = ACTIONS(1128),
    [anon_sym_static] = ACTIONS(1128),
    [anon_sym_new] = ACTIONS(1128),
    [anon_sym_decl] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1130),
    [anon_sym_RBRACE] = ACTIONS(1130),
    [anon_sym_void] = ACTIONS(1128),
    [anon_sym_bool] = ACTIONS(1128),
    [anon_sym_int] = ACTIONS(1128),
    [anon_sym_float] = ACTIONS(1128),
    [anon_sym_char] = ACTIONS(1128),
    [anon_sym__] = ACTIONS(1128),
    [anon_sym_Float] = ACTIONS(1128),
    [anon_sym_String] = ACTIONS(1128),
    [sym_any_type] = ACTIONS(1128),
    [anon_sym_for] = ACTIONS(1128),
    [anon_sym_while] = ACTIONS(1128),
    [anon_sym_do] = ACTIONS(1128),
    [anon_sym_break] = ACTIONS(1128),
    [anon_sym_continue] = ACTIONS(1128),
    [anon_sym_if] = ACTIONS(1128),
    [anon_sym_else] = ACTIONS(1128),
    [anon_sym_switch] = ACTIONS(1128),
    [anon_sym_return] = ACTIONS(1128),
    [anon_sym_delete] = ACTIONS(1128),
    [anon_sym_DASH_DASH] = ACTIONS(1130),
    [anon_sym_PLUS_PLUS] = ACTIONS(1130),
    [anon_sym_sizeof] = ACTIONS(1128),
    [anon_sym_view_as] = ACTIONS(1128),
    [sym_int_literal] = ACTIONS(1128),
    [sym_float_literal] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1130),
    [anon_sym_DQUOTE] = ACTIONS(1130),
    [sym_bool_literal] = ACTIONS(1128),
    [sym_null] = ACTIONS(1128),
    [sym_this] = ACTIONS(1128),
    [sym_comment] = ACTIONS(19),
  },
  [480] = {
    [sym_preproc_include] = STATE(480),
    [sym_preproc_tryinclude] = STATE(480),
    [sym_preproc_macro] = STATE(480),
    [sym_preproc_define] = STATE(480),
    [sym_preproc_undefine] = STATE(480),
    [sym_preproc_if] = STATE(480),
    [sym_preproc_elseif] = STATE(480),
    [sym_preproc_assert] = STATE(480),
    [sym_preproc_pragma] = STATE(480),
    [sym_preproc_error] = STATE(480),
    [sym_preproc_warning] = STATE(480),
    [sym_identifier] = ACTIONS(1132),
    [anon_sym_LPAREN] = ACTIONS(1134),
    [anon_sym_BANG] = ACTIONS(1134),
    [anon_sym_TILDE] = ACTIONS(1134),
    [anon_sym_DASH] = ACTIONS(1132),
    [anon_sym_PLUS] = ACTIONS(1132),
    [anon_sym_AMP] = ACTIONS(1134),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1132),
    [anon_sym_public] = ACTIONS(1132),
    [anon_sym_stock] = ACTIONS(1132),
    [anon_sym_static] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(1132),
    [anon_sym_decl] = ACTIONS(1132),
    [anon_sym_LBRACE] = ACTIONS(1134),
    [anon_sym_RBRACE] = ACTIONS(1134),
    [anon_sym_void] = ACTIONS(1132),
    [anon_sym_bool] = ACTIONS(1132),
    [anon_sym_int] = ACTIONS(1132),
    [anon_sym_float] = ACTIONS(1132),
    [anon_sym_char] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1132),
    [anon_sym_Float] = ACTIONS(1132),
    [anon_sym_String] = ACTIONS(1132),
    [sym_any_type] = ACTIONS(1132),
    [anon_sym_for] = ACTIONS(1132),
    [anon_sym_while] = ACTIONS(1132),
    [anon_sym_do] = ACTIONS(1132),
    [anon_sym_break] = ACTIONS(1132),
    [anon_sym_continue] = ACTIONS(1132),
    [anon_sym_if] = ACTIONS(1132),
    [anon_sym_else] = ACTIONS(1132),
    [anon_sym_switch] = ACTIONS(1132),
    [anon_sym_return] = ACTIONS(1132),
    [anon_sym_delete] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1134),
    [anon_sym_PLUS_PLUS] = ACTIONS(1134),
    [anon_sym_sizeof] = ACTIONS(1132),
    [anon_sym_view_as] = ACTIONS(1132),
    [sym_int_literal] = ACTIONS(1132),
    [sym_float_literal] = ACTIONS(1134),
    [anon_sym_SQUOTE] = ACTIONS(1134),
    [anon_sym_DQUOTE] = ACTIONS(1134),
    [sym_bool_literal] = ACTIONS(1132),
    [sym_null] = ACTIONS(1132),
    [sym_this] = ACTIONS(1132),
    [sym_comment] = ACTIONS(19),
  },
  [481] = {
    [sym_preproc_include] = STATE(481),
    [sym_preproc_tryinclude] = STATE(481),
    [sym_preproc_macro] = STATE(481),
    [sym_preproc_define] = STATE(481),
    [sym_preproc_undefine] = STATE(481),
    [sym_preproc_if] = STATE(481),
    [sym_preproc_elseif] = STATE(481),
    [sym_preproc_assert] = STATE(481),
    [sym_preproc_pragma] = STATE(481),
    [sym_preproc_error] = STATE(481),
    [sym_preproc_warning] = STATE(481),
    [anon_sym_RPAREN] = ACTIONS(331),
    [anon_sym_DASH] = ACTIONS(329),
    [anon_sym_PLUS] = ACTIONS(329),
    [anon_sym_AMP] = ACTIONS(329),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(331),
    [anon_sym_STAR] = ACTIONS(329),
    [anon_sym_SLASH] = ACTIONS(329),
    [anon_sym_PERCENT] = ACTIONS(329),
    [anon_sym_PIPE_PIPE] = ACTIONS(331),
    [anon_sym_AMP_AMP] = ACTIONS(331),
    [anon_sym_PIPE] = ACTIONS(329),
    [anon_sym_CARET] = ACTIONS(329),
    [anon_sym_EQ_EQ] = ACTIONS(331),
    [anon_sym_BANG_EQ] = ACTIONS(331),
    [anon_sym_GT] = ACTIONS(329),
    [anon_sym_GT_EQ] = ACTIONS(331),
    [anon_sym_LT_EQ] = ACTIONS(331),
    [anon_sym_LT] = ACTIONS(329),
    [anon_sym_LT_LT] = ACTIONS(329),
    [anon_sym_GT_GT] = ACTIONS(329),
    [anon_sym_GT_GT_GT] = ACTIONS(329),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(331),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(329),
    [anon_sym_PLUS_EQ] = ACTIONS(331),
    [anon_sym_DASH_EQ] = ACTIONS(331),
    [anon_sym_STAR_EQ] = ACTIONS(331),
    [anon_sym_SLASH_EQ] = ACTIONS(331),
    [anon_sym_PIPE_EQ] = ACTIONS(331),
    [anon_sym_AMP_EQ] = ACTIONS(331),
    [anon_sym_CARET_EQ] = ACTIONS(331),
    [anon_sym_TILDE_EQ] = ACTIONS(331),
    [anon_sym_LT_LT_EQ] = ACTIONS(331),
    [anon_sym_GT_GT_EQ] = ACTIONS(331),
    [anon_sym_RBRACE] = ACTIONS(331),
    [anon_sym_LBRACK] = ACTIONS(331),
    [anon_sym_RBRACK] = ACTIONS(331),
    [anon_sym_COLON2] = ACTIONS(331),
    [anon_sym_SEMI] = ACTIONS(331),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(331),
    [anon_sym_PERCENT_EQ] = ACTIONS(331),
    [anon_sym_DOT] = ACTIONS(329),
    [anon_sym_QMARK] = ACTIONS(331),
    [anon_sym_DASH_DASH] = ACTIONS(331),
    [anon_sym_PLUS_PLUS] = ACTIONS(331),
    [sym_comment] = ACTIONS(19),
  },
  [482] = {
    [sym_preproc_include] = STATE(482),
    [sym_preproc_tryinclude] = STATE(482),
    [sym_preproc_macro] = STATE(482),
    [sym_preproc_define] = STATE(482),
    [sym_preproc_undefine] = STATE(482),
    [sym_preproc_if] = STATE(482),
    [sym_preproc_elseif] = STATE(482),
    [sym_preproc_assert] = STATE(482),
    [sym_preproc_pragma] = STATE(482),
    [sym_preproc_error] = STATE(482),
    [sym_preproc_warning] = STATE(482),
    [sym_call_arguments] = STATE(632),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_RPAREN] = ACTIONS(264),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_PLUS] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(261),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(261),
    [anon_sym_SLASH] = ACTIONS(261),
    [anon_sym_PERCENT] = ACTIONS(261),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_CARET] = ACTIONS(261),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_GT] = ACTIONS(261),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(261),
    [anon_sym_LT_LT] = ACTIONS(261),
    [anon_sym_GT_GT] = ACTIONS(261),
    [anon_sym_GT_GT_GT] = ACTIONS(261),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(980),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_COLON_COLON] = ACTIONS(834),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
  },
  [483] = {
    [sym_preproc_include] = STATE(483),
    [sym_preproc_tryinclude] = STATE(483),
    [sym_preproc_macro] = STATE(483),
    [sym_preproc_define] = STATE(483),
    [sym_preproc_undefine] = STATE(483),
    [sym_preproc_if] = STATE(483),
    [sym_preproc_elseif] = STATE(483),
    [sym_preproc_assert] = STATE(483),
    [sym_preproc_pragma] = STATE(483),
    [sym_preproc_error] = STATE(483),
    [sym_preproc_warning] = STATE(483),
    [sym_identifier] = ACTIONS(1136),
    [anon_sym_LPAREN] = ACTIONS(1138),
    [anon_sym_BANG] = ACTIONS(1138),
    [anon_sym_TILDE] = ACTIONS(1138),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_AMP] = ACTIONS(1138),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_const] = ACTIONS(1136),
    [anon_sym_public] = ACTIONS(1136),
    [anon_sym_stock] = ACTIONS(1136),
    [anon_sym_static] = ACTIONS(1136),
    [anon_sym_new] = ACTIONS(1136),
    [anon_sym_decl] = ACTIONS(1136),
    [anon_sym_LBRACE] = ACTIONS(1138),
    [anon_sym_RBRACE] = ACTIONS(1138),
    [anon_sym_void] = ACTIONS(1136),
    [anon_sym_bool] = ACTIONS(1136),
    [anon_sym_int] = ACTIONS(1136),
    [anon_sym_float] = ACTIONS(1136),
    [anon_sym_char] = ACTIONS(1136),
    [anon_sym__] = ACTIONS(1136),
    [anon_sym_Float] = ACTIONS(1136),
    [anon_sym_String] = ACTIONS(1136),
    [sym_any_type] = ACTIONS(1136),
    [anon_sym_for] = ACTIONS(1136),
    [anon_sym_while] = ACTIONS(1136),
    [anon_sym_do] = ACTIONS(1136),
    [anon_sym_break] = ACTIONS(1136),
    [anon_sym_continue] = ACTIONS(1136),
    [anon_sym_if] = ACTIONS(1136),
    [anon_sym_switch] = ACTIONS(1136),
    [anon_sym_return] = ACTIONS(1136),
    [anon_sym_delete] = ACTIONS(1136),
    [anon_sym_DASH_DASH] = ACTIONS(1138),
    [anon_sym_PLUS_PLUS] = ACTIONS(1138),
    [anon_sym_sizeof] = ACTIONS(1136),
    [anon_sym_view_as] = ACTIONS(1136),
    [sym_int_literal] = ACTIONS(1136),
    [sym_float_literal] = ACTIONS(1138),
    [anon_sym_SQUOTE] = ACTIONS(1138),
    [anon_sym_DQUOTE] = ACTIONS(1138),
    [sym_bool_literal] = ACTIONS(1136),
    [sym_null] = ACTIONS(1136),
    [sym_this] = ACTIONS(1136),
    [sym_comment] = ACTIONS(19),
  },
  [484] = {
    [sym_preproc_include] = STATE(484),
    [sym_preproc_tryinclude] = STATE(484),
    [sym_preproc_macro] = STATE(484),
    [sym_preproc_define] = STATE(484),
    [sym_preproc_undefine] = STATE(484),
    [sym_preproc_if] = STATE(484),
    [sym_preproc_elseif] = STATE(484),
    [sym_preproc_assert] = STATE(484),
    [sym_preproc_pragma] = STATE(484),
    [sym_preproc_error] = STATE(484),
    [sym_preproc_warning] = STATE(484),
    [sym_call_arguments] = STATE(843),
    [anon_sym_LPAREN] = ACTIONS(1094),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(1140),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(1142),
    [anon_sym_DASH_EQ] = ACTIONS(1142),
    [anon_sym_STAR_EQ] = ACTIONS(1142),
    [anon_sym_SLASH_EQ] = ACTIONS(1142),
    [anon_sym_PIPE_EQ] = ACTIONS(1142),
    [anon_sym_AMP_EQ] = ACTIONS(1142),
    [anon_sym_CARET_EQ] = ACTIONS(1142),
    [anon_sym_TILDE_EQ] = ACTIONS(1142),
    [anon_sym_LT_LT_EQ] = ACTIONS(1142),
    [anon_sym_GT_GT_EQ] = ACTIONS(1142),
    [anon_sym_LBRACK] = ACTIONS(1144),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1142),
    [anon_sym_PERCENT_EQ] = ACTIONS(1142),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_COLON_COLON] = ACTIONS(1098),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
    [sym__ternary_colon] = ACTIONS(246),
  },
  [485] = {
    [sym_preproc_include] = STATE(485),
    [sym_preproc_tryinclude] = STATE(485),
    [sym_preproc_macro] = STATE(485),
    [sym_preproc_define] = STATE(485),
    [sym_preproc_undefine] = STATE(485),
    [sym_preproc_if] = STATE(485),
    [sym_preproc_elseif] = STATE(485),
    [sym_preproc_assert] = STATE(485),
    [sym_preproc_pragma] = STATE(485),
    [sym_preproc_error] = STATE(485),
    [sym_preproc_warning] = STATE(485),
    [anon_sym_RPAREN] = ACTIONS(246),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_LBRACK] = ACTIONS(980),
    [anon_sym_RBRACK] = ACTIONS(246),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
  },
  [486] = {
    [sym_preproc_include] = STATE(486),
    [sym_preproc_tryinclude] = STATE(486),
    [sym_preproc_macro] = STATE(486),
    [sym_preproc_define] = STATE(486),
    [sym_preproc_undefine] = STATE(486),
    [sym_preproc_if] = STATE(486),
    [sym_preproc_elseif] = STATE(486),
    [sym_preproc_assert] = STATE(486),
    [sym_preproc_pragma] = STATE(486),
    [sym_preproc_error] = STATE(486),
    [sym_preproc_warning] = STATE(486),
    [sym_call_arguments] = STATE(632),
    [sym_identifier] = ACTIONS(1146),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_COLON] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_COLON_COLON] = ACTIONS(834),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
  },
  [487] = {
    [sym_preproc_include] = STATE(487),
    [sym_preproc_tryinclude] = STATE(487),
    [sym_preproc_macro] = STATE(487),
    [sym_preproc_define] = STATE(487),
    [sym_preproc_undefine] = STATE(487),
    [sym_preproc_if] = STATE(487),
    [sym_preproc_elseif] = STATE(487),
    [sym_preproc_assert] = STATE(487),
    [sym_preproc_pragma] = STATE(487),
    [sym_preproc_error] = STATE(487),
    [sym_preproc_warning] = STATE(487),
    [anon_sym_RPAREN] = ACTIONS(349),
    [anon_sym_DASH] = ACTIONS(347),
    [anon_sym_PLUS] = ACTIONS(347),
    [anon_sym_AMP] = ACTIONS(347),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(349),
    [anon_sym_STAR] = ACTIONS(347),
    [anon_sym_SLASH] = ACTIONS(347),
    [anon_sym_PERCENT] = ACTIONS(347),
    [anon_sym_PIPE_PIPE] = ACTIONS(349),
    [anon_sym_AMP_AMP] = ACTIONS(349),
    [anon_sym_PIPE] = ACTIONS(347),
    [anon_sym_CARET] = ACTIONS(347),
    [anon_sym_EQ_EQ] = ACTIONS(349),
    [anon_sym_BANG_EQ] = ACTIONS(349),
    [anon_sym_GT] = ACTIONS(347),
    [anon_sym_GT_EQ] = ACTIONS(349),
    [anon_sym_LT_EQ] = ACTIONS(349),
    [anon_sym_LT] = ACTIONS(347),
    [anon_sym_LT_LT] = ACTIONS(347),
    [anon_sym_GT_GT] = ACTIONS(347),
    [anon_sym_GT_GT_GT] = ACTIONS(347),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(349),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(347),
    [anon_sym_PLUS_EQ] = ACTIONS(349),
    [anon_sym_DASH_EQ] = ACTIONS(349),
    [anon_sym_STAR_EQ] = ACTIONS(349),
    [anon_sym_SLASH_EQ] = ACTIONS(349),
    [anon_sym_PIPE_EQ] = ACTIONS(349),
    [anon_sym_AMP_EQ] = ACTIONS(349),
    [anon_sym_CARET_EQ] = ACTIONS(349),
    [anon_sym_TILDE_EQ] = ACTIONS(349),
    [anon_sym_LT_LT_EQ] = ACTIONS(349),
    [anon_sym_GT_GT_EQ] = ACTIONS(349),
    [anon_sym_RBRACE] = ACTIONS(349),
    [anon_sym_RBRACK] = ACTIONS(349),
    [anon_sym_COLON2] = ACTIONS(349),
    [anon_sym_SEMI] = ACTIONS(349),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(349),
    [anon_sym_PERCENT_EQ] = ACTIONS(349),
    [anon_sym_DOT] = ACTIONS(347),
    [anon_sym_QMARK] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [sym_comment] = ACTIONS(19),
  },
  [488] = {
    [sym_preproc_include] = STATE(488),
    [sym_preproc_tryinclude] = STATE(488),
    [sym_preproc_macro] = STATE(488),
    [sym_preproc_define] = STATE(488),
    [sym_preproc_undefine] = STATE(488),
    [sym_preproc_if] = STATE(488),
    [sym_preproc_elseif] = STATE(488),
    [sym_preproc_assert] = STATE(488),
    [sym_preproc_pragma] = STATE(488),
    [sym_preproc_error] = STATE(488),
    [sym_preproc_warning] = STATE(488),
    [sym_call_arguments] = STATE(632),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(980),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
  },
  [489] = {
    [sym_preproc_include] = STATE(489),
    [sym_preproc_tryinclude] = STATE(489),
    [sym_preproc_macro] = STATE(489),
    [sym_preproc_define] = STATE(489),
    [sym_preproc_undefine] = STATE(489),
    [sym_preproc_if] = STATE(489),
    [sym_preproc_elseif] = STATE(489),
    [sym_preproc_assert] = STATE(489),
    [sym_preproc_pragma] = STATE(489),
    [sym_preproc_error] = STATE(489),
    [sym_preproc_warning] = STATE(489),
    [sym_dimension] = STATE(511),
    [sym_fixed_dimension] = STATE(511),
    [aux_sym_parameter_declaration_repeat1] = STATE(489),
    [ts_builtin_sym_end] = ACTIONS(758),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(758),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(758),
    [anon_sym_assert] = ACTIONS(756),
    [anon_sym_static_assert] = ACTIONS(756),
    [anon_sym_EQ] = ACTIONS(758),
    [anon_sym_forward] = ACTIONS(756),
    [anon_sym_native] = ACTIONS(756),
    [anon_sym_const] = ACTIONS(756),
    [anon_sym_public] = ACTIONS(756),
    [anon_sym_stock] = ACTIONS(756),
    [anon_sym_static] = ACTIONS(756),
    [anon_sym_new] = ACTIONS(756),
    [anon_sym_decl] = ACTIONS(756),
    [anon_sym_enum] = ACTIONS(756),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_struct] = ACTIONS(756),
    [anon_sym_typedef] = ACTIONS(756),
    [anon_sym_typeset] = ACTIONS(756),
    [anon_sym_funcenum] = ACTIONS(756),
    [anon_sym_functag] = ACTIONS(756),
    [anon_sym_methodmap] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(1151),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_bool] = ACTIONS(756),
    [anon_sym_int] = ACTIONS(756),
    [anon_sym_float] = ACTIONS(756),
    [anon_sym_char] = ACTIONS(756),
    [anon_sym__] = ACTIONS(756),
    [anon_sym_Float] = ACTIONS(756),
    [anon_sym_String] = ACTIONS(756),
    [sym_any_type] = ACTIONS(756),
    [anon_sym_while] = ACTIONS(756),
    [anon_sym_else] = ACTIONS(756),
    [anon_sym_case] = ACTIONS(756),
    [anon_sym_default] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(758),
  },
  [490] = {
    [sym_preproc_include] = STATE(490),
    [sym_preproc_tryinclude] = STATE(490),
    [sym_preproc_macro] = STATE(490),
    [sym_preproc_define] = STATE(490),
    [sym_preproc_undefine] = STATE(490),
    [sym_preproc_if] = STATE(490),
    [sym_preproc_elseif] = STATE(490),
    [sym_preproc_assert] = STATE(490),
    [sym_preproc_pragma] = STATE(490),
    [sym_preproc_error] = STATE(490),
    [sym_preproc_warning] = STATE(490),
    [anon_sym_RPAREN] = ACTIONS(353),
    [anon_sym_DASH] = ACTIONS(351),
    [anon_sym_PLUS] = ACTIONS(351),
    [anon_sym_AMP] = ACTIONS(351),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(353),
    [anon_sym_STAR] = ACTIONS(351),
    [anon_sym_SLASH] = ACTIONS(351),
    [anon_sym_PERCENT] = ACTIONS(351),
    [anon_sym_PIPE_PIPE] = ACTIONS(353),
    [anon_sym_AMP_AMP] = ACTIONS(353),
    [anon_sym_PIPE] = ACTIONS(351),
    [anon_sym_CARET] = ACTIONS(351),
    [anon_sym_EQ_EQ] = ACTIONS(353),
    [anon_sym_BANG_EQ] = ACTIONS(353),
    [anon_sym_GT] = ACTIONS(351),
    [anon_sym_GT_EQ] = ACTIONS(353),
    [anon_sym_LT_EQ] = ACTIONS(353),
    [anon_sym_LT] = ACTIONS(351),
    [anon_sym_LT_LT] = ACTIONS(351),
    [anon_sym_GT_GT] = ACTIONS(351),
    [anon_sym_GT_GT_GT] = ACTIONS(351),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(353),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(351),
    [anon_sym_PLUS_EQ] = ACTIONS(353),
    [anon_sym_DASH_EQ] = ACTIONS(353),
    [anon_sym_STAR_EQ] = ACTIONS(353),
    [anon_sym_SLASH_EQ] = ACTIONS(353),
    [anon_sym_PIPE_EQ] = ACTIONS(353),
    [anon_sym_AMP_EQ] = ACTIONS(353),
    [anon_sym_CARET_EQ] = ACTIONS(353),
    [anon_sym_TILDE_EQ] = ACTIONS(353),
    [anon_sym_LT_LT_EQ] = ACTIONS(353),
    [anon_sym_GT_GT_EQ] = ACTIONS(353),
    [anon_sym_RBRACE] = ACTIONS(353),
    [anon_sym_RBRACK] = ACTIONS(353),
    [anon_sym_SEMI] = ACTIONS(353),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(353),
    [anon_sym_PERCENT_EQ] = ACTIONS(353),
    [anon_sym_DOT] = ACTIONS(351),
    [anon_sym_QMARK] = ACTIONS(353),
    [anon_sym_DASH_DASH] = ACTIONS(353),
    [anon_sym_PLUS_PLUS] = ACTIONS(353),
    [sym_comment] = ACTIONS(19),
  },
  [491] = {
    [sym_preproc_include] = STATE(491),
    [sym_preproc_tryinclude] = STATE(491),
    [sym_preproc_macro] = STATE(491),
    [sym_preproc_define] = STATE(491),
    [sym_preproc_undefine] = STATE(491),
    [sym_preproc_if] = STATE(491),
    [sym_preproc_elseif] = STATE(491),
    [sym_preproc_assert] = STATE(491),
    [sym_preproc_pragma] = STATE(491),
    [sym_preproc_error] = STATE(491),
    [sym_preproc_warning] = STATE(491),
    [sym_call_arguments] = STATE(632),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(980),
    [anon_sym_COLON2] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
  },
  [492] = {
    [sym_preproc_include] = STATE(492),
    [sym_preproc_tryinclude] = STATE(492),
    [sym_preproc_macro] = STATE(492),
    [sym_preproc_define] = STATE(492),
    [sym_preproc_undefine] = STATE(492),
    [sym_preproc_if] = STATE(492),
    [sym_preproc_elseif] = STATE(492),
    [sym_preproc_assert] = STATE(492),
    [sym_preproc_pragma] = STATE(492),
    [sym_preproc_error] = STATE(492),
    [sym_preproc_warning] = STATE(492),
    [sym_dimension] = STATE(511),
    [sym_fixed_dimension] = STATE(511),
    [aux_sym_parameter_declaration_repeat1] = STATE(494),
    [ts_builtin_sym_end] = ACTIONS(744),
    [sym_identifier] = ACTIONS(742),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(744),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(744),
    [anon_sym_assert] = ACTIONS(742),
    [anon_sym_static_assert] = ACTIONS(742),
    [anon_sym_EQ] = ACTIONS(1154),
    [anon_sym_forward] = ACTIONS(742),
    [anon_sym_native] = ACTIONS(742),
    [anon_sym_const] = ACTIONS(742),
    [anon_sym_public] = ACTIONS(742),
    [anon_sym_stock] = ACTIONS(742),
    [anon_sym_static] = ACTIONS(742),
    [anon_sym_new] = ACTIONS(742),
    [anon_sym_decl] = ACTIONS(742),
    [anon_sym_enum] = ACTIONS(742),
    [anon_sym_RBRACE] = ACTIONS(744),
    [anon_sym_struct] = ACTIONS(742),
    [anon_sym_typedef] = ACTIONS(742),
    [anon_sym_typeset] = ACTIONS(742),
    [anon_sym_funcenum] = ACTIONS(742),
    [anon_sym_functag] = ACTIONS(742),
    [anon_sym_methodmap] = ACTIONS(742),
    [anon_sym_LBRACK] = ACTIONS(1156),
    [anon_sym_void] = ACTIONS(742),
    [anon_sym_bool] = ACTIONS(742),
    [anon_sym_int] = ACTIONS(742),
    [anon_sym_float] = ACTIONS(742),
    [anon_sym_char] = ACTIONS(742),
    [anon_sym__] = ACTIONS(742),
    [anon_sym_Float] = ACTIONS(742),
    [anon_sym_String] = ACTIONS(742),
    [sym_any_type] = ACTIONS(742),
    [anon_sym_while] = ACTIONS(742),
    [anon_sym_else] = ACTIONS(742),
    [anon_sym_case] = ACTIONS(742),
    [anon_sym_default] = ACTIONS(742),
    [anon_sym_SEMI] = ACTIONS(744),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(744),
  },
  [493] = {
    [sym_preproc_include] = STATE(493),
    [sym_preproc_tryinclude] = STATE(493),
    [sym_preproc_macro] = STATE(493),
    [sym_preproc_define] = STATE(493),
    [sym_preproc_undefine] = STATE(493),
    [sym_preproc_if] = STATE(493),
    [sym_preproc_elseif] = STATE(493),
    [sym_preproc_assert] = STATE(493),
    [sym_preproc_pragma] = STATE(493),
    [sym_preproc_error] = STATE(493),
    [sym_preproc_warning] = STATE(493),
    [sym_dimension] = STATE(908),
    [aux_sym_function_definition_repeat1] = STATE(840),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(994),
    [anon_sym_COLON2] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
  },
  [494] = {
    [sym_preproc_include] = STATE(494),
    [sym_preproc_tryinclude] = STATE(494),
    [sym_preproc_macro] = STATE(494),
    [sym_preproc_define] = STATE(494),
    [sym_preproc_undefine] = STATE(494),
    [sym_preproc_if] = STATE(494),
    [sym_preproc_elseif] = STATE(494),
    [sym_preproc_assert] = STATE(494),
    [sym_preproc_pragma] = STATE(494),
    [sym_preproc_error] = STATE(494),
    [sym_preproc_warning] = STATE(494),
    [sym_dimension] = STATE(511),
    [sym_fixed_dimension] = STATE(511),
    [aux_sym_parameter_declaration_repeat1] = STATE(489),
    [ts_builtin_sym_end] = ACTIONS(752),
    [sym_identifier] = ACTIONS(750),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(752),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(752),
    [anon_sym_assert] = ACTIONS(750),
    [anon_sym_static_assert] = ACTIONS(750),
    [anon_sym_EQ] = ACTIONS(1158),
    [anon_sym_forward] = ACTIONS(750),
    [anon_sym_native] = ACTIONS(750),
    [anon_sym_const] = ACTIONS(750),
    [anon_sym_public] = ACTIONS(750),
    [anon_sym_stock] = ACTIONS(750),
    [anon_sym_static] = ACTIONS(750),
    [anon_sym_new] = ACTIONS(750),
    [anon_sym_decl] = ACTIONS(750),
    [anon_sym_enum] = ACTIONS(750),
    [anon_sym_RBRACE] = ACTIONS(752),
    [anon_sym_struct] = ACTIONS(750),
    [anon_sym_typedef] = ACTIONS(750),
    [anon_sym_typeset] = ACTIONS(750),
    [anon_sym_funcenum] = ACTIONS(750),
    [anon_sym_functag] = ACTIONS(750),
    [anon_sym_methodmap] = ACTIONS(750),
    [anon_sym_LBRACK] = ACTIONS(1156),
    [anon_sym_void] = ACTIONS(750),
    [anon_sym_bool] = ACTIONS(750),
    [anon_sym_int] = ACTIONS(750),
    [anon_sym_float] = ACTIONS(750),
    [anon_sym_char] = ACTIONS(750),
    [anon_sym__] = ACTIONS(750),
    [anon_sym_Float] = ACTIONS(750),
    [anon_sym_String] = ACTIONS(750),
    [sym_any_type] = ACTIONS(750),
    [anon_sym_while] = ACTIONS(750),
    [anon_sym_else] = ACTIONS(750),
    [anon_sym_case] = ACTIONS(750),
    [anon_sym_default] = ACTIONS(750),
    [anon_sym_SEMI] = ACTIONS(752),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(752),
  },
  [495] = {
    [sym_preproc_include] = STATE(495),
    [sym_preproc_tryinclude] = STATE(495),
    [sym_preproc_macro] = STATE(495),
    [sym_preproc_define] = STATE(495),
    [sym_preproc_undefine] = STATE(495),
    [sym_preproc_if] = STATE(495),
    [sym_preproc_elseif] = STATE(495),
    [sym_preproc_assert] = STATE(495),
    [sym_preproc_pragma] = STATE(495),
    [sym_preproc_error] = STATE(495),
    [sym_preproc_warning] = STATE(495),
    [sym_dimension] = STATE(621),
    [aux_sym_function_definition_repeat1] = STATE(614),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(832),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
  },
  [496] = {
    [sym_preproc_include] = STATE(496),
    [sym_preproc_tryinclude] = STATE(496),
    [sym_preproc_macro] = STATE(496),
    [sym_preproc_define] = STATE(496),
    [sym_preproc_undefine] = STATE(496),
    [sym_preproc_if] = STATE(496),
    [sym_preproc_elseif] = STATE(496),
    [sym_preproc_assert] = STATE(496),
    [sym_preproc_pragma] = STATE(496),
    [sym_preproc_error] = STATE(496),
    [sym_preproc_warning] = STATE(496),
    [anon_sym_RPAREN] = ACTIONS(246),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(246),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_RBRACE] = ACTIONS(246),
    [anon_sym_RBRACK] = ACTIONS(246),
    [anon_sym_SEMI] = ACTIONS(246),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
  },
  [497] = {
    [sym_preproc_include] = STATE(497),
    [sym_preproc_tryinclude] = STATE(497),
    [sym_preproc_macro] = STATE(497),
    [sym_preproc_define] = STATE(497),
    [sym_preproc_undefine] = STATE(497),
    [sym_preproc_if] = STATE(497),
    [sym_preproc_elseif] = STATE(497),
    [sym_preproc_assert] = STATE(497),
    [sym_preproc_pragma] = STATE(497),
    [sym_preproc_error] = STATE(497),
    [sym_preproc_warning] = STATE(497),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_RBRACK] = ACTIONS(127),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [sym_comment] = ACTIONS(19),
  },
  [498] = {
    [sym_preproc_include] = STATE(498),
    [sym_preproc_tryinclude] = STATE(498),
    [sym_preproc_macro] = STATE(498),
    [sym_preproc_define] = STATE(498),
    [sym_preproc_undefine] = STATE(498),
    [sym_preproc_if] = STATE(498),
    [sym_preproc_elseif] = STATE(498),
    [sym_preproc_assert] = STATE(498),
    [sym_preproc_pragma] = STATE(498),
    [sym_preproc_error] = STATE(498),
    [sym_preproc_warning] = STATE(498),
    [sym_dimension] = STATE(787),
    [aux_sym_function_definition_repeat1] = STATE(745),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(1096),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [sym_comment] = ACTIONS(19),
    [sym__ternary_colon] = ACTIONS(127),
  },
  [499] = {
    [sym_preproc_include] = STATE(499),
    [sym_preproc_tryinclude] = STATE(499),
    [sym_preproc_macro] = STATE(499),
    [sym_preproc_define] = STATE(499),
    [sym_preproc_undefine] = STATE(499),
    [sym_preproc_if] = STATE(499),
    [sym_preproc_elseif] = STATE(499),
    [sym_preproc_assert] = STATE(499),
    [sym_preproc_pragma] = STATE(499),
    [sym_preproc_error] = STATE(499),
    [sym_preproc_warning] = STATE(499),
    [sym_call_arguments] = STATE(843),
    [anon_sym_LPAREN] = ACTIONS(1094),
    [anon_sym_DASH] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(244),
    [anon_sym_AMP] = ACTIONS(244),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(246),
    [anon_sym_STAR] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(244),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(246),
    [anon_sym_AMP_AMP] = ACTIONS(246),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(246),
    [anon_sym_BANG_EQ] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(246),
    [anon_sym_LT_EQ] = ACTIONS(246),
    [anon_sym_LT] = ACTIONS(244),
    [anon_sym_LT_LT] = ACTIONS(244),
    [anon_sym_GT_GT] = ACTIONS(244),
    [anon_sym_GT_GT_GT] = ACTIONS(244),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(1140),
    [anon_sym_PLUS_EQ] = ACTIONS(1142),
    [anon_sym_DASH_EQ] = ACTIONS(1142),
    [anon_sym_STAR_EQ] = ACTIONS(1142),
    [anon_sym_SLASH_EQ] = ACTIONS(1142),
    [anon_sym_PIPE_EQ] = ACTIONS(1142),
    [anon_sym_AMP_EQ] = ACTIONS(1142),
    [anon_sym_CARET_EQ] = ACTIONS(1142),
    [anon_sym_TILDE_EQ] = ACTIONS(1142),
    [anon_sym_LT_LT_EQ] = ACTIONS(1142),
    [anon_sym_GT_GT_EQ] = ACTIONS(1142),
    [anon_sym_LBRACK] = ACTIONS(1144),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1142),
    [anon_sym_PERCENT_EQ] = ACTIONS(1142),
    [anon_sym_DOT] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_DASH_DASH] = ACTIONS(246),
    [anon_sym_PLUS_PLUS] = ACTIONS(246),
    [sym_comment] = ACTIONS(19),
    [sym__ternary_colon] = ACTIONS(246),
  },
  [500] = {
    [sym_preproc_include] = STATE(500),
    [sym_preproc_tryinclude] = STATE(500),
    [sym_preproc_macro] = STATE(500),
    [sym_preproc_define] = STATE(500),
    [sym_preproc_undefine] = STATE(500),
    [sym_preproc_if] = STATE(500),
    [sym_preproc_elseif] = STATE(500),
    [sym_preproc_assert] = STATE(500),
    [sym_preproc_pragma] = STATE(500),
    [sym_preproc_error] = STATE(500),
    [sym_preproc_warning] = STATE(500),
    [sym_call_arguments] = STATE(843),
    [anon_sym_LPAREN] = ACTIONS(1094),
    [anon_sym_DASH] = ACTIONS(123),
    [anon_sym_PLUS] = ACTIONS(123),
    [anon_sym_AMP] = ACTIONS(123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(123),
    [anon_sym_SLASH] = ACTIONS(123),
    [anon_sym_PERCENT] = ACTIONS(123),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(123),
    [anon_sym_CARET] = ACTIONS(123),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(123),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(123),
    [anon_sym_LT_LT] = ACTIONS(123),
    [anon_sym_GT_GT] = ACTIONS(123),
    [anon_sym_GT_GT_GT] = ACTIONS(123),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_PLUS_EQ] = ACTIONS(133),
    [anon_sym_DASH_EQ] = ACTIONS(133),
    [anon_sym_STAR_EQ] = ACTIONS(133),
    [anon_sym_SLASH_EQ] = ACTIONS(133),
    [anon_sym_PIPE_EQ] = ACTIONS(133),
    [anon_sym_AMP_EQ] = ACTIONS(133),
    [anon_sym_CARET_EQ] = ACTIONS(133),
    [anon_sym_TILDE_EQ] = ACTIONS(133),
    [anon_sym_LT_LT_EQ] = ACTIONS(133),
    [anon_sym_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(1144),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(133),
    [anon_sym_PERCENT_EQ] = ACTIONS(133),
    [anon_sym_DOT] = ACTIONS(123),
    [anon_sym_QMARK] = ACTIONS(127),
    [anon_sym_DASH_DASH] = ACTIONS(127),
    [anon_sym_PLUS_PLUS] = ACTIONS(127),
    [sym_comment] = ACTIONS(19),
    [sym__ternary_colon] = ACTIONS(127),
  },
  [501] = {
    [sym_preproc_include] = STATE(501),
    [sym_preproc_tryinclude] = STATE(501),
    [sym_preproc_macro] = STATE(501),
    [sym_preproc_define] = STATE(501),
    [sym_preproc_undefine] = STATE(501),
    [sym_preproc_if] = STATE(501),
    [sym_preproc_elseif] = STATE(501),
    [sym_preproc_assert] = STATE(501),
    [sym_preproc_pragma] = STATE(501),
    [sym_preproc_error] = STATE(501),
    [sym_preproc_warning] = STATE(501),
    [sym__manual_semicolon] = STATE(526),
    [sym__semicolon] = STATE(549),
    [aux_sym_global_variable_declaration_repeat1] = STATE(505),
    [ts_builtin_sym_end] = ACTIONS(767),
    [sym_identifier] = ACTIONS(765),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(1160),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(767),
    [anon_sym_assert] = ACTIONS(765),
    [anon_sym_static_assert] = ACTIONS(765),
    [anon_sym_forward] = ACTIONS(765),
    [anon_sym_native] = ACTIONS(765),
    [anon_sym_const] = ACTIONS(765),
    [anon_sym_public] = ACTIONS(765),
    [anon_sym_stock] = ACTIONS(765),
    [anon_sym_static] = ACTIONS(765),
    [anon_sym_new] = ACTIONS(765),
    [anon_sym_decl] = ACTIONS(765),
    [anon_sym_enum] = ACTIONS(765),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_struct] = ACTIONS(765),
    [anon_sym_typedef] = ACTIONS(765),
    [anon_sym_typeset] = ACTIONS(765),
    [anon_sym_funcenum] = ACTIONS(765),
    [anon_sym_functag] = ACTIONS(765),
    [anon_sym_methodmap] = ACTIONS(765),
    [anon_sym_void] = ACTIONS(765),
    [anon_sym_bool] = ACTIONS(765),
    [anon_sym_int] = ACTIONS(765),
    [anon_sym_float] = ACTIONS(765),
    [anon_sym_char] = ACTIONS(765),
    [anon_sym__] = ACTIONS(765),
    [anon_sym_Float] = ACTIONS(765),
    [anon_sym_String] = ACTIONS(765),
    [sym_any_type] = ACTIONS(765),
    [anon_sym_while] = ACTIONS(765),
    [anon_sym_else] = ACTIONS(765),
    [anon_sym_case] = ACTIONS(765),
    [anon_sym_default] = ACTIONS(765),
    [anon_sym_SEMI] = ACTIONS(376),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(378),
  },
  [502] = {
    [sym_preproc_include] = STATE(502),
    [sym_preproc_tryinclude] = STATE(502),
    [sym_preproc_macro] = STATE(502),
    [sym_preproc_define] = STATE(502),
    [sym_preproc_undefine] = STATE(502),
    [sym_preproc_if] = STATE(502),
    [sym_preproc_elseif] = STATE(502),
    [sym_preproc_assert] = STATE(502),
    [sym_preproc_pragma] = STATE(502),
    [sym_preproc_error] = STATE(502),
    [sym_preproc_warning] = STATE(502),
    [sym__manual_semicolon] = STATE(526),
    [sym__semicolon] = STATE(551),
    [aux_sym_variable_declaration_statement_repeat1] = STATE(517),
    [ts_builtin_sym_end] = ACTIONS(788),
    [sym_identifier] = ACTIONS(786),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(1162),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(788),
    [anon_sym_assert] = ACTIONS(786),
    [anon_sym_static_assert] = ACTIONS(786),
    [anon_sym_forward] = ACTIONS(786),
    [anon_sym_native] = ACTIONS(786),
    [anon_sym_const] = ACTIONS(786),
    [anon_sym_public] = ACTIONS(786),
    [anon_sym_stock] = ACTIONS(786),
    [anon_sym_static] = ACTIONS(786),
    [anon_sym_new] = ACTIONS(786),
    [anon_sym_decl] = ACTIONS(786),
    [anon_sym_enum] = ACTIONS(786),
    [anon_sym_RBRACE] = ACTIONS(788),
    [anon_sym_struct] = ACTIONS(786),
    [anon_sym_typedef] = ACTIONS(786),
    [anon_sym_typeset] = ACTIONS(786),
    [anon_sym_funcenum] = ACTIONS(786),
    [anon_sym_functag] = ACTIONS(786),
    [anon_sym_methodmap] = ACTIONS(786),
    [anon_sym_void] = ACTIONS(786),
    [anon_sym_bool] = ACTIONS(786),
    [anon_sym_int] = ACTIONS(786),
    [anon_sym_float] = ACTIONS(786),
    [anon_sym_char] = ACTIONS(786),
    [anon_sym__] = ACTIONS(786),
    [anon_sym_Float] = ACTIONS(786),
    [anon_sym_String] = ACTIONS(786),
    [sym_any_type] = ACTIONS(786),
    [anon_sym_while] = ACTIONS(786),
    [anon_sym_else] = ACTIONS(786),
    [anon_sym_case] = ACTIONS(786),
    [anon_sym_default] = ACTIONS(786),
    [anon_sym_SEMI] = ACTIONS(376),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(378),
  },
  [503] = {
    [sym_preproc_include] = STATE(503),
    [sym_preproc_tryinclude] = STATE(503),
    [sym_preproc_macro] = STATE(503),
    [sym_preproc_define] = STATE(503),
    [sym_preproc_undefine] = STATE(503),
    [sym_preproc_if] = STATE(503),
    [sym_preproc_elseif] = STATE(503),
    [sym_preproc_assert] = STATE(503),
    [sym_preproc_pragma] = STATE(503),
    [sym_preproc_error] = STATE(503),
    [sym_preproc_warning] = STATE(503),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_DASH] = ACTIONS(325),
    [anon_sym_PLUS] = ACTIONS(325),
    [anon_sym_AMP] = ACTIONS(325),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(327),
    [anon_sym_STAR] = ACTIONS(325),
    [anon_sym_SLASH] = ACTIONS(325),
    [anon_sym_PERCENT] = ACTIONS(325),
    [anon_sym_PIPE_PIPE] = ACTIONS(327),
    [anon_sym_AMP_AMP] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(325),
    [anon_sym_CARET] = ACTIONS(325),
    [anon_sym_EQ_EQ] = ACTIONS(327),
    [anon_sym_BANG_EQ] = ACTIONS(327),
    [anon_sym_GT] = ACTIONS(325),
    [anon_sym_GT_EQ] = ACTIONS(327),
    [anon_sym_LT_EQ] = ACTIONS(327),
    [anon_sym_LT] = ACTIONS(325),
    [anon_sym_LT_LT] = ACTIONS(325),
    [anon_sym_GT_GT] = ACTIONS(325),
    [anon_sym_GT_GT_GT] = ACTIONS(325),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_EQ] = ACTIONS(325),
    [anon_sym_PLUS_EQ] = ACTIONS(327),
    [anon_sym_DASH_EQ] = ACTIONS(327),
    [anon_sym_STAR_EQ] = ACTIONS(327),
    [anon_sym_SLASH_EQ] = ACTIONS(327),
    [anon_sym_PIPE_EQ] = ACTIONS(327),
    [anon_sym_AMP_EQ] = ACTIONS(327),
    [anon_sym_CARET_EQ] = ACTIONS(327),
    [anon_sym_TILDE_EQ] = ACTIONS(327),
    [anon_sym_LT_LT_EQ] = ACTIONS(327),
    [anon_sym_GT_GT_EQ] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(327),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(327),
    [anon_sym_PERCENT_EQ] = ACTIONS(327),
    [anon_sym_DOT] = ACTIONS(325),
    [anon_sym_QMARK] = ACTIONS(327),
    [anon_sym_DASH_DASH] = ACTIONS(327),
    [anon_sym_PLUS_PLUS] = ACTIONS(327),
    [sym_comment] = ACTIONS(19),
    [sym__ternary_colon] = ACTIONS(327),
  },
  [504] = {
    [sym_preproc_include] = STATE(504),
    [sym_preproc_tryinclude] = STATE(504),
    [sym_preproc_macro] = STATE(504),
    [sym_preproc_define] = STATE(504),
    [sym_preproc_undefine] = STATE(504),
    [sym_preproc_if] = STATE(504),
    [sym_preproc_elseif] = STATE(504),
    [sym_preproc_assert] = STATE(504),
    [sym_preproc_pragma] = STATE(504),
    [sym_preproc_error] = STATE(504),
    [sym_preproc_warning] = STATE(504),
    [sym__manual_semicolon] = STATE(526),
    [sym__semicolon] = STATE(550),
    [aux_sym_global_variable_declaration_repeat1] = STATE(508),
    [ts_builtin_sym_end] = ACTIONS(798),
    [sym_identifier] = ACTIONS(796),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(1160),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(798),
    [anon_sym_assert] = ACTIONS(796),
    [anon_sym_static_assert] = ACTIONS(796),
    [anon_sym_forward] = ACTIONS(796),
    [anon_sym_native] = ACTIONS(796),
    [anon_sym_const] = ACTIONS(796),
    [anon_sym_public] = ACTIONS(796),
    [anon_sym_stock] = ACTIONS(796),
    [anon_sym_static] = ACTIONS(796),
    [anon_sym_new] = ACTIONS(796),
    [anon_sym_decl] = ACTIONS(796),
    [anon_sym_enum] = ACTIONS(796),
    [anon_sym_RBRACE] = ACTIONS(798),
    [anon_sym_struct] = ACTIONS(796),
    [anon_sym_typedef] = ACTIONS(796),
    [anon_sym_typeset] = ACTIONS(796),
    [anon_sym_funcenum] = ACTIONS(796),
    [anon_sym_functag] = ACTIONS(796),
    [anon_sym_methodmap] = ACTIONS(796),
    [anon_sym_void] = ACTIONS(796),
    [anon_sym_bool] = ACTIONS(796),
    [anon_sym_int] = ACTIONS(796),
    [anon_sym_float] = ACTIONS(796),
    [anon_sym_char] = ACTIONS(796),
    [anon_sym__] = ACTIONS(796),
    [anon_sym_Float] = ACTIONS(796),
    [anon_sym_String] = ACTIONS(796),
    [sym_any_type] = ACTIONS(796),
    [anon_sym_while] = ACTIONS(796),
    [anon_sym_else] = ACTIONS(796),
    [anon_sym_case] = ACTIONS(796),
    [anon_sym_default] = ACTIONS(796),
    [anon_sym_SEMI] = ACTIONS(376),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(378),
  },
  [505] = {
    [sym_preproc_include] = STATE(505),
    [sym_preproc_tryinclude] = STATE(505),
    [sym_preproc_macro] = STATE(505),
    [sym_preproc_define] = STATE(505),
    [sym_preproc_undefine] = STATE(505),
    [sym_preproc_if] = STATE(505),
    [sym_preproc_elseif] = STATE(505),
    [sym_preproc_assert] = STATE(505),
    [sym_preproc_pragma] = STATE(505),
    [sym_preproc_error] = STATE(505),
    [sym_preproc_warning] = STATE(505),
    [sym__manual_semicolon] = STATE(526),
    [sym__semicolon] = STATE(552),
    [aux_sym_global_variable_declaration_repeat1] = STATE(515),
    [ts_builtin_sym_end] = ACTIONS(780),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(1160),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(780),
    [anon_sym_assert] = ACTIONS(778),
    [anon_sym_static_assert] = ACTIONS(778),
    [anon_sym_forward] = ACTIONS(778),
    [anon_sym_native] = ACTIONS(778),
    [anon_sym_const] = ACTIONS(778),
    [anon_sym_public] = ACTIONS(778),
    [anon_sym_stock] = ACTIONS(778),
    [anon_sym_static] = ACTIONS(778),
    [anon_sym_new] = ACTIONS(778),
    [anon_sym_decl] = ACTIONS(778),
    [anon_sym_enum] = ACTIONS(778),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_struct] = ACTIONS(778),
    [anon_sym_typedef] = ACTIONS(778),
    [anon_sym_typeset] = ACTIONS(778),
    [anon_sym_funcenum] = ACTIONS(778),
    [anon_sym_functag] = ACTIONS(778),
    [anon_sym_methodmap] = ACTIONS(778),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_bool] = ACTIONS(778),
    [anon_sym_int] = ACTIONS(778),
    [anon_sym_float] = ACTIONS(778),
    [anon_sym_char] = ACTIONS(778),
    [anon_sym__] = ACTIONS(778),
    [anon_sym_Float] = ACTIONS(778),
    [anon_sym_String] = ACTIONS(778),
    [sym_any_type] = ACTIONS(778),
    [anon_sym_while] = ACTIONS(778),
    [anon_sym_else] = ACTIONS(778),
    [anon_sym_case] = ACTIONS(778),
    [anon_sym_default] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(376),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(378),
  },
  [506] = {
    [sym_preproc_include] = STATE(506),
    [sym_preproc_tryinclude] = STATE(506),
    [sym_preproc_macro] = STATE(506),
    [sym_preproc_define] = STATE(506),
    [sym_preproc_undefine] = STATE(506),
    [sym_preproc_if] = STATE(506),
    [sym_preproc_elseif] = STATE(506),
    [sym_preproc_assert] = STATE(506),
    [sym_preproc_pragma] = STATE(506),
    [sym_preproc_error] = STATE(506),
    [sym_preproc_warning] = STATE(506),
    [sym__manual_semicolon] = STATE(526),
    [sym__semicolon] = STATE(547),
    [aux_sym_global_variable_declaration_repeat1] = STATE(515),
    [ts_builtin_sym_end] = ACTIONS(794),
    [sym_identifier] = ACTIONS(792),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(1160),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(794),
    [anon_sym_assert] = ACTIONS(792),
    [anon_sym_static_assert] = ACTIONS(792),
    [anon_sym_forward] = ACTIONS(792),
    [anon_sym_native] = ACTIONS(792),
    [anon_sym_const] = ACTIONS(792),
    [anon_sym_public] = ACTIONS(792),
    [anon_sym_stock] = ACTIONS(792),
    [anon_sym_static] = ACTIONS(792),
    [anon_sym_new] = ACTIONS(792),
    [anon_sym_decl] = ACTIONS(792),
    [anon_sym_enum] = ACTIONS(792),
    [anon_sym_RBRACE] = ACTIONS(794),
    [anon_sym_struct] = ACTIONS(792),
    [anon_sym_typedef] = ACTIONS(792),
    [anon_sym_typeset] = ACTIONS(792),
    [anon_sym_funcenum] = ACTIONS(792),
    [anon_sym_functag] = ACTIONS(792),
    [anon_sym_methodmap] = ACTIONS(792),
    [anon_sym_void] = ACTIONS(792),
    [anon_sym_bool] = ACTIONS(792),
    [anon_sym_int] = ACTIONS(792),
    [anon_sym_float] = ACTIONS(792),
    [anon_sym_char] = ACTIONS(792),
    [anon_sym__] = ACTIONS(792),
    [anon_sym_Float] = ACTIONS(792),
    [anon_sym_String] = ACTIONS(792),
    [sym_any_type] = ACTIONS(792),
    [anon_sym_while] = ACTIONS(792),
    [anon_sym_else] = ACTIONS(792),
    [anon_sym_case] = ACTIONS(792),
    [anon_sym_default] = ACTIONS(792),
    [anon_sym_SEMI] = ACTIONS(376),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(378),
  },
  [507] = {
    [sym_preproc_include] = STATE(507),
    [sym_preproc_tryinclude] = STATE(507),
    [sym_preproc_macro] = STATE(507),
    [sym_preproc_define] = STATE(507),
    [sym_preproc_undefine] = STATE(507),
    [sym_preproc_if] = STATE(507),
    [sym_preproc_elseif] = STATE(507),
    [sym_preproc_assert] = STATE(507),
    [sym_preproc_pragma] = STATE(507),
    [sym_preproc_error] = STATE(507),
    [sym_preproc_warning] = STATE(507),
    [sym__manual_semicolon] = STATE(526),
    [sym__semicolon] = STATE(547),
    [aux_sym_variable_declaration_statement_repeat1] = STATE(502),
    [ts_builtin_sym_end] = ACTIONS(794),
    [sym_identifier] = ACTIONS(792),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(1162),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(794),
    [anon_sym_assert] = ACTIONS(792),
    [anon_sym_static_assert] = ACTIONS(792),
    [anon_sym_forward] = ACTIONS(792),
    [anon_sym_native] = ACTIONS(792),
    [anon_sym_const] = ACTIONS(792),
    [anon_sym_public] = ACTIONS(792),
    [anon_sym_stock] = ACTIONS(792),
    [anon_sym_static] = ACTIONS(792),
    [anon_sym_new] = ACTIONS(792),
    [anon_sym_decl] = ACTIONS(792),
    [anon_sym_enum] = ACTIONS(792),
    [anon_sym_RBRACE] = ACTIONS(794),
    [anon_sym_struct] = ACTIONS(792),
    [anon_sym_typedef] = ACTIONS(792),
    [anon_sym_typeset] = ACTIONS(792),
    [anon_sym_funcenum] = ACTIONS(792),
    [anon_sym_functag] = ACTIONS(792),
    [anon_sym_methodmap] = ACTIONS(792),
    [anon_sym_void] = ACTIONS(792),
    [anon_sym_bool] = ACTIONS(792),
    [anon_sym_int] = ACTIONS(792),
    [anon_sym_float] = ACTIONS(792),
    [anon_sym_char] = ACTIONS(792),
    [anon_sym__] = ACTIONS(792),
    [anon_sym_Float] = ACTIONS(792),
    [anon_sym_String] = ACTIONS(792),
    [sym_any_type] = ACTIONS(792),
    [anon_sym_while] = ACTIONS(792),
    [anon_sym_else] = ACTIONS(792),
    [anon_sym_case] = ACTIONS(792),
    [anon_sym_default] = ACTIONS(792),
    [anon_sym_SEMI] = ACTIONS(376),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(378),
  },
  [508] = {
    [sym_preproc_include] = STATE(508),
    [sym_preproc_tryinclude] = STATE(508),
    [sym_preproc_macro] = STATE(508),
    [sym_preproc_define] = STATE(508),
    [sym_preproc_undefine] = STATE(508),
    [sym_preproc_if] = STATE(508),
    [sym_preproc_elseif] = STATE(508),
    [sym_preproc_assert] = STATE(508),
    [sym_preproc_pragma] = STATE(508),
    [sym_preproc_error] = STATE(508),
    [sym_preproc_warning] = STATE(508),
    [sym__manual_semicolon] = STATE(526),
    [sym__semicolon] = STATE(548),
    [aux_sym_global_variable_declaration_repeat1] = STATE(515),
    [ts_builtin_sym_end] = ACTIONS(776),
    [sym_identifier] = ACTIONS(774),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(1160),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(776),
    [anon_sym_assert] = ACTIONS(774),
    [anon_sym_static_assert] = ACTIONS(774),
    [anon_sym_forward] = ACTIONS(774),
    [anon_sym_native] = ACTIONS(774),
    [anon_sym_const] = ACTIONS(774),
    [anon_sym_public] = ACTIONS(774),
    [anon_sym_stock] = ACTIONS(774),
    [anon_sym_static] = ACTIONS(774),
    [anon_sym_new] = ACTIONS(774),
    [anon_sym_decl] = ACTIONS(774),
    [anon_sym_enum] = ACTIONS(774),
    [anon_sym_RBRACE] = ACTIONS(776),
    [anon_sym_struct] = ACTIONS(774),
    [anon_sym_typedef] = ACTIONS(774),
    [anon_sym_typeset] = ACTIONS(774),
    [anon_sym_funcenum] = ACTIONS(774),
    [anon_sym_functag] = ACTIONS(774),
    [anon_sym_methodmap] = ACTIONS(774),
    [anon_sym_void] = ACTIONS(774),
    [anon_sym_bool] = ACTIONS(774),
    [anon_sym_int] = ACTIONS(774),
    [anon_sym_float] = ACTIONS(774),
    [anon_sym_char] = ACTIONS(774),
    [anon_sym__] = ACTIONS(774),
    [anon_sym_Float] = ACTIONS(774),
    [anon_sym_String] = ACTIONS(774),
    [sym_any_type] = ACTIONS(774),
    [anon_sym_while] = ACTIONS(774),
    [anon_sym_else] = ACTIONS(774),
    [anon_sym_case] = ACTIONS(774),
    [anon_sym_default] = ACTIONS(774),
    [anon_sym_SEMI] = ACTIONS(376),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(378),
  },
  [509] = {
    [sym_preproc_include] = STATE(509),
    [sym_preproc_tryinclude] = STATE(509),
    [sym_preproc_macro] = STATE(509),
    [sym_preproc_define] = STATE(509),
    [sym_preproc_undefine] = STATE(509),
    [sym_preproc_if] = STATE(509),
    [sym_preproc_elseif] = STATE(509),
    [sym_preproc_assert] = STATE(509),
    [sym_preproc_pragma] = STATE(509),
    [sym_preproc_error] = STATE(509),
    [sym_preproc_warning] = STATE(509),
    [sym__manual_semicolon] = STATE(526),
    [sym__semicolon] = STATE(546),
    [aux_sym_global_variable_declaration_repeat1] = STATE(506),
    [ts_builtin_sym_end] = ACTIONS(784),
    [sym_identifier] = ACTIONS(782),
    [anon_sym_POUNDinclude] = ACTIONS(3),
    [anon_sym_POUNDtryinclude] = ACTIONS(5),
    [anon_sym_POUNDdefine] = ACTIONS(7),
    [anon_sym_COMMA] = ACTIONS(1160),
    [anon_sym_POUNDundef] = ACTIONS(9),
    [anon_sym_POUNDif] = ACTIONS(11),
    [anon_sym_POUNDelseif] = ACTIONS(13),
    [anon_sym_POUNDassert] = ACTIONS(15),
    [sym_preproc_else] = ACTIONS(17),
    [sym_preproc_endif] = ACTIONS(19),
    [sym_preproc_endinput] = ACTIONS(19),
    [anon_sym_POUNDpragma] = ACTIONS(21),
    [anon_sym_POUNDerror] = ACTIONS(23),
    [anon_sym_POUNDwarning] = ACTIONS(25),
    [anon_sym_using__intrinsics__DOTHandle] = ACTIONS(784),
    [anon_sym_assert] = ACTIONS(782),
    [anon_sym_static_assert] = ACTIONS(782),
    [anon_sym_forward] = ACTIONS(782),
    [anon_sym_native] = ACTIONS(782),
    [anon_sym_const] = ACTIONS(782),
    [anon_sym_public] = ACTIONS(782),
    [anon_sym_stock] = ACTIONS(782),
    [anon_sym_static] = ACTIONS(782),
    [anon_sym_new] = ACTIONS(782),
    [anon_sym_decl] = ACTIONS(782),
    [anon_sym_enum] = ACTIONS(782),
    [anon_sym_RBRACE] = ACTIONS(784),
    [anon_sym_struct] = ACTIONS(782),
    [anon_sym_typedef] = ACTIONS(782),
    [anon_sym_typeset] = ACTIONS(782),
    [anon_sym_funcenum] = ACTIONS(782),
    [anon_sym_functag] = ACTIONS(782),
    [anon_sym_methodmap] = ACTIONS(782),
    [anon_sym_void] = ACTIONS(782),
    [anon_sym_bool] = ACTIONS(782),
    [anon_sym_int] = ACTIONS(782),
    [anon_sym_float] = ACTIONS(782),
    [anon_sym_char] = ACTIONS(782),
    [anon_sym__] = ACTIONS(782),
    [anon_sym_Float] = ACTIONS(782),
    [anon_sym_String] = ACTIONS(782),
    [sym_any_type] = ACTIONS(782),
    [anon_sym_while] = ACTIONS(782),
    [anon_sym_else] = ACTIONS(782),
    [anon_sym_case] = ACTIONS(782),
    [anon_sym_default] = ACTIONS(782),
    [anon_sym_SEMI] = ACTIONS(376),
    [sym_comment] = ACTIONS(19),
    [sym__automatic_semicolon] = ACTIONS(378),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(129), 1,
      anon_sym_EQ,
    ACTIONS(244), 1,
      anon_sym_DOT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(246), 3,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(127), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      anon_sym_COLON2,
    STATE(510), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(133), 12,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_PERCENT_EQ,
    ACTIONS(123), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
  [103] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(814), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_EQ,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(511), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(812), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [198] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(512), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(329), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
    ACTIONS(331), 24,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [293] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1140), 1,
      anon_sym_EQ,
    ACTIONS(1144), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(246), 11,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    STATE(513), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1142), 12,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_PERCENT_EQ,
    ACTIONS(244), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_DOT,
  [394] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(127), 1,
      anon_sym_RPAREN,
    ACTIONS(129), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(246), 11,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    STATE(514), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(133), 12,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_PERCENT_EQ,
    ACTIONS(244), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_DOT,
  [495] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1164), 1,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(849), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(515), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_global_variable_declaration_repeat1,
    ACTIONS(847), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [591] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(576), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(856), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(516), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(854), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [693] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1167), 1,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(842), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(517), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_variable_declaration_statement_repeat1,
    ACTIONS(840), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [789] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(562), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(828), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(518), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(826), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [891] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(944), 5,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(519), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(942), 33,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_function,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_property,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [985] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(520), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(347), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
    ACTIONS(349), 23,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [1079] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(554), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(420), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(521), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(418), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [1181] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(129), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(127), 11,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    STATE(522), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(133), 12,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_PERCENT_EQ,
    ACTIONS(123), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_DOT,
  [1279] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(579), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(460), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(523), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(458), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [1381] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1140), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(246), 11,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    STATE(524), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1142), 12,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_PERCENT_EQ,
    ACTIONS(244), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_DOT,
  [1479] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(525), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(351), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
    ACTIONS(353), 23,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [1573] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1058), 5,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(526), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1056), 33,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_function,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_property,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [1667] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(577), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(838), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(527), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(836), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [1769] = 34,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1176), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1180), 1,
      anon_sym_RBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    STATE(390), 1,
      sym_old_type,
    STATE(962), 1,
      sym__preproc_expression,
    STATE(1489), 1,
      sym_rest_operator,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1396), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(528), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [1900] = 34,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1176), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1190), 1,
      anon_sym_RBRACE,
    STATE(390), 1,
      sym_old_type,
    STATE(962), 1,
      sym__preproc_expression,
    STATE(1530), 1,
      sym_rest_operator,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1396), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(529), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [2031] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(884), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(530), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(882), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [2124] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(842), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(531), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(840), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [2217] = 34,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1176), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1192), 1,
      anon_sym_RBRACE,
    STATE(390), 1,
      sym_old_type,
    STATE(962), 1,
      sym__preproc_expression,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1564), 1,
      sym_rest_operator,
    STATE(1396), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(532), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [2348] = 34,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1176), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1194), 1,
      anon_sym_RBRACE,
    STATE(390), 1,
      sym_old_type,
    STATE(962), 1,
      sym__preproc_expression,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1541), 1,
      sym_rest_operator,
    STATE(1396), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(533), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [2479] = 34,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1176), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1196), 1,
      anon_sym_RBRACE,
    STATE(390), 1,
      sym_old_type,
    STATE(962), 1,
      sym__preproc_expression,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1536), 1,
      sym_rest_operator,
    STATE(1396), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(534), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [2610] = 34,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1176), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1198), 1,
      anon_sym_RBRACE,
    STATE(390), 1,
      sym_old_type,
    STATE(962), 1,
      sym__preproc_expression,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1577), 1,
      sym_rest_operator,
    STATE(1396), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(535), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [2741] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(849), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(536), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(847), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [2834] = 34,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1176), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1200), 1,
      anon_sym_RBRACE,
    STATE(390), 1,
      sym_old_type,
    STATE(962), 1,
      sym__preproc_expression,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1557), 1,
      sym_rest_operator,
    STATE(1396), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(537), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [2965] = 34,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1176), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1202), 1,
      anon_sym_RBRACE,
    STATE(390), 1,
      sym_old_type,
    STATE(962), 1,
      sym__preproc_expression,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1545), 1,
      sym_rest_operator,
    STATE(1396), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(538), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [3096] = 34,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1176), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1204), 1,
      anon_sym_RBRACE,
    STATE(390), 1,
      sym_old_type,
    STATE(962), 1,
      sym__preproc_expression,
    STATE(1495), 1,
      sym_rest_operator,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1396), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(539), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [3227] = 34,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1176), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1206), 1,
      anon_sym_RBRACE,
    STATE(390), 1,
      sym_old_type,
    STATE(962), 1,
      sym__preproc_expression,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1561), 1,
      sym_rest_operator,
    STATE(1396), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(540), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [3358] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(576), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(541), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(574), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [3450] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(940), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_EQ,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(542), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(938), 29,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_function,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_property,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [3542] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(948), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_EQ,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(543), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(946), 29,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_function,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_property,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [3634] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(976), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_EQ,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(544), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(974), 29,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_function,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_property,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [3726] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1054), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(545), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1052), 32,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_property,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [3817] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(794), 4,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(546), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(792), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [3908] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(788), 4,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(547), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(786), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [3999] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1080), 4,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(548), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1078), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [4090] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(780), 4,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(549), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(778), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [4181] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(776), 4,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(550), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(774), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [4272] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1102), 4,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(551), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1100), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [4363] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1106), 4,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(552), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1104), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [4454] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1014), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(553), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1012), 32,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_property,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [4545] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1002), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(554), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1000), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [4635] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1062), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(555), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1060), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [4725] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1070), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(556), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1068), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [4815] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1118), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(557), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1116), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [4905] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1130), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(558), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1128), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [4995] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1010), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(559), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1008), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [5085] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1122), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(560), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1120), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [5175] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1042), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(561), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1040), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [5265] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1046), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(562), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1044), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [5355] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1134), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(563), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1132), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [5445] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1050), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(564), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1048), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [5535] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1066), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(565), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1064), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [5625] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1088), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(566), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1086), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [5715] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1110), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(567), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1108), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [5805] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1114), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(568), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1112), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [5895] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1018), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(569), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1016), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [5985] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1038), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(570), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1036), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [6075] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(998), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(571), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(996), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [6165] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1092), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(572), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1090), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [6255] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1022), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(573), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1020), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [6345] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1006), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(574), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1004), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [6435] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    STATE(390), 1,
      sym_old_type,
    STATE(928), 1,
      sym__preproc_expression,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1322), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(575), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [6557] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1026), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(576), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1024), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [6647] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1030), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(577), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1028), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [6737] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1034), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(578), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1032), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [6827] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1084), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(579), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1082), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [6917] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    STATE(390), 1,
      sym_old_type,
    STATE(962), 1,
      sym__preproc_expression,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1396), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(580), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [7039] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    STATE(390), 1,
      sym_old_type,
    STATE(938), 1,
      sym__preproc_expression,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1259), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(581), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [7161] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    STATE(390), 1,
      sym_old_type,
    STATE(924), 1,
      sym__preproc_expression,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1285), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(582), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [7283] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    STATE(390), 1,
      sym_old_type,
    STATE(940), 1,
      sym__preproc_expression,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1305), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(583), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [7405] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1126), 3,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_RBRACE,
    STATE(584), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1124), 31,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_while,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [7495] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(656), 1,
      anon_sym_view_as,
    ACTIONS(1170), 1,
      sym_identifier,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    STATE(390), 1,
      sym_old_type,
    STATE(939), 1,
      sym__preproc_expression,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1316), 2,
      sym_view_as,
      sym_old_type_cast,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(585), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [7617] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(478), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
    STATE(586), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(480), 23,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_identifier,
  [7706] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(679), 1,
      sym__semicolon,
    ACTIONS(1208), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(587), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1210), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [7803] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(646), 1,
      sym__semicolon,
    ACTIONS(1212), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(588), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1214), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [7900] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(474), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
    STATE(589), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(476), 23,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_identifier,
  [7989] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(728), 1,
      sym__semicolon,
    ACTIONS(1216), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(590), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1218), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [8086] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1220), 1,
      anon_sym_LBRACK,
    STATE(621), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(411), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(591), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_function_definition_repeat1,
    ACTIONS(413), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_identifier,
  [8179] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(674), 1,
      sym__semicolon,
    ACTIONS(1223), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(592), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1225), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [8276] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(719), 1,
      sym__semicolon,
    ACTIONS(1227), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(593), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1229), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [8373] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(720), 1,
      sym__semicolon,
    ACTIONS(1231), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(594), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1233), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [8470] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(726), 1,
      sym__semicolon,
    ACTIONS(1235), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(595), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1237), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [8567] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(733), 1,
      sym__semicolon,
    ACTIONS(1239), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(596), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1241), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [8664] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(724), 1,
      sym__semicolon,
    ACTIONS(1243), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(597), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1245), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [8761] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(731), 1,
      sym__semicolon,
    ACTIONS(1247), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(598), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1249), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [8858] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(722), 1,
      sym__semicolon,
    ACTIONS(1251), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(599), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1253), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [8955] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(713), 1,
      sym__semicolon,
    ACTIONS(1255), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(600), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1257), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [9052] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(700), 1,
      sym__semicolon,
    ACTIONS(1259), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(601), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1261), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [9149] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(730), 1,
      sym__semicolon,
    ACTIONS(1263), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(602), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1265), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [9246] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(643), 1,
      sym__semicolon,
    ACTIONS(1267), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(603), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1269), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [9343] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(647), 1,
      sym__semicolon,
    ACTIONS(1271), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(604), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1273), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [9440] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(649), 1,
      sym__semicolon,
    ACTIONS(1275), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(605), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1277), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [9537] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(650), 1,
      sym__semicolon,
    ACTIONS(1279), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(606), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1281), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [9634] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(678), 1,
      sym__semicolon,
    ACTIONS(1283), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(607), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1285), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [9731] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(676), 1,
      sym__semicolon,
    ACTIONS(1287), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(608), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1289), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [9828] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(655), 1,
      sym__semicolon,
    ACTIONS(1291), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(609), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1293), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [9925] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(644), 1,
      sym__semicolon,
    ACTIONS(1295), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(610), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1297), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [10022] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1299), 1,
      anon_sym_LBRACK,
    STATE(630), 1,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(396), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(611), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_dynamic_array_repeat1,
    ACTIONS(398), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [10114] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(1304), 1,
      anon_sym_DOT,
    STATE(591), 1,
      aux_sym_function_definition_repeat1,
    STATE(621), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(403), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(612), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(405), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [10210] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1306), 1,
      anon_sym_LBRACK,
    STATE(611), 1,
      aux_sym_dynamic_array_repeat1,
    STATE(630), 1,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(390), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(613), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(392), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [10304] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    STATE(591), 1,
      aux_sym_function_definition_repeat1,
    STATE(621), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(403), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(614), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(405), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [10398] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1308), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_SEMI,
    STATE(615), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1310), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [10485] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1312), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_SEMI,
    STATE(616), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1314), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [10572] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1316), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_SEMI,
    STATE(617), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1318), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [10659] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1320), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_SEMI,
    STATE(618), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1322), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [10746] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1324), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_SEMI,
    STATE(619), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1326), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [10833] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1328), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_SEMI,
    STATE(620), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1330), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [10920] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(470), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(621), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(472), 22,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_identifier,
  [11007] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1332), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_SEMI,
    STATE(622), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1334), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [11094] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1336), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
      anon_sym_SEMI,
    STATE(623), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1338), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [11181] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(546), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(624), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(548), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [11267] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(586), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(625), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(588), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [11353] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(582), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(626), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(584), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [11439] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(562), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(627), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(564), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [11525] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(550), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(628), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(552), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [11611] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(554), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(629), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(556), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [11697] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(462), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(630), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(464), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [11783] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(530), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(631), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(532), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [11869] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(506), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(632), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(508), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [11955] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(570), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(633), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(572), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [12041] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(518), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(634), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(520), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [12127] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1340), 1,
      anon_sym_else,
    ACTIONS(1074), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(635), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1072), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [12215] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(534), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(636), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(536), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [12301] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(542), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(637), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(544), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [12387] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(514), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(638), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(516), 21,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_COLON2,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [12473] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1342), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(639), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1344), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [12558] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1346), 1,
      sym_identifier,
    ACTIONS(1348), 1,
      anon_sym_LPAREN,
    ACTIONS(1352), 1,
      anon_sym_new,
    ACTIONS(1354), 1,
      anon_sym_sizeof,
    ACTIONS(1356), 1,
      anon_sym_view_as,
    STATE(968), 1,
      sym__case_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1350), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(947), 8,
      sym_new_expression,
      sym_parenthesized_expression,
      sym_scope_access,
      sym_case_unary_expression,
      sym_case_binary_expression,
      sym_sizeof_expression,
      sym_view_as,
      sym__literal,
    STATE(640), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [12667] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1346), 1,
      sym_identifier,
    ACTIONS(1348), 1,
      anon_sym_LPAREN,
    ACTIONS(1352), 1,
      anon_sym_new,
    ACTIONS(1354), 1,
      anon_sym_sizeof,
    ACTIONS(1356), 1,
      anon_sym_view_as,
    STATE(969), 1,
      sym__case_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1350), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(947), 8,
      sym_new_expression,
      sym_parenthesized_expression,
      sym_scope_access,
      sym_case_unary_expression,
      sym_case_binary_expression,
      sym_sizeof_expression,
      sym_view_as,
      sym__literal,
    STATE(641), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [12776] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1346), 1,
      sym_identifier,
    ACTIONS(1348), 1,
      anon_sym_LPAREN,
    ACTIONS(1352), 1,
      anon_sym_new,
    ACTIONS(1354), 1,
      anon_sym_sizeof,
    ACTIONS(1356), 1,
      anon_sym_view_as,
    STATE(970), 1,
      sym__case_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1350), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(947), 8,
      sym_new_expression,
      sym_parenthesized_expression,
      sym_scope_access,
      sym_case_unary_expression,
      sym_case_binary_expression,
      sym_sizeof_expression,
      sym_view_as,
      sym__literal,
    STATE(642), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [12885] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1358), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(643), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1360), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [12970] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1208), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(644), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1210), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [13055] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1362), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(645), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1364), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [13140] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1366), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(646), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1368), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [13225] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1247), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(647), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1249), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [13310] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1370), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(648), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1372), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [13395] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1374), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(649), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1376), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [13480] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1378), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(650), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1380), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [13565] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1382), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(651), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1384), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [13650] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1386), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(652), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1388), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [13735] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1390), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(653), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1392), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [13820] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1394), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(654), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1396), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [13905] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1212), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(655), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1214), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [13990] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1398), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(656), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1400), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [14075] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1402), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(657), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1404), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [14160] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1406), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(658), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1408), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [14245] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(494), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(659), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(496), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [14332] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1412), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(660), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1414), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [14417] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1416), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(661), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1418), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [14502] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(498), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(662), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(500), 18,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
  [14591] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(123), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(663), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(127), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [14676] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(522), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(664), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(524), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [14761] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(123), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(665), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(127), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [14846] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1422), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(666), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1424), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [14931] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(482), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(667), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(484), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [15018] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1426), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(668), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1428), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [15103] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(510), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(669), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(512), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [15188] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1430), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(670), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1432), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [15273] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1434), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(671), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1436), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [15358] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1438), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(672), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1440), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [15443] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(558), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(673), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(560), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [15528] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1442), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(674), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1444), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [15613] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1446), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(675), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1448), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [15698] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1450), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(676), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1452), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [15783] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1454), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(677), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1456), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [15868] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1458), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(678), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1460), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [15953] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1462), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(679), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1464), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [16038] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1466), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(680), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1468), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [16123] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1470), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(681), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1472), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [16208] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1474), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(682), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1476), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [16293] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1478), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(683), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1480), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [16378] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1482), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(684), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1484), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [16463] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1486), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(685), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1488), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [16548] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1490), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(686), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1492), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [16633] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1494), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(687), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1496), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [16718] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1498), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(688), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1500), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [16803] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1502), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(689), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1504), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [16888] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1506), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(690), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1508), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [16973] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1510), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(691), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1512), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [17058] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1346), 1,
      sym_identifier,
    ACTIONS(1348), 1,
      anon_sym_LPAREN,
    ACTIONS(1352), 1,
      anon_sym_new,
    ACTIONS(1354), 1,
      anon_sym_sizeof,
    ACTIONS(1356), 1,
      anon_sym_view_as,
    STATE(967), 1,
      sym__case_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1350), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(947), 8,
      sym_new_expression,
      sym_parenthesized_expression,
      sym_scope_access,
      sym_case_unary_expression,
      sym_case_binary_expression,
      sym_sizeof_expression,
      sym_view_as,
      sym__literal,
    STATE(692), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [17167] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1514), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(693), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1516), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [17252] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1518), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(694), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1520), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [17337] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(538), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(695), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(540), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [17422] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1522), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(696), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1524), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [17507] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1526), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(697), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1528), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [17592] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1530), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(698), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1532), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [17677] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1534), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(699), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1536), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [17762] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1538), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(700), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1540), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [17847] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(490), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(701), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(492), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [17932] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(492), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
    STATE(702), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [18049] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(502), 7,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(703), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(504), 16,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
  [18142] = 26,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(502), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(504), 9,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
    STATE(704), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [18249] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(502), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(705), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(504), 18,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
  [18338] = 29,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(504), 7,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
    STATE(706), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [18451] = 28,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(504), 8,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
    STATE(707), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [18562] = 28,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(502), 1,
      anon_sym_PIPE,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(504), 8,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
    STATE(708), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [18673] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(502), 1,
      anon_sym_PIPE,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(504), 9,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
    STATE(709), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [18782] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(502), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(504), 11,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
    STATE(710), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [18887] = 23,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(502), 4,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    STATE(711), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(504), 13,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
  [18988] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(502), 5,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(712), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(504), 15,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
  [19085] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1572), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(713), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1574), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [19170] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1576), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(714), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1578), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [19255] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(566), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(715), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(568), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [19340] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1580), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(716), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1582), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [19425] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1584), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(717), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1586), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [19510] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1588), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(718), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1590), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [19595] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1592), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(719), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1594), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [19680] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1263), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(720), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1265), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [19765] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(580), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
    STATE(721), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [19882] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1596), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(722), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1598), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [19967] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1346), 1,
      sym_identifier,
    ACTIONS(1348), 1,
      anon_sym_LPAREN,
    ACTIONS(1352), 1,
      anon_sym_new,
    ACTIONS(1354), 1,
      anon_sym_sizeof,
    ACTIONS(1356), 1,
      anon_sym_view_as,
    STATE(963), 1,
      sym__case_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1350), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(947), 8,
      sym_new_expression,
      sym_parenthesized_expression,
      sym_scope_access,
      sym_case_unary_expression,
      sym_case_binary_expression,
      sym_sizeof_expression,
      sym_view_as,
      sym__literal,
    STATE(723), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [20076] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1600), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(724), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1602), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [20161] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1604), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(725), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1606), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [20246] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1608), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(726), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1610), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [20331] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1612), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(727), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1614), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [20416] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1616), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(728), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1618), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [20501] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(244), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(729), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(246), 20,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [20586] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1620), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(730), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1622), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [20671] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1283), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(731), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1285), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [20756] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1346), 1,
      sym_identifier,
    ACTIONS(1348), 1,
      anon_sym_LPAREN,
    ACTIONS(1352), 1,
      anon_sym_new,
    ACTIONS(1354), 1,
      anon_sym_sizeof,
    ACTIONS(1356), 1,
      anon_sym_view_as,
    STATE(948), 1,
      sym__case_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1350), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(947), 8,
      sym_new_expression,
      sym_parenthesized_expression,
      sym_scope_access,
      sym_case_unary_expression,
      sym_case_binary_expression,
      sym_sizeof_expression,
      sym_view_as,
      sym__literal,
    STATE(732), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [20865] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1291), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(733), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1293), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [20950] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1346), 1,
      sym_identifier,
    ACTIONS(1348), 1,
      anon_sym_LPAREN,
    ACTIONS(1352), 1,
      anon_sym_new,
    ACTIONS(1354), 1,
      anon_sym_sizeof,
    ACTIONS(1356), 1,
      anon_sym_view_as,
    STATE(950), 1,
      sym__case_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1350), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(947), 8,
      sym_new_expression,
      sym_parenthesized_expression,
      sym_scope_access,
      sym_case_unary_expression,
      sym_case_binary_expression,
      sym_sizeof_expression,
      sym_view_as,
      sym__literal,
    STATE(734), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [21059] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1346), 1,
      sym_identifier,
    ACTIONS(1348), 1,
      anon_sym_LPAREN,
    ACTIONS(1352), 1,
      anon_sym_new,
    ACTIONS(1354), 1,
      anon_sym_sizeof,
    ACTIONS(1356), 1,
      anon_sym_view_as,
    STATE(951), 1,
      sym__case_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1350), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(947), 8,
      sym_new_expression,
      sym_parenthesized_expression,
      sym_scope_access,
      sym_case_unary_expression,
      sym_case_binary_expression,
      sym_sizeof_expression,
      sym_view_as,
      sym__literal,
    STATE(735), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [21168] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1624), 2,
      ts_builtin_sym_end,
      anon_sym_using__intrinsics__DOTHandle,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(736), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1626), 27,
      anon_sym_assert,
      anon_sym_static_assert,
      anon_sym_forward,
      anon_sym_native,
      anon_sym_const,
      anon_sym_public,
      anon_sym_stock,
      anon_sym_static,
      anon_sym_new,
      anon_sym_decl,
      anon_sym_enum,
      anon_sym_struct,
      anon_sym_typedef,
      anon_sym_typeset,
      anon_sym_funcenum,
      anon_sym_functag,
      anon_sym_methodmap,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
  [21253] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1346), 1,
      sym_identifier,
    ACTIONS(1348), 1,
      anon_sym_LPAREN,
    ACTIONS(1352), 1,
      anon_sym_new,
    ACTIONS(1354), 1,
      anon_sym_sizeof,
    ACTIONS(1356), 1,
      anon_sym_view_as,
    STATE(953), 1,
      sym__case_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1350), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(947), 8,
      sym_new_expression,
      sym_parenthesized_expression,
      sym_scope_access,
      sym_case_unary_expression,
      sym_case_binary_expression,
      sym_sizeof_expression,
      sym_view_as,
      sym__literal,
    STATE(737), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [21362] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1346), 1,
      sym_identifier,
    ACTIONS(1348), 1,
      anon_sym_LPAREN,
    ACTIONS(1352), 1,
      anon_sym_new,
    ACTIONS(1354), 1,
      anon_sym_sizeof,
    ACTIONS(1356), 1,
      anon_sym_view_as,
    STATE(964), 1,
      sym__case_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1350), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(947), 8,
      sym_new_expression,
      sym_parenthesized_expression,
      sym_scope_access,
      sym_case_unary_expression,
      sym_case_binary_expression,
      sym_sizeof_expression,
      sym_view_as,
      sym__literal,
    STATE(738), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [21471] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1346), 1,
      sym_identifier,
    ACTIONS(1348), 1,
      anon_sym_LPAREN,
    ACTIONS(1352), 1,
      anon_sym_new,
    ACTIONS(1354), 1,
      anon_sym_sizeof,
    ACTIONS(1356), 1,
      anon_sym_view_as,
    STATE(965), 1,
      sym__case_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1350), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(947), 8,
      sym_new_expression,
      sym_parenthesized_expression,
      sym_scope_access,
      sym_case_unary_expression,
      sym_case_binary_expression,
      sym_sizeof_expression,
      sym_view_as,
      sym__literal,
    STATE(739), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [21580] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1346), 1,
      sym_identifier,
    ACTIONS(1348), 1,
      anon_sym_LPAREN,
    ACTIONS(1352), 1,
      anon_sym_new,
    ACTIONS(1354), 1,
      anon_sym_sizeof,
    ACTIONS(1356), 1,
      anon_sym_view_as,
    STATE(966), 1,
      sym__case_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1350), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(947), 8,
      sym_new_expression,
      sym_parenthesized_expression,
      sym_scope_access,
      sym_case_unary_expression,
      sym_case_binary_expression,
      sym_sizeof_expression,
      sym_view_as,
      sym__literal,
    STATE(740), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [21689] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1346), 1,
      sym_identifier,
    ACTIONS(1348), 1,
      anon_sym_LPAREN,
    ACTIONS(1352), 1,
      anon_sym_new,
    ACTIONS(1354), 1,
      anon_sym_sizeof,
    ACTIONS(1356), 1,
      anon_sym_view_as,
    STATE(945), 1,
      sym__case_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1350), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(947), 8,
      sym_new_expression,
      sym_parenthesized_expression,
      sym_scope_access,
      sym_case_unary_expression,
      sym_case_binary_expression,
      sym_sizeof_expression,
      sym_view_as,
      sym__literal,
    STATE(741), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [21798] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1630), 11,
      anon_sym_LPAREN,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LBRACE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_float_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
    STATE(742), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1628), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_operator,
      anon_sym_public,
      anon_sym_new,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      anon_sym_sizeof,
      anon_sym_view_as,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
      sym_this,
      sym_identifier,
  [21882] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1632), 1,
      anon_sym_LBRACK,
    STATE(814), 1,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(396), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(743), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_dynamic_array_repeat1,
    ACTIONS(398), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [21970] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1635), 1,
      anon_sym_COMMA,
    STATE(281), 1,
      sym__manual_semicolon,
    STATE(1197), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(244), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(744), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(246), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [22062] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1637), 1,
      anon_sym_LBRACK,
    STATE(749), 1,
      aux_sym_function_definition_repeat1,
    STATE(787), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(403), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(745), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(405), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [22152] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1637), 1,
      anon_sym_LBRACK,
    ACTIONS(1639), 1,
      anon_sym_DOT,
    STATE(749), 1,
      aux_sym_function_definition_repeat1,
    STATE(787), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(403), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(746), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(405), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [22244] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1635), 1,
      anon_sym_COMMA,
    STATE(276), 1,
      sym__manual_semicolon,
    STATE(1243), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(244), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(747), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(246), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [22336] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1635), 1,
      anon_sym_COMMA,
    STATE(278), 1,
      sym__manual_semicolon,
    STATE(1253), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(244), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(748), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(246), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [22428] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1641), 1,
      anon_sym_LBRACK,
    STATE(787), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(411), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(749), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_function_definition_repeat1,
    ACTIONS(413), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [22516] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1644), 1,
      anon_sym_LBRACK,
    STATE(743), 1,
      aux_sym_dynamic_array_repeat1,
    STATE(814), 1,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(390), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(750), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(392), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [22606] = 33,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1646), 1,
      anon_sym_RPAREN,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    STATE(1255), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(751), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [22725] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(604), 1,
      anon_sym_AMP,
    ACTIONS(606), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(610), 1,
      anon_sym_SLASH,
    ACTIONS(612), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(614), 1,
      anon_sym_AMP_AMP,
    ACTIONS(616), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_CARET,
    ACTIONS(628), 1,
      anon_sym_GT_GT,
    ACTIONS(632), 1,
      anon_sym_DOT,
    ACTIONS(634), 1,
      anon_sym_QMARK,
    ACTIONS(602), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(608), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(620), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(622), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(624), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(626), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(636), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1650), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(752), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [22840] = 33,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    ACTIONS(1652), 1,
      anon_sym_RPAREN,
    STATE(1317), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(753), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [22959] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(604), 1,
      anon_sym_AMP,
    ACTIONS(606), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(610), 1,
      anon_sym_SLASH,
    ACTIONS(612), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(614), 1,
      anon_sym_AMP_AMP,
    ACTIONS(616), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_CARET,
    ACTIONS(628), 1,
      anon_sym_GT_GT,
    ACTIONS(632), 1,
      anon_sym_DOT,
    ACTIONS(634), 1,
      anon_sym_QMARK,
    ACTIONS(602), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(608), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(620), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(622), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(624), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(626), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(636), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1654), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(754), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [23074] = 33,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    ACTIONS(1656), 1,
      anon_sym_RPAREN,
    STATE(1264), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(755), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [23193] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(604), 1,
      anon_sym_AMP,
    ACTIONS(606), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(610), 1,
      anon_sym_SLASH,
    ACTIONS(612), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(614), 1,
      anon_sym_AMP_AMP,
    ACTIONS(616), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_CARET,
    ACTIONS(628), 1,
      anon_sym_GT_GT,
    ACTIONS(632), 1,
      anon_sym_DOT,
    ACTIONS(634), 1,
      anon_sym_QMARK,
    ACTIONS(602), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(608), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(620), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(622), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(624), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(626), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(636), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1658), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(756), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [23308] = 33,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    ACTIONS(1660), 1,
      anon_sym_RPAREN,
    STATE(1286), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(757), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [23427] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(604), 1,
      anon_sym_AMP,
    ACTIONS(606), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(610), 1,
      anon_sym_SLASH,
    ACTIONS(612), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(614), 1,
      anon_sym_AMP_AMP,
    ACTIONS(616), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_CARET,
    ACTIONS(628), 1,
      anon_sym_GT_GT,
    ACTIONS(632), 1,
      anon_sym_DOT,
    ACTIONS(634), 1,
      anon_sym_QMARK,
    ACTIONS(602), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(608), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(620), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(622), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(624), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(626), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(636), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1662), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(758), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [23542] = 33,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    ACTIONS(1664), 1,
      anon_sym_RPAREN,
    STATE(1261), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(759), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [23661] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(127), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(244), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(760), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(246), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [23745] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1666), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(761), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [23859] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1654), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(762), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [23973] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1668), 1,
      anon_sym_LBRACK,
    STATE(908), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(411), 7,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(763), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_function_definition_repeat1,
    ACTIONS(413), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [24059] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1650), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(764), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [24173] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1671), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(765), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [24287] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1673), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(766), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [24401] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1675), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(767), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [24515] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1677), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(768), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [24629] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1679), 1,
      anon_sym_LBRACK,
    ACTIONS(1681), 1,
      anon_sym_DOT,
    STATE(763), 1,
      aux_sym_function_definition_repeat1,
    STATE(908), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(403), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(769), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(405), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [24719] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1683), 1,
      anon_sym_RPAREN,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(770), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [24835] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(576), 1,
      anon_sym_RPAREN,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(771), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [24951] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1662), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(772), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [25065] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(244), 1,
      anon_sym_DOT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(246), 3,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(123), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(773), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(127), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [25151] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1687), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(774), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [25265] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1689), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(775), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [25379] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1691), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(776), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [25493] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1693), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(777), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [25607] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1695), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(778), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [25723] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    STATE(286), 1,
      sym__manual_semicolon,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(779), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [25839] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1697), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(780), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [25955] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    STATE(267), 1,
      sym__manual_semicolon,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(781), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [26071] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1699), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(782), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [26187] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1701), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(783), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [26301] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1703), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(244), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(784), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(246), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [26385] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1705), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(785), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [26499] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1707), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(786), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [26613] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(470), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(787), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(472), 17,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [26695] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1709), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(788), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [26809] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1711), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(789), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [26923] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1713), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(790), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [27039] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(474), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(791), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(476), 17,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [27121] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1715), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(792), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [27235] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1717), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(793), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [27349] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1719), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(794), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [27465] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1721), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(795), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [27581] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1723), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(796), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [27697] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1725), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(797), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [27813] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1727), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(798), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [27929] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1729), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(799), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [28045] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(484), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(800), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [28159] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1731), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(801), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [28275] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(478), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(802), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(480), 17,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [28357] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1733), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(803), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [28473] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1735), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(804), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [28589] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1737), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(805), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [28705] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1739), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(806), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [28821] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1741), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(807), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [28937] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1743), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(808), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [29053] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1658), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(809), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [29167] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1745), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(810), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [29283] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1747), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(811), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [29399] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    STATE(285), 1,
      sym__manual_semicolon,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(812), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [29515] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1749), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(813), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [29631] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(462), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(814), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(464), 17,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [29713] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    STATE(256), 1,
      sym__manual_semicolon,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(815), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [29829] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1751), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(816), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [29943] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    STATE(257), 1,
      sym__manual_semicolon,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(817), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [30059] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    STATE(259), 1,
      sym__manual_semicolon,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(818), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [30175] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1753), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(819), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [30291] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1755), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(820), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [30405] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    STATE(287), 1,
      sym__manual_semicolon,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(821), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [30521] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    STATE(268), 1,
      sym__manual_semicolon,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(822), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [30637] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    STATE(270), 1,
      sym__manual_semicolon,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(823), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [30753] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1757), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(824), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [30867] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1759), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(825), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [30981] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1761), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(826), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [31095] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(244), 1,
      anon_sym_DOT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(246), 4,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(261), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(827), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(264), 13,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [31181] = 32,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1685), 1,
      anon_sym_COMMA,
    ACTIONS(1763), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(828), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [31297] = 28,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1767), 1,
      anon_sym_AMP,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1775), 1,
      anon_sym_PIPE,
    ACTIONS(1777), 1,
      anon_sym_CARET,
    ACTIONS(1787), 1,
      anon_sym_GT_GT,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1779), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1781), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1783), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1785), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(504), 4,
      sym__ternary_colon,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
    STATE(829), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [31404] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(498), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(830), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(500), 14,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
  [31489] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1793), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(831), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [31602] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1795), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(832), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [31715] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1797), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(833), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [31828] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1799), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(834), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [31941] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(518), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(835), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(520), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [32022] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(586), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(836), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(588), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [32103] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1801), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(837), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [32216] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(542), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(838), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(544), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [32297] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(482), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(839), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(484), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [32380] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1679), 1,
      anon_sym_LBRACK,
    STATE(763), 1,
      aux_sym_function_definition_repeat1,
    STATE(908), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(403), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(840), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(405), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [32467] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(522), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(841), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(524), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [32548] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(123), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(842), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(127), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [32629] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(506), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(843), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(508), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [32710] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(546), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(844), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(548), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [32791] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1803), 1,
      anon_sym_RBRACK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(845), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [32904] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(123), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(846), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(127), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [32985] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(530), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(847), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(532), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [33066] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1805), 1,
      anon_sym_RBRACK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(848), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [33179] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1767), 1,
      anon_sym_AMP,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1775), 1,
      anon_sym_PIPE,
    ACTIONS(1777), 1,
      anon_sym_CARET,
    ACTIONS(1787), 1,
      anon_sym_GT_GT,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1809), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1811), 1,
      anon_sym_QMARK,
    ACTIONS(1813), 1,
      sym__ternary_colon,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1779), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1781), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1783), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1785), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(849), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [33292] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1815), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(850), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [33405] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1817), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(851), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [33518] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(510), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(852), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(512), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [33599] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(492), 1,
      sym__ternary_colon,
    ACTIONS(1767), 1,
      anon_sym_AMP,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1775), 1,
      anon_sym_PIPE,
    ACTIONS(1777), 1,
      anon_sym_CARET,
    ACTIONS(1787), 1,
      anon_sym_GT_GT,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1809), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1811), 1,
      anon_sym_QMARK,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1779), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1781), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1783), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1785), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(853), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [33712] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(502), 7,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(854), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(504), 12,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
  [33801] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1819), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(855), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [33914] = 26,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1787), 1,
      anon_sym_GT_GT,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(502), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1779), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1781), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1783), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1785), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(504), 5,
      sym__ternary_colon,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_QMARK,
    STATE(856), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [34017] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1821), 1,
      anon_sym_RBRACK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(857), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [34130] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(502), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(858), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(504), 14,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
  [34215] = 29,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1767), 1,
      anon_sym_AMP,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1775), 1,
      anon_sym_PIPE,
    ACTIONS(1777), 1,
      anon_sym_CARET,
    ACTIONS(1787), 1,
      anon_sym_GT_GT,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1809), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1779), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1781), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1783), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1785), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(504), 3,
      sym__ternary_colon,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
    STATE(859), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [34324] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(534), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(860), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(536), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [34405] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1823), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(861), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [34518] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(538), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(862), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(540), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [34599] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1825), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(863), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [34712] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1827), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(864), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [34825] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1829), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(865), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [34938] = 28,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(502), 1,
      anon_sym_PIPE,
    ACTIONS(1767), 1,
      anon_sym_AMP,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1777), 1,
      anon_sym_CARET,
    ACTIONS(1787), 1,
      anon_sym_GT_GT,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1779), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1781), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1783), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1785), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(504), 4,
      sym__ternary_colon,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
    STATE(866), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [35045] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(490), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(867), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(492), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [35126] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(502), 1,
      anon_sym_PIPE,
    ACTIONS(1767), 1,
      anon_sym_AMP,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1787), 1,
      anon_sym_GT_GT,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1779), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1781), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1783), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1785), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(504), 5,
      sym__ternary_colon,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_QMARK,
    STATE(868), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [35231] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1831), 1,
      anon_sym_RBRACK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(869), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [35344] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1767), 1,
      anon_sym_AMP,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1775), 1,
      anon_sym_PIPE,
    ACTIONS(1777), 1,
      anon_sym_CARET,
    ACTIONS(1787), 1,
      anon_sym_GT_GT,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1809), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1811), 1,
      anon_sym_QMARK,
    ACTIONS(1833), 1,
      sym__ternary_colon,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1779), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1781), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1783), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1785), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(870), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [35457] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(871), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [35570] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1837), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(872), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [35683] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(550), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(873), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(552), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [35764] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1839), 1,
      anon_sym_RBRACK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(874), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [35877] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1787), 1,
      anon_sym_GT_GT,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(502), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1781), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1783), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1785), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(504), 7,
      sym__ternary_colon,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
    STATE(875), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [35978] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(558), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(876), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(560), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [36059] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1841), 1,
      anon_sym_RBRACK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(877), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [36172] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1843), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(878), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [36285] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1845), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(879), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [36398] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(566), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(880), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(568), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [36479] = 23,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1787), 1,
      anon_sym_GT_GT,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1785), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(502), 4,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(504), 9,
      sym__ternary_colon,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
    STATE(881), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [36576] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(514), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(882), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(516), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [36657] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(502), 5,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    ACTIONS(504), 11,
      sym__ternary_colon,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
    STATE(883), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [36750] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1767), 1,
      anon_sym_AMP,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1775), 1,
      anon_sym_PIPE,
    ACTIONS(1777), 1,
      anon_sym_CARET,
    ACTIONS(1787), 1,
      anon_sym_GT_GT,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1809), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1811), 1,
      anon_sym_QMARK,
    ACTIONS(1847), 1,
      sym__ternary_colon,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1779), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1781), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1783), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1785), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(884), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [36863] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(244), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(885), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(246), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [36944] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1849), 1,
      anon_sym_RBRACK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(886), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [37057] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(554), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(887), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(556), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [37138] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(562), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(888), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(564), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [37219] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(580), 1,
      sym__ternary_colon,
    ACTIONS(1767), 1,
      anon_sym_AMP,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1775), 1,
      anon_sym_PIPE,
    ACTIONS(1777), 1,
      anon_sym_CARET,
    ACTIONS(1787), 1,
      anon_sym_GT_GT,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1809), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1811), 1,
      anon_sym_QMARK,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1779), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1781), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1783), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1785), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(889), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [37332] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(570), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(890), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(572), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [37413] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(582), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(891), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(584), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [37494] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1851), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(892), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [37607] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(494), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(893), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(496), 16,
      sym__ternary_colon,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_QMARK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [37690] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1853), 1,
      anon_sym_RBRACK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(894), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [37803] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1855), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(895), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [37916] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1767), 1,
      anon_sym_AMP,
    ACTIONS(1769), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1773), 1,
      anon_sym_SLASH,
    ACTIONS(1775), 1,
      anon_sym_PIPE,
    ACTIONS(1777), 1,
      anon_sym_CARET,
    ACTIONS(1787), 1,
      anon_sym_GT_GT,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1807), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1809), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1811), 1,
      anon_sym_QMARK,
    ACTIONS(1857), 1,
      sym__ternary_colon,
    ACTIONS(1765), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1771), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1779), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1781), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1783), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1785), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1791), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(896), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [38029] = 31,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1859), 1,
      anon_sym_RBRACK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(897), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [38142] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(562), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(898), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(564), 18,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON2,
  [38222] = 30,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(899), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [38332] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1861), 1,
      sym_identifier,
    STATE(972), 1,
      sym__preproc_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(900), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [38432] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1861), 1,
      sym_identifier,
    STATE(934), 1,
      sym__preproc_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(901), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [38532] = 30,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1410), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(902), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [38642] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(518), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(903), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(520), 18,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON2,
  [38722] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(542), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(904), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(544), 18,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON2,
  [38802] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(546), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(905), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(548), 18,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON2,
  [38882] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(554), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(906), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(556), 18,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON2,
  [38962] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(570), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(907), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(572), 18,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON2,
  [39042] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(470), 7,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(908), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(472), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON2,
  [39122] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(582), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(909), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(584), 18,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON2,
  [39202] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(586), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(910), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(588), 18,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON2,
  [39282] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1861), 1,
      sym_identifier,
    STATE(925), 1,
      sym__preproc_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(911), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [39382] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1861), 1,
      sym_identifier,
    STATE(926), 1,
      sym__preproc_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(912), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [39482] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1861), 1,
      sym_identifier,
    STATE(930), 1,
      sym__preproc_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(913), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [39582] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1861), 1,
      sym_identifier,
    STATE(931), 1,
      sym__preproc_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(914), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [39682] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1861), 1,
      sym_identifier,
    STATE(932), 1,
      sym__preproc_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(915), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [39782] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1861), 1,
      sym_identifier,
    STATE(933), 1,
      sym__preproc_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(916), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [39882] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1861), 1,
      sym_identifier,
    STATE(936), 1,
      sym__preproc_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(917), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [39982] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1861), 1,
      sym_identifier,
    STATE(937), 1,
      sym__preproc_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(918), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [40082] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1861), 1,
      sym_identifier,
    STATE(941), 1,
      sym__preproc_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(919), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [40182] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(77), 1,
      anon_sym_defined,
    ACTIONS(1172), 1,
      anon_sym_LPAREN,
    ACTIONS(1178), 1,
      anon_sym_LBRACE,
    ACTIONS(1184), 1,
      sym_float_literal,
    ACTIONS(1186), 1,
      anon_sym_SQUOTE,
    ACTIONS(1188), 1,
      anon_sym_DQUOTE,
    ACTIONS(1861), 1,
      sym_identifier,
    STATE(943), 1,
      sym__preproc_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1182), 3,
      sym_int_literal,
      sym_bool_literal,
      sym_null,
    STATE(903), 3,
      sym_array_literal,
      sym_char_literal,
      sym_string_literal,
    ACTIONS(1174), 5,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_AMP,
    STATE(929), 5,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
      sym_preproc_defined_condition,
      sym__literal,
    STATE(920), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [40282] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(474), 7,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    STATE(921), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(476), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON2,
  [40362] = 30,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(632), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(922), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [40472] = 30,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(452), 1,
      anon_sym_DOT,
    ACTIONS(1544), 1,
      anon_sym_AMP,
    ACTIONS(1546), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1550), 1,
      anon_sym_SLASH,
    ACTIONS(1552), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1556), 1,
      anon_sym_PIPE,
    ACTIONS(1558), 1,
      anon_sym_CARET,
    ACTIONS(1568), 1,
      anon_sym_GT_GT,
    ACTIONS(1570), 1,
      anon_sym_QMARK,
    ACTIONS(1420), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(1542), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1560), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1562), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1566), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(923), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [40582] = 29,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1865), 1,
      anon_sym_AMP,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1871), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1875), 1,
      anon_sym_PIPE,
    ACTIONS(1877), 1,
      anon_sym_CARET,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    ACTIONS(1889), 1,
      anon_sym_COMMA,
    ACTIONS(1891), 1,
      anon_sym_RBRACE,
    STATE(1288), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1879), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1881), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1883), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    STATE(924), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [40689] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1895), 5,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(925), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1893), 15,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [40772] = 23,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1879), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1881), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1883), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1895), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1893), 6,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(926), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [40867] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1899), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(927), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1897), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [40948] = 29,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1865), 1,
      anon_sym_AMP,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1871), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1875), 1,
      anon_sym_PIPE,
    ACTIONS(1877), 1,
      anon_sym_CARET,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_RBRACE,
    STATE(1331), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1879), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1881), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1883), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    STATE(928), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [41055] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1899), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(929), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1897), 17,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [41134] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1895), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(930), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1893), 17,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [41213] = 26,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1865), 1,
      anon_sym_AMP,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1875), 1,
      anon_sym_PIPE,
    ACTIONS(1877), 1,
      anon_sym_CARET,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1879), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1881), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1883), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1893), 4,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(931), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [41314] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1865), 1,
      anon_sym_AMP,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1875), 1,
      anon_sym_PIPE,
    ACTIONS(1877), 1,
      anon_sym_CARET,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1879), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1881), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1883), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1893), 5,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(932), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [41413] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1865), 1,
      anon_sym_AMP,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1877), 1,
      anon_sym_CARET,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1879), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1881), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1883), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1893), 5,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(933), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [41512] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1909), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(934), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1907), 17,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [41591] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1913), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(935), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1911), 17,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [41670] = 24,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1865), 1,
      anon_sym_AMP,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1879), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1881), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1883), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1893), 6,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(936), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [41767] = 22,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1883), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1895), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1893), 8,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(937), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [41860] = 29,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(339), 1,
      anon_sym_COMMA,
    ACTIONS(341), 1,
      anon_sym_RBRACE,
    ACTIONS(1865), 1,
      anon_sym_AMP,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1871), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1875), 1,
      anon_sym_PIPE,
    ACTIONS(1877), 1,
      anon_sym_CARET,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    STATE(1267), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1879), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1881), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1883), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    STATE(938), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [41967] = 29,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(343), 1,
      anon_sym_COMMA,
    ACTIONS(345), 1,
      anon_sym_RBRACE,
    ACTIONS(1865), 1,
      anon_sym_AMP,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1871), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1875), 1,
      anon_sym_PIPE,
    ACTIONS(1877), 1,
      anon_sym_CARET,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    STATE(1308), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1879), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1881), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1883), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    STATE(939), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [42074] = 29,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1865), 1,
      anon_sym_AMP,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1871), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1875), 1,
      anon_sym_PIPE,
    ACTIONS(1877), 1,
      anon_sym_CARET,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    ACTIONS(1915), 1,
      anon_sym_COMMA,
    ACTIONS(1917), 1,
      anon_sym_RBRACE,
    STATE(1318), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1879), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1881), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1883), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    STATE(940), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [42181] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1895), 4,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1893), 10,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(941), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [42270] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1921), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(942), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1919), 17,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [42349] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1895), 5,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(943), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1893), 12,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [42434] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1927), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1925), 7,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON2,
    STATE(944), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1923), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
  [42515] = 29,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1931), 1,
      anon_sym_AMP,
    ACTIONS(1935), 1,
      anon_sym_SLASH,
    ACTIONS(1937), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1939), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1941), 1,
      anon_sym_PIPE,
    ACTIONS(1943), 1,
      anon_sym_CARET,
    ACTIONS(1953), 1,
      anon_sym_GT_GT,
    ACTIONS(1955), 1,
      anon_sym_COMMA,
    ACTIONS(1957), 1,
      anon_sym_COLON2,
    STATE(1325), 1,
      aux_sym_switch_case_repeat1,
    ACTIONS(1933), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1945), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1947), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1949), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1951), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1929), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    STATE(945), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [42622] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(550), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(946), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(552), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [42700] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1925), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(947), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1923), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [42778] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1935), 1,
      anon_sym_SLASH,
    ACTIONS(1933), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1961), 5,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(948), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1959), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [42860] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(530), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(949), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(532), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [42938] = 23,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1935), 1,
      anon_sym_SLASH,
    ACTIONS(1953), 1,
      anon_sym_GT_GT,
    ACTIONS(1933), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1945), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1947), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1949), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1951), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1961), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1929), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1959), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_COMMA,
      anon_sym_COLON2,
    STATE(950), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [43032] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1961), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(951), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1959), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [43110] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(514), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(952), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(516), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [43188] = 26,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1931), 1,
      anon_sym_AMP,
    ACTIONS(1935), 1,
      anon_sym_SLASH,
    ACTIONS(1939), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1941), 1,
      anon_sym_PIPE,
    ACTIONS(1943), 1,
      anon_sym_CARET,
    ACTIONS(1953), 1,
      anon_sym_GT_GT,
    ACTIONS(1933), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1945), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1947), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1949), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1951), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1929), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1959), 3,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_COLON2,
    STATE(953), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [43288] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(522), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(954), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(524), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [43366] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(123), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(955), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(127), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [43444] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(534), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(956), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(536), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [43522] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(347), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(957), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(349), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [43600] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(538), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(958), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(540), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [43678] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(558), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(959), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(560), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [43756] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(566), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(960), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(568), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [43834] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(351), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(961), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(353), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [43912] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1865), 1,
      anon_sym_AMP,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1871), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1875), 1,
      anon_sym_PIPE,
    ACTIONS(1877), 1,
      anon_sym_CARET,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1879), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1881), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1883), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1963), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    STATE(962), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [44014] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1967), 6,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    STATE(963), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
    ACTIONS(1965), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
  [44092] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1931), 1,
      anon_sym_AMP,
    ACTIONS(1935), 1,
      anon_sym_SLASH,
    ACTIONS(1941), 1,
      anon_sym_PIPE,
    ACTIONS(1943), 1,
      anon_sym_CARET,
    ACTIONS(1953), 1,
      anon_sym_GT_GT,
    ACTIONS(1933), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1945), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1947), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1949), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1951), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1929), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1959), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_COLON2,
    STATE(964), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [44190] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1931), 1,
      anon_sym_AMP,
    ACTIONS(1935), 1,
      anon_sym_SLASH,
    ACTIONS(1943), 1,
      anon_sym_CARET,
    ACTIONS(1953), 1,
      anon_sym_GT_GT,
    ACTIONS(1961), 1,
      anon_sym_PIPE,
    ACTIONS(1933), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1945), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1947), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1949), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1951), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1929), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1959), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_COLON2,
    STATE(965), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [44288] = 24,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1931), 1,
      anon_sym_AMP,
    ACTIONS(1935), 1,
      anon_sym_SLASH,
    ACTIONS(1953), 1,
      anon_sym_GT_GT,
    ACTIONS(1961), 1,
      anon_sym_PIPE,
    ACTIONS(1933), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1945), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1947), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1949), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1951), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1929), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1959), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_COMMA,
      anon_sym_COLON2,
    STATE(966), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [44384] = 22,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1935), 1,
      anon_sym_SLASH,
    ACTIONS(1953), 1,
      anon_sym_GT_GT,
    ACTIONS(1933), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1947), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1949), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1951), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1961), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1929), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1959), 7,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_COMMA,
      anon_sym_COLON2,
    STATE(967), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [44476] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1935), 1,
      anon_sym_SLASH,
    ACTIONS(1953), 1,
      anon_sym_GT_GT,
    ACTIONS(1933), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1951), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1929), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1961), 4,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1959), 9,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      anon_sym_COLON2,
    STATE(968), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [44564] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1935), 1,
      anon_sym_SLASH,
    ACTIONS(1933), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1929), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1961), 5,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_GT_GT,
    ACTIONS(1959), 11,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON2,
    STATE(969), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [44648] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1931), 1,
      anon_sym_AMP,
    ACTIONS(1935), 1,
      anon_sym_SLASH,
    ACTIONS(1937), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1939), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1941), 1,
      anon_sym_PIPE,
    ACTIONS(1943), 1,
      anon_sym_CARET,
    ACTIONS(1953), 1,
      anon_sym_GT_GT,
    ACTIONS(1933), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1945), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1947), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1949), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1951), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1969), 2,
      anon_sym_COMMA,
      anon_sym_COLON2,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1929), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    STATE(970), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [44750] = 28,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1971), 1,
      sym_identifier,
    ACTIONS(1973), 1,
      anon_sym_RPAREN,
    ACTIONS(1975), 1,
      anon_sym_AMP,
    STATE(983), 1,
      sym_variable_storage_class,
    STATE(1094), 1,
      sym_type,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1369), 1,
      sym_old_type,
    STATE(1445), 1,
      sym_array_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1301), 2,
      sym_parameter_declaration,
      sym_rest_parameter,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(971), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [44853] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1865), 1,
      anon_sym_AMP,
    ACTIONS(1869), 1,
      anon_sym_SLASH,
    ACTIONS(1871), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1875), 1,
      anon_sym_PIPE,
    ACTIONS(1877), 1,
      anon_sym_CARET,
    ACTIONS(1887), 1,
      anon_sym_GT_GT,
    ACTIONS(1977), 1,
      anon_sym_RPAREN,
    ACTIONS(1867), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1879), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1881), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1883), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1885), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1863), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DOT_DOT_DOT,
    STATE(972), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [44954] = 28,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1971), 1,
      sym_identifier,
    ACTIONS(1975), 1,
      anon_sym_AMP,
    ACTIONS(1979), 1,
      anon_sym_RPAREN,
    STATE(983), 1,
      sym_variable_storage_class,
    STATE(1094), 1,
      sym_type,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1369), 1,
      sym_old_type,
    STATE(1445), 1,
      sym_array_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1256), 2,
      sym_parameter_declaration,
      sym_rest_parameter,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(973), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [45057] = 28,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1971), 1,
      sym_identifier,
    ACTIONS(1975), 1,
      anon_sym_AMP,
    ACTIONS(1981), 1,
      anon_sym_RPAREN,
    STATE(983), 1,
      sym_variable_storage_class,
    STATE(1094), 1,
      sym_type,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1369), 1,
      sym_old_type,
    STATE(1445), 1,
      sym_array_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1301), 2,
      sym_parameter_declaration,
      sym_rest_parameter,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(974), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [45160] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1971), 1,
      sym_identifier,
    ACTIONS(1975), 1,
      anon_sym_AMP,
    STATE(983), 1,
      sym_variable_storage_class,
    STATE(1094), 1,
      sym_type,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1369), 1,
      sym_old_type,
    STATE(1445), 1,
      sym_array_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1437), 2,
      sym_parameter_declaration,
      sym_rest_parameter,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(975), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [45260] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1971), 1,
      sym_identifier,
    ACTIONS(1975), 1,
      anon_sym_AMP,
    STATE(982), 1,
      sym_variable_storage_class,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1128), 1,
      sym_type,
    STATE(1513), 1,
      sym_parameter_declaration,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1548), 1,
      sym_array_type,
    STATE(1592), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(976), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [45359] = 27,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1971), 1,
      sym_identifier,
    ACTIONS(1975), 1,
      anon_sym_AMP,
    STATE(982), 1,
      sym_variable_storage_class,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1128), 1,
      sym_type,
    STATE(1458), 1,
      sym_parameter_declaration,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1548), 1,
      sym_array_type,
    STATE(1592), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(977), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [45458] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1983), 1,
      sym_identifier,
    STATE(990), 1,
      sym_variable_storage_class,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1143), 1,
      sym_old_variable_declaration,
    STATE(1449), 1,
      sym_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(978), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [45551] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1985), 1,
      sym_identifier,
    STATE(987), 1,
      sym_variable_storage_class,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1124), 1,
      sym_old_variable_declaration,
    STATE(1142), 1,
      sym_type,
    STATE(1436), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(979), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [45644] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1983), 1,
      sym_identifier,
    STATE(985), 1,
      sym_variable_storage_class,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1112), 1,
      sym_old_variable_declaration,
    STATE(1417), 1,
      sym_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(980), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [45737] = 25,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1987), 1,
      sym_identifier,
    STATE(989), 1,
      sym_variable_storage_class,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1339), 1,
      sym_old_variable_declaration,
    STATE(1378), 1,
      sym_type,
    STATE(1464), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(981), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [45830] = 24,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1989), 1,
      sym_identifier,
    ACTIONS(1991), 1,
      anon_sym_AMP,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1109), 1,
      sym_type,
    STATE(1467), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1568), 1,
      sym_array_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(982), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [45920] = 24,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1989), 1,
      sym_identifier,
    ACTIONS(1991), 1,
      anon_sym_AMP,
    STATE(1087), 1,
      sym_type,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1450), 1,
      sym_array_type,
    STATE(1452), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(983), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [46010] = 23,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1983), 1,
      sym_identifier,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1161), 1,
      sym_old_variable_declaration,
    STATE(1356), 1,
      sym_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(984), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [46097] = 23,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1983), 1,
      sym_identifier,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1111), 1,
      sym_old_variable_declaration,
    STATE(1428), 1,
      sym_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(985), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [46184] = 23,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1983), 1,
      sym_identifier,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1112), 1,
      sym_old_variable_declaration,
    STATE(1417), 1,
      sym_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(986), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [46271] = 23,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1983), 1,
      sym_identifier,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1123), 1,
      sym_old_variable_declaration,
    STATE(1410), 1,
      sym_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(987), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [46358] = 23,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1987), 1,
      sym_identifier,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1339), 1,
      sym_old_variable_declaration,
    STATE(1378), 1,
      sym_type,
    STATE(1464), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(988), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [46445] = 23,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1987), 1,
      sym_identifier,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1290), 1,
      sym_old_variable_declaration,
    STATE(1384), 1,
      sym_type,
    STATE(1464), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(989), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [46532] = 23,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1983), 1,
      sym_identifier,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1106), 1,
      sym_old_variable_declaration,
    STATE(1425), 1,
      sym_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(990), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [46619] = 23,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1993), 1,
      sym_identifier,
    ACTIONS(1995), 1,
      anon_sym_operator,
    STATE(1279), 1,
      sym_type,
    STATE(1281), 1,
      sym_builtin_type,
    STATE(1481), 1,
      sym_old_type,
    STATE(1540), 1,
      sym_old_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(991), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [46706] = 23,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(63), 1,
      anon_sym_bool,
    ACTIONS(67), 1,
      sym_any_type,
    ACTIONS(1983), 1,
      sym_identifier,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1143), 1,
      sym_old_variable_declaration,
    STATE(1449), 1,
      sym_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 3,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    ACTIONS(61), 4,
      anon_sym_void,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(992), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [46793] = 22,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    ACTIONS(2001), 1,
      anon_sym_EQ,
    ACTIONS(2003), 1,
      anon_sym_LBRACK,
    STATE(69), 1,
      sym_parameter_declarations,
    STATE(1068), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(256), 2,
      anon_sym_operator,
      sym_identifier,
    STATE(511), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1999), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(993), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [46876] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2009), 1,
      anon_sym_RBRACE,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1254), 1,
      sym_type,
    ACTIONS(2006), 2,
      sym_any_type,
      sym_identifier,
    STATE(1077), 2,
      sym_enum_struct_field,
      sym_enum_struct_method,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2011), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(994), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_enum_struct_repeat1,
  [46953] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2016), 2,
      anon_sym_public,
      anon_sym_stock,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2014), 11,
      anon_sym_const,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
    STATE(995), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [47022] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2020), 1,
      anon_sym_RBRACE,
    STATE(994), 1,
      aux_sym_enum_struct_repeat1,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1254), 1,
      sym_type,
    ACTIONS(2018), 2,
      sym_any_type,
      sym_identifier,
    STATE(1077), 2,
      sym_enum_struct_field,
      sym_enum_struct_method,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(996), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [47101] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2022), 1,
      anon_sym_RBRACE,
    STATE(996), 1,
      aux_sym_enum_struct_repeat1,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1254), 1,
      sym_type,
    ACTIONS(2018), 2,
      sym_any_type,
      sym_identifier,
    STATE(1077), 2,
      sym_enum_struct_field,
      sym_enum_struct_method,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(997), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [47180] = 22,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    ACTIONS(2001), 1,
      anon_sym_EQ,
    ACTIONS(2003), 1,
      anon_sym_LBRACK,
    STATE(15), 1,
      sym_parameter_declarations,
    STATE(1068), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(256), 2,
      anon_sym_operator,
      sym_identifier,
    STATE(511), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1999), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(998), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [47263] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2024), 1,
      anon_sym_public,
    ACTIONS(2026), 1,
      anon_sym_RBRACE,
    ACTIONS(2028), 1,
      anon_sym_property,
    STATE(1007), 1,
      aux_sym_methodmap_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1328), 8,
      sym_methodmap_alias,
      sym_methodmap_native,
      sym_methodmap_native_constructor,
      sym_methodmap_native_destructor,
      sym_methodmap_method,
      sym_methodmap_method_constructor,
      sym_methodmap_method_destructor,
      sym_methodmap_property,
    STATE(999), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [47337] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2024), 1,
      anon_sym_public,
    ACTIONS(2028), 1,
      anon_sym_property,
    ACTIONS(2030), 1,
      anon_sym_RBRACE,
    STATE(1006), 1,
      aux_sym_methodmap_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1328), 8,
      sym_methodmap_alias,
      sym_methodmap_native,
      sym_methodmap_native_constructor,
      sym_methodmap_native_destructor,
      sym_methodmap_method,
      sym_methodmap_method_constructor,
      sym_methodmap_method_destructor,
      sym_methodmap_property,
    STATE(1000), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [47411] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2024), 1,
      anon_sym_public,
    ACTIONS(2028), 1,
      anon_sym_property,
    ACTIONS(2032), 1,
      anon_sym_RBRACE,
    STATE(999), 1,
      aux_sym_methodmap_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1328), 8,
      sym_methodmap_alias,
      sym_methodmap_native,
      sym_methodmap_native_constructor,
      sym_methodmap_native_destructor,
      sym_methodmap_method,
      sym_methodmap_method_constructor,
      sym_methodmap_method_destructor,
      sym_methodmap_property,
    STATE(1001), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [47485] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2024), 1,
      anon_sym_public,
    ACTIONS(2028), 1,
      anon_sym_property,
    ACTIONS(2034), 1,
      anon_sym_RBRACE,
    STATE(1007), 1,
      aux_sym_methodmap_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1328), 8,
      sym_methodmap_alias,
      sym_methodmap_native,
      sym_methodmap_native_constructor,
      sym_methodmap_native_destructor,
      sym_methodmap_method,
      sym_methodmap_method_constructor,
      sym_methodmap_method_destructor,
      sym_methodmap_property,
    STATE(1002), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [47559] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2018), 1,
      sym_any_type,
    ACTIONS(2036), 1,
      sym_identifier,
    ACTIONS(2038), 1,
      anon_sym_TILDE,
    ACTIONS(2040), 1,
      anon_sym_native,
    ACTIONS(2042), 1,
      anon_sym_static,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1242), 1,
      sym_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1003), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [47639] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2016), 1,
      anon_sym_static,
    ACTIONS(2044), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2014), 10,
      anon_sym_const,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
    STATE(1004), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [47709] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2024), 1,
      anon_sym_public,
    ACTIONS(2028), 1,
      anon_sym_property,
    ACTIONS(2047), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      aux_sym_methodmap_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1328), 8,
      sym_methodmap_alias,
      sym_methodmap_native,
      sym_methodmap_native_constructor,
      sym_methodmap_native_destructor,
      sym_methodmap_method,
      sym_methodmap_method_constructor,
      sym_methodmap_method_destructor,
      sym_methodmap_property,
    STATE(1005), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [47783] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2024), 1,
      anon_sym_public,
    ACTIONS(2028), 1,
      anon_sym_property,
    ACTIONS(2047), 1,
      anon_sym_RBRACE,
    STATE(1007), 1,
      aux_sym_methodmap_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1328), 8,
      sym_methodmap_alias,
      sym_methodmap_native,
      sym_methodmap_native_constructor,
      sym_methodmap_native_destructor,
      sym_methodmap_method,
      sym_methodmap_method_constructor,
      sym_methodmap_method_destructor,
      sym_methodmap_property,
    STATE(1006), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [47857] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2049), 1,
      anon_sym_public,
    ACTIONS(2052), 1,
      anon_sym_RBRACE,
    ACTIONS(2054), 1,
      anon_sym_property,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1328), 8,
      sym_methodmap_alias,
      sym_methodmap_native,
      sym_methodmap_native_constructor,
      sym_methodmap_native_destructor,
      sym_methodmap_method,
      sym_methodmap_method_constructor,
      sym_methodmap_method_destructor,
      sym_methodmap_property,
    STATE(1007), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_methodmap_repeat1,
  [47929] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2016), 1,
      anon_sym_static,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2014), 11,
      anon_sym_const,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
    STATE(1008), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [47997] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2057), 1,
      anon_sym_public,
    ACTIONS(2059), 1,
      anon_sym_RBRACE,
    STATE(1420), 1,
      sym_funcenum_member,
    STATE(1503), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    ACTIONS(374), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1009), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [48074] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2061), 1,
      sym_identifier,
    STATE(1041), 1,
      sym_variable_storage_class,
    STATE(1339), 1,
      sym_old_variable_declaration,
    STATE(1464), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1010), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [48153] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2063), 1,
      sym_identifier,
    STATE(1049), 1,
      sym_variable_storage_class,
    STATE(1143), 1,
      sym_old_variable_declaration,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1011), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [48232] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2065), 1,
      sym_identifier,
    STATE(1049), 1,
      sym_variable_storage_class,
    STATE(1143), 1,
      sym_old_variable_declaration,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1012), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [48311] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2067), 11,
      anon_sym_const,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
    STATE(1013), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [48376] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2069), 1,
      sym_identifier,
    STATE(1048), 1,
      sym_variable_storage_class,
    STATE(1112), 1,
      sym_old_variable_declaration,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1014), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [48455] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2071), 1,
      anon_sym_LBRACK,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(758), 7,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_SEMI,
      sym_identifier,
    STATE(1015), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_parameter_declaration_repeat1,
  [48524] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2074), 11,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
    STATE(1016), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [48589] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(2078), 1,
      anon_sym_EQ,
    ACTIONS(2080), 1,
      anon_sym_LBRACK,
    STATE(1092), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(2076), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1146), 3,
      anon_sym_AMP,
      anon_sym_DOT_DOT_DOT,
      sym_identifier,
    STATE(1017), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [48666] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2065), 1,
      sym_identifier,
    STATE(1048), 1,
      sym_variable_storage_class,
    STATE(1112), 1,
      sym_old_variable_declaration,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1018), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [48745] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2083), 11,
      anon_sym_operator,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
    STATE(1019), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [48810] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2085), 11,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
    STATE(1020), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [48875] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(125), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_LBRACK,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(2001), 1,
      anon_sym_EQ,
    STATE(130), 1,
      sym_call_arguments,
    STATE(1068), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(511), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1999), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1021), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [48954] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_LBRACK,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(2001), 1,
      anon_sym_EQ,
    STATE(174), 1,
      sym_call_arguments,
    STATE(1068), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(511), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1999), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1022), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49033] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(2080), 1,
      anon_sym_LBRACK,
    ACTIONS(2089), 1,
      anon_sym_EQ,
    STATE(1086), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(2087), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1146), 3,
      anon_sym_AMP,
      anon_sym_DOT_DOT_DOT,
      sym_identifier,
    STATE(1023), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49110] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2065), 1,
      sym_identifier,
    STATE(1046), 1,
      sym_variable_storage_class,
    STATE(1117), 1,
      sym_old_variable_declaration,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1024), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49189] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2057), 1,
      anon_sym_public,
    ACTIONS(2091), 1,
      anon_sym_RBRACE,
    STATE(1420), 1,
      sym_funcenum_member,
    STATE(1503), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    ACTIONS(374), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1025), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49266] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2095), 1,
      anon_sym_AMP,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2093), 10,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
      sym_any_type,
      sym_identifier,
    STATE(1026), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49333] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2097), 11,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
    STATE(1027), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49398] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(37), 1,
      anon_sym_const,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2099), 1,
      sym_identifier,
    STATE(1041), 1,
      sym_variable_storage_class,
    STATE(1339), 1,
      sym_old_variable_declaration,
    STATE(1464), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1028), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49477] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1146), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_LBRACK,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(2001), 1,
      anon_sym_EQ,
    STATE(1068), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(511), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1999), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1029), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49553] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2057), 1,
      anon_sym_public,
    STATE(1420), 1,
      sym_funcenum_member,
    STATE(1503), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    ACTIONS(374), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1030), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49627] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2101), 1,
      anon_sym_const,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1166), 1,
      sym_type,
    ACTIONS(2018), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1031), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49699] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1156), 1,
      anon_sym_LBRACK,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    ACTIONS(2105), 1,
      anon_sym_EQ,
    STATE(32), 1,
      sym_parameter_declarations,
    STATE(1074), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(511), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2103), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1032), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49775] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(830), 1,
      anon_sym_LPAREN,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(2107), 1,
      anon_sym_EQ,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    STATE(695), 1,
      sym_call_arguments,
    STATE(1080), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(1999), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1033), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49853] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2111), 1,
      sym_identifier,
    ACTIONS(2113), 1,
      anon_sym_COMMA,
    ACTIONS(2115), 1,
      anon_sym_RBRACE,
    STATE(1283), 1,
      sym_enum_entry,
    STATE(1547), 1,
      sym_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1034), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49927] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2117), 1,
      anon_sym_native,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1221), 1,
      sym_type,
    ACTIONS(2018), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1035), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [49999] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2018), 1,
      sym_any_type,
    ACTIONS(2119), 1,
      sym_identifier,
    ACTIONS(2121), 1,
      anon_sym_TILDE,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1220), 1,
      sym_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1036), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [50073] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1154), 1,
      anon_sym_EQ,
    ACTIONS(1156), 1,
      anon_sym_LBRACK,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(494), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1364), 1,
      sym_parameter_declarations,
    STATE(511), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(744), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1037), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [50149] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1154), 1,
      anon_sym_EQ,
    ACTIONS(1156), 1,
      anon_sym_LBRACK,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(494), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1394), 1,
      sym_parameter_declarations,
    STATE(511), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(744), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1038), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [50225] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1156), 1,
      anon_sym_LBRACK,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    ACTIONS(2105), 1,
      anon_sym_EQ,
    STATE(65), 1,
      sym_parameter_declarations,
    STATE(1074), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(511), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2103), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1039), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [50301] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2057), 1,
      anon_sym_public,
    STATE(1294), 1,
      sym_funcenum_member,
    STATE(1503), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    ACTIONS(374), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1040), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [50375] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2099), 1,
      sym_identifier,
    STATE(1290), 1,
      sym_old_variable_declaration,
    STATE(1464), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1041), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [50448] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1648), 1,
      sym_type,
    ACTIONS(2018), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1042), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [50517] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1156), 1,
      anon_sym_LBRACK,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(2001), 1,
      anon_sym_EQ,
    STATE(1068), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(511), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1999), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1043), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [50590] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2099), 1,
      sym_identifier,
    STATE(1392), 1,
      sym_old_variable_declaration,
    STATE(1464), 1,
      sym_old_type,
    STATE(1531), 1,
      sym_old_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1044), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [50663] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2111), 1,
      sym_identifier,
    ACTIONS(2123), 1,
      anon_sym_RBRACE,
    STATE(1380), 1,
      sym_enum_entry,
    STATE(1547), 1,
      sym_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1045), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [50734] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2065), 1,
      sym_identifier,
    STATE(1162), 1,
      sym_old_variable_declaration,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1046), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [50807] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1652), 1,
      sym_type,
    ACTIONS(2018), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1047), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [50876] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2065), 1,
      sym_identifier,
    STATE(1111), 1,
      sym_old_variable_declaration,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1048), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [50949] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2065), 1,
      sym_identifier,
    STATE(1106), 1,
      sym_old_variable_declaration,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1049), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51022] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2111), 1,
      sym_identifier,
    ACTIONS(2125), 1,
      anon_sym_RBRACE,
    STATE(1380), 1,
      sym_enum_entry,
    STATE(1547), 1,
      sym_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1050), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51093] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2018), 1,
      sym_any_type,
    ACTIONS(2127), 1,
      sym_identifier,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1250), 1,
      sym_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1051), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51164] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1127), 1,
      sym_type,
    ACTIONS(2018), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1052), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51233] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1172), 1,
      sym_type,
    ACTIONS(2018), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1053), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51302] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1131), 1,
      sym_type,
    ACTIONS(2018), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1054), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51371] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2129), 1,
      anon_sym_public,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1539), 1,
      sym_old_type,
    ACTIONS(374), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1055), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51442] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1578), 1,
      sym_type,
    ACTIONS(2018), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1056), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51511] = 20,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1146), 1,
      sym_identifier,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(2107), 1,
      anon_sym_EQ,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    STATE(1080), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(1999), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1057), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51586] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2065), 1,
      sym_identifier,
    STATE(1329), 1,
      sym_old_variable_declaration,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1603), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1058), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51659] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1649), 1,
      sym_type,
    ACTIONS(2018), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1059), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51728] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1645), 1,
      sym_type,
    ACTIONS(2018), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1060), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51797] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    STATE(1103), 1,
      sym_builtin_type,
    STATE(1647), 1,
      sym_type,
    ACTIONS(2018), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1061), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51866] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(2107), 1,
      anon_sym_EQ,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    STATE(1080), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(1999), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1062), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [51938] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2133), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2131), 7,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      sym_any_type,
      sym_identifier,
    STATE(1063), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52002] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1580), 1,
      sym_old_type,
    ACTIONS(374), 2,
      sym_any_type,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1064), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52070] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2137), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2135), 7,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      sym_any_type,
      sym_identifier,
    STATE(1065), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52134] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2139), 1,
      sym_identifier,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1594), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1066), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52204] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2141), 2,
      anon_sym_operator,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2143), 6,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_DOT_DOT_DOT,
      anon_sym_GT,
      anon_sym_COLON,
      anon_sym_LBRACK,
    STATE(1067), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52268] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1156), 1,
      anon_sym_LBRACK,
    ACTIONS(2147), 1,
      anon_sym_EQ,
    STATE(489), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(511), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2145), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1068), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52338] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(814), 8,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym_identifier,
    STATE(1069), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52400] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2111), 1,
      sym_identifier,
    STATE(1380), 1,
      sym_enum_entry,
    STATE(1547), 1,
      sym_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1070), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52468] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(374), 1,
      sym_any_type,
    ACTIONS(2149), 1,
      sym_identifier,
    STATE(1531), 1,
      sym_old_builtin_type,
    STATE(1602), 1,
      sym_old_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(65), 4,
      anon_sym_bool,
      anon_sym__,
      anon_sym_Float,
      anon_sym_String,
    STATE(1071), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52538] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2153), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2151), 7,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      sym_any_type,
      sym_identifier,
    STATE(1072), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52602] = 21,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(388), 1,
      sym__automatic_semicolon,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(460), 1,
      sym__manual_semicolon,
    STATE(1075), 1,
      sym__semicolon,
    STATE(1212), 1,
      sym_fixed_dimension,
    STATE(1441), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1073), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52678] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1156), 1,
      anon_sym_LBRACK,
    ACTIONS(2157), 1,
      anon_sym_EQ,
    STATE(489), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(511), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2155), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1074), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52748] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2161), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2159), 7,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      sym_any_type,
      sym_identifier,
    STATE(1075), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52812] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1156), 1,
      anon_sym_LBRACK,
    ACTIONS(2105), 1,
      anon_sym_EQ,
    STATE(1074), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(511), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2103), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1076), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52882] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2165), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2163), 7,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
      sym_any_type,
      sym_identifier,
    STATE(1077), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [52946] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2169), 1,
      anon_sym_EQ,
    STATE(1015), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(2167), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1078), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53015] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1292), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2171), 3,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_function,
    STATE(1079), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53084] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2173), 1,
      anon_sym_EQ,
    STATE(1015), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(2145), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1080), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53153] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1333), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2175), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1081), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53222] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2177), 1,
      sym_identifier,
    STATE(1270), 1,
      sym_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1082), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53287] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2179), 1,
      sym_identifier,
    STATE(1270), 1,
      sym_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1083), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53352] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2183), 1,
      anon_sym_EQ,
    STATE(1015), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(2181), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1084), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53421] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2185), 1,
      sym_identifier,
    STATE(1320), 1,
      sym_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1085), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53486] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2189), 1,
      anon_sym_EQ,
    STATE(1015), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(2187), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1086), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53555] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2191), 1,
      sym_identifier,
    ACTIONS(2193), 1,
      anon_sym_AMP,
    ACTIONS(2195), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(1130), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1087), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53626] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1350), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2197), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1088), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53695] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1313), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2199), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1089), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53764] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1297), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2201), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1090), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53833] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2203), 1,
      sym_identifier,
    STATE(1291), 1,
      sym_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1091), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53898] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2207), 1,
      anon_sym_EQ,
    STATE(1015), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(2205), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1092), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [53967] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2211), 1,
      anon_sym_EQ,
    STATE(1078), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(2209), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1093), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54036] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2213), 1,
      sym_identifier,
    ACTIONS(2215), 1,
      anon_sym_AMP,
    ACTIONS(2217), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(1130), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1094), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54107] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2221), 1,
      anon_sym_EQ,
    STATE(1084), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(2219), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1095), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54176] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2223), 1,
      anon_sym_EQ,
    STATE(1097), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(2103), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1096), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54245] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2225), 1,
      anon_sym_EQ,
    STATE(1015), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(2155), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1097), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54314] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1295), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2227), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1098), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54383] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2229), 1,
      sym_identifier,
    STATE(1311), 1,
      sym_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1099), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54448] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1266), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2231), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1100), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54517] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1258), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2233), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1101), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54586] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2235), 1,
      sym_identifier,
    STATE(1334), 1,
      sym_builtin_type,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(61), 5,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_float,
      anon_sym_char,
    STATE(1102), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54651] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(256), 2,
      anon_sym_operator,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1146), 5,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_DOT_DOT_DOT,
      anon_sym_GT,
      anon_sym_LBRACK,
    STATE(1103), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54714] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1347), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2237), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1104), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54783] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1349), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2239), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1105), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54852] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(573), 1,
      sym__semicolon,
    STATE(1158), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1106), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54922] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(780), 1,
      anon_sym_SEMI,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(515), 1,
      aux_sym_global_variable_declaration_repeat1,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(552), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1107), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [54992] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(256), 2,
      anon_sym_operator,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1146), 3,
      anon_sym_AMP,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LBRACK,
    STATE(1108), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55056] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2191), 1,
      sym_identifier,
    ACTIONS(2193), 1,
      anon_sym_AMP,
    STATE(1130), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1109), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55124] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2243), 1,
      anon_sym_public,
    ACTIONS(2245), 1,
      anon_sym_RBRACE,
    STATE(1134), 1,
      aux_sym_methodmap_property_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1363), 3,
      sym_methodmap_property_alias,
      sym_methodmap_property_native,
      sym_methodmap_property_method,
    STATE(1110), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55190] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(388), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(448), 1,
      sym__semicolon,
    STATE(460), 1,
      sym__manual_semicolon,
    STATE(1126), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1111), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55260] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(388), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(460), 1,
      sym__manual_semicolon,
    STATE(478), 1,
      sym__semicolon,
    STATE(1113), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1112), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55330] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(388), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(448), 1,
      sym__semicolon,
    STATE(460), 1,
      sym__manual_semicolon,
    STATE(1201), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1113), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55400] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1456), 1,
      sym__semicolon,
    ACTIONS(2247), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1114), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55468] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(515), 1,
      aux_sym_global_variable_declaration_repeat1,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(675), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1115), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55538] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(686), 1,
      sym__semicolon,
    STATE(1115), 1,
      aux_sym_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1116), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55608] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(680), 1,
      sym__semicolon,
    STATE(1120), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1117), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55678] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(699), 1,
      sym__semicolon,
    STATE(1201), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1118), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55748] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(716), 1,
      sym__semicolon,
    STATE(1157), 1,
      aux_sym_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1119), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55818] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(671), 1,
      sym__semicolon,
    STATE(1201), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1120), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55888] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1381), 1,
      sym__semicolon,
    ACTIONS(2249), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1121), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [55956] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1306), 1,
      anon_sym_LBRACK,
    ACTIONS(2253), 1,
      anon_sym_EQ,
    ACTIONS(2255), 1,
      anon_sym_COLON,
    STATE(1273), 1,
      sym_fixed_dimension,
    ACTIONS(2251), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1122), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56024] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(688), 1,
      sym__semicolon,
    STATE(1118), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1123), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56094] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(657), 1,
      sym__semicolon,
    STATE(1129), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1124), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56164] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(515), 1,
      aux_sym_global_variable_declaration_repeat1,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(645), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1125), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56234] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(388), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(460), 1,
      sym__manual_semicolon,
    STATE(461), 1,
      sym__semicolon,
    STATE(1201), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1126), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56304] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(1135), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1183), 1,
      sym_parameter_declarations,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1127), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56372] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2213), 1,
      sym_identifier,
    ACTIONS(2215), 1,
      anon_sym_AMP,
    STATE(1130), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1128), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56440] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(689), 1,
      sym__semicolon,
    STATE(1201), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1129), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56510] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    STATE(1015), 1,
      aux_sym_parameter_declaration_repeat1,
    ACTIONS(2259), 2,
      anon_sym_DOT_DOT_DOT,
      sym_identifier,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1130), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56576] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    STATE(1151), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1529), 1,
      sym_parameter_declarations,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1131), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56644] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1385), 1,
      sym__semicolon,
    ACTIONS(2261), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1132), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56712] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(784), 1,
      anon_sym_SEMI,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(546), 1,
      sym__semicolon,
    STATE(1147), 1,
      aux_sym_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1133), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56782] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2263), 1,
      anon_sym_public,
    ACTIONS(2266), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1363), 3,
      sym_methodmap_property_alias,
      sym_methodmap_property_native,
      sym_methodmap_property_method,
    STATE(1134), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_methodmap_property_repeat1,
  [56846] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(1015), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1163), 1,
      sym_parameter_declarations,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1135), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56914] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2243), 1,
      anon_sym_public,
    ACTIONS(2268), 1,
      anon_sym_RBRACE,
    STATE(1110), 1,
      aux_sym_methodmap_property_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1363), 3,
      sym_methodmap_property_alias,
      sym_methodmap_property_native,
      sym_methodmap_property_method,
    STATE(1136), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [56980] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2270), 1,
      anon_sym_COLON,
    ACTIONS(2141), 2,
      anon_sym_operator,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2143), 3,
      anon_sym_AMP,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LBRACK,
    STATE(1137), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57044] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1434), 1,
      sym__semicolon,
    ACTIONS(2272), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1138), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57112] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(714), 1,
      sym__semicolon,
    STATE(1201), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1139), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57182] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1440), 1,
      sym__semicolon,
    ACTIONS(2274), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1140), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57250] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(690), 1,
      sym__semicolon,
    STATE(1125), 1,
      aux_sym_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1141), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57320] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2276), 1,
      sym_identifier,
    ACTIONS(2278), 1,
      anon_sym_operator,
    STATE(621), 1,
      sym_dimension,
    STATE(1141), 1,
      sym_variable_declaration,
    STATE(1200), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1142), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57390] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(584), 1,
      sym__semicolon,
    STATE(1159), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1143), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57460] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(736), 1,
      sym__semicolon,
    STATE(1155), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1144), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57530] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(798), 1,
      anon_sym_SEMI,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(550), 1,
      sym__semicolon,
    STATE(1152), 1,
      aux_sym_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1145), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57600] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(1404), 1,
      sym__semicolon,
    ACTIONS(2280), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1146), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57668] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(794), 1,
      anon_sym_SEMI,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(515), 1,
      aux_sym_global_variable_declaration_repeat1,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(547), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1147), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57738] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(794), 1,
      anon_sym_SEMI,
    ACTIONS(1162), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(547), 1,
      sym__semicolon,
    STATE(1154), 1,
      aux_sym_variable_declaration_statement_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1148), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57808] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2284), 1,
      anon_sym_operator,
    STATE(621), 1,
      sym_dimension,
    STATE(1156), 1,
      sym_variable_declaration,
    STATE(1206), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1149), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57878] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(515), 1,
      aux_sym_global_variable_declaration_repeat1,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(693), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1150), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [57948] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    STATE(1015), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1617), 1,
      sym_parameter_declarations,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1151), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58016] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(776), 1,
      anon_sym_SEMI,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(515), 1,
      aux_sym_global_variable_declaration_repeat1,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(548), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1152), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58086] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(767), 1,
      anon_sym_SEMI,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(549), 1,
      sym__semicolon,
    STATE(1107), 1,
      aux_sym_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1153), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58156] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(788), 1,
      anon_sym_SEMI,
    ACTIONS(1162), 1,
      anon_sym_COMMA,
    STATE(517), 1,
      aux_sym_variable_declaration_statement_repeat1,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(551), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1154), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58226] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(680), 1,
      sym__semicolon,
    STATE(1201), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1155), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58296] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(658), 1,
      sym__semicolon,
    STATE(1150), 1,
      aux_sym_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1156), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58366] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(1160), 1,
      anon_sym_COMMA,
    STATE(515), 1,
      aux_sym_global_variable_declaration_repeat1,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(682), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1157), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58436] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(555), 1,
      sym__semicolon,
    STATE(1201), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1158), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58506] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(573), 1,
      sym__semicolon,
    STATE(1201), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1159), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58576] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(685), 1,
      sym__semicolon,
    STATE(1201), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1160), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58646] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(654), 1,
      sym__semicolon,
    STATE(1160), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1161), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58716] = 19,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(670), 1,
      sym__semicolon,
    STATE(1139), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1162), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58786] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2286), 5,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_function,
      anon_sym_SEMI,
    STATE(1163), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58845] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2288), 1,
      sym_identifier,
    STATE(1015), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1164), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58910] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2290), 1,
      anon_sym_RBRACE,
    ACTIONS(2292), 1,
      anon_sym_case,
    ACTIONS(2294), 1,
      anon_sym_default,
    STATE(1193), 1,
      aux_sym_switch_statement_repeat1,
    STATE(1277), 1,
      sym_switch_case,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1165), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [58977] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2296), 1,
      sym_identifier,
    STATE(1177), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1166), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59042] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2298), 1,
      sym_identifier,
    STATE(621), 1,
      sym_dimension,
    STATE(1133), 1,
      sym_variable_declaration,
    STATE(1171), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1167), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59109] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2300), 1,
      sym_identifier,
    STATE(221), 1,
      sym_variable_declaration,
    STATE(621), 1,
      sym_dimension,
    STATE(1191), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1168), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59176] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(1170), 1,
      sym_parameter_declarations,
    ACTIONS(1146), 2,
      anon_sym_LBRACK,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1169), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59241] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2302), 1,
      anon_sym_EQ,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(684), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1170), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59308] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2304), 1,
      sym_identifier,
    STATE(591), 1,
      aux_sym_function_definition_repeat1,
    STATE(621), 1,
      sym_dimension,
    STATE(1148), 1,
      sym_dynamic_array_declaration,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1171), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59375] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2306), 1,
      sym_identifier,
    STATE(1164), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1172), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59440] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2298), 1,
      sym_identifier,
    STATE(509), 1,
      sym_variable_declaration,
    STATE(621), 1,
      sym_dimension,
    STATE(1185), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1173), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59507] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2308), 5,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_function,
      anon_sym_SEMI,
    STATE(1174), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59566] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(125), 1,
      anon_sym_LPAREN,
    ACTIONS(394), 1,
      anon_sym_LBRACK,
    STATE(97), 1,
      aux_sym_dynamic_array_repeat1,
    STATE(104), 1,
      sym_fixed_dimension,
    STATE(130), 1,
      sym_call_arguments,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1175), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59633] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2310), 1,
      anon_sym_LPAREN,
    ACTIONS(2313), 1,
      anon_sym_RBRACE,
    ACTIONS(2315), 1,
      anon_sym_function,
    STATE(1079), 1,
      sym_typedef_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1176), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_typeset_repeat1,
  [59698] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2109), 1,
      anon_sym_LBRACK,
    ACTIONS(2318), 1,
      sym_identifier,
    STATE(1015), 1,
      aux_sym_parameter_declaration_repeat1,
    STATE(1069), 2,
      sym_dimension,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1177), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59763] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    STATE(155), 1,
      aux_sym_dynamic_array_repeat1,
    STATE(164), 1,
      sym_fixed_dimension,
    STATE(174), 1,
      sym_call_arguments,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1178), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59830] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2320), 1,
      anon_sym_native,
    ACTIONS(2322), 1,
      anon_sym_get,
    ACTIONS(2324), 1,
      anon_sym_set,
    STATE(1352), 1,
      sym_methodmap_property_getter,
    STATE(1424), 1,
      sym_methodmap_property_setter,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1179), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59897] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(830), 1,
      anon_sym_LPAREN,
    ACTIONS(1306), 1,
      anon_sym_LBRACK,
    STATE(613), 1,
      aux_sym_dynamic_array_repeat1,
    STATE(630), 1,
      sym_fixed_dimension,
    STATE(695), 1,
      sym_call_arguments,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1180), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [59964] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1306), 1,
      anon_sym_LBRACK,
    ACTIONS(2328), 1,
      anon_sym_EQ,
    STATE(1271), 1,
      sym_fixed_dimension,
    ACTIONS(2326), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1181), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60029] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2330), 1,
      anon_sym_else,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(1074), 4,
      anon_sym_RBRACE,
      anon_sym_while,
      anon_sym_case,
      anon_sym_default,
    STATE(1182), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60090] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2332), 5,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_function,
      anon_sym_SEMI,
    STATE(1183), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60149] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2292), 1,
      anon_sym_case,
    ACTIONS(2294), 1,
      anon_sym_default,
    ACTIONS(2334), 1,
      anon_sym_RBRACE,
    STATE(1190), 1,
      aux_sym_switch_statement_repeat1,
    STATE(1277), 1,
      sym_switch_case,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1184), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60216] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2304), 1,
      sym_identifier,
    STATE(507), 1,
      sym_dynamic_array_declaration,
    STATE(591), 1,
      aux_sym_function_definition_repeat1,
    STATE(621), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1185), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60283] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2336), 5,
      sym__automatic_semicolon,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_function,
      anon_sym_SEMI,
    STATE(1186), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60342] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2338), 1,
      anon_sym_RBRACE,
    ACTIONS(2340), 1,
      anon_sym_case,
    ACTIONS(2343), 1,
      anon_sym_default,
    STATE(1277), 1,
      sym_switch_case,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1187), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_switch_statement_repeat1,
  [60407] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1094), 1,
      anon_sym_LPAREN,
    ACTIONS(1644), 1,
      anon_sym_LBRACK,
    STATE(750), 1,
      aux_sym_dynamic_array_repeat1,
    STATE(814), 1,
      sym_fixed_dimension,
    STATE(862), 1,
      sym_call_arguments,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1188), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60474] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2346), 1,
      anon_sym_EQ,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(672), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1189), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60541] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2292), 1,
      anon_sym_case,
    ACTIONS(2294), 1,
      anon_sym_default,
    ACTIONS(2348), 1,
      anon_sym_RBRACE,
    STATE(1187), 1,
      aux_sym_switch_statement_repeat1,
    STATE(1277), 1,
      sym_switch_case,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1190), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60608] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2350), 1,
      sym_identifier,
    STATE(225), 1,
      sym_dynamic_array_declaration,
    STATE(591), 1,
      aux_sym_function_definition_repeat1,
    STATE(621), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1191), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60675] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    ACTIONS(2352), 1,
      anon_sym_EQ,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(681), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1192), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60742] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2292), 1,
      anon_sym_case,
    ACTIONS(2294), 1,
      anon_sym_default,
    ACTIONS(2354), 1,
      anon_sym_RBRACE,
    STATE(1187), 1,
      aux_sym_switch_statement_repeat1,
    STATE(1277), 1,
      sym_switch_case,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1193), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60809] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2356), 1,
      anon_sym_LPAREN,
    ACTIONS(2358), 1,
      anon_sym_RBRACE,
    ACTIONS(2360), 1,
      anon_sym_function,
    STATE(1079), 1,
      sym_typedef_expression,
    STATE(1176), 1,
      aux_sym_typeset_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1194), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60876] = 18,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2362), 1,
      sym_identifier,
    ACTIONS(2364), 1,
      anon_sym_LPAREN,
    ACTIONS(2366), 1,
      anon_sym_LBRACE,
    ACTIONS(2368), 1,
      anon_sym_struct,
    STATE(597), 1,
      sym_enum_entries,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1195), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [60943] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2390), 1,
      anon_sym_DQUOTE,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    STATE(1238), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1196), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61005] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1635), 1,
      anon_sym_COMMA,
    STATE(282), 1,
      sym__manual_semicolon,
    STATE(1263), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1197), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61069] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(677), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1198), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61133] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2366), 1,
      anon_sym_LBRACE,
    ACTIONS(2396), 1,
      anon_sym_LPAREN,
    ACTIONS(2398), 1,
      anon_sym_COLON,
    STATE(592), 1,
      sym_enum_entries,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1199), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61197] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2400), 1,
      sym_identifier,
    STATE(591), 1,
      aux_sym_function_definition_repeat1,
    STATE(621), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1200), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61261] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2402), 1,
      anon_sym_COMMA,
    ACTIONS(2405), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1201), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_old_global_variable_declaration_repeat1,
  [61321] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(660), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1202), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61385] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2407), 1,
      sym_identifier,
    STATE(591), 1,
      aux_sym_function_definition_repeat1,
    STATE(621), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1203), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61449] = 15,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2409), 1,
      anon_sym_DQUOTE,
    ACTIONS(2411), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2414), 1,
      sym_escape_sequence,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1204), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_string_literal_repeat1,
  [61509] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(661), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1205), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61573] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2417), 1,
      sym_identifier,
    STATE(591), 1,
      aux_sym_function_definition_repeat1,
    STATE(621), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1206), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61637] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(696), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1207), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61701] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(697), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1208), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61765] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2356), 1,
      anon_sym_LPAREN,
    ACTIONS(2360), 1,
      anon_sym_function,
    STATE(1079), 1,
      sym_typedef_expression,
    STATE(1194), 1,
      aux_sym_typeset_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1209), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61829] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(698), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1210), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61893] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    ACTIONS(2419), 1,
      anon_sym_DQUOTE,
    STATE(1230), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1211), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [61955] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(388), 1,
      sym__automatic_semicolon,
    STATE(460), 1,
      sym__manual_semicolon,
    STATE(1063), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1212), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62019] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2421), 1,
      sym_identifier,
    STATE(591), 1,
      aux_sym_function_definition_repeat1,
    STATE(621), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1213), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62083] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    ACTIONS(2423), 1,
      anon_sym_DQUOTE,
    STATE(1215), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1214), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62145] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    ACTIONS(2425), 1,
      anon_sym_DQUOTE,
    STATE(1204), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1215), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62207] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2427), 1,
      sym_identifier,
    ACTIONS(2429), 1,
      anon_sym_COMMA,
    ACTIONS(2431), 1,
      anon_sym_RBRACE,
    STATE(1306), 1,
      sym_struct_field_value,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1216), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62271] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(648), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1217), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62335] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(311), 1,
      anon_sym_DQUOTE,
    ACTIONS(2433), 1,
      anon_sym_new,
    STATE(530), 2,
      sym_dynamic_array,
      sym_string_literal,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1218), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62397] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(1081), 1,
      sym_parameter_declarations,
    ACTIONS(1146), 2,
      anon_sym_LBRACK,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1219), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62459] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2435), 1,
      sym_identifier,
    STATE(621), 1,
      sym_dimension,
    STATE(1246), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1220), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62523] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2437), 1,
      sym_identifier,
    STATE(621), 1,
      sym_dimension,
    STATE(1251), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1221), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62587] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2439), 1,
      anon_sym_new,
    ACTIONS(2441), 1,
      anon_sym_DQUOTE,
    STATE(264), 2,
      sym_dynamic_array,
      sym_string_literal,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1222), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62649] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2443), 1,
      sym_identifier,
    STATE(591), 1,
      aux_sym_function_definition_repeat1,
    STATE(621), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1223), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62713] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    ACTIONS(2445), 1,
      anon_sym_DQUOTE,
    STATE(1225), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1224), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62775] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    ACTIONS(2447), 1,
      anon_sym_DQUOTE,
    STATE(1204), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1225), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62837] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2449), 1,
      anon_sym_public,
    ACTIONS(2452), 1,
      anon_sym_RBRACE,
    STATE(1399), 1,
      sym_struct_field,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1226), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_struct_repeat1,
  [62899] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(727), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1227), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [62963] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2454), 1,
      anon_sym_public,
    ACTIONS(2456), 1,
      anon_sym_RBRACE,
    STATE(1226), 1,
      aux_sym_struct_repeat1,
    STATE(1399), 1,
      sym_struct_field,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1228), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63027] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(639), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1229), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63091] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    ACTIONS(2458), 1,
      anon_sym_DQUOTE,
    STATE(1204), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1230), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63153] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2460), 4,
      sym__automatic_semicolon,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(1231), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63211] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2462), 4,
      sym__automatic_semicolon,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(1232), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63269] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    ACTIONS(2464), 1,
      anon_sym_DQUOTE,
    STATE(1234), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1233), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63331] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    ACTIONS(2466), 1,
      anon_sym_DQUOTE,
    STATE(1204), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1234), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63393] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2468), 1,
      anon_sym_get,
    ACTIONS(2470), 1,
      anon_sym_set,
    STATE(1132), 2,
      sym_methodmap_property_getter,
      sym_methodmap_property_setter,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1235), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63455] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    ACTIONS(2472), 1,
      anon_sym_DQUOTE,
    STATE(1237), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1236), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63517] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    ACTIONS(2474), 1,
      anon_sym_DQUOTE,
    STATE(1204), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1237), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63579] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    ACTIONS(2476), 1,
      anon_sym_DQUOTE,
    STATE(1204), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1238), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63641] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    ACTIONS(2478), 1,
      anon_sym_DQUOTE,
    STATE(1240), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1239), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63703] = 16,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2392), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2394), 1,
      sym_escape_sequence,
    ACTIONS(2480), 1,
      anon_sym_DQUOTE,
    STATE(1204), 1,
      aux_sym_string_literal_repeat1,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1240), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63765] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2482), 1,
      anon_sym_LPAREN,
    STATE(1391), 1,
      sym_parameter_declarations,
    ACTIONS(1146), 2,
      anon_sym_LBRACK,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1241), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63827] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2484), 1,
      sym_identifier,
    STATE(621), 1,
      sym_dimension,
    STATE(1223), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1242), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63891] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1635), 1,
      anon_sym_COMMA,
    STATE(253), 1,
      sym__manual_semicolon,
    STATE(1263), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1243), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [63955] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(2488), 1,
      anon_sym_EQ,
    ACTIONS(2486), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1244), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64017] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(668), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1245), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64081] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2490), 1,
      sym_identifier,
    STATE(591), 1,
      aux_sym_function_definition_repeat1,
    STATE(621), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1246), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64145] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(376), 1,
      anon_sym_SEMI,
    ACTIONS(378), 1,
      sym__automatic_semicolon,
    STATE(526), 1,
      sym__manual_semicolon,
    STATE(666), 1,
      sym__semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1247), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64209] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(2494), 1,
      anon_sym_EQ,
    ACTIONS(2492), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1248), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64271] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(1090), 1,
      sym_parameter_declarations,
    ACTIONS(1146), 2,
      anon_sym_LBRACK,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1249), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64333] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2496), 1,
      sym_identifier,
    STATE(621), 1,
      sym_dimension,
    STATE(1213), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1250), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64397] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2498), 1,
      sym_identifier,
    STATE(591), 1,
      aux_sym_function_definition_repeat1,
    STATE(621), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1251), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64461] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2454), 1,
      anon_sym_public,
    ACTIONS(2500), 1,
      anon_sym_RBRACE,
    STATE(1228), 1,
      aux_sym_struct_repeat1,
    STATE(1399), 1,
      sym_struct_field,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1252), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64525] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    ACTIONS(1635), 1,
      anon_sym_COMMA,
    STATE(251), 1,
      sym__manual_semicolon,
    STATE(1263), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1253), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64589] = 17,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2502), 1,
      sym_identifier,
    STATE(621), 1,
      sym_dimension,
    STATE(1203), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1254), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64653] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    ACTIONS(2504), 1,
      anon_sym_RPAREN,
    STATE(1348), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1255), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64714] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2506), 1,
      anon_sym_RPAREN,
    ACTIONS(2508), 1,
      anon_sym_COMMA,
    STATE(1262), 1,
      aux_sym_parameter_declarations_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1256), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64775] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2510), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    STATE(1257), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64832] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2512), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1258), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64889] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(339), 1,
      anon_sym_COMMA,
    ACTIONS(341), 1,
      anon_sym_RBRACE,
    STATE(1267), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1259), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [64950] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    ACTIONS(2516), 1,
      anon_sym_SEMI,
    STATE(1276), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1260), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [65011] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    ACTIONS(2518), 1,
      anon_sym_RPAREN,
    STATE(1348), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1261), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [65072] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2508), 1,
      anon_sym_COMMA,
    ACTIONS(2520), 1,
      anon_sym_RPAREN,
    STATE(1335), 1,
      aux_sym_parameter_declarations_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1262), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [65133] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1703), 1,
      anon_sym_SEMI,
    ACTIONS(2522), 1,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1263), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_for_statement_repeat1,
  [65192] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    ACTIONS(2525), 1,
      anon_sym_RPAREN,
    STATE(1348), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1264), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [65253] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1963), 1,
      anon_sym_RBRACE,
    ACTIONS(2527), 1,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1265), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_array_literal_repeat1,
  [65312] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2530), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1266), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [65369] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1202), 1,
      anon_sym_RBRACE,
    ACTIONS(2532), 1,
      anon_sym_COMMA,
    STATE(1265), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1267), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [65430] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2534), 1,
      anon_sym_COMMA,
    ACTIONS(2537), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1268), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_enum_entries_repeat1,
  [65489] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(256), 1,
      sym_identifier,
    ACTIONS(1146), 1,
      anon_sym_LBRACK,
    ACTIONS(2539), 1,
      anon_sym_operator,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1269), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [65550] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    STATE(155), 1,
      aux_sym_dynamic_array_repeat1,
    STATE(164), 1,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1270), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [65611] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2542), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1271), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [65670] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2211), 1,
      anon_sym_EQ,
    ACTIONS(2209), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1272), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [65729] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2548), 1,
      anon_sym_EQ,
    ACTIONS(2546), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1273), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [65788] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2123), 1,
      anon_sym_RBRACE,
    ACTIONS(2550), 1,
      anon_sym_COMMA,
    STATE(1268), 1,
      aux_sym_enum_entries_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1274), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [65849] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2552), 1,
      anon_sym_RPAREN,
    ACTIONS(2554), 1,
      anon_sym_COMMA,
    STATE(1323), 1,
      aux_sym_preproc_macro_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1275), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [65910] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2405), 1,
      anon_sym_SEMI,
    ACTIONS(2556), 1,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1276), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_old_global_variable_declaration_repeat1,
  [65969] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2559), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    STATE(1277), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66026] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2561), 1,
      anon_sym_LT,
    ACTIONS(2563), 1,
      anon_sym_LBRACE,
    ACTIONS(2565), 1,
      anon_sym___nullable__,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1278), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66087] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1302), 1,
      anon_sym_LBRACK,
    ACTIONS(2567), 1,
      sym_identifier,
    STATE(1473), 1,
      sym_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1279), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66148] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2356), 1,
      anon_sym_LPAREN,
    ACTIONS(2360), 1,
      anon_sym_function,
    STATE(1229), 1,
      sym_typedef_expression,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1280), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66209] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(256), 1,
      sym_identifier,
    ACTIONS(1146), 1,
      anon_sym_LBRACK,
    ACTIONS(2569), 1,
      anon_sym_operator,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1281), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66270] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    ACTIONS(1660), 1,
      anon_sym_RPAREN,
    STATE(1286), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1282), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66331] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2571), 1,
      anon_sym_COMMA,
    ACTIONS(2573), 1,
      anon_sym_RBRACE,
    STATE(1274), 1,
      aux_sym_enum_entries_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1283), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66392] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2427), 1,
      sym_identifier,
    ACTIONS(2575), 1,
      anon_sym_RBRACE,
    STATE(1422), 1,
      sym_struct_field_value,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1284), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66453] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1889), 1,
      anon_sym_COMMA,
    ACTIONS(1891), 1,
      anon_sym_RBRACE,
    STATE(1288), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1285), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66514] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    ACTIONS(2577), 1,
      anon_sym_RPAREN,
    STATE(1348), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1286), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66575] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2575), 1,
      anon_sym_RBRACE,
    ACTIONS(2579), 1,
      anon_sym_COMMA,
    STATE(1312), 1,
      aux_sym_struct_constructor_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1287), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66636] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1180), 1,
      anon_sym_RBRACE,
    ACTIONS(2581), 1,
      anon_sym_COMMA,
    STATE(1265), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1288), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66697] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2583), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    STATE(1289), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66754] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    ACTIONS(2585), 1,
      anon_sym_SEMI,
    STATE(1260), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1290), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66815] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(394), 1,
      anon_sym_LBRACK,
    STATE(97), 1,
      aux_sym_dynamic_array_repeat1,
    STATE(104), 1,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1291), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66876] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2313), 3,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_function,
    STATE(1292), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66933] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2587), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1293), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [66990] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2589), 1,
      anon_sym_COMMA,
    ACTIONS(2591), 1,
      anon_sym_RBRACE,
    STATE(1300), 1,
      aux_sym_funcenum_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1294), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67051] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2593), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1295), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67108] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    ACTIONS(2585), 1,
      anon_sym_SEMI,
    STATE(1276), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1296), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67169] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2595), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1297), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67226] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2597), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1298), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67283] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2599), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    STATE(1299), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67340] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2091), 1,
      anon_sym_RBRACE,
    ACTIONS(2601), 1,
      anon_sym_COMMA,
    STATE(1321), 1,
      aux_sym_funcenum_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1300), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67401] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2508), 1,
      anon_sym_COMMA,
    ACTIONS(2603), 1,
      anon_sym_RPAREN,
    STATE(1342), 1,
      aux_sym_parameter_declarations_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1301), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67462] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2605), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1302), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67519] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1646), 1,
      anon_sym_RPAREN,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    STATE(1255), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1303), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67580] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2427), 1,
      sym_identifier,
    ACTIONS(2607), 1,
      anon_sym_RBRACE,
    STATE(1422), 1,
      sym_struct_field_value,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1304), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67641] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1915), 1,
      anon_sym_COMMA,
    ACTIONS(1917), 1,
      anon_sym_RBRACE,
    STATE(1318), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1305), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67702] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2609), 1,
      anon_sym_COMMA,
    ACTIONS(2611), 1,
      anon_sym_RBRACE,
    STATE(1287), 1,
      aux_sym_struct_constructor_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1306), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67763] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    ACTIONS(1664), 1,
      anon_sym_RPAREN,
    STATE(1261), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1307), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67824] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1196), 1,
      anon_sym_RBRACE,
    ACTIONS(2613), 1,
      anon_sym_COMMA,
    STATE(1265), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1308), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67885] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2615), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1309), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [67942] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2270), 1,
      anon_sym_COLON,
    ACTIONS(2617), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1310), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68001] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1644), 1,
      anon_sym_LBRACK,
    STATE(750), 1,
      aux_sym_dynamic_array_repeat1,
    STATE(814), 1,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1311), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68062] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2619), 1,
      anon_sym_COMMA,
    ACTIONS(2622), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1312), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_struct_constructor_repeat1,
  [68121] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2624), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1313), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68178] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    ACTIONS(1652), 1,
      anon_sym_RPAREN,
    STATE(1317), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1314), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68239] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2628), 1,
      anon_sym_EQ,
    ACTIONS(2626), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1315), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68298] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(343), 1,
      anon_sym_COMMA,
    ACTIONS(345), 1,
      anon_sym_RBRACE,
    STATE(1308), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1316), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68359] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    ACTIONS(2630), 1,
      anon_sym_RPAREN,
    STATE(1348), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1317), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68420] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1206), 1,
      anon_sym_RBRACE,
    ACTIONS(2632), 1,
      anon_sym_COMMA,
    STATE(1265), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1318), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68481] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2634), 1,
      anon_sym_RPAREN,
    ACTIONS(2636), 1,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1319), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_preproc_macro_repeat1,
  [68540] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(800), 1,
      anon_sym_LBRACK,
    STATE(227), 1,
      aux_sym_dynamic_array_repeat1,
    STATE(248), 1,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1320), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68601] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2639), 1,
      anon_sym_COMMA,
    ACTIONS(2642), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1321), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_funcenum_repeat1,
  [68660] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_RBRACE,
    STATE(1331), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1322), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68721] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2554), 1,
      anon_sym_COMMA,
    ACTIONS(2644), 1,
      anon_sym_RPAREN,
    STATE(1319), 1,
      aux_sym_preproc_macro_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1323), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68782] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2646), 1,
      anon_sym_DQUOTE,
    ACTIONS(2648), 1,
      sym_system_lib_string,
    STATE(1662), 1,
      sym_string_literal,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1324), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68843] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1955), 1,
      anon_sym_COMMA,
    ACTIONS(2650), 1,
      anon_sym_COLON2,
    STATE(1340), 1,
      aux_sym_switch_case_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1325), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68904] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2366), 1,
      anon_sym_LBRACE,
    ACTIONS(2652), 1,
      anon_sym_LPAREN,
    STATE(593), 1,
      sym_enum_entries,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1326), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [68965] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2656), 1,
      anon_sym_EQ,
    ACTIONS(2654), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1327), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69024] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2658), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1328), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69081] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2405), 3,
      sym__automatic_semicolon,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(1329), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69138] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2662), 1,
      anon_sym_EQ,
    ACTIONS(2660), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1330), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69197] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1200), 1,
      anon_sym_RBRACE,
    ACTIONS(2664), 1,
      anon_sym_COMMA,
    STATE(1265), 1,
      aux_sym_array_literal_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1331), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69258] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2666), 1,
      anon_sym_EQ,
    ACTIONS(2668), 1,
      anon_sym_LBRACE,
    STATE(1293), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1332), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69319] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2670), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1333), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69376] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1306), 1,
      anon_sym_LBRACK,
    STATE(613), 1,
      aux_sym_dynamic_array_repeat1,
    STATE(630), 1,
      sym_fixed_dimension,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1334), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69437] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2672), 1,
      anon_sym_RPAREN,
    ACTIONS(2674), 1,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1335), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_parameter_declarations_repeat1,
  [69496] = 14,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2679), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2677), 2,
      anon_sym_DQUOTE,
      sym_escape_sequence,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1336), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69553] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2681), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1337), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69610] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2683), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1338), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69667] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    ACTIONS(2685), 1,
      anon_sym_SEMI,
    STATE(1296), 1,
      aux_sym_old_global_variable_declaration_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1339), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69728] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1969), 1,
      anon_sym_COLON2,
    ACTIONS(2687), 1,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1340), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_switch_case_repeat1,
  [69787] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2221), 1,
      anon_sym_EQ,
    ACTIONS(2219), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1341), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69846] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2508), 1,
      anon_sym_COMMA,
    ACTIONS(2690), 1,
      anon_sym_RPAREN,
    STATE(1335), 1,
      aux_sym_parameter_declarations_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1342), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69907] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2692), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1343), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [69964] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2696), 1,
      anon_sym_EQ,
    ACTIONS(2694), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1344), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70023] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2698), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1345), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70080] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1648), 1,
      anon_sym_COMMA,
    ACTIONS(1656), 1,
      anon_sym_RPAREN,
    STATE(1264), 1,
      aux_sym_call_arguments_repeat1,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1346), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70141] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2700), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1347), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70198] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1709), 1,
      anon_sym_RPAREN,
    ACTIONS(2702), 1,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1348), 12,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
      aux_sym_call_arguments_repeat1,
  [70257] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2705), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1349), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70314] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    ACTIONS(2707), 3,
      anon_sym_public,
      anon_sym_RBRACE,
      anon_sym_property,
    STATE(1350), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70371] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2646), 1,
      anon_sym_DQUOTE,
    ACTIONS(2709), 1,
      sym_system_lib_string,
    STATE(1663), 1,
      sym_string_literal,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1351), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70432] = 16,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2668), 1,
      anon_sym_LBRACE,
    ACTIONS(2711), 1,
      anon_sym_EQ,
    STATE(1403), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1352), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70493] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(1361), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1353), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70551] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(1431), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1354), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70609] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(68), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1355), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70667] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2298), 1,
      sym_identifier,
    STATE(1116), 1,
      sym_variable_declaration,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1356), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70725] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(1105), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1357), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70783] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(1088), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1358), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70841] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2668), 1,
      anon_sym_LBRACE,
    STATE(1298), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1359), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70899] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(1416), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1360), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [70957] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2668), 1,
      anon_sym_LBRACE,
    STATE(1302), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1361), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71015] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1709), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1362), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71071] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2713), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1363), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71127] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2668), 1,
      anon_sym_LBRACE,
    STATE(691), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1364), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71185] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(1202), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1365), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71243] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2366), 1,
      anon_sym_LBRACE,
    STATE(601), 1,
      sym_enum_entries,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1366), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71301] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2715), 1,
      anon_sym_LBRACE,
    STATE(599), 1,
      sym_struct_constructor,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1367), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71359] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2298), 1,
      sym_identifier,
    STATE(536), 1,
      sym_variable_declaration,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1368), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71417] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2213), 1,
      sym_identifier,
    ACTIONS(2217), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1369), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71475] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    STATE(174), 1,
      sym_call_arguments,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1370), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71533] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2717), 1,
      sym_identifier,
    ACTIONS(2719), 1,
      anon_sym_COLON,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1371), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71591] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(1192), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1372), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71649] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(1537), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1373), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71707] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2366), 1,
      anon_sym_LBRACE,
    STATE(590), 1,
      sym_enum_entries,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1374), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71765] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(1189), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1375), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71823] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2715), 1,
      anon_sym_LBRACE,
    STATE(600), 1,
      sym_struct_constructor,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1376), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71881] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(1406), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1377), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71939] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2298), 1,
      sym_identifier,
    STATE(1145), 1,
      sym_variable_declaration,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1378), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [71997] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2304), 1,
      sym_identifier,
    STATE(531), 1,
      sym_dynamic_array_declaration,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1379), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72055] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2537), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1380), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72111] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2721), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1381), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72167] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2366), 1,
      anon_sym_LBRACE,
    STATE(608), 1,
      sym_enum_entries,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1382), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72225] = 13,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2723), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1383), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72279] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2298), 1,
      sym_identifier,
    STATE(1153), 1,
      sym_variable_declaration,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1384), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72337] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2725), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1385), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72393] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2284), 1,
      anon_sym_operator,
    ACTIONS(2727), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1386), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72451] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2350), 1,
      sym_identifier,
    STATE(271), 1,
      sym_dynamic_array_declaration,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1387), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72509] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2460), 2,
      anon_sym_EQ,
      anon_sym_LBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1388), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72565] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(70), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1389), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72623] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(1550), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1390), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72681] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2668), 1,
      anon_sym_LBRACE,
    STATE(1345), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1391), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72739] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2405), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1392), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72795] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(1405), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1393), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72853] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2668), 1,
      anon_sym_LBRACE,
    STATE(717), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1394), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72911] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2300), 1,
      sym_identifier,
    STATE(273), 1,
      sym_variable_declaration,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1395), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [72969] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1963), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1396), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73025] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(1418), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1397), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73083] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2634), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1398), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73139] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2729), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1399), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73195] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1094), 1,
      anon_sym_LPAREN,
    STATE(862), 1,
      sym_call_arguments,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1400), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73253] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2731), 1,
      sym_identifier,
    ACTIONS(2733), 1,
      anon_sym_public,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1401), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73311] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2427), 1,
      sym_identifier,
    STATE(1422), 1,
      sym_struct_field_value,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1402), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73369] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2735), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1403), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73425] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2737), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1404), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73481] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2668), 1,
      anon_sym_LBRACE,
    STATE(1338), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1405), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73539] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2668), 1,
      anon_sym_LBRACE,
    STATE(656), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1406), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73597] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(830), 1,
      anon_sym_LPAREN,
    STATE(695), 1,
      sym_call_arguments,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1407), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73655] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(1411), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1408), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73713] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1628), 1,
      sym_identifier,
    ACTIONS(2739), 1,
      anon_sym_operator,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1409), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73771] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2298), 1,
      sym_identifier,
    STATE(1119), 1,
      sym_variable_declaration,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1410), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73829] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2741), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1411), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73885] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(1610), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1412), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [73943] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(605), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1413), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74001] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(1100), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1414), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74059] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(1433), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1415), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74117] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2668), 1,
      anon_sym_LBRACE,
    STATE(1337), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1416), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74175] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2300), 1,
      sym_identifier,
    STATE(226), 1,
      sym_variable_declaration,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1417), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74233] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2668), 1,
      anon_sym_LBRACE,
    STATE(694), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1418), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74291] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(125), 1,
      anon_sym_LPAREN,
    STATE(130), 1,
      sym_call_arguments,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1419), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74349] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2642), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1420), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74405] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1628), 1,
      sym_identifier,
    ACTIONS(2743), 1,
      anon_sym_operator,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1421), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74463] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2622), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1422), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74519] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(606), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1423), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74577] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2668), 1,
      anon_sym_LBRACE,
    STATE(1403), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1424), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74635] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2298), 1,
      sym_identifier,
    STATE(501), 1,
      sym_variable_declaration,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1425), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74693] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2746), 1,
      anon_sym_LPAREN,
    STATE(958), 1,
      sym_call_arguments,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1426), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74751] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(1465), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1427), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74809] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2300), 1,
      sym_identifier,
    STATE(217), 1,
      sym_variable_declaration,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1428), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74867] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2748), 1,
      anon_sym_RPAREN,
    ACTIONS(2750), 1,
      sym_macro_param,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1429), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74925] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    STATE(276), 1,
      sym__manual_semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1430), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [74983] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2752), 1,
      anon_sym_LBRACE,
    STATE(1065), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1431), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75041] = 13,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2754), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1432), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75095] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2756), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1433), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75151] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2758), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1434), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75207] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(595), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1435), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75265] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2278), 1,
      anon_sym_operator,
    ACTIONS(2760), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1436), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75323] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2672), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1437), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75379] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(1098), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1438), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75437] = 13,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2762), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1439), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75491] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2764), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1440), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75547] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2752), 1,
      anon_sym_LBRACE,
    STATE(1072), 1,
      sym_block,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1441), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75605] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2766), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1442), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75661] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    STATE(1359), 1,
      sym_parameter_declarations,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1443), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75719] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(333), 1,
      anon_sym_LPAREN,
    STATE(1217), 1,
      sym_call_arguments,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1444), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75777] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2217), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2768), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1445), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75835] = 13,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2770), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1446), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75889] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2772), 1,
      anon_sym_LPAREN,
    ACTIONS(2774), 1,
      sym_preproc_arg,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1447), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [75947] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(2776), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1448), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76005] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2298), 1,
      sym_identifier,
    STATE(504), 1,
      sym_variable_declaration,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1449), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76063] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2778), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1450), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76121] = 13,
    ACTIONS(2370), 1,
      anon_sym_POUNDinclude,
    ACTIONS(2372), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(2374), 1,
      anon_sym_POUNDdefine,
    ACTIONS(2376), 1,
      anon_sym_POUNDundef,
    ACTIONS(2378), 1,
      anon_sym_POUNDif,
    ACTIONS(2380), 1,
      anon_sym_POUNDelseif,
    ACTIONS(2382), 1,
      anon_sym_POUNDassert,
    ACTIONS(2384), 1,
      anon_sym_POUNDpragma,
    ACTIONS(2386), 1,
      anon_sym_POUNDerror,
    ACTIONS(2388), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2780), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
    ACTIONS(17), 4,
      sym_preproc_else,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1451), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76175] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2191), 1,
      sym_identifier,
    ACTIONS(2195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1452), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76233] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    STATE(278), 1,
      sym__manual_semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1453), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76291] = 15,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(386), 1,
      anon_sym_SEMI,
    STATE(281), 1,
      sym__manual_semicolon,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1454), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76349] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2782), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1455), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76405] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2784), 2,
      anon_sym_public,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1456), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76461] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2786), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1457), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76516] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2788), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1458), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76571] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2790), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1459), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76626] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2792), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1460), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76681] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2794), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1461), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76736] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2796), 1,
      sym_preproc_arg,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1462), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76791] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(982), 1,
      anon_sym_RBRACK,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1463), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76846] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2798), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1464), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76901] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2800), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1465), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [76956] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2802), 1,
      sym_preproc_arg,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1466), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77011] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2191), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1467), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77066] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2804), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1468), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77121] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2806), 1,
      anon_sym_SQUOTE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1469), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77176] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2808), 1,
      sym_alias_operator,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1470), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77231] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1731), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1471), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77286] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2810), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1472), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77341] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2812), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1473), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77396] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2814), 1,
      anon_sym_while,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1474), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77451] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2816), 1,
      anon_sym_function,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1475), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77506] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2818), 1,
      anon_sym_SQUOTE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1476), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77561] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2820), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1477), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77616] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2822), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1478), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77671] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1763), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1479), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77726] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2824), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1480), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77781] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2567), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1481), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77836] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2826), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1482), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77891] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2828), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1483), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [77946] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2830), 1,
      sym_alias_operator,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1484), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78001] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2832), 1,
      sym_alias_operator,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1485), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78056] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2834), 1,
      sym_preproc_arg,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1486), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78111] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2836), 1,
      sym_preproc_arg,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1487), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78166] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2838), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1488), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78221] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1204), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1489), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78276] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(978), 1,
      anon_sym_RBRACK,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1490), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78331] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2840), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1491), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78386] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2842), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1492), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78441] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2462), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1493), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78496] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2844), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1494), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78551] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2846), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1495), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78606] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2848), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1496), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78661] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2850), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1497), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78716] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1733), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1498), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78771] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2852), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1499), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78826] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2854), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1500), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78881] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1735), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1501), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78936] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2856), 1,
      sym_preproc_arg,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1502), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [78991] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2858), 1,
      anon_sym_public,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1503), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79046] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1737), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1504), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79101] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2860), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1505), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79156] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2862), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1506), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79211] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1739), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1507), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79266] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1741), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1508), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79321] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2864), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1509), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79376] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2866), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1510), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79431] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1743), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1511), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79486] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2868), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1512), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79541] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2870), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1513), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79596] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(988), 1,
      anon_sym_RBRACK,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1514), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79651] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2872), 1,
      sym_alias_operator,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1515), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79706] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2874), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1516), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79761] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1695), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1517), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79816] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2876), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1518), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79871] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2878), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1519), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79926] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2880), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1520), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [79981] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2882), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1521), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80036] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1745), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1522), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80091] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2884), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1523), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80146] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2886), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1524), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80201] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2888), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1525), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80256] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2890), 1,
      anon_sym_SQUOTE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1526), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80311] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2892), 1,
      anon_sym_LT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1527), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80366] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2894), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1528), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80421] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2896), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1529), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80476] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2898), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1530), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80531] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1901), 1,
      anon_sym_COLON,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1531), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80586] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2900), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1532), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80641] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2902), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1533), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80696] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2904), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1534), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80751] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2906), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1535), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80806] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1194), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1536), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80861] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2908), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1537), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80916] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2910), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1538), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [80971] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2912), 1,
      anon_sym_public,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1539), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81026] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2914), 1,
      anon_sym_COLON,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1540), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81081] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2916), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1541), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81136] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2918), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1542), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81191] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2920), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1543), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81246] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(990), 1,
      anon_sym_RBRACK,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1544), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81301] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1198), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1545), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81356] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2922), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1546), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81411] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2255), 1,
      anon_sym_COLON,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1547), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81466] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2768), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1548), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81521] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2924), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1549), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81576] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2926), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1550), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81631] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1749), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1551), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81686] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2928), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1552), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81741] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2930), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1553), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81796] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1554), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81851] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2934), 1,
      anon_sym_SQUOTE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1555), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81906] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2936), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1556), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [81961] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1190), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1557), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82016] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1747), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1558), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82071] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2938), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1559), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82126] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2940), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1560), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82181] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1192), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1561), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82236] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2942), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1562), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82291] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2944), 1,
      sym_preproc_arg,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1563), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82346] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2946), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1564), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82401] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2948), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1565), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82456] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1697), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1566), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82511] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2950), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1567), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82566] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2778), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1568), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82621] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2952), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1569), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82676] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2611), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1570), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82731] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2954), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1571), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82786] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2956), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1572), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82841] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2958), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1573), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82896] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2960), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1574), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [82951] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2962), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1575), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83006] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2964), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1576), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83061] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2966), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1577), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83116] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2968), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1578), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83171] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2970), 1,
      anon_sym_COLON,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1579), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83226] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2972), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1580), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83281] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2974), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1581), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83336] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2976), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1582), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83391] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2978), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1583), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83446] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2270), 1,
      anon_sym_COLON,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1584), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83501] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1753), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1585), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83556] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(576), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1586), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83611] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2980), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1587), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83666] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2982), 1,
      sym_preproc_arg,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1588), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83721] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2573), 1,
      anon_sym_RBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1589), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83776] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1719), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1590), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83831] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2984), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1591), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83886] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2213), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1592), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83941] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2986), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1593), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [83996] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2988), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1594), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84051] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2990), 1,
      sym_alias_operator,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1595), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84106] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2992), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1596), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84161] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2994), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1597), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84216] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2996), 1,
      sym_preproc_arg,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1598), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84271] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1699), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1599), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84326] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1683), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1600), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84381] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(2998), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1601), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84436] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3000), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1602), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84491] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3002), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1603), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84546] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3004), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1604), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84601] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3006), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1605), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84656] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3008), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1606), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84711] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3010), 1,
      sym_preproc_arg,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1607), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84766] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1721), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1608), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84821] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3012), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1609), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84876] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3014), 1,
      anon_sym_EQ,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1610), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84931] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3016), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1611), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [84986] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3018), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1612), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85041] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1723), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1613), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85096] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3020), 1,
      anon_sym_SQUOTE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1614), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85151] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3022), 1,
      sym_alias_operator,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1615), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85206] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1713), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1616), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85261] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3024), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1617), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85316] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3026), 1,
      anon_sym_LBRACE,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1618), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85371] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3028), 1,
      anon_sym_COLON2,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1619), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85426] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3030), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1620), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85481] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3032), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1621), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85536] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1725), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1622), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85591] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1727), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1623), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85646] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3034), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1624), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85701] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3036), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1625), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85756] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3038), 1,
      sym_alias_operator,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1626), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85811] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3040), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1627), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85866] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3042), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1628), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85921] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3044), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1629), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [85976] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3046), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1630), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86031] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3048), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1631), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86086] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3050), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1632), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86141] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3052), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1633), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86196] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3054), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1634), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86251] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3056), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1635), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86306] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3058), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1636), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86361] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3060), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1637), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86416] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3062), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1638), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86471] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3064), 1,
      sym_identifier,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1639), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86526] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3066), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1640), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86581] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3068), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1641), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86636] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3070), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1642), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86691] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3072), 1,
      anon_sym_while,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1643), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86746] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(954), 1,
      anon_sym_RBRACK,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1644), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86801] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3074), 1,
      anon_sym_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1645), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86856] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3076), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1646), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86911] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3078), 1,
      anon_sym_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1647), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [86966] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3080), 1,
      anon_sym_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1648), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [87021] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3082), 1,
      anon_sym_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1649), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [87076] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3084), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1650), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [87131] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3086), 1,
      ts_builtin_sym_end,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1651), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [87186] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3088), 1,
      anon_sym_GT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1652), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [87241] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(1729), 1,
      anon_sym_RPAREN,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1653), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [87296] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3090), 1,
      anon_sym_LT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1654), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [87351] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3092), 1,
      anon_sym_LT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1655), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [87406] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3094), 1,
      anon_sym_LT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1656), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [87461] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3096), 1,
      anon_sym_LT,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1657), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [87516] = 14,
    ACTIONS(3), 1,
      anon_sym_POUNDinclude,
    ACTIONS(5), 1,
      anon_sym_POUNDtryinclude,
    ACTIONS(7), 1,
      anon_sym_POUNDdefine,
    ACTIONS(9), 1,
      anon_sym_POUNDundef,
    ACTIONS(11), 1,
      anon_sym_POUNDif,
    ACTIONS(13), 1,
      anon_sym_POUNDelseif,
    ACTIONS(15), 1,
      anon_sym_POUNDassert,
    ACTIONS(17), 1,
      sym_preproc_else,
    ACTIONS(21), 1,
      anon_sym_POUNDpragma,
    ACTIONS(23), 1,
      anon_sym_POUNDerror,
    ACTIONS(25), 1,
      anon_sym_POUNDwarning,
    ACTIONS(3098), 1,
      sym_macro_param,
    ACTIONS(19), 3,
      sym_preproc_endif,
      sym_preproc_endinput,
      sym_comment,
    STATE(1658), 11,
      sym_preproc_include,
      sym_preproc_tryinclude,
      sym_preproc_macro,
      sym_preproc_define,
      sym_preproc_undefine,
      sym_preproc_if,
      sym_preproc_elseif,
      sym_preproc_assert,
      sym_preproc_pragma,
      sym_preproc_error,
      sym_preproc_warning,
  [87571] = 1,
    ACTIONS(3100), 1,
      ts_builtin_sym_end,
  [87575] = 1,
    ACTIONS(3102), 1,
      ts_builtin_sym_end,
  [87579] = 1,
    ACTIONS(588), 1,
      ts_builtin_sym_end,
  [87583] = 1,
    ACTIONS(3104), 1,
      ts_builtin_sym_end,
  [87587] = 1,
    ACTIONS(3106), 1,
      ts_builtin_sym_end,
  [87591] = 1,
    ACTIONS(3108), 1,
      ts_builtin_sym_end,
  [87595] = 1,
    ACTIONS(3110), 1,
      ts_builtin_sym_end,
  [87599] = 1,
    ACTIONS(3112), 1,
      ts_builtin_sym_end,
  [87603] = 1,
    ACTIONS(3114), 1,
      ts_builtin_sym_end,
  [87607] = 1,
    ACTIONS(3116), 1,
      ts_builtin_sym_end,
  [87611] = 1,
    ACTIONS(3118), 1,
      ts_builtin_sym_end,
  [87615] = 1,
    ACTIONS(584), 1,
      ts_builtin_sym_end,
  [87619] = 1,
    ACTIONS(3120), 1,
      ts_builtin_sym_end,
  [87623] = 1,
    ACTIONS(3122), 1,
      ts_builtin_sym_end,
  [87627] = 1,
    ACTIONS(3124), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(510)] = 0,
  [SMALL_STATE(511)] = 103,
  [SMALL_STATE(512)] = 198,
  [SMALL_STATE(513)] = 293,
  [SMALL_STATE(514)] = 394,
  [SMALL_STATE(515)] = 495,
  [SMALL_STATE(516)] = 591,
  [SMALL_STATE(517)] = 693,
  [SMALL_STATE(518)] = 789,
  [SMALL_STATE(519)] = 891,
  [SMALL_STATE(520)] = 985,
  [SMALL_STATE(521)] = 1079,
  [SMALL_STATE(522)] = 1181,
  [SMALL_STATE(523)] = 1279,
  [SMALL_STATE(524)] = 1381,
  [SMALL_STATE(525)] = 1479,
  [SMALL_STATE(526)] = 1573,
  [SMALL_STATE(527)] = 1667,
  [SMALL_STATE(528)] = 1769,
  [SMALL_STATE(529)] = 1900,
  [SMALL_STATE(530)] = 2031,
  [SMALL_STATE(531)] = 2124,
  [SMALL_STATE(532)] = 2217,
  [SMALL_STATE(533)] = 2348,
  [SMALL_STATE(534)] = 2479,
  [SMALL_STATE(535)] = 2610,
  [SMALL_STATE(536)] = 2741,
  [SMALL_STATE(537)] = 2834,
  [SMALL_STATE(538)] = 2965,
  [SMALL_STATE(539)] = 3096,
  [SMALL_STATE(540)] = 3227,
  [SMALL_STATE(541)] = 3358,
  [SMALL_STATE(542)] = 3450,
  [SMALL_STATE(543)] = 3542,
  [SMALL_STATE(544)] = 3634,
  [SMALL_STATE(545)] = 3726,
  [SMALL_STATE(546)] = 3817,
  [SMALL_STATE(547)] = 3908,
  [SMALL_STATE(548)] = 3999,
  [SMALL_STATE(549)] = 4090,
  [SMALL_STATE(550)] = 4181,
  [SMALL_STATE(551)] = 4272,
  [SMALL_STATE(552)] = 4363,
  [SMALL_STATE(553)] = 4454,
  [SMALL_STATE(554)] = 4545,
  [SMALL_STATE(555)] = 4635,
  [SMALL_STATE(556)] = 4725,
  [SMALL_STATE(557)] = 4815,
  [SMALL_STATE(558)] = 4905,
  [SMALL_STATE(559)] = 4995,
  [SMALL_STATE(560)] = 5085,
  [SMALL_STATE(561)] = 5175,
  [SMALL_STATE(562)] = 5265,
  [SMALL_STATE(563)] = 5355,
  [SMALL_STATE(564)] = 5445,
  [SMALL_STATE(565)] = 5535,
  [SMALL_STATE(566)] = 5625,
  [SMALL_STATE(567)] = 5715,
  [SMALL_STATE(568)] = 5805,
  [SMALL_STATE(569)] = 5895,
  [SMALL_STATE(570)] = 5985,
  [SMALL_STATE(571)] = 6075,
  [SMALL_STATE(572)] = 6165,
  [SMALL_STATE(573)] = 6255,
  [SMALL_STATE(574)] = 6345,
  [SMALL_STATE(575)] = 6435,
  [SMALL_STATE(576)] = 6557,
  [SMALL_STATE(577)] = 6647,
  [SMALL_STATE(578)] = 6737,
  [SMALL_STATE(579)] = 6827,
  [SMALL_STATE(580)] = 6917,
  [SMALL_STATE(581)] = 7039,
  [SMALL_STATE(582)] = 7161,
  [SMALL_STATE(583)] = 7283,
  [SMALL_STATE(584)] = 7405,
  [SMALL_STATE(585)] = 7495,
  [SMALL_STATE(586)] = 7617,
  [SMALL_STATE(587)] = 7706,
  [SMALL_STATE(588)] = 7803,
  [SMALL_STATE(589)] = 7900,
  [SMALL_STATE(590)] = 7989,
  [SMALL_STATE(591)] = 8086,
  [SMALL_STATE(592)] = 8179,
  [SMALL_STATE(593)] = 8276,
  [SMALL_STATE(594)] = 8373,
  [SMALL_STATE(595)] = 8470,
  [SMALL_STATE(596)] = 8567,
  [SMALL_STATE(597)] = 8664,
  [SMALL_STATE(598)] = 8761,
  [SMALL_STATE(599)] = 8858,
  [SMALL_STATE(600)] = 8955,
  [SMALL_STATE(601)] = 9052,
  [SMALL_STATE(602)] = 9149,
  [SMALL_STATE(603)] = 9246,
  [SMALL_STATE(604)] = 9343,
  [SMALL_STATE(605)] = 9440,
  [SMALL_STATE(606)] = 9537,
  [SMALL_STATE(607)] = 9634,
  [SMALL_STATE(608)] = 9731,
  [SMALL_STATE(609)] = 9828,
  [SMALL_STATE(610)] = 9925,
  [SMALL_STATE(611)] = 10022,
  [SMALL_STATE(612)] = 10114,
  [SMALL_STATE(613)] = 10210,
  [SMALL_STATE(614)] = 10304,
  [SMALL_STATE(615)] = 10398,
  [SMALL_STATE(616)] = 10485,
  [SMALL_STATE(617)] = 10572,
  [SMALL_STATE(618)] = 10659,
  [SMALL_STATE(619)] = 10746,
  [SMALL_STATE(620)] = 10833,
  [SMALL_STATE(621)] = 10920,
  [SMALL_STATE(622)] = 11007,
  [SMALL_STATE(623)] = 11094,
  [SMALL_STATE(624)] = 11181,
  [SMALL_STATE(625)] = 11267,
  [SMALL_STATE(626)] = 11353,
  [SMALL_STATE(627)] = 11439,
  [SMALL_STATE(628)] = 11525,
  [SMALL_STATE(629)] = 11611,
  [SMALL_STATE(630)] = 11697,
  [SMALL_STATE(631)] = 11783,
  [SMALL_STATE(632)] = 11869,
  [SMALL_STATE(633)] = 11955,
  [SMALL_STATE(634)] = 12041,
  [SMALL_STATE(635)] = 12127,
  [SMALL_STATE(636)] = 12215,
  [SMALL_STATE(637)] = 12301,
  [SMALL_STATE(638)] = 12387,
  [SMALL_STATE(639)] = 12473,
  [SMALL_STATE(640)] = 12558,
  [SMALL_STATE(641)] = 12667,
  [SMALL_STATE(642)] = 12776,
  [SMALL_STATE(643)] = 12885,
  [SMALL_STATE(644)] = 12970,
  [SMALL_STATE(645)] = 13055,
  [SMALL_STATE(646)] = 13140,
  [SMALL_STATE(647)] = 13225,
  [SMALL_STATE(648)] = 13310,
  [SMALL_STATE(649)] = 13395,
  [SMALL_STATE(650)] = 13480,
  [SMALL_STATE(651)] = 13565,
  [SMALL_STATE(652)] = 13650,
  [SMALL_STATE(653)] = 13735,
  [SMALL_STATE(654)] = 13820,
  [SMALL_STATE(655)] = 13905,
  [SMALL_STATE(656)] = 13990,
  [SMALL_STATE(657)] = 14075,
  [SMALL_STATE(658)] = 14160,
  [SMALL_STATE(659)] = 14245,
  [SMALL_STATE(660)] = 14332,
  [SMALL_STATE(661)] = 14417,
  [SMALL_STATE(662)] = 14502,
  [SMALL_STATE(663)] = 14591,
  [SMALL_STATE(664)] = 14676,
  [SMALL_STATE(665)] = 14761,
  [SMALL_STATE(666)] = 14846,
  [SMALL_STATE(667)] = 14931,
  [SMALL_STATE(668)] = 15018,
  [SMALL_STATE(669)] = 15103,
  [SMALL_STATE(670)] = 15188,
  [SMALL_STATE(671)] = 15273,
  [SMALL_STATE(672)] = 15358,
  [SMALL_STATE(673)] = 15443,
  [SMALL_STATE(674)] = 15528,
  [SMALL_STATE(675)] = 15613,
  [SMALL_STATE(676)] = 15698,
  [SMALL_STATE(677)] = 15783,
  [SMALL_STATE(678)] = 15868,
  [SMALL_STATE(679)] = 15953,
  [SMALL_STATE(680)] = 16038,
  [SMALL_STATE(681)] = 16123,
  [SMALL_STATE(682)] = 16208,
  [SMALL_STATE(683)] = 16293,
  [SMALL_STATE(684)] = 16378,
  [SMALL_STATE(685)] = 16463,
  [SMALL_STATE(686)] = 16548,
  [SMALL_STATE(687)] = 16633,
  [SMALL_STATE(688)] = 16718,
  [SMALL_STATE(689)] = 16803,
  [SMALL_STATE(690)] = 16888,
  [SMALL_STATE(691)] = 16973,
  [SMALL_STATE(692)] = 17058,
  [SMALL_STATE(693)] = 17167,
  [SMALL_STATE(694)] = 17252,
  [SMALL_STATE(695)] = 17337,
  [SMALL_STATE(696)] = 17422,
  [SMALL_STATE(697)] = 17507,
  [SMALL_STATE(698)] = 17592,
  [SMALL_STATE(699)] = 17677,
  [SMALL_STATE(700)] = 17762,
  [SMALL_STATE(701)] = 17847,
  [SMALL_STATE(702)] = 17932,
  [SMALL_STATE(703)] = 18049,
  [SMALL_STATE(704)] = 18142,
  [SMALL_STATE(705)] = 18249,
  [SMALL_STATE(706)] = 18338,
  [SMALL_STATE(707)] = 18451,
  [SMALL_STATE(708)] = 18562,
  [SMALL_STATE(709)] = 18673,
  [SMALL_STATE(710)] = 18782,
  [SMALL_STATE(711)] = 18887,
  [SMALL_STATE(712)] = 18988,
  [SMALL_STATE(713)] = 19085,
  [SMALL_STATE(714)] = 19170,
  [SMALL_STATE(715)] = 19255,
  [SMALL_STATE(716)] = 19340,
  [SMALL_STATE(717)] = 19425,
  [SMALL_STATE(718)] = 19510,
  [SMALL_STATE(719)] = 19595,
  [SMALL_STATE(720)] = 19680,
  [SMALL_STATE(721)] = 19765,
  [SMALL_STATE(722)] = 19882,
  [SMALL_STATE(723)] = 19967,
  [SMALL_STATE(724)] = 20076,
  [SMALL_STATE(725)] = 20161,
  [SMALL_STATE(726)] = 20246,
  [SMALL_STATE(727)] = 20331,
  [SMALL_STATE(728)] = 20416,
  [SMALL_STATE(729)] = 20501,
  [SMALL_STATE(730)] = 20586,
  [SMALL_STATE(731)] = 20671,
  [SMALL_STATE(732)] = 20756,
  [SMALL_STATE(733)] = 20865,
  [SMALL_STATE(734)] = 20950,
  [SMALL_STATE(735)] = 21059,
  [SMALL_STATE(736)] = 21168,
  [SMALL_STATE(737)] = 21253,
  [SMALL_STATE(738)] = 21362,
  [SMALL_STATE(739)] = 21471,
  [SMALL_STATE(740)] = 21580,
  [SMALL_STATE(741)] = 21689,
  [SMALL_STATE(742)] = 21798,
  [SMALL_STATE(743)] = 21882,
  [SMALL_STATE(744)] = 21970,
  [SMALL_STATE(745)] = 22062,
  [SMALL_STATE(746)] = 22152,
  [SMALL_STATE(747)] = 22244,
  [SMALL_STATE(748)] = 22336,
  [SMALL_STATE(749)] = 22428,
  [SMALL_STATE(750)] = 22516,
  [SMALL_STATE(751)] = 22606,
  [SMALL_STATE(752)] = 22725,
  [SMALL_STATE(753)] = 22840,
  [SMALL_STATE(754)] = 22959,
  [SMALL_STATE(755)] = 23074,
  [SMALL_STATE(756)] = 23193,
  [SMALL_STATE(757)] = 23308,
  [SMALL_STATE(758)] = 23427,
  [SMALL_STATE(759)] = 23542,
  [SMALL_STATE(760)] = 23661,
  [SMALL_STATE(761)] = 23745,
  [SMALL_STATE(762)] = 23859,
  [SMALL_STATE(763)] = 23973,
  [SMALL_STATE(764)] = 24059,
  [SMALL_STATE(765)] = 24173,
  [SMALL_STATE(766)] = 24287,
  [SMALL_STATE(767)] = 24401,
  [SMALL_STATE(768)] = 24515,
  [SMALL_STATE(769)] = 24629,
  [SMALL_STATE(770)] = 24719,
  [SMALL_STATE(771)] = 24835,
  [SMALL_STATE(772)] = 24951,
  [SMALL_STATE(773)] = 25065,
  [SMALL_STATE(774)] = 25151,
  [SMALL_STATE(775)] = 25265,
  [SMALL_STATE(776)] = 25379,
  [SMALL_STATE(777)] = 25493,
  [SMALL_STATE(778)] = 25607,
  [SMALL_STATE(779)] = 25723,
  [SMALL_STATE(780)] = 25839,
  [SMALL_STATE(781)] = 25955,
  [SMALL_STATE(782)] = 26071,
  [SMALL_STATE(783)] = 26187,
  [SMALL_STATE(784)] = 26301,
  [SMALL_STATE(785)] = 26385,
  [SMALL_STATE(786)] = 26499,
  [SMALL_STATE(787)] = 26613,
  [SMALL_STATE(788)] = 26695,
  [SMALL_STATE(789)] = 26809,
  [SMALL_STATE(790)] = 26923,
  [SMALL_STATE(791)] = 27039,
  [SMALL_STATE(792)] = 27121,
  [SMALL_STATE(793)] = 27235,
  [SMALL_STATE(794)] = 27349,
  [SMALL_STATE(795)] = 27465,
  [SMALL_STATE(796)] = 27581,
  [SMALL_STATE(797)] = 27697,
  [SMALL_STATE(798)] = 27813,
  [SMALL_STATE(799)] = 27929,
  [SMALL_STATE(800)] = 28045,
  [SMALL_STATE(801)] = 28159,
  [SMALL_STATE(802)] = 28275,
  [SMALL_STATE(803)] = 28357,
  [SMALL_STATE(804)] = 28473,
  [SMALL_STATE(805)] = 28589,
  [SMALL_STATE(806)] = 28705,
  [SMALL_STATE(807)] = 28821,
  [SMALL_STATE(808)] = 28937,
  [SMALL_STATE(809)] = 29053,
  [SMALL_STATE(810)] = 29167,
  [SMALL_STATE(811)] = 29283,
  [SMALL_STATE(812)] = 29399,
  [SMALL_STATE(813)] = 29515,
  [SMALL_STATE(814)] = 29631,
  [SMALL_STATE(815)] = 29713,
  [SMALL_STATE(816)] = 29829,
  [SMALL_STATE(817)] = 29943,
  [SMALL_STATE(818)] = 30059,
  [SMALL_STATE(819)] = 30175,
  [SMALL_STATE(820)] = 30291,
  [SMALL_STATE(821)] = 30405,
  [SMALL_STATE(822)] = 30521,
  [SMALL_STATE(823)] = 30637,
  [SMALL_STATE(824)] = 30753,
  [SMALL_STATE(825)] = 30867,
  [SMALL_STATE(826)] = 30981,
  [SMALL_STATE(827)] = 31095,
  [SMALL_STATE(828)] = 31181,
  [SMALL_STATE(829)] = 31297,
  [SMALL_STATE(830)] = 31404,
  [SMALL_STATE(831)] = 31489,
  [SMALL_STATE(832)] = 31602,
  [SMALL_STATE(833)] = 31715,
  [SMALL_STATE(834)] = 31828,
  [SMALL_STATE(835)] = 31941,
  [SMALL_STATE(836)] = 32022,
  [SMALL_STATE(837)] = 32103,
  [SMALL_STATE(838)] = 32216,
  [SMALL_STATE(839)] = 32297,
  [SMALL_STATE(840)] = 32380,
  [SMALL_STATE(841)] = 32467,
  [SMALL_STATE(842)] = 32548,
  [SMALL_STATE(843)] = 32629,
  [SMALL_STATE(844)] = 32710,
  [SMALL_STATE(845)] = 32791,
  [SMALL_STATE(846)] = 32904,
  [SMALL_STATE(847)] = 32985,
  [SMALL_STATE(848)] = 33066,
  [SMALL_STATE(849)] = 33179,
  [SMALL_STATE(850)] = 33292,
  [SMALL_STATE(851)] = 33405,
  [SMALL_STATE(852)] = 33518,
  [SMALL_STATE(853)] = 33599,
  [SMALL_STATE(854)] = 33712,
  [SMALL_STATE(855)] = 33801,
  [SMALL_STATE(856)] = 33914,
  [SMALL_STATE(857)] = 34017,
  [SMALL_STATE(858)] = 34130,
  [SMALL_STATE(859)] = 34215,
  [SMALL_STATE(860)] = 34324,
  [SMALL_STATE(861)] = 34405,
  [SMALL_STATE(862)] = 34518,
  [SMALL_STATE(863)] = 34599,
  [SMALL_STATE(864)] = 34712,
  [SMALL_STATE(865)] = 34825,
  [SMALL_STATE(866)] = 34938,
  [SMALL_STATE(867)] = 35045,
  [SMALL_STATE(868)] = 35126,
  [SMALL_STATE(869)] = 35231,
  [SMALL_STATE(870)] = 35344,
  [SMALL_STATE(871)] = 35457,
  [SMALL_STATE(872)] = 35570,
  [SMALL_STATE(873)] = 35683,
  [SMALL_STATE(874)] = 35764,
  [SMALL_STATE(875)] = 35877,
  [SMALL_STATE(876)] = 35978,
  [SMALL_STATE(877)] = 36059,
  [SMALL_STATE(878)] = 36172,
  [SMALL_STATE(879)] = 36285,
  [SMALL_STATE(880)] = 36398,
  [SMALL_STATE(881)] = 36479,
  [SMALL_STATE(882)] = 36576,
  [SMALL_STATE(883)] = 36657,
  [SMALL_STATE(884)] = 36750,
  [SMALL_STATE(885)] = 36863,
  [SMALL_STATE(886)] = 36944,
  [SMALL_STATE(887)] = 37057,
  [SMALL_STATE(888)] = 37138,
  [SMALL_STATE(889)] = 37219,
  [SMALL_STATE(890)] = 37332,
  [SMALL_STATE(891)] = 37413,
  [SMALL_STATE(892)] = 37494,
  [SMALL_STATE(893)] = 37607,
  [SMALL_STATE(894)] = 37690,
  [SMALL_STATE(895)] = 37803,
  [SMALL_STATE(896)] = 37916,
  [SMALL_STATE(897)] = 38029,
  [SMALL_STATE(898)] = 38142,
  [SMALL_STATE(899)] = 38222,
  [SMALL_STATE(900)] = 38332,
  [SMALL_STATE(901)] = 38432,
  [SMALL_STATE(902)] = 38532,
  [SMALL_STATE(903)] = 38642,
  [SMALL_STATE(904)] = 38722,
  [SMALL_STATE(905)] = 38802,
  [SMALL_STATE(906)] = 38882,
  [SMALL_STATE(907)] = 38962,
  [SMALL_STATE(908)] = 39042,
  [SMALL_STATE(909)] = 39122,
  [SMALL_STATE(910)] = 39202,
  [SMALL_STATE(911)] = 39282,
  [SMALL_STATE(912)] = 39382,
  [SMALL_STATE(913)] = 39482,
  [SMALL_STATE(914)] = 39582,
  [SMALL_STATE(915)] = 39682,
  [SMALL_STATE(916)] = 39782,
  [SMALL_STATE(917)] = 39882,
  [SMALL_STATE(918)] = 39982,
  [SMALL_STATE(919)] = 40082,
  [SMALL_STATE(920)] = 40182,
  [SMALL_STATE(921)] = 40282,
  [SMALL_STATE(922)] = 40362,
  [SMALL_STATE(923)] = 40472,
  [SMALL_STATE(924)] = 40582,
  [SMALL_STATE(925)] = 40689,
  [SMALL_STATE(926)] = 40772,
  [SMALL_STATE(927)] = 40867,
  [SMALL_STATE(928)] = 40948,
  [SMALL_STATE(929)] = 41055,
  [SMALL_STATE(930)] = 41134,
  [SMALL_STATE(931)] = 41213,
  [SMALL_STATE(932)] = 41314,
  [SMALL_STATE(933)] = 41413,
  [SMALL_STATE(934)] = 41512,
  [SMALL_STATE(935)] = 41591,
  [SMALL_STATE(936)] = 41670,
  [SMALL_STATE(937)] = 41767,
  [SMALL_STATE(938)] = 41860,
  [SMALL_STATE(939)] = 41967,
  [SMALL_STATE(940)] = 42074,
  [SMALL_STATE(941)] = 42181,
  [SMALL_STATE(942)] = 42270,
  [SMALL_STATE(943)] = 42349,
  [SMALL_STATE(944)] = 42434,
  [SMALL_STATE(945)] = 42515,
  [SMALL_STATE(946)] = 42622,
  [SMALL_STATE(947)] = 42700,
  [SMALL_STATE(948)] = 42778,
  [SMALL_STATE(949)] = 42860,
  [SMALL_STATE(950)] = 42938,
  [SMALL_STATE(951)] = 43032,
  [SMALL_STATE(952)] = 43110,
  [SMALL_STATE(953)] = 43188,
  [SMALL_STATE(954)] = 43288,
  [SMALL_STATE(955)] = 43366,
  [SMALL_STATE(956)] = 43444,
  [SMALL_STATE(957)] = 43522,
  [SMALL_STATE(958)] = 43600,
  [SMALL_STATE(959)] = 43678,
  [SMALL_STATE(960)] = 43756,
  [SMALL_STATE(961)] = 43834,
  [SMALL_STATE(962)] = 43912,
  [SMALL_STATE(963)] = 44014,
  [SMALL_STATE(964)] = 44092,
  [SMALL_STATE(965)] = 44190,
  [SMALL_STATE(966)] = 44288,
  [SMALL_STATE(967)] = 44384,
  [SMALL_STATE(968)] = 44476,
  [SMALL_STATE(969)] = 44564,
  [SMALL_STATE(970)] = 44648,
  [SMALL_STATE(971)] = 44750,
  [SMALL_STATE(972)] = 44853,
  [SMALL_STATE(973)] = 44954,
  [SMALL_STATE(974)] = 45057,
  [SMALL_STATE(975)] = 45160,
  [SMALL_STATE(976)] = 45260,
  [SMALL_STATE(977)] = 45359,
  [SMALL_STATE(978)] = 45458,
  [SMALL_STATE(979)] = 45551,
  [SMALL_STATE(980)] = 45644,
  [SMALL_STATE(981)] = 45737,
  [SMALL_STATE(982)] = 45830,
  [SMALL_STATE(983)] = 45920,
  [SMALL_STATE(984)] = 46010,
  [SMALL_STATE(985)] = 46097,
  [SMALL_STATE(986)] = 46184,
  [SMALL_STATE(987)] = 46271,
  [SMALL_STATE(988)] = 46358,
  [SMALL_STATE(989)] = 46445,
  [SMALL_STATE(990)] = 46532,
  [SMALL_STATE(991)] = 46619,
  [SMALL_STATE(992)] = 46706,
  [SMALL_STATE(993)] = 46793,
  [SMALL_STATE(994)] = 46876,
  [SMALL_STATE(995)] = 46953,
  [SMALL_STATE(996)] = 47022,
  [SMALL_STATE(997)] = 47101,
  [SMALL_STATE(998)] = 47180,
  [SMALL_STATE(999)] = 47263,
  [SMALL_STATE(1000)] = 47337,
  [SMALL_STATE(1001)] = 47411,
  [SMALL_STATE(1002)] = 47485,
  [SMALL_STATE(1003)] = 47559,
  [SMALL_STATE(1004)] = 47639,
  [SMALL_STATE(1005)] = 47709,
  [SMALL_STATE(1006)] = 47783,
  [SMALL_STATE(1007)] = 47857,
  [SMALL_STATE(1008)] = 47929,
  [SMALL_STATE(1009)] = 47997,
  [SMALL_STATE(1010)] = 48074,
  [SMALL_STATE(1011)] = 48153,
  [SMALL_STATE(1012)] = 48232,
  [SMALL_STATE(1013)] = 48311,
  [SMALL_STATE(1014)] = 48376,
  [SMALL_STATE(1015)] = 48455,
  [SMALL_STATE(1016)] = 48524,
  [SMALL_STATE(1017)] = 48589,
  [SMALL_STATE(1018)] = 48666,
  [SMALL_STATE(1019)] = 48745,
  [SMALL_STATE(1020)] = 48810,
  [SMALL_STATE(1021)] = 48875,
  [SMALL_STATE(1022)] = 48954,
  [SMALL_STATE(1023)] = 49033,
  [SMALL_STATE(1024)] = 49110,
  [SMALL_STATE(1025)] = 49189,
  [SMALL_STATE(1026)] = 49266,
  [SMALL_STATE(1027)] = 49333,
  [SMALL_STATE(1028)] = 49398,
  [SMALL_STATE(1029)] = 49477,
  [SMALL_STATE(1030)] = 49553,
  [SMALL_STATE(1031)] = 49627,
  [SMALL_STATE(1032)] = 49699,
  [SMALL_STATE(1033)] = 49775,
  [SMALL_STATE(1034)] = 49853,
  [SMALL_STATE(1035)] = 49927,
  [SMALL_STATE(1036)] = 49999,
  [SMALL_STATE(1037)] = 50073,
  [SMALL_STATE(1038)] = 50149,
  [SMALL_STATE(1039)] = 50225,
  [SMALL_STATE(1040)] = 50301,
  [SMALL_STATE(1041)] = 50375,
  [SMALL_STATE(1042)] = 50448,
  [SMALL_STATE(1043)] = 50517,
  [SMALL_STATE(1044)] = 50590,
  [SMALL_STATE(1045)] = 50663,
  [SMALL_STATE(1046)] = 50734,
  [SMALL_STATE(1047)] = 50807,
  [SMALL_STATE(1048)] = 50876,
  [SMALL_STATE(1049)] = 50949,
  [SMALL_STATE(1050)] = 51022,
  [SMALL_STATE(1051)] = 51093,
  [SMALL_STATE(1052)] = 51164,
  [SMALL_STATE(1053)] = 51233,
  [SMALL_STATE(1054)] = 51302,
  [SMALL_STATE(1055)] = 51371,
  [SMALL_STATE(1056)] = 51442,
  [SMALL_STATE(1057)] = 51511,
  [SMALL_STATE(1058)] = 51586,
  [SMALL_STATE(1059)] = 51659,
  [SMALL_STATE(1060)] = 51728,
  [SMALL_STATE(1061)] = 51797,
  [SMALL_STATE(1062)] = 51866,
  [SMALL_STATE(1063)] = 51938,
  [SMALL_STATE(1064)] = 52002,
  [SMALL_STATE(1065)] = 52070,
  [SMALL_STATE(1066)] = 52134,
  [SMALL_STATE(1067)] = 52204,
  [SMALL_STATE(1068)] = 52268,
  [SMALL_STATE(1069)] = 52338,
  [SMALL_STATE(1070)] = 52400,
  [SMALL_STATE(1071)] = 52468,
  [SMALL_STATE(1072)] = 52538,
  [SMALL_STATE(1073)] = 52602,
  [SMALL_STATE(1074)] = 52678,
  [SMALL_STATE(1075)] = 52748,
  [SMALL_STATE(1076)] = 52812,
  [SMALL_STATE(1077)] = 52882,
  [SMALL_STATE(1078)] = 52946,
  [SMALL_STATE(1079)] = 53015,
  [SMALL_STATE(1080)] = 53084,
  [SMALL_STATE(1081)] = 53153,
  [SMALL_STATE(1082)] = 53222,
  [SMALL_STATE(1083)] = 53287,
  [SMALL_STATE(1084)] = 53352,
  [SMALL_STATE(1085)] = 53421,
  [SMALL_STATE(1086)] = 53486,
  [SMALL_STATE(1087)] = 53555,
  [SMALL_STATE(1088)] = 53626,
  [SMALL_STATE(1089)] = 53695,
  [SMALL_STATE(1090)] = 53764,
  [SMALL_STATE(1091)] = 53833,
  [SMALL_STATE(1092)] = 53898,
  [SMALL_STATE(1093)] = 53967,
  [SMALL_STATE(1094)] = 54036,
  [SMALL_STATE(1095)] = 54107,
  [SMALL_STATE(1096)] = 54176,
  [SMALL_STATE(1097)] = 54245,
  [SMALL_STATE(1098)] = 54314,
  [SMALL_STATE(1099)] = 54383,
  [SMALL_STATE(1100)] = 54448,
  [SMALL_STATE(1101)] = 54517,
  [SMALL_STATE(1102)] = 54586,
  [SMALL_STATE(1103)] = 54651,
  [SMALL_STATE(1104)] = 54714,
  [SMALL_STATE(1105)] = 54783,
  [SMALL_STATE(1106)] = 54852,
  [SMALL_STATE(1107)] = 54922,
  [SMALL_STATE(1108)] = 54992,
  [SMALL_STATE(1109)] = 55056,
  [SMALL_STATE(1110)] = 55124,
  [SMALL_STATE(1111)] = 55190,
  [SMALL_STATE(1112)] = 55260,
  [SMALL_STATE(1113)] = 55330,
  [SMALL_STATE(1114)] = 55400,
  [SMALL_STATE(1115)] = 55468,
  [SMALL_STATE(1116)] = 55538,
  [SMALL_STATE(1117)] = 55608,
  [SMALL_STATE(1118)] = 55678,
  [SMALL_STATE(1119)] = 55748,
  [SMALL_STATE(1120)] = 55818,
  [SMALL_STATE(1121)] = 55888,
  [SMALL_STATE(1122)] = 55956,
  [SMALL_STATE(1123)] = 56024,
  [SMALL_STATE(1124)] = 56094,
  [SMALL_STATE(1125)] = 56164,
  [SMALL_STATE(1126)] = 56234,
  [SMALL_STATE(1127)] = 56304,
  [SMALL_STATE(1128)] = 56372,
  [SMALL_STATE(1129)] = 56440,
  [SMALL_STATE(1130)] = 56510,
  [SMALL_STATE(1131)] = 56576,
  [SMALL_STATE(1132)] = 56644,
  [SMALL_STATE(1133)] = 56712,
  [SMALL_STATE(1134)] = 56782,
  [SMALL_STATE(1135)] = 56846,
  [SMALL_STATE(1136)] = 56914,
  [SMALL_STATE(1137)] = 56980,
  [SMALL_STATE(1138)] = 57044,
  [SMALL_STATE(1139)] = 57112,
  [SMALL_STATE(1140)] = 57182,
  [SMALL_STATE(1141)] = 57250,
  [SMALL_STATE(1142)] = 57320,
  [SMALL_STATE(1143)] = 57390,
  [SMALL_STATE(1144)] = 57460,
  [SMALL_STATE(1145)] = 57530,
  [SMALL_STATE(1146)] = 57600,
  [SMALL_STATE(1147)] = 57668,
  [SMALL_STATE(1148)] = 57738,
  [SMALL_STATE(1149)] = 57808,
  [SMALL_STATE(1150)] = 57878,
  [SMALL_STATE(1151)] = 57948,
  [SMALL_STATE(1152)] = 58016,
  [SMALL_STATE(1153)] = 58086,
  [SMALL_STATE(1154)] = 58156,
  [SMALL_STATE(1155)] = 58226,
  [SMALL_STATE(1156)] = 58296,
  [SMALL_STATE(1157)] = 58366,
  [SMALL_STATE(1158)] = 58436,
  [SMALL_STATE(1159)] = 58506,
  [SMALL_STATE(1160)] = 58576,
  [SMALL_STATE(1161)] = 58646,
  [SMALL_STATE(1162)] = 58716,
  [SMALL_STATE(1163)] = 58786,
  [SMALL_STATE(1164)] = 58845,
  [SMALL_STATE(1165)] = 58910,
  [SMALL_STATE(1166)] = 58977,
  [SMALL_STATE(1167)] = 59042,
  [SMALL_STATE(1168)] = 59109,
  [SMALL_STATE(1169)] = 59176,
  [SMALL_STATE(1170)] = 59241,
  [SMALL_STATE(1171)] = 59308,
  [SMALL_STATE(1172)] = 59375,
  [SMALL_STATE(1173)] = 59440,
  [SMALL_STATE(1174)] = 59507,
  [SMALL_STATE(1175)] = 59566,
  [SMALL_STATE(1176)] = 59633,
  [SMALL_STATE(1177)] = 59698,
  [SMALL_STATE(1178)] = 59763,
  [SMALL_STATE(1179)] = 59830,
  [SMALL_STATE(1180)] = 59897,
  [SMALL_STATE(1181)] = 59964,
  [SMALL_STATE(1182)] = 60029,
  [SMALL_STATE(1183)] = 60090,
  [SMALL_STATE(1184)] = 60149,
  [SMALL_STATE(1185)] = 60216,
  [SMALL_STATE(1186)] = 60283,
  [SMALL_STATE(1187)] = 60342,
  [SMALL_STATE(1188)] = 60407,
  [SMALL_STATE(1189)] = 60474,
  [SMALL_STATE(1190)] = 60541,
  [SMALL_STATE(1191)] = 60608,
  [SMALL_STATE(1192)] = 60675,
  [SMALL_STATE(1193)] = 60742,
  [SMALL_STATE(1194)] = 60809,
  [SMALL_STATE(1195)] = 60876,
  [SMALL_STATE(1196)] = 60943,
  [SMALL_STATE(1197)] = 61005,
  [SMALL_STATE(1198)] = 61069,
  [SMALL_STATE(1199)] = 61133,
  [SMALL_STATE(1200)] = 61197,
  [SMALL_STATE(1201)] = 61261,
  [SMALL_STATE(1202)] = 61321,
  [SMALL_STATE(1203)] = 61385,
  [SMALL_STATE(1204)] = 61449,
  [SMALL_STATE(1205)] = 61509,
  [SMALL_STATE(1206)] = 61573,
  [SMALL_STATE(1207)] = 61637,
  [SMALL_STATE(1208)] = 61701,
  [SMALL_STATE(1209)] = 61765,
  [SMALL_STATE(1210)] = 61829,
  [SMALL_STATE(1211)] = 61893,
  [SMALL_STATE(1212)] = 61955,
  [SMALL_STATE(1213)] = 62019,
  [SMALL_STATE(1214)] = 62083,
  [SMALL_STATE(1215)] = 62145,
  [SMALL_STATE(1216)] = 62207,
  [SMALL_STATE(1217)] = 62271,
  [SMALL_STATE(1218)] = 62335,
  [SMALL_STATE(1219)] = 62397,
  [SMALL_STATE(1220)] = 62459,
  [SMALL_STATE(1221)] = 62523,
  [SMALL_STATE(1222)] = 62587,
  [SMALL_STATE(1223)] = 62649,
  [SMALL_STATE(1224)] = 62713,
  [SMALL_STATE(1225)] = 62775,
  [SMALL_STATE(1226)] = 62837,
  [SMALL_STATE(1227)] = 62899,
  [SMALL_STATE(1228)] = 62963,
  [SMALL_STATE(1229)] = 63027,
  [SMALL_STATE(1230)] = 63091,
  [SMALL_STATE(1231)] = 63153,
  [SMALL_STATE(1232)] = 63211,
  [SMALL_STATE(1233)] = 63269,
  [SMALL_STATE(1234)] = 63331,
  [SMALL_STATE(1235)] = 63393,
  [SMALL_STATE(1236)] = 63455,
  [SMALL_STATE(1237)] = 63517,
  [SMALL_STATE(1238)] = 63579,
  [SMALL_STATE(1239)] = 63641,
  [SMALL_STATE(1240)] = 63703,
  [SMALL_STATE(1241)] = 63765,
  [SMALL_STATE(1242)] = 63827,
  [SMALL_STATE(1243)] = 63891,
  [SMALL_STATE(1244)] = 63955,
  [SMALL_STATE(1245)] = 64017,
  [SMALL_STATE(1246)] = 64081,
  [SMALL_STATE(1247)] = 64145,
  [SMALL_STATE(1248)] = 64209,
  [SMALL_STATE(1249)] = 64271,
  [SMALL_STATE(1250)] = 64333,
  [SMALL_STATE(1251)] = 64397,
  [SMALL_STATE(1252)] = 64461,
  [SMALL_STATE(1253)] = 64525,
  [SMALL_STATE(1254)] = 64589,
  [SMALL_STATE(1255)] = 64653,
  [SMALL_STATE(1256)] = 64714,
  [SMALL_STATE(1257)] = 64775,
  [SMALL_STATE(1258)] = 64832,
  [SMALL_STATE(1259)] = 64889,
  [SMALL_STATE(1260)] = 64950,
  [SMALL_STATE(1261)] = 65011,
  [SMALL_STATE(1262)] = 65072,
  [SMALL_STATE(1263)] = 65133,
  [SMALL_STATE(1264)] = 65192,
  [SMALL_STATE(1265)] = 65253,
  [SMALL_STATE(1266)] = 65312,
  [SMALL_STATE(1267)] = 65369,
  [SMALL_STATE(1268)] = 65430,
  [SMALL_STATE(1269)] = 65489,
  [SMALL_STATE(1270)] = 65550,
  [SMALL_STATE(1271)] = 65611,
  [SMALL_STATE(1272)] = 65670,
  [SMALL_STATE(1273)] = 65729,
  [SMALL_STATE(1274)] = 65788,
  [SMALL_STATE(1275)] = 65849,
  [SMALL_STATE(1276)] = 65910,
  [SMALL_STATE(1277)] = 65969,
  [SMALL_STATE(1278)] = 66026,
  [SMALL_STATE(1279)] = 66087,
  [SMALL_STATE(1280)] = 66148,
  [SMALL_STATE(1281)] = 66209,
  [SMALL_STATE(1282)] = 66270,
  [SMALL_STATE(1283)] = 66331,
  [SMALL_STATE(1284)] = 66392,
  [SMALL_STATE(1285)] = 66453,
  [SMALL_STATE(1286)] = 66514,
  [SMALL_STATE(1287)] = 66575,
  [SMALL_STATE(1288)] = 66636,
  [SMALL_STATE(1289)] = 66697,
  [SMALL_STATE(1290)] = 66754,
  [SMALL_STATE(1291)] = 66815,
  [SMALL_STATE(1292)] = 66876,
  [SMALL_STATE(1293)] = 66933,
  [SMALL_STATE(1294)] = 66990,
  [SMALL_STATE(1295)] = 67051,
  [SMALL_STATE(1296)] = 67108,
  [SMALL_STATE(1297)] = 67169,
  [SMALL_STATE(1298)] = 67226,
  [SMALL_STATE(1299)] = 67283,
  [SMALL_STATE(1300)] = 67340,
  [SMALL_STATE(1301)] = 67401,
  [SMALL_STATE(1302)] = 67462,
  [SMALL_STATE(1303)] = 67519,
  [SMALL_STATE(1304)] = 67580,
  [SMALL_STATE(1305)] = 67641,
  [SMALL_STATE(1306)] = 67702,
  [SMALL_STATE(1307)] = 67763,
  [SMALL_STATE(1308)] = 67824,
  [SMALL_STATE(1309)] = 67885,
  [SMALL_STATE(1310)] = 67942,
  [SMALL_STATE(1311)] = 68001,
  [SMALL_STATE(1312)] = 68062,
  [SMALL_STATE(1313)] = 68121,
  [SMALL_STATE(1314)] = 68178,
  [SMALL_STATE(1315)] = 68239,
  [SMALL_STATE(1316)] = 68298,
  [SMALL_STATE(1317)] = 68359,
  [SMALL_STATE(1318)] = 68420,
  [SMALL_STATE(1319)] = 68481,
  [SMALL_STATE(1320)] = 68540,
  [SMALL_STATE(1321)] = 68601,
  [SMALL_STATE(1322)] = 68660,
  [SMALL_STATE(1323)] = 68721,
  [SMALL_STATE(1324)] = 68782,
  [SMALL_STATE(1325)] = 68843,
  [SMALL_STATE(1326)] = 68904,
  [SMALL_STATE(1327)] = 68965,
  [SMALL_STATE(1328)] = 69024,
  [SMALL_STATE(1329)] = 69081,
  [SMALL_STATE(1330)] = 69138,
  [SMALL_STATE(1331)] = 69197,
  [SMALL_STATE(1332)] = 69258,
  [SMALL_STATE(1333)] = 69319,
  [SMALL_STATE(1334)] = 69376,
  [SMALL_STATE(1335)] = 69437,
  [SMALL_STATE(1336)] = 69496,
  [SMALL_STATE(1337)] = 69553,
  [SMALL_STATE(1338)] = 69610,
  [SMALL_STATE(1339)] = 69667,
  [SMALL_STATE(1340)] = 69728,
  [SMALL_STATE(1341)] = 69787,
  [SMALL_STATE(1342)] = 69846,
  [SMALL_STATE(1343)] = 69907,
  [SMALL_STATE(1344)] = 69964,
  [SMALL_STATE(1345)] = 70023,
  [SMALL_STATE(1346)] = 70080,
  [SMALL_STATE(1347)] = 70141,
  [SMALL_STATE(1348)] = 70198,
  [SMALL_STATE(1349)] = 70257,
  [SMALL_STATE(1350)] = 70314,
  [SMALL_STATE(1351)] = 70371,
  [SMALL_STATE(1352)] = 70432,
  [SMALL_STATE(1353)] = 70493,
  [SMALL_STATE(1354)] = 70551,
  [SMALL_STATE(1355)] = 70609,
  [SMALL_STATE(1356)] = 70667,
  [SMALL_STATE(1357)] = 70725,
  [SMALL_STATE(1358)] = 70783,
  [SMALL_STATE(1359)] = 70841,
  [SMALL_STATE(1360)] = 70899,
  [SMALL_STATE(1361)] = 70957,
  [SMALL_STATE(1362)] = 71015,
  [SMALL_STATE(1363)] = 71071,
  [SMALL_STATE(1364)] = 71127,
  [SMALL_STATE(1365)] = 71185,
  [SMALL_STATE(1366)] = 71243,
  [SMALL_STATE(1367)] = 71301,
  [SMALL_STATE(1368)] = 71359,
  [SMALL_STATE(1369)] = 71417,
  [SMALL_STATE(1370)] = 71475,
  [SMALL_STATE(1371)] = 71533,
  [SMALL_STATE(1372)] = 71591,
  [SMALL_STATE(1373)] = 71649,
  [SMALL_STATE(1374)] = 71707,
  [SMALL_STATE(1375)] = 71765,
  [SMALL_STATE(1376)] = 71823,
  [SMALL_STATE(1377)] = 71881,
  [SMALL_STATE(1378)] = 71939,
  [SMALL_STATE(1379)] = 71997,
  [SMALL_STATE(1380)] = 72055,
  [SMALL_STATE(1381)] = 72111,
  [SMALL_STATE(1382)] = 72167,
  [SMALL_STATE(1383)] = 72225,
  [SMALL_STATE(1384)] = 72279,
  [SMALL_STATE(1385)] = 72337,
  [SMALL_STATE(1386)] = 72393,
  [SMALL_STATE(1387)] = 72451,
  [SMALL_STATE(1388)] = 72509,
  [SMALL_STATE(1389)] = 72565,
  [SMALL_STATE(1390)] = 72623,
  [SMALL_STATE(1391)] = 72681,
  [SMALL_STATE(1392)] = 72739,
  [SMALL_STATE(1393)] = 72795,
  [SMALL_STATE(1394)] = 72853,
  [SMALL_STATE(1395)] = 72911,
  [SMALL_STATE(1396)] = 72969,
  [SMALL_STATE(1397)] = 73025,
  [SMALL_STATE(1398)] = 73083,
  [SMALL_STATE(1399)] = 73139,
  [SMALL_STATE(1400)] = 73195,
  [SMALL_STATE(1401)] = 73253,
  [SMALL_STATE(1402)] = 73311,
  [SMALL_STATE(1403)] = 73369,
  [SMALL_STATE(1404)] = 73425,
  [SMALL_STATE(1405)] = 73481,
  [SMALL_STATE(1406)] = 73539,
  [SMALL_STATE(1407)] = 73597,
  [SMALL_STATE(1408)] = 73655,
  [SMALL_STATE(1409)] = 73713,
  [SMALL_STATE(1410)] = 73771,
  [SMALL_STATE(1411)] = 73829,
  [SMALL_STATE(1412)] = 73885,
  [SMALL_STATE(1413)] = 73943,
  [SMALL_STATE(1414)] = 74001,
  [SMALL_STATE(1415)] = 74059,
  [SMALL_STATE(1416)] = 74117,
  [SMALL_STATE(1417)] = 74175,
  [SMALL_STATE(1418)] = 74233,
  [SMALL_STATE(1419)] = 74291,
  [SMALL_STATE(1420)] = 74349,
  [SMALL_STATE(1421)] = 74405,
  [SMALL_STATE(1422)] = 74463,
  [SMALL_STATE(1423)] = 74519,
  [SMALL_STATE(1424)] = 74577,
  [SMALL_STATE(1425)] = 74635,
  [SMALL_STATE(1426)] = 74693,
  [SMALL_STATE(1427)] = 74751,
  [SMALL_STATE(1428)] = 74809,
  [SMALL_STATE(1429)] = 74867,
  [SMALL_STATE(1430)] = 74925,
  [SMALL_STATE(1431)] = 74983,
  [SMALL_STATE(1432)] = 75041,
  [SMALL_STATE(1433)] = 75095,
  [SMALL_STATE(1434)] = 75151,
  [SMALL_STATE(1435)] = 75207,
  [SMALL_STATE(1436)] = 75265,
  [SMALL_STATE(1437)] = 75323,
  [SMALL_STATE(1438)] = 75379,
  [SMALL_STATE(1439)] = 75437,
  [SMALL_STATE(1440)] = 75491,
  [SMALL_STATE(1441)] = 75547,
  [SMALL_STATE(1442)] = 75605,
  [SMALL_STATE(1443)] = 75661,
  [SMALL_STATE(1444)] = 75719,
  [SMALL_STATE(1445)] = 75777,
  [SMALL_STATE(1446)] = 75835,
  [SMALL_STATE(1447)] = 75889,
  [SMALL_STATE(1448)] = 75947,
  [SMALL_STATE(1449)] = 76005,
  [SMALL_STATE(1450)] = 76063,
  [SMALL_STATE(1451)] = 76121,
  [SMALL_STATE(1452)] = 76175,
  [SMALL_STATE(1453)] = 76233,
  [SMALL_STATE(1454)] = 76291,
  [SMALL_STATE(1455)] = 76349,
  [SMALL_STATE(1456)] = 76405,
  [SMALL_STATE(1457)] = 76461,
  [SMALL_STATE(1458)] = 76516,
  [SMALL_STATE(1459)] = 76571,
  [SMALL_STATE(1460)] = 76626,
  [SMALL_STATE(1461)] = 76681,
  [SMALL_STATE(1462)] = 76736,
  [SMALL_STATE(1463)] = 76791,
  [SMALL_STATE(1464)] = 76846,
  [SMALL_STATE(1465)] = 76901,
  [SMALL_STATE(1466)] = 76956,
  [SMALL_STATE(1467)] = 77011,
  [SMALL_STATE(1468)] = 77066,
  [SMALL_STATE(1469)] = 77121,
  [SMALL_STATE(1470)] = 77176,
  [SMALL_STATE(1471)] = 77231,
  [SMALL_STATE(1472)] = 77286,
  [SMALL_STATE(1473)] = 77341,
  [SMALL_STATE(1474)] = 77396,
  [SMALL_STATE(1475)] = 77451,
  [SMALL_STATE(1476)] = 77506,
  [SMALL_STATE(1477)] = 77561,
  [SMALL_STATE(1478)] = 77616,
  [SMALL_STATE(1479)] = 77671,
  [SMALL_STATE(1480)] = 77726,
  [SMALL_STATE(1481)] = 77781,
  [SMALL_STATE(1482)] = 77836,
  [SMALL_STATE(1483)] = 77891,
  [SMALL_STATE(1484)] = 77946,
  [SMALL_STATE(1485)] = 78001,
  [SMALL_STATE(1486)] = 78056,
  [SMALL_STATE(1487)] = 78111,
  [SMALL_STATE(1488)] = 78166,
  [SMALL_STATE(1489)] = 78221,
  [SMALL_STATE(1490)] = 78276,
  [SMALL_STATE(1491)] = 78331,
  [SMALL_STATE(1492)] = 78386,
  [SMALL_STATE(1493)] = 78441,
  [SMALL_STATE(1494)] = 78496,
  [SMALL_STATE(1495)] = 78551,
  [SMALL_STATE(1496)] = 78606,
  [SMALL_STATE(1497)] = 78661,
  [SMALL_STATE(1498)] = 78716,
  [SMALL_STATE(1499)] = 78771,
  [SMALL_STATE(1500)] = 78826,
  [SMALL_STATE(1501)] = 78881,
  [SMALL_STATE(1502)] = 78936,
  [SMALL_STATE(1503)] = 78991,
  [SMALL_STATE(1504)] = 79046,
  [SMALL_STATE(1505)] = 79101,
  [SMALL_STATE(1506)] = 79156,
  [SMALL_STATE(1507)] = 79211,
  [SMALL_STATE(1508)] = 79266,
  [SMALL_STATE(1509)] = 79321,
  [SMALL_STATE(1510)] = 79376,
  [SMALL_STATE(1511)] = 79431,
  [SMALL_STATE(1512)] = 79486,
  [SMALL_STATE(1513)] = 79541,
  [SMALL_STATE(1514)] = 79596,
  [SMALL_STATE(1515)] = 79651,
  [SMALL_STATE(1516)] = 79706,
  [SMALL_STATE(1517)] = 79761,
  [SMALL_STATE(1518)] = 79816,
  [SMALL_STATE(1519)] = 79871,
  [SMALL_STATE(1520)] = 79926,
  [SMALL_STATE(1521)] = 79981,
  [SMALL_STATE(1522)] = 80036,
  [SMALL_STATE(1523)] = 80091,
  [SMALL_STATE(1524)] = 80146,
  [SMALL_STATE(1525)] = 80201,
  [SMALL_STATE(1526)] = 80256,
  [SMALL_STATE(1527)] = 80311,
  [SMALL_STATE(1528)] = 80366,
  [SMALL_STATE(1529)] = 80421,
  [SMALL_STATE(1530)] = 80476,
  [SMALL_STATE(1531)] = 80531,
  [SMALL_STATE(1532)] = 80586,
  [SMALL_STATE(1533)] = 80641,
  [SMALL_STATE(1534)] = 80696,
  [SMALL_STATE(1535)] = 80751,
  [SMALL_STATE(1536)] = 80806,
  [SMALL_STATE(1537)] = 80861,
  [SMALL_STATE(1538)] = 80916,
  [SMALL_STATE(1539)] = 80971,
  [SMALL_STATE(1540)] = 81026,
  [SMALL_STATE(1541)] = 81081,
  [SMALL_STATE(1542)] = 81136,
  [SMALL_STATE(1543)] = 81191,
  [SMALL_STATE(1544)] = 81246,
  [SMALL_STATE(1545)] = 81301,
  [SMALL_STATE(1546)] = 81356,
  [SMALL_STATE(1547)] = 81411,
  [SMALL_STATE(1548)] = 81466,
  [SMALL_STATE(1549)] = 81521,
  [SMALL_STATE(1550)] = 81576,
  [SMALL_STATE(1551)] = 81631,
  [SMALL_STATE(1552)] = 81686,
  [SMALL_STATE(1553)] = 81741,
  [SMALL_STATE(1554)] = 81796,
  [SMALL_STATE(1555)] = 81851,
  [SMALL_STATE(1556)] = 81906,
  [SMALL_STATE(1557)] = 81961,
  [SMALL_STATE(1558)] = 82016,
  [SMALL_STATE(1559)] = 82071,
  [SMALL_STATE(1560)] = 82126,
  [SMALL_STATE(1561)] = 82181,
  [SMALL_STATE(1562)] = 82236,
  [SMALL_STATE(1563)] = 82291,
  [SMALL_STATE(1564)] = 82346,
  [SMALL_STATE(1565)] = 82401,
  [SMALL_STATE(1566)] = 82456,
  [SMALL_STATE(1567)] = 82511,
  [SMALL_STATE(1568)] = 82566,
  [SMALL_STATE(1569)] = 82621,
  [SMALL_STATE(1570)] = 82676,
  [SMALL_STATE(1571)] = 82731,
  [SMALL_STATE(1572)] = 82786,
  [SMALL_STATE(1573)] = 82841,
  [SMALL_STATE(1574)] = 82896,
  [SMALL_STATE(1575)] = 82951,
  [SMALL_STATE(1576)] = 83006,
  [SMALL_STATE(1577)] = 83061,
  [SMALL_STATE(1578)] = 83116,
  [SMALL_STATE(1579)] = 83171,
  [SMALL_STATE(1580)] = 83226,
  [SMALL_STATE(1581)] = 83281,
  [SMALL_STATE(1582)] = 83336,
  [SMALL_STATE(1583)] = 83391,
  [SMALL_STATE(1584)] = 83446,
  [SMALL_STATE(1585)] = 83501,
  [SMALL_STATE(1586)] = 83556,
  [SMALL_STATE(1587)] = 83611,
  [SMALL_STATE(1588)] = 83666,
  [SMALL_STATE(1589)] = 83721,
  [SMALL_STATE(1590)] = 83776,
  [SMALL_STATE(1591)] = 83831,
  [SMALL_STATE(1592)] = 83886,
  [SMALL_STATE(1593)] = 83941,
  [SMALL_STATE(1594)] = 83996,
  [SMALL_STATE(1595)] = 84051,
  [SMALL_STATE(1596)] = 84106,
  [SMALL_STATE(1597)] = 84161,
  [SMALL_STATE(1598)] = 84216,
  [SMALL_STATE(1599)] = 84271,
  [SMALL_STATE(1600)] = 84326,
  [SMALL_STATE(1601)] = 84381,
  [SMALL_STATE(1602)] = 84436,
  [SMALL_STATE(1603)] = 84491,
  [SMALL_STATE(1604)] = 84546,
  [SMALL_STATE(1605)] = 84601,
  [SMALL_STATE(1606)] = 84656,
  [SMALL_STATE(1607)] = 84711,
  [SMALL_STATE(1608)] = 84766,
  [SMALL_STATE(1609)] = 84821,
  [SMALL_STATE(1610)] = 84876,
  [SMALL_STATE(1611)] = 84931,
  [SMALL_STATE(1612)] = 84986,
  [SMALL_STATE(1613)] = 85041,
  [SMALL_STATE(1614)] = 85096,
  [SMALL_STATE(1615)] = 85151,
  [SMALL_STATE(1616)] = 85206,
  [SMALL_STATE(1617)] = 85261,
  [SMALL_STATE(1618)] = 85316,
  [SMALL_STATE(1619)] = 85371,
  [SMALL_STATE(1620)] = 85426,
  [SMALL_STATE(1621)] = 85481,
  [SMALL_STATE(1622)] = 85536,
  [SMALL_STATE(1623)] = 85591,
  [SMALL_STATE(1624)] = 85646,
  [SMALL_STATE(1625)] = 85701,
  [SMALL_STATE(1626)] = 85756,
  [SMALL_STATE(1627)] = 85811,
  [SMALL_STATE(1628)] = 85866,
  [SMALL_STATE(1629)] = 85921,
  [SMALL_STATE(1630)] = 85976,
  [SMALL_STATE(1631)] = 86031,
  [SMALL_STATE(1632)] = 86086,
  [SMALL_STATE(1633)] = 86141,
  [SMALL_STATE(1634)] = 86196,
  [SMALL_STATE(1635)] = 86251,
  [SMALL_STATE(1636)] = 86306,
  [SMALL_STATE(1637)] = 86361,
  [SMALL_STATE(1638)] = 86416,
  [SMALL_STATE(1639)] = 86471,
  [SMALL_STATE(1640)] = 86526,
  [SMALL_STATE(1641)] = 86581,
  [SMALL_STATE(1642)] = 86636,
  [SMALL_STATE(1643)] = 86691,
  [SMALL_STATE(1644)] = 86746,
  [SMALL_STATE(1645)] = 86801,
  [SMALL_STATE(1646)] = 86856,
  [SMALL_STATE(1647)] = 86911,
  [SMALL_STATE(1648)] = 86966,
  [SMALL_STATE(1649)] = 87021,
  [SMALL_STATE(1650)] = 87076,
  [SMALL_STATE(1651)] = 87131,
  [SMALL_STATE(1652)] = 87186,
  [SMALL_STATE(1653)] = 87241,
  [SMALL_STATE(1654)] = 87296,
  [SMALL_STATE(1655)] = 87351,
  [SMALL_STATE(1656)] = 87406,
  [SMALL_STATE(1657)] = 87461,
  [SMALL_STATE(1658)] = 87516,
  [SMALL_STATE(1659)] = 87571,
  [SMALL_STATE(1660)] = 87575,
  [SMALL_STATE(1661)] = 87579,
  [SMALL_STATE(1662)] = 87583,
  [SMALL_STATE(1663)] = 87587,
  [SMALL_STATE(1664)] = 87591,
  [SMALL_STATE(1665)] = 87595,
  [SMALL_STATE(1666)] = 87599,
  [SMALL_STATE(1667)] = 87603,
  [SMALL_STATE(1668)] = 87607,
  [SMALL_STATE(1669)] = 87611,
  [SMALL_STATE(1670)] = 87615,
  [SMALL_STATE(1671)] = 87619,
  [SMALL_STATE(1672)] = 87623,
  [SMALL_STATE(1673)] = 87627,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1534),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1565),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1598),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1502),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1462),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [27] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(998),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1444),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1019),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1026),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1004),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1008),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(995),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1024),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1195),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1533),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1505),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1506),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1606),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1401),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1524),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1067),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1137),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1584),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1108),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(216),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1520),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1014),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1018),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [85] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1642),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1624),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(66),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(250),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1625),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1650),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(96),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(391),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(262),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1655),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(123),
  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1446),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__sizeof_call_expression, 1, 0, 0),
  [125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sizeof_call_expression, 1, 0, 0),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(309),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(742),
  [133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11),
  [141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(407),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [149] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(11),
  [152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(289),
  [155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(407),
  [158] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(407),
  [161] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1026),
  [164] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1008),
  [167] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(995),
  [170] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1014),
  [173] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1018),
  [176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3),
  [179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [181] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1067),
  [184] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1137),
  [187] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1584),
  [190] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1108),
  [193] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1642),
  [196] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1624),
  [199] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(66),
  [202] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(250),
  [205] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(240),
  [208] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1625),
  [211] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1650),
  [214] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(96),
  [217] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(391),
  [220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(403),
  [223] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(262),
  [226] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1655),
  [229] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(123),
  [232] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(123),
  [235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1446),
  [238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1236),
  [241] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(77),
  [244] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(293),
  [250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [256] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type, 1, 0, 0),
  [258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(423),
  [261] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__preproc_expression, 1, 0, 0), REDUCE(sym__expression, 1, 0, 0),
  [264] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__preproc_expression, 1, 0, 0), REDUCE(sym__expression, 1, 0, 0),
  [267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(90),
  [269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(388),
  [275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1011),
  [277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1012),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1627),
  [283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1461),
  [285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(33),
  [287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(516),
  [289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(527),
  [291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1553),
  [293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1575),
  [295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(91),
  [297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(333),
  [299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(283),
  [303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1654),
  [305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1432),
  [311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1224),
  [313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(93),
  [315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(223),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1646),
  [319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1633),
  [321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1634),
  [323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(207),
  [325] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_access, 3, 0, 38),
  [327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_access, 3, 0, 38),
  [329] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_indexed_access, 4, 0, 62),
  [331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_indexed_access, 4, 0, 62),
  [333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1472),
  [339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scope_access, 3, 0, 37),
  [349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scope_access, 3, 0, 37),
  [351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_view_as, 7, 0, 113),
  [353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_view_as, 7, 0, 113),
  [355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(297),
  [357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [361] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(413),
  [364] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 1, 0, 0),
  [366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(83),
  [368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 1, 0, 0),
  [370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1571),
  [372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1531),
  [376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1611),
  [384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [390] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dynamic_array, 3, 0, 15),
  [392] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dynamic_array, 3, 0, 15),
  [394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [396] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_dynamic_array_repeat1, 2, 0, 0),
  [398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dynamic_array_repeat1, 2, 0, 0),
  [400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dynamic_array_repeat1, 2, 0, 0), SHIFT_REPEAT(415),
  [403] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__sizeof_call_expression, 2, 0, 0),
  [405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sizeof_call_expression, 2, 0, 0),
  [407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1463),
  [409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1491),
  [411] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1463),
  [418] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2, 0, 23),
  [420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2, 0, 23),
  [422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(319),
  [424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(320),
  [426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(321),
  [432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(324),
  [438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(327),
  [444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(328),
  [450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1478),
  [454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0),
  [460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 1, 0, 0),
  [462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_dynamic_array_repeat1, 1, 0, 0),
  [464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dynamic_array_repeat1, 1, 0, 0),
  [466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_statement, 2, 0, 24),
  [468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 2, 0, 24),
  [470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 1, 0, 0),
  [472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 1, 0, 0),
  [474] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimension, 2, 0, 0),
  [476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimension, 2, 0, 0),
  [478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fixed_dimension, 3, 0, 0),
  [480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fixed_dimension, 3, 0, 0),
  [482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_type_cast, 2, 0, 17),
  [484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_type_cast, 2, 0, 17),
  [486] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 4, 0, 56),
  [488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 4, 0, 56),
  [490] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 3, 0, 36),
  [492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 0, 36),
  [494] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 14),
  [496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 14),
  [498] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 14),
  [500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, 0, 14),
  [502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 36),
  [504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 36),
  [506] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, 0, 16),
  [508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, 0, 16),
  [510] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 18),
  [512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, 0, 18),
  [514] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_arguments, 2, 0, 0),
  [516] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_arguments, 2, 0, 0),
  [518] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__literal, 1, 0, 0),
  [520] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__literal, 1, 0, 0),
  [522] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sizeof_expression, 2, 0, 15),
  [524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sizeof_expression, 2, 0, 15),
  [526] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 3, 0, 31),
  [528] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 3, 0, 31),
  [530] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_arguments, 3, 0, 0),
  [532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_arguments, 3, 0, 0),
  [534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 23),
  [536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 23),
  [538] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 35),
  [540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 35),
  [542] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_literal, 3, 0, 0),
  [544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_literal, 3, 0, 0),
  [546] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_char_literal, 3, 0, 0),
  [548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_char_literal, 3, 0, 0),
  [550] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_arguments, 4, 0, 0),
  [552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_arguments, 4, 0, 0),
  [554] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_literal, 4, 0, 0),
  [556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_literal, 4, 0, 0),
  [558] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sizeof_expression, 4, 0, 61),
  [560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sizeof_expression, 4, 0, 61),
  [562] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_literal, 5, 0, 0),
  [564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_literal, 5, 0, 0),
  [566] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_scope_access, 4, 0, 80),
  [568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_scope_access, 4, 0, 80),
  [570] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_literal, 6, 0, 0),
  [572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_literal, 6, 0, 0),
  [574] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comma_expression, 3, 0, 50),
  [576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comma_expression, 3, 0, 50),
  [578] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ternary_expression, 5, 0, 81),
  [580] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ternary_expression, 5, 0, 81),
  [582] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 2, 0, 0),
  [584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 2, 0, 0),
  [586] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 3, 0, 0),
  [588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 3, 0, 0),
  [590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [592] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1490),
  [595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1554),
  [597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [599] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dynamic_array_repeat1, 2, 0, 0), SHIFT_REPEAT(393),
  [602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(346),
  [606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(347),
  [612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(351),
  [618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(354),
  [624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1480),
  [634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(486),
  [640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(340),
  [646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1010),
  [648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1028),
  [650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(252),
  [656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1527),
  [658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(634),
  [660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1383),
  [664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(496),
  [668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [672] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(998),
  [675] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1245),
  [678] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1444),
  [681] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1019),
  [684] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1026),
  [687] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1004),
  [690] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1008),
  [693] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(995),
  [696] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1024),
  [699] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1195),
  [702] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1533),
  [705] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1505),
  [708] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1506),
  [711] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1606),
  [714] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1401),
  [717] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1524),
  [720] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1067),
  [723] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1137),
  [726] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1584),
  [729] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1108),
  [732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(482),
  [734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(215),
  [740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1510),
  [742] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 1, 0, 1),
  [744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 1, 0, 1),
  [746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [750] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 2, 0, 1),
  [752] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 2, 0, 1),
  [754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_parameter_declaration_repeat1, 2, 0, 0),
  [758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameter_declaration_repeat1, 2, 0, 0),
  [760] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameter_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(308),
  [763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [765] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_statement, 4, 0, 61),
  [767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_statement, 4, 0, 61),
  [769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1395),
  [771] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dynamic_array_repeat1, 2, 0, 0), SHIFT_REPEAT(432),
  [774] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_statement, 4, 0, 15),
  [776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_statement, 4, 0, 15),
  [778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_statement, 5, 0, 61),
  [780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_statement, 5, 0, 61),
  [782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_statement, 2, 0, 13),
  [784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_statement, 2, 0, 13),
  [786] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_statement, 4, 0, 13),
  [788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_statement, 4, 0, 13),
  [790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1387),
  [792] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_statement, 3, 0, 13),
  [794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_statement, 3, 0, 13),
  [796] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_statement, 3, 0, 15),
  [798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_statement, 3, 0, 15),
  [800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(304),
  [804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1310),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1591),
  [810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [812] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_parameter_declaration_repeat1, 1, 0, 0),
  [814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameter_declaration_repeat1, 1, 0, 0),
  [816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(318),
  [824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(514),
  [826] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_while_statement, 6, 0, 109),
  [828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_while_statement, 6, 0, 109),
  [830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1635),
  [836] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [840] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_variable_declaration_statement_repeat1, 2, 0, 0),
  [842] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_declaration_statement_repeat1, 2, 0, 0),
  [844] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1387),
  [847] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_global_variable_declaration_repeat1, 2, 0, 0),
  [849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_global_variable_declaration_repeat1, 2, 0, 0),
  [851] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_global_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(1395),
  [854] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 1, 0, 0),
  [856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 1, 0, 0),
  [858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(239),
  [860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(497),
  [864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(81),
  [882] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dynamic_array_declaration, 3, 0, 31),
  [884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dynamic_array_declaration, 3, 0, 31),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(470),
  [900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(835),
  [906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1451),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(522),
  [914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(385),
  [918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(510),
  [922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(94),
  [930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [938] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_declarations, 3, 0, 0),
  [940] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declarations, 3, 0, 0),
  [942] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__manual_semicolon, 1, 0, 0),
  [944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__manual_semicolon, 1, 0, 0),
  [946] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_declarations, 2, 0, 0),
  [948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declarations, 2, 0, 0),
  [950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1091),
  [952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1082),
  [954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(484),
  [958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(402),
  [964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1099),
  [966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(272),
  [970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1656),
  [972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(524),
  [974] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_declarations, 4, 0, 0),
  [976] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declarations, 4, 0, 0),
  [978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1102),
  [988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1596),
  [994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [996] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 138),
  [998] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, 0, 138),
  [1000] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 3, 0, 23),
  [1002] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 3, 0, 23),
  [1004] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_statement, 3, 0, 24),
  [1006] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 3, 0, 24),
  [1008] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 122),
  [1010] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 122),
  [1012] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2, 0, 0),
  [1014] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 0),
  [1016] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 136),
  [1018] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, 0, 136),
  [1020] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_variable_declaration_statement, 4, 0, 0),
  [1022] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_variable_declaration_statement, 4, 0, 0),
  [1024] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 2, 0, 0),
  [1026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 2, 0, 0),
  [1028] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [1030] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [1032] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2, 0, 0),
  [1034] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2, 0, 0),
  [1036] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 137),
  [1038] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, 0, 137),
  [1040] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 124),
  [1042] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 124),
  [1044] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_while_statement, 7, 0, 109),
  [1046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_while_statement, 7, 0, 109),
  [1048] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 7, 0, 110),
  [1050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 7, 0, 110),
  [1052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 0),
  [1054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 0),
  [1056] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__semicolon, 1, 0, 0),
  [1058] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__semicolon, 1, 0, 0),
  [1060] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_variable_declaration_statement, 5, 0, 0),
  [1062] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_variable_declaration_statement, 5, 0, 0),
  [1064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 131),
  [1066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 131),
  [1068] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, 0, 95),
  [1070] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, 0, 95),
  [1072] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_condition_statement, 5, 0, 96),
  [1074] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_condition_statement, 5, 0, 96),
  [1076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(40),
  [1078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_statement, 5, 0, 15),
  [1080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_statement, 5, 0, 15),
  [1082] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [1084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [1086] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 132),
  [1088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 132),
  [1090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 10, 0, 141),
  [1092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 10, 0, 141),
  [1094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1457),
  [1100] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_statement, 5, 0, 13),
  [1102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_statement, 5, 0, 13),
  [1104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration_statement, 6, 0, 61),
  [1106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration_statement, 6, 0, 61),
  [1108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 133),
  [1110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 133),
  [1112] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 134),
  [1114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 134),
  [1116] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, 0, 108),
  [1118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 108),
  [1120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 123),
  [1122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 123),
  [1124] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_variable_declaration_statement, 3, 0, 0),
  [1126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_variable_declaration_statement, 3, 0, 0),
  [1128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 6, 0, 110),
  [1130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 6, 0, 110),
  [1132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_condition_statement, 7, 0, 125),
  [1134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_condition_statement, 7, 0, 125),
  [1136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 1, 0, 0),
  [1138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 1, 0, 0),
  [1140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [1142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [1144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [1146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1, 0, 0),
  [1148] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(404),
  [1151] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameter_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(303),
  [1154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [1156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [1158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [1160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1368),
  [1162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1379),
  [1164] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_global_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(1368),
  [1167] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1379),
  [1170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(927),
  [1172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [1174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [1176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [1178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [1180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [1182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(903),
  [1184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [1188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [1190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [1192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [1194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [1196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [1198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [1200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [1202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [1204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [1206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [1208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap, 7, 0, 69),
  [1210] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_methodmap, 7, 0, 69),
  [1212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap, 6, 0, 3),
  [1214] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_methodmap, 6, 0, 3),
  [1216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 6, 0, 64),
  [1218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 6, 0, 64),
  [1220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1644),
  [1223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 3, 0, 8),
  [1225] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 3, 0, 8),
  [1227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 4, 0, 20),
  [1229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 4, 0, 20),
  [1231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 4, 0, 3),
  [1233] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct, 4, 0, 3),
  [1235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functag, 4, 0, 21),
  [1237] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functag, 4, 0, 21),
  [1239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap, 4, 0, 3),
  [1241] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_methodmap, 4, 0, 3),
  [1243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 2, 0, 5),
  [1245] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 2, 0, 5),
  [1247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_funcenum, 6, 0, 3),
  [1249] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_funcenum, 6, 0, 3),
  [1251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 6, 0, 63),
  [1253] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 6, 0, 63),
  [1255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 5, 0, 39),
  [1257] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 5, 0, 39),
  [1259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 8, 0, 100),
  [1261] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 8, 0, 100),
  [1263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 5, 0, 3),
  [1265] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct, 5, 0, 3),
  [1267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typeset, 5, 0, 3),
  [1269] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typeset, 5, 0, 3),
  [1271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_funcenum, 5, 0, 3),
  [1273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_funcenum, 5, 0, 3),
  [1275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functag, 5, 0, 44),
  [1277] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functag, 5, 0, 44),
  [1279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functag, 5, 0, 45),
  [1281] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functag, 5, 0, 45),
  [1283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_funcenum, 7, 0, 3),
  [1285] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_funcenum, 7, 0, 3),
  [1287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 7, 0, 83),
  [1289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 7, 0, 83),
  [1291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap, 5, 0, 3),
  [1293] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_methodmap, 5, 0, 3),
  [1295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap, 6, 0, 69),
  [1297] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_methodmap, 6, 0, 69),
  [1299] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dynamic_array_repeat1, 2, 0, 0), SHIFT_REPEAT(335),
  [1302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1644),
  [1304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1574),
  [1306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [1308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_constructor, 2, 0, 0),
  [1310] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_constructor, 2, 0, 0),
  [1312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_entries, 4, 0, 0),
  [1314] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_entries, 4, 0, 0),
  [1316] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_entries, 3, 0, 0),
  [1318] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_entries, 3, 0, 0),
  [1320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_constructor, 4, 0, 0),
  [1322] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_constructor, 4, 0, 0),
  [1324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_constructor, 3, 0, 0),
  [1326] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_constructor, 3, 0, 0),
  [1328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_entries, 2, 0, 0),
  [1330] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_entries, 2, 0, 0),
  [1332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_constructor, 5, 0, 0),
  [1334] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_constructor, 5, 0, 0),
  [1336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_entries, 5, 0, 0),
  [1338] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_entries, 5, 0, 0),
  [1340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20),
  [1342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typedef, 5, 0, 3),
  [1344] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typedef, 5, 0, 3),
  [1346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(944),
  [1348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [1350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [1352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1621),
  [1354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(275),
  [1356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1657),
  [1358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typeset, 6, 0, 3),
  [1360] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typeset, 6, 0, 3),
  [1362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_variable_declaration, 5, 0, 30),
  [1364] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_variable_declaration, 5, 0, 30),
  [1366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap, 7, 0, 3),
  [1368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_methodmap, 7, 0, 3),
  [1370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assertion, 3, 0, 0),
  [1372] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assertion, 3, 0, 0),
  [1374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functag, 6, 0, 44),
  [1376] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functag, 6, 0, 44),
  [1378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functag, 6, 0, 45),
  [1380] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functag, 6, 0, 45),
  [1382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 10),
  [1384] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 3, 0, 10),
  [1386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_declaration, 5, 0, 55),
  [1388] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_declaration, 5, 0, 55),
  [1390] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 1, 0, 0),
  [1392] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 1, 0, 0),
  [1394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_global_variable_declaration, 3, 0, 11),
  [1396] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_global_variable_declaration, 3, 0, 11),
  [1398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 57),
  [1400] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 57),
  [1402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_global_variable_declaration, 3, 0, 12),
  [1404] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_global_variable_declaration, 3, 0, 12),
  [1406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_variable_declaration, 3, 0, 13),
  [1408] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_variable_declaration, 3, 0, 13),
  [1410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1601),
  [1412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_declaration, 5, 0, 51),
  [1414] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_declaration, 5, 0, 51),
  [1416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 7, 0, 52),
  [1418] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 7, 0, 52),
  [1420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [1422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_assignment, 7, 0, 97),
  [1424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_assignment, 7, 0, 97),
  [1426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hardcoded_symbol, 2, 0, 0),
  [1428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hardcoded_symbol, 2, 0, 0),
  [1430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_global_variable_declaration, 4, 0, 19),
  [1432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_global_variable_declaration, 4, 0, 19),
  [1434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_global_variable_declaration, 4, 0, 0),
  [1436] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_global_variable_declaration, 4, 0, 0),
  [1438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 5, 0, 52),
  [1440] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 5, 0, 52),
  [1442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 4, 0, 8),
  [1444] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 4, 0, 8),
  [1446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_variable_declaration, 5, 0, 27),
  [1448] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_variable_declaration, 5, 0, 27),
  [1450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 8, 0, 83),
  [1452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 8, 0, 83),
  [1454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 6, 0, 26),
  [1456] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 6, 0, 26),
  [1458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_funcenum, 8, 0, 3),
  [1460] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_funcenum, 8, 0, 3),
  [1462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap, 8, 0, 69),
  [1464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_methodmap, 8, 0, 69),
  [1466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_global_variable_declaration, 3, 0, 0),
  [1468] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_global_variable_declaration, 3, 0, 0),
  [1470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 6, 0, 76),
  [1472] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 6, 0, 76),
  [1474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_variable_declaration, 6, 0, 53),
  [1476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_variable_declaration, 6, 0, 53),
  [1478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_declaration, 6, 0, 77),
  [1480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_declaration, 6, 0, 77),
  [1482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 4, 0, 26),
  [1484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 4, 0, 26),
  [1486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_global_variable_declaration, 4, 0, 11),
  [1488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_global_variable_declaration, 4, 0, 11),
  [1490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_variable_declaration, 4, 0, 27),
  [1492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_variable_declaration, 4, 0, 27),
  [1494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 28),
  [1496] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 28),
  [1498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_global_variable_declaration, 4, 0, 29),
  [1500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_global_variable_declaration, 4, 0, 29),
  [1502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_global_variable_declaration, 4, 0, 12),
  [1504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_global_variable_declaration, 4, 0, 12),
  [1506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_variable_declaration, 4, 0, 30),
  [1508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_variable_declaration, 4, 0, 30),
  [1510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 32),
  [1512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 32),
  [1514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_variable_declaration, 4, 0, 13),
  [1516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_variable_declaration, 4, 0, 13),
  [1518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 78),
  [1520] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 78),
  [1522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 8, 0, 76),
  [1524] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 8, 0, 76),
  [1526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_assignment, 8, 0, 111),
  [1528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_assignment, 8, 0, 111),
  [1530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_assignment, 8, 0, 112),
  [1532] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_assignment, 8, 0, 112),
  [1534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_global_variable_declaration, 5, 0, 29),
  [1536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_global_variable_declaration, 5, 0, 29),
  [1538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 9, 0, 100),
  [1540] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 9, 0, 100),
  [1542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(406),
  [1544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [1546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [1548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [1550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(410),
  [1552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [1554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [1556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(421),
  [1558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [1560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [1562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(436),
  [1564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [1566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [1568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(437),
  [1570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [1572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 6, 0, 39),
  [1574] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 6, 0, 39),
  [1576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_global_variable_declaration, 5, 0, 19),
  [1578] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_global_variable_declaration, 5, 0, 19),
  [1580] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_variable_declaration, 5, 0, 53),
  [1582] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_variable_declaration, 5, 0, 53),
  [1584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 54),
  [1586] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 54),
  [1588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_struct, 5, 0, 42),
  [1590] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_struct, 5, 0, 42),
  [1592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 5, 0, 20),
  [1594] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 5, 0, 20),
  [1596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 7, 0, 63),
  [1598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 7, 0, 63),
  [1600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 3, 0, 5),
  [1602] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 3, 0, 5),
  [1604] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_struct, 6, 0, 42),
  [1606] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_struct, 6, 0, 42),
  [1608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functag, 5, 0, 21),
  [1610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functag, 5, 0, 21),
  [1612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_assignment, 9, 0, 126),
  [1614] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_assignment, 9, 0, 126),
  [1616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 7, 0, 64),
  [1618] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 7, 0, 64),
  [1620] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 6, 0, 3),
  [1622] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct, 6, 0, 3),
  [1624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_global_variable_declaration, 2, 0, 0),
  [1626] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_global_variable_declaration, 2, 0, 0),
  [1628] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_old_type, 2, 0, 0),
  [1630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_type, 2, 0, 0),
  [1632] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dynamic_array_repeat1, 2, 0, 0), SHIFT_REPEAT(425),
  [1635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [1637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1514),
  [1639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1538),
  [1641] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1514),
  [1644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [1646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [1648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [1650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_variable_declaration, 4, 0, 33),
  [1652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [1654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_variable_declaration, 4, 0, 25),
  [1656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [1658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_variable_declaration, 3, 0, 9),
  [1660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [1662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_variable_declaration, 5, 0, 58),
  [1664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [1666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 5, 0, 91),
  [1668] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1544),
  [1671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_entry, 6, 0, 99),
  [1673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 5, 0, 92),
  [1675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 5, 0, 93),
  [1677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 5, 0, 94),
  [1679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1544),
  [1681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1562),
  [1683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [1685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [1687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 6, 0, 105),
  [1689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 6, 0, 106),
  [1691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 6, 0, 107),
  [1693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_entry, 4, 0, 65),
  [1695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [1697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [1699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [1701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 4, 0, 70),
  [1703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0),
  [1705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 4, 0, 71),
  [1707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_entry, 5, 0, 82),
  [1709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_call_arguments_repeat1, 2, 0, 0),
  [1711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 4, 0, 73),
  [1713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [1715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_entry, 3, 0, 40),
  [1717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 4, 0, 75),
  [1719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [1721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [1723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [1725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [1727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [1729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [1731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [1735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [1737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [1739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [1741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [1743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [1745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [1747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [1749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [1751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 3, 0, 46),
  [1753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [1755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_named_arg, 4, 0, 60),
  [1757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 5, 0, 89),
  [1759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 5, 0, 90),
  [1761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_field_value, 3, 0, 98),
  [1763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [1765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(356),
  [1767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(357),
  [1769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [1771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [1773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(358),
  [1775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(361),
  [1777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [1779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [1781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(364),
  [1783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [1785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [1787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(365),
  [1789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1528),
  [1791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [1793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [1795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1618),
  [1797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [1799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [1801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1382),
  [1803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [1805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [1807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [1809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [1811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [1813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [1815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [1817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [1819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [1821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [1823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [1825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [1829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [1831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [1833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [1835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [1837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [1839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [1841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [1843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [1845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1366),
  [1847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [1849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [1851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [1853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [1855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [1857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [1859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [1861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(929),
  [1863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [1865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(912),
  [1867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [1869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(913),
  [1871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [1873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [1875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(916),
  [1877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [1879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [1881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(919),
  [1883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [1885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [1887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(920),
  [1889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [1891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [1893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_binary_expression, 3, 0, 36),
  [1895] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_binary_expression, 3, 0, 36),
  [1897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__preproc_expression, 1, 0, 0),
  [1899] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__preproc_expression, 1, 0, 0),
  [1901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [1903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [1905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [1907] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_unary_expression, 2, 0, 14),
  [1909] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_unary_expression, 2, 0, 14),
  [1911] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_defined_condition, 2, 0, 3),
  [1913] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_defined_condition, 2, 0, 3),
  [1915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [1917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [1919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_parenthesized_expression, 3, 0, 0),
  [1921] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_parenthesized_expression, 3, 0, 0),
  [1923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__case_expression, 1, 0, 0),
  [1925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__case_expression, 1, 0, 0),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1556),
  [1929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [1931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(734),
  [1933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [1935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(735),
  [1937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [1941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(739),
  [1943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [1945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [1947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(640),
  [1949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [1953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(641),
  [1955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [1959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_binary_expression, 3, 0, 36),
  [1961] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_binary_expression, 3, 0, 36),
  [1963] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_literal_repeat1, 2, 0, 0),
  [1965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_unary_expression, 2, 0, 14),
  [1967] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_unary_expression, 2, 0, 14),
  [1969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_case_repeat1, 2, 0, 0),
  [1971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1023),
  [1973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [1977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [1979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1448),
  [1983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1029),
  [1985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(993),
  [1987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1057),
  [1989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1017),
  [1991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [1993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1169),
  [1995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1470),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [1999] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_variable_declaration, 1, 0, 1),
  [2001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [2003] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(303),
  [2006] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_struct_repeat1, 2, 0, 0), SHIFT_REPEAT(1103),
  [2009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_struct_repeat1, 2, 0, 0),
  [2011] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_struct_repeat1, 2, 0, 0), SHIFT_REPEAT(1067),
  [2014] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_visibility, 1, 0, 0),
  [2016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1013),
  [2018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1103),
  [2020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [2022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [2024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [2026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [2028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [2030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [2032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [2034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [2036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1241),
  [2038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1543),
  [2040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1036),
  [2042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1035),
  [2044] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_visibility, 1, 0, 0), SHIFT(1371),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [2049] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methodmap_repeat1, 2, 0, 0), SHIFT_REPEAT(1003),
  [2052] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_methodmap_repeat1, 2, 0, 0),
  [2054] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methodmap_repeat1, 2, 0, 0), SHIFT_REPEAT(1056),
  [2057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1408),
  [2059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [2061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1033),
  [2063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1022),
  [2065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1043),
  [2067] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_visibility, 2, 0, 0),
  [2069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1021),
  [2071] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameter_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(305),
  [2074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [2076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 2, 0, 22),
  [2078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [2080] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(305),
  [2083] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration_kind, 1, 0, 0),
  [2085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [2087] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 1, 0, 1),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [2093] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_storage_class, 1, 0, 0),
  [2095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_storage_class, 1, 0, 0),
  [2097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [2099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1062),
  [2101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1053),
  [2103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_variable_declaration, 2, 0, 6),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [2111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1122),
  [2113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [2115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [2117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1051),
  [2119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1219),
  [2121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1612),
  [2123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [2125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [2127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1249),
  [2129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1435),
  [2131] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_struct_field, 4, 0, 6),
  [2133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_struct_field, 4, 0, 6),
  [2135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_struct_method, 5, 0, 57),
  [2137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_struct_method, 5, 0, 57),
  [2139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1244),
  [2141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_builtin_type, 1, 0, 0),
  [2143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_builtin_type, 1, 0, 0),
  [2145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_variable_declaration, 2, 0, 1),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [2149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1248),
  [2151] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_struct_method, 4, 0, 32),
  [2153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_struct_method, 4, 0, 32),
  [2155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_variable_declaration, 3, 0, 6),
  [2157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [2159] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_struct_field, 3, 0, 6),
  [2161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_struct_field, 3, 0, 6),
  [2163] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enum_struct_repeat1, 1, 0, 0),
  [2165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_struct_repeat1, 1, 0, 0),
  [2167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 3, 0, 6),
  [2169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [2171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_typeset_repeat1, 1, 0, 0),
  [2173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [2175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native_constructor, 4, 0, 87),
  [2177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1178),
  [2179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1270),
  [2181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 4, 0, 48),
  [2183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [2185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1320),
  [2187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 2, 0, 1),
  [2189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [2191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [2193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1604),
  [2195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1442),
  [2197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native, 6, 0, 118),
  [2199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_alias, 6, 0, 120),
  [2201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native_constructor, 5, 0, 103),
  [2203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1175),
  [2205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 3, 0, 22),
  [2207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [2209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 2, 0, 6),
  [2211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [2213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [2215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [2217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [2219] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 3, 0, 48),
  [2221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [2223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [2225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [2227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native, 5, 0, 44),
  [2229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1188),
  [2231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native, 7, 0, 128),
  [2233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_alias, 7, 0, 127),
  [2235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1180),
  [2237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native_destructor, 6, 0, 116),
  [2239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native, 6, 0, 117),
  [2241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [2243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1179),
  [2245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [2247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_property_alias, 4, 0, 135),
  [2249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_field, 3, 0, 66),
  [2251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_entry, 1, 0, 1),
  [2253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [2255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1559),
  [2257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [2259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0),
  [2261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_property_native, 3, 0, 0),
  [2263] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methodmap_property_repeat1, 2, 0, 0), SHIFT_REPEAT(1179),
  [2266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_methodmap_property_repeat1, 2, 0, 0),
  [2268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [2270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_builtin_type, 1, 0, 0),
  [2272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_field, 4, 0, 84),
  [2274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_field, 4, 0, 85),
  [2276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1038),
  [2278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1515),
  [2280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_field, 5, 0, 101),
  [2282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1037),
  [2284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1626),
  [2286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typedef_expression, 4, 0, 86),
  [2288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [2290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [2292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [2294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [2296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [2298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [2300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [2302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1500),
  [2304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1523),
  [2306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [2308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typedef_expression, 6, 0, 114),
  [2310] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_typeset_repeat1, 2, 0, 0), SHIFT_REPEAT(1475),
  [2313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_typeset_repeat1, 2, 0, 0),
  [2315] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_typeset_repeat1, 2, 0, 0), SHIFT_REPEAT(1052),
  [2318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [2320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [2322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [2324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1525),
  [2326] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_entry, 3, 0, 41),
  [2328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [2330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [2332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typedef_expression, 3, 0, 67),
  [2334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [2336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typedef_expression, 5, 0, 102),
  [2338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0),
  [2340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(741),
  [2343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1619),
  [2346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [2348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [2350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1583),
  [2352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1482),
  [2354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [2356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [2358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [2360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [2362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1199),
  [2364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [2366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [2368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1535),
  [2370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1324),
  [2372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1351),
  [2374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1534),
  [2376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1565),
  [2378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1598),
  [2380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1607),
  [2382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1486),
  [2384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1502),
  [2386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1462),
  [2388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1588),
  [2390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(891),
  [2392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1336),
  [2394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1336),
  [2396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [2398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [2400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [2402] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_old_global_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(1058),
  [2405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_old_global_variable_declaration_repeat1, 2, 0, 0),
  [2407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [2409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0),
  [2411] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1336),
  [2414] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1336),
  [2417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [2419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1670),
  [2421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [2423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(626),
  [2425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(625),
  [2427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [2429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [2431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [2433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [2435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1438),
  [2437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1443),
  [2439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [2441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [2443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1353),
  [2445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(201),
  [2447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(202),
  [2449] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_repeat1, 2, 0, 0), SHIFT_REPEAT(1031),
  [2452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_repeat1, 2, 0, 0),
  [2454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [2456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [2458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1661),
  [2460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_property_getter, 3, 0, 1),
  [2462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_property_setter, 4, 0, 140),
  [2464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(909),
  [2466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(910),
  [2468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1593),
  [2470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1632),
  [2472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(147),
  [2474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(148),
  [2476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(836),
  [2478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [2480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(263),
  [2482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [2484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1393),
  [2486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 2, 0, 3),
  [2488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [2490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [2492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 3, 0, 47),
  [2494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [2496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [2498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1360),
  [2500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [2502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [2504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [2506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [2508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [2510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 3, 0, 130),
  [2512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_alias, 8, 0, 127),
  [2514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [2516] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_for_loop_variable_declaration_statement, 4, 0, 0),
  [2518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [2520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [2522] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(384),
  [2525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [2527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(580),
  [2530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native, 8, 0, 128),
  [2532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [2534] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_entries_repeat1, 2, 0, 0), SHIFT_REPEAT(1070),
  [2537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_entries_repeat1, 2, 0, 0),
  [2539] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), SHIFT(1595),
  [2542] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_entry, 4, 0, 41),
  [2544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [2546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_entry, 2, 0, 1),
  [2548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [2550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [2552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [2554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1658),
  [2556] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_old_global_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(1044),
  [2559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 1, 0, 0),
  [2561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1542),
  [2563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [2565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1497),
  [2567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1375),
  [2569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1484),
  [2571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [2573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [2575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [2577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [2579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [2581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [2583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 5, 0, 142),
  [2585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_for_loop_variable_declaration_statement, 3, 0, 0),
  [2587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_method_destructor, 6, 0, 115),
  [2589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [2591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [2593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native, 6, 0, 44),
  [2595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native_constructor, 6, 0, 103),
  [2597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_method, 6, 0, 119),
  [2599] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 4, 0, 139),
  [2601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [2603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [2605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_method, 6, 0, 121),
  [2607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [2609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [2611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [2613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [2615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_property, 6, 0, 66),
  [2617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ignore_argument, 1, 0, 0),
  [2619] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_constructor_repeat1, 2, 0, 0), SHIFT_REPEAT(1402),
  [2622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_constructor_repeat1, 2, 0, 0),
  [2624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_alias, 7, 0, 120),
  [2626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 4, 0, 72),
  [2628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [2630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [2632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [2634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_macro_repeat1, 2, 0, 0),
  [2636] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_macro_repeat1, 2, 0, 0), SHIFT_REPEAT(1658),
  [2639] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_funcenum_repeat1, 2, 0, 0), SHIFT_REPEAT(1030),
  [2642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_funcenum_repeat1, 2, 0, 0),
  [2644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1487),
  [2646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [2648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1662),
  [2650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [2652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [2654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 4, 0, 74),
  [2656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [2658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_methodmap_repeat1, 1, 0, 0),
  [2660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 3, 0, 41),
  [2662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [2664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [2666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [2668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [2670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native_constructor, 5, 0, 87),
  [2672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameter_declarations_repeat1, 2, 0, 0),
  [2674] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameter_declarations_repeat1, 2, 0, 0), SHIFT_REPEAT(975),
  [2677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 1, 0, 0),
  [2679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_literal_repeat1, 1, 0, 0),
  [2681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_method, 7, 0, 129),
  [2683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_method, 5, 0, 104),
  [2685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_old_for_loop_variable_declaration_statement, 2, 0, 0),
  [2687] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_case_repeat1, 2, 0, 0), SHIFT_REPEAT(642),
  [2690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [2692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_property, 5, 0, 66),
  [2694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 3, 0, 49),
  [2696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [2698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_method_constructor, 4, 0, 88),
  [2700] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native_destructor, 7, 0, 116),
  [2702] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_call_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(247),
  [2705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native, 7, 0, 117),
  [2707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_native, 7, 0, 118),
  [2709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1663),
  [2711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [2713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_methodmap_property_repeat1, 1, 0, 0),
  [2715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [2717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1460),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1488),
  [2721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_field, 4, 0, 66),
  [2723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1614),
  [2725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_property_native, 4, 0, 0),
  [2727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1032),
  [2729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_repeat1, 1, 0, 0),
  [2731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1055),
  [2733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1064),
  [2735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_property_method, 3, 0, 130),
  [2737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_field, 6, 0, 101),
  [2739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1485),
  [2741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_funcenum_member, 2, 0, 43),
  [2743] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_old_type, 2, 0, 0), SHIFT(1615),
  [2746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [2748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1466),
  [2750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [2752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [2754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1469),
  [2756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_funcenum_member, 3, 0, 68),
  [2758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_field, 5, 0, 84),
  [2760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1039),
  [2762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1476),
  [2764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_field, 5, 0, 85),
  [2766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rest_parameter, 3, 0, 27),
  [2768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [2770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1526),
  [2772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1429),
  [2774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1660),
  [2776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1552),
  [2778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [2780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1555),
  [2782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rest_parameter, 2, 0, 13),
  [2784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methodmap_property_alias, 5, 0, 135),
  [2786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [2788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [2790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [2792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [2794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [2796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1669),
  [2798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [2800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [2802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1659),
  [2804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1280),
  [2806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [2808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1365),
  [2810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [2812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1372),
  [2814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1637),
  [2816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [2818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [2820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [2822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [2824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [2826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1207),
  [2828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [2830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1373),
  [2832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1412),
  [2834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [2836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1667),
  [2838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [2840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [2842] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rest_operator, 1, 0, 0),
  [2844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1388),
  [2846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [2848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [2850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [2852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [2854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [2856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [2858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [2860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [2862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [2864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [2866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [2868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [2870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1493),
  [2872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1389),
  [2874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [2876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [2878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [2880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [2882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1494),
  [2884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [2886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1278),
  [2888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [2890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [2892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [2894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [2896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1186),
  [2898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [2900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [2902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1569),
  [2904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1447),
  [2906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1549),
  [2908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1605),
  [2910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [2912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1423),
  [2914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [2916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [2918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1546),
  [2920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1609),
  [2922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [2924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [2926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1639),
  [2928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [2930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [2932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [2934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [2936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [2938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1181),
  [2940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [2942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [2944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1672),
  [2946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [2948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1671),
  [2950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [2952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1252),
  [2954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1370),
  [2956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [2958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [2960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [2962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [2964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [2966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [2968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1459),
  [2970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1421),
  [2972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1413),
  [2974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [2976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [2978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [2980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [2982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1673),
  [2984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1567),
  [2986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1636),
  [2988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1330),
  [2990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1390),
  [2992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [2994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [2996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [2998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [3000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [3002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [3004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1327),
  [3006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [3008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1516),
  [3010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [3012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
  [3014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1512),
  [3016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1419),
  [3018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [3020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [3022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1427),
  [3024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [3026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [3028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [3030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1210),
  [3032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [3034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [3036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [3038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1355),
  [3040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [3042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [3044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [3046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [3048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [3050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [3052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [3054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [3056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [3058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [3060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [3062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [3064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [3066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [3068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [3070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [3072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [3074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [3076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [3078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [3080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1640),
  [3082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [3084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [3086] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [3088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1582),
  [3090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [3092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [3094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [3096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [3098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1398),
  [3100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_macro, 5, 0, 34),
  [3102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_define, 3, 0, 7),
  [3104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_include, 2, 0, 2),
  [3106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_tryinclude, 2, 0, 2),
  [3108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_assert, 2, 0, 4),
  [3110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 2, 0, 4),
  [3112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_pragma, 2, 0, 0),
  [3114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_macro, 7, 0, 79),
  [3116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elseif, 2, 0, 4),
  [3118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_error, 2, 0, 0),
  [3120] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_undefine, 2, 0, 3),
  [3122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_macro, 6, 0, 59),
  [3124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_warning, 2, 0, 0),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token__automatic_semicolon = 0,
  ts_external_token__ternary_colon = 1,
  ts_external_token_preproc_arg = 2,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__automatic_semicolon] = sym__automatic_semicolon,
  [ts_external_token__ternary_colon] = sym__ternary_colon,
  [ts_external_token_preproc_arg] = sym_preproc_arg,
};

static const bool ts_external_scanner_states[5][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__ternary_colon] = true,
    [ts_external_token_preproc_arg] = true,
  },
  [2] = {
    [ts_external_token__automatic_semicolon] = true,
  },
  [3] = {
    [ts_external_token__ternary_colon] = true,
  },
  [4] = {
    [ts_external_token_preproc_arg] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_sourcepawn_external_scanner_create(void);
void tree_sitter_sourcepawn_external_scanner_destroy(void *);
bool tree_sitter_sourcepawn_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_sourcepawn_external_scanner_serialize(void *, char *);
void tree_sitter_sourcepawn_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_sourcepawn(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_sourcepawn_external_scanner_create,
      tree_sitter_sourcepawn_external_scanner_destroy,
      tree_sitter_sourcepawn_external_scanner_scan,
      tree_sitter_sourcepawn_external_scanner_serialize,
      tree_sitter_sourcepawn_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
