#include <tree_sitter/parser.h>

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 13
#define STATE_COUNT 1898
#define LARGE_STATE_COUNT 153
#define SYMBOL_COUNT 153
#define ALIAS_COUNT 1
#define TOKEN_COUNT 89
#define EXTERNAL_TOKEN_COUNT 4
#define FIELD_COUNT 18
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define PRODUCTION_ID_COUNT 28

enum {
  sym_identifier = 1,
  anon_sym_COMMA = 2,
  anon_sym_BEGIN = 3,
  anon_sym_END = 4,
  anon_sym_BEGINFILE = 5,
  anon_sym_ENDFILE = 6,
  anon_sym_ATinclude = 7,
  anon_sym_ATload = 8,
  anon_sym_ATnamespace = 9,
  anon_sym_SEMI = 10,
  anon_sym_LF = 11,
  anon_sym_CR_LF = 12,
  anon_sym_if = 13,
  anon_sym_LPAREN = 14,
  anon_sym_RPAREN = 15,
  anon_sym_else = 16,
  anon_sym_while = 17,
  anon_sym_do = 18,
  anon_sym_for = 19,
  anon_sym_in = 20,
  sym_break_statement = 21,
  sym_continue_statement = 22,
  anon_sym_delete = 23,
  anon_sym_exit = 24,
  anon_sym_return = 25,
  anon_sym_switch = 26,
  anon_sym_LBRACE = 27,
  anon_sym_RBRACE = 28,
  anon_sym_case = 29,
  anon_sym_COLON = 30,
  anon_sym_default = 31,
  anon_sym_getline = 32,
  anon_sym_LT = 33,
  sym_next_statement = 34,
  sym_nextfile_statement = 35,
  anon_sym_print = 36,
  anon_sym_LPAREN2 = 37,
  anon_sym_printf = 38,
  anon_sym_GT = 39,
  anon_sym_GT_GT = 40,
  anon_sym_PIPE = 41,
  anon_sym_PIPE_AMP = 42,
  anon_sym_QMARK = 43,
  anon_sym_CARET = 44,
  anon_sym_STAR_STAR = 45,
  anon_sym_STAR = 46,
  anon_sym_SLASH = 47,
  anon_sym_PERCENT = 48,
  anon_sym_PLUS = 49,
  anon_sym_DASH = 50,
  anon_sym_LT_EQ = 51,
  anon_sym_GT_EQ = 52,
  anon_sym_EQ_EQ = 53,
  anon_sym_BANG_EQ = 54,
  anon_sym_TILDE = 55,
  anon_sym_BANG_TILDE = 56,
  anon_sym_AMP_AMP = 57,
  anon_sym_PIPE_PIPE = 58,
  anon_sym_BANG = 59,
  anon_sym_PLUS_PLUS = 60,
  anon_sym_DASH_DASH = 61,
  anon_sym_EQ = 62,
  anon_sym_PLUS_EQ = 63,
  anon_sym_DASH_EQ = 64,
  anon_sym_STAR_EQ = 65,
  anon_sym_SLASH_EQ = 66,
  anon_sym_PERCENT_EQ = 67,
  anon_sym_CARET_EQ = 68,
  anon_sym_DOLLAR = 69,
  anon_sym_LBRACK = 70,
  anon_sym_RBRACK = 71,
  anon_sym_SLASH2 = 72,
  sym_regex_pattern = 73,
  sym_regex_flags = 74,
  anon_sym_AT = 75,
  anon_sym_COLON_COLON = 76,
  sym_number = 77,
  anon_sym_DQUOTE = 78,
  aux_sym_string_token1 = 79,
  sym_escape_sequence = 80,
  anon_sym_function = 81,
  anon_sym_func = 82,
  anon_sym_POUND = 83,
  aux_sym_comment_token1 = 84,
  sym_concatenating_space = 85,
  sym__if_else_separator = 86,
  sym__ambiguous_comment = 87,
  sym__no_space = 88,
  sym_program = 89,
  sym_rule = 90,
  sym_pattern = 91,
  sym_range_pattern = 92,
  sym__special_pattern = 93,
  sym_directive = 94,
  sym__statement = 95,
  sym__statement_separated = 96,
  sym__control_statement = 97,
  sym_if_statement = 98,
  sym_else_clause = 99,
  sym_while_statement = 100,
  sym_do_while_statement = 101,
  sym_for_statement = 102,
  sym_for_in_statement = 103,
  sym_delete_statement = 104,
  sym_exit_statement = 105,
  sym_return_statement = 106,
  sym_switch_statement = 107,
  sym_switch_body = 108,
  sym_switch_case = 109,
  sym_switch_default = 110,
  sym__io_statement = 111,
  sym__getline_exp = 112,
  sym_getline_input = 113,
  sym_getline_file = 114,
  sym__print_args = 115,
  sym_print_statement = 116,
  sym_printf_statement = 117,
  sym_redirected_io_statement = 118,
  sym_piped_io_statement = 119,
  sym_block = 120,
  sym__block_content = 121,
  sym__exp = 122,
  sym_ternary_exp = 123,
  sym_binary_exp = 124,
  sym_unary_exp = 125,
  sym_update_exp = 126,
  sym_assignment_exp = 127,
  sym_piped_io_exp = 128,
  sym_string_concat = 129,
  sym_field_ref = 130,
  sym_array_ref = 131,
  sym_exp_list = 132,
  sym_regex = 133,
  sym_regex_constant = 134,
  sym_grouping = 135,
  sym__primitive = 136,
  sym_namespace = 137,
  sym_ns_qualified_name = 138,
  sym_string = 139,
  sym_func_def = 140,
  sym_param_list = 141,
  sym_func_call = 142,
  sym_indirect_func_call = 143,
  sym_args = 144,
  sym_comment = 145,
  aux_sym_program_repeat1 = 146,
  aux_sym_switch_body_repeat1 = 147,
  aux_sym_block_repeat1 = 148,
  aux_sym_exp_list_repeat1 = 149,
  aux_sym_string_repeat1 = 150,
  aux_sym_param_list_repeat1 = 151,
  aux_sym_args_repeat1 = 152,
  anon_alias_sym_namespace = 153,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_COMMA] = ",",
  [anon_sym_BEGIN] = "BEGIN",
  [anon_sym_END] = "END",
  [anon_sym_BEGINFILE] = "BEGINFILE",
  [anon_sym_ENDFILE] = "ENDFILE",
  [anon_sym_ATinclude] = "@include",
  [anon_sym_ATload] = "@load",
  [anon_sym_ATnamespace] = "@namespace",
  [anon_sym_SEMI] = ";",
  [anon_sym_LF] = "\n",
  [anon_sym_CR_LF] = "\r\n",
  [anon_sym_if] = "if",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_else] = "else",
  [anon_sym_while] = "while",
  [anon_sym_do] = "do",
  [anon_sym_for] = "for",
  [anon_sym_in] = "in",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [anon_sym_delete] = "delete",
  [anon_sym_exit] = "exit",
  [anon_sym_return] = "return",
  [anon_sym_switch] = "switch",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_case] = "case",
  [anon_sym_COLON] = ":",
  [anon_sym_default] = "default",
  [anon_sym_getline] = "getline",
  [anon_sym_LT] = "<",
  [sym_next_statement] = "next_statement",
  [sym_nextfile_statement] = "nextfile_statement",
  [anon_sym_print] = "print",
  [anon_sym_LPAREN2] = "(",
  [anon_sym_printf] = "printf",
  [anon_sym_GT] = ">",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_PIPE] = "|",
  [anon_sym_PIPE_AMP] = "|&",
  [anon_sym_QMARK] = "\?",
  [anon_sym_CARET] = "^",
  [anon_sym_STAR_STAR] = "**",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_TILDE] = "~",
  [anon_sym_BANG_TILDE] = "!~",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_BANG] = "!",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_EQ] = "=",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_DOLLAR] = "$",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_SLASH2] = "/",
  [sym_regex_pattern] = "regex_pattern",
  [sym_regex_flags] = "regex_flags",
  [anon_sym_AT] = "@",
  [anon_sym_COLON_COLON] = "::",
  [sym_number] = "number",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_string_token1] = "string_token1",
  [sym_escape_sequence] = "escape_sequence",
  [anon_sym_function] = "function",
  [anon_sym_func] = "func",
  [anon_sym_POUND] = "#",
  [aux_sym_comment_token1] = "comment_token1",
  [sym_concatenating_space] = "concatenating_space",
  [sym__if_else_separator] = "_if_else_separator",
  [sym__ambiguous_comment] = "_ambiguous_comment",
  [sym__no_space] = "_no_space",
  [sym_program] = "program",
  [sym_rule] = "rule",
  [sym_pattern] = "pattern",
  [sym_range_pattern] = "range_pattern",
  [sym__special_pattern] = "_special_pattern",
  [sym_directive] = "directive",
  [sym__statement] = "_statement",
  [sym__statement_separated] = "_statement_separated",
  [sym__control_statement] = "_control_statement",
  [sym_if_statement] = "if_statement",
  [sym_else_clause] = "else_clause",
  [sym_while_statement] = "while_statement",
  [sym_do_while_statement] = "do_while_statement",
  [sym_for_statement] = "for_statement",
  [sym_for_in_statement] = "for_in_statement",
  [sym_delete_statement] = "delete_statement",
  [sym_exit_statement] = "exit_statement",
  [sym_return_statement] = "return_statement",
  [sym_switch_statement] = "switch_statement",
  [sym_switch_body] = "switch_body",
  [sym_switch_case] = "switch_case",
  [sym_switch_default] = "switch_default",
  [sym__io_statement] = "_io_statement",
  [sym__getline_exp] = "_getline_exp",
  [sym_getline_input] = "getline_input",
  [sym_getline_file] = "getline_file",
  [sym__print_args] = "_print_args",
  [sym_print_statement] = "print_statement",
  [sym_printf_statement] = "printf_statement",
  [sym_redirected_io_statement] = "redirected_io_statement",
  [sym_piped_io_statement] = "piped_io_statement",
  [sym_block] = "block",
  [sym__block_content] = "_block_content",
  [sym__exp] = "_exp",
  [sym_ternary_exp] = "ternary_exp",
  [sym_binary_exp] = "binary_exp",
  [sym_unary_exp] = "unary_exp",
  [sym_update_exp] = "update_exp",
  [sym_assignment_exp] = "assignment_exp",
  [sym_piped_io_exp] = "piped_io_exp",
  [sym_string_concat] = "string_concat",
  [sym_field_ref] = "field_ref",
  [sym_array_ref] = "array_ref",
  [sym_exp_list] = "exp_list",
  [sym_regex] = "regex",
  [sym_regex_constant] = "regex_constant",
  [sym_grouping] = "grouping",
  [sym__primitive] = "_primitive",
  [sym_namespace] = "namespace",
  [sym_ns_qualified_name] = "ns_qualified_name",
  [sym_string] = "string",
  [sym_func_def] = "func_def",
  [sym_param_list] = "param_list",
  [sym_func_call] = "func_call",
  [sym_indirect_func_call] = "indirect_func_call",
  [sym_args] = "args",
  [sym_comment] = "comment",
  [aux_sym_program_repeat1] = "program_repeat1",
  [aux_sym_switch_body_repeat1] = "switch_body_repeat1",
  [aux_sym_block_repeat1] = "block_repeat1",
  [aux_sym_exp_list_repeat1] = "exp_list_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_param_list_repeat1] = "param_list_repeat1",
  [aux_sym_args_repeat1] = "args_repeat1",
  [anon_alias_sym_namespace] = "namespace",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_BEGIN] = anon_sym_BEGIN,
  [anon_sym_END] = anon_sym_END,
  [anon_sym_BEGINFILE] = anon_sym_BEGINFILE,
  [anon_sym_ENDFILE] = anon_sym_ENDFILE,
  [anon_sym_ATinclude] = anon_sym_ATinclude,
  [anon_sym_ATload] = anon_sym_ATload,
  [anon_sym_ATnamespace] = anon_sym_ATnamespace,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_LF] = anon_sym_LF,
  [anon_sym_CR_LF] = anon_sym_CR_LF,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_in] = anon_sym_in,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [anon_sym_delete] = anon_sym_delete,
  [anon_sym_exit] = anon_sym_exit,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_getline] = anon_sym_getline,
  [anon_sym_LT] = anon_sym_LT,
  [sym_next_statement] = sym_next_statement,
  [sym_nextfile_statement] = sym_nextfile_statement,
  [anon_sym_print] = anon_sym_print,
  [anon_sym_LPAREN2] = anon_sym_LPAREN,
  [anon_sym_printf] = anon_sym_printf,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_PIPE_AMP] = anon_sym_PIPE_AMP,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_STAR_STAR] = anon_sym_STAR_STAR,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_BANG_TILDE] = anon_sym_BANG_TILDE,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_SLASH2] = anon_sym_SLASH,
  [sym_regex_pattern] = sym_regex_pattern,
  [sym_regex_flags] = sym_regex_flags,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [sym_number] = sym_number,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_string_token1] = aux_sym_string_token1,
  [sym_escape_sequence] = sym_escape_sequence,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_func] = anon_sym_func,
  [anon_sym_POUND] = anon_sym_POUND,
  [aux_sym_comment_token1] = aux_sym_comment_token1,
  [sym_concatenating_space] = sym_concatenating_space,
  [sym__if_else_separator] = sym__if_else_separator,
  [sym__ambiguous_comment] = sym__ambiguous_comment,
  [sym__no_space] = sym__no_space,
  [sym_program] = sym_program,
  [sym_rule] = sym_rule,
  [sym_pattern] = sym_pattern,
  [sym_range_pattern] = sym_range_pattern,
  [sym__special_pattern] = sym__special_pattern,
  [sym_directive] = sym_directive,
  [sym__statement] = sym__statement,
  [sym__statement_separated] = sym__statement_separated,
  [sym__control_statement] = sym__control_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_else_clause] = sym_else_clause,
  [sym_while_statement] = sym_while_statement,
  [sym_do_while_statement] = sym_do_while_statement,
  [sym_for_statement] = sym_for_statement,
  [sym_for_in_statement] = sym_for_in_statement,
  [sym_delete_statement] = sym_delete_statement,
  [sym_exit_statement] = sym_exit_statement,
  [sym_return_statement] = sym_return_statement,
  [sym_switch_statement] = sym_switch_statement,
  [sym_switch_body] = sym_switch_body,
  [sym_switch_case] = sym_switch_case,
  [sym_switch_default] = sym_switch_default,
  [sym__io_statement] = sym__io_statement,
  [sym__getline_exp] = sym__getline_exp,
  [sym_getline_input] = sym_getline_input,
  [sym_getline_file] = sym_getline_file,
  [sym__print_args] = sym__print_args,
  [sym_print_statement] = sym_print_statement,
  [sym_printf_statement] = sym_printf_statement,
  [sym_redirected_io_statement] = sym_redirected_io_statement,
  [sym_piped_io_statement] = sym_piped_io_statement,
  [sym_block] = sym_block,
  [sym__block_content] = sym__block_content,
  [sym__exp] = sym__exp,
  [sym_ternary_exp] = sym_ternary_exp,
  [sym_binary_exp] = sym_binary_exp,
  [sym_unary_exp] = sym_unary_exp,
  [sym_update_exp] = sym_update_exp,
  [sym_assignment_exp] = sym_assignment_exp,
  [sym_piped_io_exp] = sym_piped_io_exp,
  [sym_string_concat] = sym_string_concat,
  [sym_field_ref] = sym_field_ref,
  [sym_array_ref] = sym_array_ref,
  [sym_exp_list] = sym_exp_list,
  [sym_regex] = sym_regex,
  [sym_regex_constant] = sym_regex_constant,
  [sym_grouping] = sym_grouping,
  [sym__primitive] = sym__primitive,
  [sym_namespace] = sym_namespace,
  [sym_ns_qualified_name] = sym_ns_qualified_name,
  [sym_string] = sym_string,
  [sym_func_def] = sym_func_def,
  [sym_param_list] = sym_param_list,
  [sym_func_call] = sym_func_call,
  [sym_indirect_func_call] = sym_indirect_func_call,
  [sym_args] = sym_args,
  [sym_comment] = sym_comment,
  [aux_sym_program_repeat1] = aux_sym_program_repeat1,
  [aux_sym_switch_body_repeat1] = aux_sym_switch_body_repeat1,
  [aux_sym_block_repeat1] = aux_sym_block_repeat1,
  [aux_sym_exp_list_repeat1] = aux_sym_exp_list_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_param_list_repeat1] = aux_sym_param_list_repeat1,
  [aux_sym_args_repeat1] = aux_sym_args_repeat1,
  [anon_alias_sym_namespace] = anon_alias_sym_namespace,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BEGIN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_END] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BEGINFILE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ENDFILE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATinclude] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATload] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATnamespace] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CR_LF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_delete] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_exit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_getline] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [sym_next_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_nextfile_statement] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_print] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_printf] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH2] = {
    .visible = true,
    .named = false,
  },
  [sym_regex_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_regex_flags] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_func] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_comment_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_concatenating_space] = {
    .visible = true,
    .named = true,
  },
  [sym__if_else_separator] = {
    .visible = false,
    .named = true,
  },
  [sym__ambiguous_comment] = {
    .visible = false,
    .named = true,
  },
  [sym__no_space] = {
    .visible = false,
    .named = true,
  },
  [sym_program] = {
    .visible = true,
    .named = true,
  },
  [sym_rule] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_range_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__special_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_directive] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym__statement_separated] = {
    .visible = false,
    .named = true,
  },
  [sym__control_statement] = {
    .visible = false,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_do_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_in_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_delete_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_exit_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_body] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_case] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_default] = {
    .visible = true,
    .named = true,
  },
  [sym__io_statement] = {
    .visible = false,
    .named = true,
  },
  [sym__getline_exp] = {
    .visible = false,
    .named = true,
  },
  [sym_getline_input] = {
    .visible = true,
    .named = true,
  },
  [sym_getline_file] = {
    .visible = true,
    .named = true,
  },
  [sym__print_args] = {
    .visible = false,
    .named = true,
  },
  [sym_print_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_printf_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_redirected_io_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_piped_io_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym__block_content] = {
    .visible = false,
    .named = true,
  },
  [sym__exp] = {
    .visible = false,
    .named = true,
  },
  [sym_ternary_exp] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_exp] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_exp] = {
    .visible = true,
    .named = true,
  },
  [sym_update_exp] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_exp] = {
    .visible = true,
    .named = true,
  },
  [sym_piped_io_exp] = {
    .visible = true,
    .named = true,
  },
  [sym_string_concat] = {
    .visible = true,
    .named = true,
  },
  [sym_field_ref] = {
    .visible = true,
    .named = true,
  },
  [sym_array_ref] = {
    .visible = true,
    .named = true,
  },
  [sym_exp_list] = {
    .visible = true,
    .named = true,
  },
  [sym_regex] = {
    .visible = true,
    .named = true,
  },
  [sym_regex_constant] = {
    .visible = true,
    .named = true,
  },
  [sym_grouping] = {
    .visible = true,
    .named = true,
  },
  [sym__primitive] = {
    .visible = false,
    .named = true,
  },
  [sym_namespace] = {
    .visible = true,
    .named = true,
  },
  [sym_ns_qualified_name] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_func_def] = {
    .visible = true,
    .named = true,
  },
  [sym_param_list] = {
    .visible = true,
    .named = true,
  },
  [sym_func_call] = {
    .visible = true,
    .named = true,
  },
  [sym_indirect_func_call] = {
    .visible = true,
    .named = true,
  },
  [sym_args] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_program_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_exp_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_param_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_args_repeat1] = {
    .visible = false,
    .named = false,
  },
  [anon_alias_sym_namespace] = {
    .visible = true,
    .named = false,
  },
};

enum {
  field_advancement = 1,
  field_alternative = 2,
  field_argument = 3,
  field_command = 4,
  field_condition = 5,
  field_consequence = 6,
  field_filename = 7,
  field_flags = 8,
  field_index = 9,
  field_initializer = 10,
  field_left = 11,
  field_name = 12,
  field_operator = 13,
  field_pattern = 14,
  field_right = 15,
  field_start = 16,
  field_stop = 17,
  field_value = 18,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_advancement] = "advancement",
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_command] = "command",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_filename] = "filename",
  [field_flags] = "flags",
  [field_index] = "index",
  [field_initializer] = "initializer",
  [field_left] = "left",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_pattern] = "pattern",
  [field_right] = "right",
  [field_start] = "start",
  [field_stop] = "stop",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 2},
  [3] = {.index = 2, .length = 2},
  [4] = {.index = 4, .length = 1},
  [5] = {.index = 5, .length = 1},
  [6] = {.index = 6, .length = 2},
  [7] = {.index = 8, .length = 1},
  [8] = {.index = 9, .length = 2},
  [9] = {.index = 11, .length = 3},
  [10] = {.index = 14, .length = 1},
  [11] = {.index = 15, .length = 1},
  [12] = {.index = 16, .length = 1},
  [13] = {.index = 17, .length = 2},
  [14] = {.index = 19, .length = 1},
  [15] = {.index = 20, .length = 1},
  [16] = {.index = 21, .length = 3},
  [17] = {.index = 24, .length = 3},
  [18] = {.index = 27, .length = 3},
  [19] = {.index = 30, .length = 1},
  [20] = {.index = 31, .length = 1},
  [21] = {.index = 32, .length = 2},
  [22] = {.index = 34, .length = 1},
  [23] = {.index = 35, .length = 2},
  [24] = {.index = 37, .length = 2},
  [25] = {.index = 39, .length = 2},
  [26] = {.index = 41, .length = 1},
  [27] = {.index = 42, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_argument, 1},
    {field_operator, 0},
  [2] =
    {field_argument, 0},
    {field_operator, 1},
  [4] =
    {field_filename, 2},
  [5] =
    {field_pattern, 1},
  [6] =
    {field_left, 0},
    {field_right, 2},
  [8] =
    {field_name, 0},
  [9] =
    {field_start, 0},
    {field_stop, 2},
  [11] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [14] =
    {field_command, 0},
  [15] =
    {field_command, 2},
  [16] =
    {field_filename, 3},
  [17] =
    {field_flags, 3},
    {field_pattern, 1},
  [19] =
    {field_index, 2},
  [20] =
    {field_name, 1},
  [21] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [24] =
    {field_condition, 1},
    {field_condition, 2},
    {field_condition, 3},
  [27] =
    {field_condition, 3},
    {field_condition, 4},
    {field_condition, 5},
  [30] =
    {field_advancement, 4},
  [31] =
    {field_condition, 3},
  [32] =
    {field_left, 2},
    {field_right, 4},
  [34] =
    {field_initializer, 2},
  [35] =
    {field_advancement, 5},
    {field_condition, 3},
  [37] =
    {field_advancement, 5},
    {field_initializer, 2},
  [39] =
    {field_condition, 4},
    {field_initializer, 2},
  [41] =
    {field_value, 1},
  [42] =
    {field_advancement, 6},
    {field_condition, 4},
    {field_initializer, 2},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = anon_alias_sym_namespace,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(104);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(141);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(124);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '*') ADVANCE(137);
      if (lookahead == '+') ADVANCE(144);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(147);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == ':') ADVANCE(122);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(178);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') ADVANCE(3);
      if (lookahead == ']') ADVANCE(169);
      if (lookahead == '^') ADVANCE(134);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(96)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(48)
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(48)
      if (lookahead == '\r') SKIP(1)
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(48)
      if (lookahead == '\r') SKIP(1)
      if (lookahead == '"' ||
          lookahead == '\\' ||
          lookahead == 'a' ||
          lookahead == 'b' ||
          lookahead == 'f' ||
          lookahead == 'n' ||
          lookahead == 'r' ||
          lookahead == 't' ||
          lookahead == 'v') ADVANCE(185);
      if (lookahead == 'x') ADVANCE(82);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(187);
      END_STATE();
    case 4:
      if (lookahead == '\n') ADVANCE(110);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(143);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(146);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ':') ADVANCE(60);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(177);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(7)
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(5)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 5:
      if (lookahead == '\n') ADVANCE(110);
      if (lookahead == '\r') ADVANCE(5);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(143);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(146);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(177);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(7)
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(5)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 6:
      if (lookahead == '\n') SKIP(5)
      END_STATE();
    case 7:
      if (lookahead == '\n') SKIP(5)
      if (lookahead == '\r') SKIP(6)
      END_STATE();
    case 8:
      if (lookahead == '\n') SKIP(49)
      END_STATE();
    case 9:
      if (lookahead == '\n') SKIP(49)
      if (lookahead == '\r') SKIP(8)
      END_STATE();
    case 10:
      if (lookahead == '\n') SKIP(38)
      END_STATE();
    case 11:
      if (lookahead == '\n') SKIP(38)
      if (lookahead == '\r') SKIP(10)
      END_STATE();
    case 12:
      if (lookahead == '\n') SKIP(42)
      END_STATE();
    case 13:
      if (lookahead == '\n') SKIP(42)
      if (lookahead == '\r') SKIP(12)
      END_STATE();
    case 14:
      if (lookahead == '\n') SKIP(44)
      END_STATE();
    case 15:
      if (lookahead == '\n') SKIP(44)
      if (lookahead == '\r') SKIP(14)
      END_STATE();
    case 16:
      if (lookahead == '\n') SKIP(51)
      END_STATE();
    case 17:
      if (lookahead == '\n') SKIP(51)
      if (lookahead == '\r') SKIP(16)
      END_STATE();
    case 18:
      if (lookahead == '\n') SKIP(53)
      END_STATE();
    case 19:
      if (lookahead == '\n') SKIP(53)
      if (lookahead == '\r') SKIP(18)
      END_STATE();
    case 20:
      if (lookahead == '\n') SKIP(55)
      END_STATE();
    case 21:
      if (lookahead == '\n') SKIP(55)
      if (lookahead == '\r') SKIP(20)
      END_STATE();
    case 22:
      if (lookahead == '\n') SKIP(55)
      if (lookahead == '\r') SKIP(20)
      if (lookahead == '"' ||
          lookahead == '\\' ||
          lookahead == 'a' ||
          lookahead == 'b' ||
          lookahead == 'f' ||
          lookahead == 'n' ||
          lookahead == 'r' ||
          lookahead == 't' ||
          lookahead == 'v') ADVANCE(185);
      if (lookahead == 'x') ADVANCE(82);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(187);
      END_STATE();
    case 23:
      if (lookahead == '\n') SKIP(57)
      END_STATE();
    case 24:
      if (lookahead == '\n') SKIP(57)
      if (lookahead == '\r') SKIP(23)
      END_STATE();
    case 25:
      if (lookahead == '\n') ADVANCE(63);
      if (lookahead == '\\') ADVANCE(174);
      if (lookahead != 0) ADVANCE(173);
      END_STATE();
    case 26:
      if (lookahead == '\n') SKIP(58)
      END_STATE();
    case 27:
      if (lookahead == '\n') SKIP(58)
      if (lookahead == '\r') ADVANCE(172);
      if (lookahead != 0) ADVANCE(172);
      END_STATE();
    case 28:
      if (lookahead == '\n') SKIP(58)
      if (lookahead == '\r') SKIP(26)
      END_STATE();
    case 29:
      if (lookahead == '\n') ADVANCE(111);
      if (lookahead == '\r') ADVANCE(30);
      if (lookahead == '!') ADVANCE(156);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '(') ADVANCE(124);
      if (lookahead == '+') ADVANCE(143);
      if (lookahead == '-') ADVANCE(146);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '>') ADVANCE(127);
      if (lookahead == '@') ADVANCE(177);
      if (lookahead == '\\') SKIP(34)
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(129);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(30)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 30:
      if (lookahead == '\n') ADVANCE(111);
      if (lookahead == '\r') ADVANCE(30);
      if (lookahead == '!') ADVANCE(156);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == '+') ADVANCE(143);
      if (lookahead == '-') ADVANCE(146);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '>') ADVANCE(127);
      if (lookahead == '@') ADVANCE(177);
      if (lookahead == '\\') SKIP(34)
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(129);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(30)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 31:
      if (lookahead == '\n') SKIP(47)
      END_STATE();
    case 32:
      if (lookahead == '\n') SKIP(47)
      if (lookahead == '\r') SKIP(31)
      END_STATE();
    case 33:
      if (lookahead == '\n') SKIP(30)
      END_STATE();
    case 34:
      if (lookahead == '\n') SKIP(30)
      if (lookahead == '\r') SKIP(33)
      END_STATE();
    case 35:
      if (lookahead == '\n') SKIP(40)
      END_STATE();
    case 36:
      if (lookahead == '\n') SKIP(40)
      if (lookahead == '\r') SKIP(35)
      END_STATE();
    case 37:
      if (lookahead == '\n') ADVANCE(112);
      if (lookahead == '\r') ADVANCE(38);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(141);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == '*') ADVANCE(137);
      if (lookahead == '+') ADVANCE(144);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(147);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(177);
      if (lookahead == '\\') SKIP(11)
      if (lookahead == '^') ADVANCE(134);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(38)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(175);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(179);
      END_STATE();
    case 38:
      if (lookahead == '\n') ADVANCE(112);
      if (lookahead == '\r') ADVANCE(38);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(141);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == '*') ADVANCE(137);
      if (lookahead == '+') ADVANCE(144);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(147);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(177);
      if (lookahead == '\\') SKIP(11)
      if (lookahead == '^') ADVANCE(134);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(38)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 39:
      if (lookahead == '\n') ADVANCE(113);
      if (lookahead == '\r') ADVANCE(40);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(143);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(146);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(177);
      if (lookahead == '\\') SKIP(36)
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(40)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(175);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(179);
      END_STATE();
    case 40:
      if (lookahead == '\n') ADVANCE(113);
      if (lookahead == '\r') ADVANCE(40);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(143);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(146);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(177);
      if (lookahead == '\\') SKIP(36)
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(40)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 41:
      if (lookahead == '\n') ADVANCE(114);
      if (lookahead == '\r') ADVANCE(42);
      if (lookahead == '!') ADVANCE(61);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(142);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(145);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ':') ADVANCE(60);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(13)
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(42)
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 42:
      if (lookahead == '\n') ADVANCE(114);
      if (lookahead == '\r') ADVANCE(42);
      if (lookahead == '!') ADVANCE(61);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(142);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(145);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(13)
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(42)
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 43:
      if (lookahead == '\n') ADVANCE(115);
      if (lookahead == '\r') ADVANCE(44);
      if (lookahead == '!') ADVANCE(61);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(142);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(145);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '\\') SKIP(15)
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(44)
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(175);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(179);
      END_STATE();
    case 44:
      if (lookahead == '\n') ADVANCE(115);
      if (lookahead == '\r') ADVANCE(44);
      if (lookahead == '!') ADVANCE(61);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(142);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(145);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '\\') SKIP(15)
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(44)
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 45:
      if (lookahead == '\n') ADVANCE(116);
      if (lookahead == '\r') ADVANCE(47);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(141);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(124);
      if (lookahead == '*') ADVANCE(137);
      if (lookahead == '+') ADVANCE(144);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(147);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == ':') ADVANCE(60);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(177);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(32)
      if (lookahead == '^') ADVANCE(134);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(47)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 46:
      if (lookahead == '\n') ADVANCE(116);
      if (lookahead == '\r') ADVANCE(47);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(141);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == '*') ADVANCE(137);
      if (lookahead == '+') ADVANCE(144);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(147);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == ':') ADVANCE(60);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(177);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(32)
      if (lookahead == '^') ADVANCE(134);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(47)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 47:
      if (lookahead == '\n') ADVANCE(116);
      if (lookahead == '\r') ADVANCE(47);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(141);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == '*') ADVANCE(137);
      if (lookahead == '+') ADVANCE(144);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(147);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(177);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(32)
      if (lookahead == '^') ADVANCE(134);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(47)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 48:
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(141);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '*') ADVANCE(137);
      if (lookahead == '+') ADVANCE(144);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(147);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == ':') ADVANCE(121);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(178);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(2)
      if (lookahead == ']') ADVANCE(169);
      if (lookahead == '^') ADVANCE(134);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(48)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 49:
      if (lookahead == '!') ADVANCE(156);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '+') ADVANCE(143);
      if (lookahead == '-') ADVANCE(146);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '@') ADVANCE(177);
      if (lookahead == '\\') SKIP(9)
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(49)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 50:
      if (lookahead == '!') ADVANCE(61);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(124);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(142);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(145);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ':') ADVANCE(122);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(125);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(17)
      if (lookahead == ']') ADVANCE(169);
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(51)
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 51:
      if (lookahead == '!') ADVANCE(61);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(142);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(145);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ':') ADVANCE(121);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(125);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(17)
      if (lookahead == ']') ADVANCE(169);
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(51)
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 52:
      if (lookahead == '!') ADVANCE(61);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(142);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(145);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ':') ADVANCE(121);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(125);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '\\') SKIP(19)
      if (lookahead == ']') ADVANCE(169);
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(53)
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(175);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(179);
      END_STATE();
    case 53:
      if (lookahead == '!') ADVANCE(61);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(142);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(145);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ':') ADVANCE(121);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(125);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '\\') SKIP(19)
      if (lookahead == ']') ADVANCE(169);
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(53)
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 54:
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(191);
      if (lookahead == '\\') ADVANCE(22);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(183);
      if (lookahead != 0) ADVANCE(184);
      END_STATE();
    case 55:
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(191);
      if (lookahead == '\\') SKIP(21)
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(183);
      if (lookahead != 0) ADVANCE(184);
      END_STATE();
    case 56:
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '/') ADVANCE(170);
      if (lookahead == ':') ADVANCE(121);
      if (lookahead == '\\') SKIP(24)
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(57)
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(176);
      END_STATE();
    case 57:
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == ':') ADVANCE(121);
      if (lookahead == '\\') SKIP(24)
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(57)
      END_STATE();
    case 58:
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '\\') SKIP(28)
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(58)
      END_STATE();
    case 59:
      if (lookahead == '&') ADVANCE(154);
      END_STATE();
    case 60:
      if (lookahead == ':') ADVANCE(180);
      END_STATE();
    case 61:
      if (lookahead == '=') ADVANCE(151);
      if (lookahead == '~') ADVANCE(153);
      END_STATE();
    case 62:
      if (lookahead == '=') ADVANCE(150);
      END_STATE();
    case 63:
      if (lookahead == '\\') ADVANCE(83);
      if (lookahead == ']') ADVANCE(172);
      if (lookahead != 0) ADVANCE(63);
      END_STATE();
    case 64:
      if (lookahead == '\\') ADVANCE(83);
      if (lookahead != 0 &&
          lookahead != ']') ADVANCE(63);
      END_STATE();
    case 65:
      if (lookahead == 'a') ADVANCE(76);
      END_STATE();
    case 66:
      if (lookahead == 'a') ADVANCE(70);
      END_STATE();
    case 67:
      if (lookahead == 'a') ADVANCE(69);
      END_STATE();
    case 68:
      if (lookahead == 'c') ADVANCE(75);
      END_STATE();
    case 69:
      if (lookahead == 'c') ADVANCE(74);
      END_STATE();
    case 70:
      if (lookahead == 'd') ADVANCE(107);
      END_STATE();
    case 71:
      if (lookahead == 'd') ADVANCE(73);
      END_STATE();
    case 72:
      if (lookahead == 'e') ADVANCE(80);
      END_STATE();
    case 73:
      if (lookahead == 'e') ADVANCE(106);
      END_STATE();
    case 74:
      if (lookahead == 'e') ADVANCE(108);
      END_STATE();
    case 75:
      if (lookahead == 'l') ADVANCE(81);
      END_STATE();
    case 76:
      if (lookahead == 'm') ADVANCE(72);
      END_STATE();
    case 77:
      if (lookahead == 'n') ADVANCE(68);
      END_STATE();
    case 78:
      if (lookahead == 'o') ADVANCE(66);
      END_STATE();
    case 79:
      if (lookahead == 'p') ADVANCE(67);
      END_STATE();
    case 80:
      if (lookahead == 's') ADVANCE(79);
      END_STATE();
    case 81:
      if (lookahead == 'u') ADVANCE(71);
      END_STATE();
    case 82:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(188);
      END_STATE();
    case 83:
      if (lookahead != 0 &&
          lookahead != '\\' &&
          lookahead != ']') ADVANCE(63);
      if (lookahead == '\\') ADVANCE(83);
      if (lookahead == ']') ADVANCE(173);
      END_STATE();
    case 84:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(172);
      END_STATE();
    case 85:
      if (eof) ADVANCE(104);
      if (lookahead == '\n') SKIP(96)
      END_STATE();
    case 86:
      if (eof) ADVANCE(104);
      if (lookahead == '\n') SKIP(96)
      if (lookahead == '\r') SKIP(85)
      END_STATE();
    case 87:
      if (eof) ADVANCE(104);
      if (lookahead == '\n') SKIP(99)
      END_STATE();
    case 88:
      if (eof) ADVANCE(104);
      if (lookahead == '\n') SKIP(99)
      if (lookahead == '\r') SKIP(87)
      END_STATE();
    case 89:
      if (eof) ADVANCE(104);
      if (lookahead == '\n') SKIP(103)
      END_STATE();
    case 90:
      if (eof) ADVANCE(104);
      if (lookahead == '\n') SKIP(103)
      if (lookahead == '\r') SKIP(89)
      END_STATE();
    case 91:
      if (eof) ADVANCE(104);
      if (lookahead == '\n') SKIP(101)
      END_STATE();
    case 92:
      if (eof) ADVANCE(104);
      if (lookahead == '\n') SKIP(101)
      if (lookahead == '\r') SKIP(91)
      END_STATE();
    case 93:
      if (eof) ADVANCE(104);
      if (lookahead == '\n') SKIP(97)
      END_STATE();
    case 94:
      if (eof) ADVANCE(104);
      if (lookahead == '\n') SKIP(97)
      if (lookahead == '\r') SKIP(93)
      END_STATE();
    case 95:
      if (eof) ADVANCE(104);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(141);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '*') ADVANCE(137);
      if (lookahead == '+') ADVANCE(144);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(147);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == ':') ADVANCE(122);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(125);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(178);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(94)
      if (lookahead == ']') ADVANCE(169);
      if (lookahead == '^') ADVANCE(134);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(97)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 96:
      if (eof) ADVANCE(104);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(141);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '*') ADVANCE(137);
      if (lookahead == '+') ADVANCE(144);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(147);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == ':') ADVANCE(121);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(126);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(178);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(86)
      if (lookahead == ']') ADVANCE(169);
      if (lookahead == '^') ADVANCE(134);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '}') ADVANCE(120);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(96)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 97:
      if (eof) ADVANCE(104);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(141);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '*') ADVANCE(137);
      if (lookahead == '+') ADVANCE(144);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(147);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == ':') ADVANCE(121);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(125);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(178);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(94)
      if (lookahead == ']') ADVANCE(169);
      if (lookahead == '^') ADVANCE(134);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(97)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 98:
      if (eof) ADVANCE(104);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(141);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '*') ADVANCE(137);
      if (lookahead == '+') ADVANCE(144);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(147);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == ':') ADVANCE(121);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(125);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(178);
      if (lookahead == '\\') SKIP(88)
      if (lookahead == ']') ADVANCE(169);
      if (lookahead == '^') ADVANCE(134);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(99)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(175);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(179);
      END_STATE();
    case 99:
      if (eof) ADVANCE(104);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(141);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '*') ADVANCE(137);
      if (lookahead == '+') ADVANCE(144);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(147);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == ':') ADVANCE(121);
      if (lookahead == ';') ADVANCE(109);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '>') ADVANCE(125);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(178);
      if (lookahead == '\\') SKIP(88)
      if (lookahead == ']') ADVANCE(169);
      if (lookahead == '^') ADVANCE(134);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(99)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 100:
      if (eof) ADVANCE(104);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(143);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(146);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ':') ADVANCE(122);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(125);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(178);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(92)
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(101)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 101:
      if (eof) ADVANCE(104);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == ')') ADVANCE(118);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(143);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(146);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == ':') ADVANCE(121);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(125);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(178);
      if (lookahead == '[') ADVANCE(168);
      if (lookahead == '\\') SKIP(92)
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(101)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 102:
      if (eof) ADVANCE(104);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(143);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(146);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(125);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(178);
      if (lookahead == '\\') SKIP(90)
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(103)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(175);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(179);
      END_STATE();
    case 103:
      if (eof) ADVANCE(104);
      if (lookahead == '!') ADVANCE(157);
      if (lookahead == '"') ADVANCE(182);
      if (lookahead == '#') ADVANCE(189);
      if (lookahead == '$') ADVANCE(167);
      if (lookahead == '%') ADVANCE(140);
      if (lookahead == '&') ADVANCE(59);
      if (lookahead == '(') ADVANCE(117);
      if (lookahead == '*') ADVANCE(136);
      if (lookahead == '+') ADVANCE(143);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(146);
      if (lookahead == '/') ADVANCE(138);
      if (lookahead == '<') ADVANCE(123);
      if (lookahead == '=') ADVANCE(62);
      if (lookahead == '>') ADVANCE(125);
      if (lookahead == '?') ADVANCE(132);
      if (lookahead == '@') ADVANCE(178);
      if (lookahead == '\\') SKIP(90)
      if (lookahead == '^') ADVANCE(133);
      if (lookahead == '{') ADVANCE(119);
      if (lookahead == '|') ADVANCE(130);
      if (lookahead == '~') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(103)
      if (('.' <= lookahead && lookahead <= '9')) ADVANCE(181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_ATinclude);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_ATload);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(anon_sym_ATnamespace);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(110);
      if (lookahead == '\r') ADVANCE(5);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(111);
      if (lookahead == '\r') ADVANCE(30);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(112);
      if (lookahead == '\r') ADVANCE(38);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(113);
      if (lookahead == '\r') ADVANCE(40);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(114);
      if (lookahead == '\r') ADVANCE(42);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(115);
      if (lookahead == '\r') ADVANCE(44);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(116);
      if (lookahead == '\r') ADVANCE(47);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(180);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(148);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_LPAREN2);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(149);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(149);
      if (lookahead == '>') ADVANCE(128);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '>') ADVANCE(128);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '&') ADVANCE(131);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '&') ADVANCE(131);
      if (lookahead == '|') ADVANCE(155);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_PIPE_AMP);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(166);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(135);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(135);
      if (lookahead == '=') ADVANCE(163);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '=') ADVANCE(164);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(165);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(158);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(158);
      if (lookahead == '=') ADVANCE(161);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(159);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(159);
      if (lookahead == '=') ADVANCE(162);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_BANG_TILDE);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(151);
      if (lookahead == '~') ADVANCE(153);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(150);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_SLASH2);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(sym_regex_pattern);
      if (lookahead == '#') ADVANCE(190);
      if (lookahead == '[') ADVANCE(64);
      if (lookahead == '\\') ADVANCE(27);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(171);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '/') ADVANCE(172);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(sym_regex_pattern);
      if (lookahead == '[') ADVANCE(64);
      if (lookahead == '\\') ADVANCE(84);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '/') ADVANCE(172);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(sym_regex_pattern);
      if (lookahead == '[') ADVANCE(63);
      if (lookahead == '\\') ADVANCE(25);
      if (lookahead == ']') ADVANCE(172);
      if (lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == '/') ADVANCE(63);
      if (lookahead != 0) ADVANCE(173);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(sym_regex_pattern);
      if (lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == '/') ADVANCE(63);
      if (lookahead == '[') ADVANCE(63);
      if (lookahead == '\\') ADVANCE(25);
      if (lookahead != 0) ADVANCE(173);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(sym_regex_flags);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(175);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(179);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(sym_regex_flags);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(176);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == 'i') ADVANCE(77);
      if (lookahead == 'l') ADVANCE(78);
      if (lookahead == 'n') ADVANCE(65);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(179);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(181);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(aux_sym_string_token1);
      if (lookahead == '#') ADVANCE(191);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(183);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(184);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(aux_sym_string_token1);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(184);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(185);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(186);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(185);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == '[') ADVANCE(64);
      if (lookahead == '\\') ADVANCE(84);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '/') ADVANCE(172);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(184);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(195);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(aux_sym_comment_token1);
      if (lookahead == '\r') ADVANCE(195);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(195);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(aux_sym_comment_token1);
      if (lookahead == '#') ADVANCE(192);
      if (lookahead == '\\') ADVANCE(193);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(194);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(195);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(aux_sym_comment_token1);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(195);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (lookahead == 'B') ADVANCE(1);
      if (lookahead == 'E') ADVANCE(2);
      if (lookahead == '\\') SKIP(3)
      if (lookahead == 'b') ADVANCE(4);
      if (lookahead == 'c') ADVANCE(5);
      if (lookahead == 'd') ADVANCE(6);
      if (lookahead == 'e') ADVANCE(7);
      if (lookahead == 'f') ADVANCE(8);
      if (lookahead == 'g') ADVANCE(9);
      if (lookahead == 'i') ADVANCE(10);
      if (lookahead == 'n') ADVANCE(11);
      if (lookahead == 'p') ADVANCE(12);
      if (lookahead == 'r') ADVANCE(13);
      if (lookahead == 's') ADVANCE(14);
      if (lookahead == 'w') ADVANCE(15);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(0)
      END_STATE();
    case 1:
      if (lookahead == 'E') ADVANCE(16);
      END_STATE();
    case 2:
      if (lookahead == 'N') ADVANCE(17);
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(0)
      if (lookahead == '\r') SKIP(18)
      END_STATE();
    case 4:
      if (lookahead == 'r') ADVANCE(19);
      END_STATE();
    case 5:
      if (lookahead == 'a') ADVANCE(20);
      if (lookahead == 'o') ADVANCE(21);
      END_STATE();
    case 6:
      if (lookahead == 'e') ADVANCE(22);
      if (lookahead == 'o') ADVANCE(23);
      END_STATE();
    case 7:
      if (lookahead == 'l') ADVANCE(24);
      if (lookahead == 'x') ADVANCE(25);
      END_STATE();
    case 8:
      if (lookahead == 'o') ADVANCE(26);
      if (lookahead == 'u') ADVANCE(27);
      END_STATE();
    case 9:
      if (lookahead == 'e') ADVANCE(28);
      END_STATE();
    case 10:
      if (lookahead == 'f') ADVANCE(29);
      if (lookahead == 'n') ADVANCE(30);
      END_STATE();
    case 11:
      if (lookahead == 'e') ADVANCE(31);
      END_STATE();
    case 12:
      if (lookahead == 'r') ADVANCE(32);
      END_STATE();
    case 13:
      if (lookahead == 'e') ADVANCE(33);
      END_STATE();
    case 14:
      if (lookahead == 'w') ADVANCE(34);
      END_STATE();
    case 15:
      if (lookahead == 'h') ADVANCE(35);
      END_STATE();
    case 16:
      if (lookahead == 'G') ADVANCE(36);
      END_STATE();
    case 17:
      if (lookahead == 'D') ADVANCE(37);
      END_STATE();
    case 18:
      if (lookahead == '\n') SKIP(0)
      END_STATE();
    case 19:
      if (lookahead == 'e') ADVANCE(38);
      END_STATE();
    case 20:
      if (lookahead == 's') ADVANCE(39);
      END_STATE();
    case 21:
      if (lookahead == 'n') ADVANCE(40);
      END_STATE();
    case 22:
      if (lookahead == 'f') ADVANCE(41);
      if (lookahead == 'l') ADVANCE(42);
      END_STATE();
    case 23:
      ACCEPT_TOKEN(anon_sym_do);
      END_STATE();
    case 24:
      if (lookahead == 's') ADVANCE(43);
      END_STATE();
    case 25:
      if (lookahead == 'i') ADVANCE(44);
      END_STATE();
    case 26:
      if (lookahead == 'r') ADVANCE(45);
      END_STATE();
    case 27:
      if (lookahead == 'n') ADVANCE(46);
      END_STATE();
    case 28:
      if (lookahead == 't') ADVANCE(47);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 31:
      if (lookahead == 'x') ADVANCE(48);
      END_STATE();
    case 32:
      if (lookahead == 'i') ADVANCE(49);
      END_STATE();
    case 33:
      if (lookahead == 't') ADVANCE(50);
      END_STATE();
    case 34:
      if (lookahead == 'i') ADVANCE(51);
      END_STATE();
    case 35:
      if (lookahead == 'i') ADVANCE(52);
      END_STATE();
    case 36:
      if (lookahead == 'I') ADVANCE(53);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(anon_sym_END);
      if (lookahead == 'F') ADVANCE(54);
      END_STATE();
    case 38:
      if (lookahead == 'a') ADVANCE(55);
      END_STATE();
    case 39:
      if (lookahead == 'e') ADVANCE(56);
      END_STATE();
    case 40:
      if (lookahead == 't') ADVANCE(57);
      END_STATE();
    case 41:
      if (lookahead == 'a') ADVANCE(58);
      END_STATE();
    case 42:
      if (lookahead == 'e') ADVANCE(59);
      END_STATE();
    case 43:
      if (lookahead == 'e') ADVANCE(60);
      END_STATE();
    case 44:
      if (lookahead == 't') ADVANCE(61);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 46:
      if (lookahead == 'c') ADVANCE(62);
      END_STATE();
    case 47:
      if (lookahead == 'l') ADVANCE(63);
      END_STATE();
    case 48:
      if (lookahead == 't') ADVANCE(64);
      END_STATE();
    case 49:
      if (lookahead == 'n') ADVANCE(65);
      END_STATE();
    case 50:
      if (lookahead == 'u') ADVANCE(66);
      END_STATE();
    case 51:
      if (lookahead == 't') ADVANCE(67);
      END_STATE();
    case 52:
      if (lookahead == 'l') ADVANCE(68);
      END_STATE();
    case 53:
      if (lookahead == 'N') ADVANCE(69);
      END_STATE();
    case 54:
      if (lookahead == 'I') ADVANCE(70);
      END_STATE();
    case 55:
      if (lookahead == 'k') ADVANCE(71);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 57:
      if (lookahead == 'i') ADVANCE(72);
      END_STATE();
    case 58:
      if (lookahead == 'u') ADVANCE(73);
      END_STATE();
    case 59:
      if (lookahead == 't') ADVANCE(74);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(anon_sym_exit);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_func);
      if (lookahead == 't') ADVANCE(75);
      END_STATE();
    case 63:
      if (lookahead == 'i') ADVANCE(76);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(sym_next_statement);
      if (lookahead == 'f') ADVANCE(77);
      END_STATE();
    case 65:
      if (lookahead == 't') ADVANCE(78);
      END_STATE();
    case 66:
      if (lookahead == 'r') ADVANCE(79);
      END_STATE();
    case 67:
      if (lookahead == 'c') ADVANCE(80);
      END_STATE();
    case 68:
      if (lookahead == 'e') ADVANCE(81);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_BEGIN);
      if (lookahead == 'F') ADVANCE(82);
      END_STATE();
    case 70:
      if (lookahead == 'L') ADVANCE(83);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym_break_statement);
      END_STATE();
    case 72:
      if (lookahead == 'n') ADVANCE(84);
      END_STATE();
    case 73:
      if (lookahead == 'l') ADVANCE(85);
      END_STATE();
    case 74:
      if (lookahead == 'e') ADVANCE(86);
      END_STATE();
    case 75:
      if (lookahead == 'i') ADVANCE(87);
      END_STATE();
    case 76:
      if (lookahead == 'n') ADVANCE(88);
      END_STATE();
    case 77:
      if (lookahead == 'i') ADVANCE(89);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_print);
      if (lookahead == 'f') ADVANCE(90);
      END_STATE();
    case 79:
      if (lookahead == 'n') ADVANCE(91);
      END_STATE();
    case 80:
      if (lookahead == 'h') ADVANCE(92);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 82:
      if (lookahead == 'I') ADVANCE(93);
      END_STATE();
    case 83:
      if (lookahead == 'E') ADVANCE(94);
      END_STATE();
    case 84:
      if (lookahead == 'u') ADVANCE(95);
      END_STATE();
    case 85:
      if (lookahead == 't') ADVANCE(96);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_delete);
      END_STATE();
    case 87:
      if (lookahead == 'o') ADVANCE(97);
      END_STATE();
    case 88:
      if (lookahead == 'e') ADVANCE(98);
      END_STATE();
    case 89:
      if (lookahead == 'l') ADVANCE(99);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(anon_sym_printf);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 93:
      if (lookahead == 'L') ADVANCE(100);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_ENDFILE);
      END_STATE();
    case 95:
      if (lookahead == 'e') ADVANCE(101);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 97:
      if (lookahead == 'n') ADVANCE(102);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(anon_sym_getline);
      END_STATE();
    case 99:
      if (lookahead == 'e') ADVANCE(103);
      END_STATE();
    case 100:
      if (lookahead == 'E') ADVANCE(104);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(sym_continue_statement);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(sym_nextfile_statement);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_BEGINFILE);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 100},
  [2] = {.lex_state = 4, .external_lex_state = 2},
  [3] = {.lex_state = 4, .external_lex_state = 2},
  [4] = {.lex_state = 4},
  [5] = {.lex_state = 49},
  [6] = {.lex_state = 49},
  [7] = {.lex_state = 49},
  [8] = {.lex_state = 49},
  [9] = {.lex_state = 49},
  [10] = {.lex_state = 49},
  [11] = {.lex_state = 49},
  [12] = {.lex_state = 4},
  [13] = {.lex_state = 49},
  [14] = {.lex_state = 49},
  [15] = {.lex_state = 4, .external_lex_state = 2},
  [16] = {.lex_state = 49},
  [17] = {.lex_state = 49},
  [18] = {.lex_state = 49},
  [19] = {.lex_state = 49},
  [20] = {.lex_state = 49},
  [21] = {.lex_state = 49},
  [22] = {.lex_state = 49},
  [23] = {.lex_state = 4},
  [24] = {.lex_state = 49},
  [25] = {.lex_state = 49},
  [26] = {.lex_state = 49},
  [27] = {.lex_state = 49},
  [28] = {.lex_state = 49},
  [29] = {.lex_state = 49},
  [30] = {.lex_state = 49},
  [31] = {.lex_state = 49},
  [32] = {.lex_state = 49},
  [33] = {.lex_state = 49},
  [34] = {.lex_state = 49},
  [35] = {.lex_state = 49},
  [36] = {.lex_state = 49},
  [37] = {.lex_state = 49},
  [38] = {.lex_state = 49},
  [39] = {.lex_state = 49},
  [40] = {.lex_state = 49},
  [41] = {.lex_state = 49},
  [42] = {.lex_state = 49},
  [43] = {.lex_state = 49},
  [44] = {.lex_state = 49},
  [45] = {.lex_state = 49},
  [46] = {.lex_state = 49},
  [47] = {.lex_state = 49},
  [48] = {.lex_state = 49},
  [49] = {.lex_state = 49},
  [50] = {.lex_state = 49},
  [51] = {.lex_state = 49},
  [52] = {.lex_state = 49},
  [53] = {.lex_state = 49},
  [54] = {.lex_state = 49},
  [55] = {.lex_state = 49},
  [56] = {.lex_state = 49},
  [57] = {.lex_state = 49},
  [58] = {.lex_state = 49},
  [59] = {.lex_state = 49},
  [60] = {.lex_state = 49},
  [61] = {.lex_state = 49},
  [62] = {.lex_state = 49},
  [63] = {.lex_state = 49},
  [64] = {.lex_state = 49},
  [65] = {.lex_state = 49},
  [66] = {.lex_state = 49},
  [67] = {.lex_state = 49},
  [68] = {.lex_state = 49},
  [69] = {.lex_state = 49},
  [70] = {.lex_state = 49},
  [71] = {.lex_state = 49},
  [72] = {.lex_state = 49},
  [73] = {.lex_state = 49},
  [74] = {.lex_state = 49},
  [75] = {.lex_state = 49},
  [76] = {.lex_state = 49},
  [77] = {.lex_state = 49},
  [78] = {.lex_state = 49},
  [79] = {.lex_state = 49},
  [80] = {.lex_state = 49},
  [81] = {.lex_state = 49},
  [82] = {.lex_state = 49},
  [83] = {.lex_state = 49},
  [84] = {.lex_state = 49},
  [85] = {.lex_state = 49},
  [86] = {.lex_state = 49},
  [87] = {.lex_state = 49},
  [88] = {.lex_state = 49},
  [89] = {.lex_state = 49},
  [90] = {.lex_state = 49},
  [91] = {.lex_state = 49},
  [92] = {.lex_state = 49},
  [93] = {.lex_state = 45, .external_lex_state = 3},
  [94] = {.lex_state = 45, .external_lex_state = 3},
  [95] = {.lex_state = 46, .external_lex_state = 3},
  [96] = {.lex_state = 45, .external_lex_state = 4},
  [97] = {.lex_state = 45, .external_lex_state = 4},
  [98] = {.lex_state = 45, .external_lex_state = 3},
  [99] = {.lex_state = 45, .external_lex_state = 3},
  [100] = {.lex_state = 45, .external_lex_state = 3},
  [101] = {.lex_state = 45, .external_lex_state = 4},
  [102] = {.lex_state = 45, .external_lex_state = 3},
  [103] = {.lex_state = 46, .external_lex_state = 3},
  [104] = {.lex_state = 46, .external_lex_state = 4},
  [105] = {.lex_state = 45, .external_lex_state = 3},
  [106] = {.lex_state = 46, .external_lex_state = 3},
  [107] = {.lex_state = 46, .external_lex_state = 3},
  [108] = {.lex_state = 45, .external_lex_state = 4},
  [109] = {.lex_state = 46, .external_lex_state = 3},
  [110] = {.lex_state = 45, .external_lex_state = 3},
  [111] = {.lex_state = 46, .external_lex_state = 3},
  [112] = {.lex_state = 45, .external_lex_state = 4},
  [113] = {.lex_state = 46, .external_lex_state = 3},
  [114] = {.lex_state = 46, .external_lex_state = 3},
  [115] = {.lex_state = 46, .external_lex_state = 3},
  [116] = {.lex_state = 46, .external_lex_state = 3},
  [117] = {.lex_state = 46, .external_lex_state = 3},
  [118] = {.lex_state = 46, .external_lex_state = 3},
  [119] = {.lex_state = 46, .external_lex_state = 3},
  [120] = {.lex_state = 46, .external_lex_state = 3},
  [121] = {.lex_state = 45, .external_lex_state = 3},
  [122] = {.lex_state = 46, .external_lex_state = 3},
  [123] = {.lex_state = 46, .external_lex_state = 3},
  [124] = {.lex_state = 46, .external_lex_state = 3},
  [125] = {.lex_state = 46, .external_lex_state = 3},
  [126] = {.lex_state = 46, .external_lex_state = 3},
  [127] = {.lex_state = 46, .external_lex_state = 3},
  [128] = {.lex_state = 46, .external_lex_state = 4},
  [129] = {.lex_state = 45, .external_lex_state = 4},
  [130] = {.lex_state = 46, .external_lex_state = 3},
  [131] = {.lex_state = 46, .external_lex_state = 3},
  [132] = {.lex_state = 45, .external_lex_state = 4},
  [133] = {.lex_state = 46, .external_lex_state = 3},
  [134] = {.lex_state = 46, .external_lex_state = 4},
  [135] = {.lex_state = 46, .external_lex_state = 3},
  [136] = {.lex_state = 46, .external_lex_state = 3},
  [137] = {.lex_state = 46, .external_lex_state = 3},
  [138] = {.lex_state = 29, .external_lex_state = 2},
  [139] = {.lex_state = 46, .external_lex_state = 4},
  [140] = {.lex_state = 46, .external_lex_state = 4},
  [141] = {.lex_state = 46, .external_lex_state = 3},
  [142] = {.lex_state = 46, .external_lex_state = 3},
  [143] = {.lex_state = 46, .external_lex_state = 3},
  [144] = {.lex_state = 45, .external_lex_state = 4},
  [145] = {.lex_state = 45, .external_lex_state = 3},
  [146] = {.lex_state = 46, .external_lex_state = 3},
  [147] = {.lex_state = 46, .external_lex_state = 4},
  [148] = {.lex_state = 46, .external_lex_state = 4},
  [149] = {.lex_state = 46, .external_lex_state = 3},
  [150] = {.lex_state = 45, .external_lex_state = 3},
  [151] = {.lex_state = 46, .external_lex_state = 3},
  [152] = {.lex_state = 46, .external_lex_state = 3},
  [153] = {.lex_state = 46, .external_lex_state = 4},
  [154] = {.lex_state = 46, .external_lex_state = 3},
  [155] = {.lex_state = 46, .external_lex_state = 4},
  [156] = {.lex_state = 46, .external_lex_state = 4},
  [157] = {.lex_state = 46, .external_lex_state = 4},
  [158] = {.lex_state = 46, .external_lex_state = 4},
  [159] = {.lex_state = 46, .external_lex_state = 4},
  [160] = {.lex_state = 46, .external_lex_state = 4},
  [161] = {.lex_state = 46, .external_lex_state = 4},
  [162] = {.lex_state = 46, .external_lex_state = 4},
  [163] = {.lex_state = 46, .external_lex_state = 4},
  [164] = {.lex_state = 45, .external_lex_state = 4},
  [165] = {.lex_state = 46, .external_lex_state = 4},
  [166] = {.lex_state = 46, .external_lex_state = 4},
  [167] = {.lex_state = 46, .external_lex_state = 4},
  [168] = {.lex_state = 46, .external_lex_state = 3},
  [169] = {.lex_state = 46, .external_lex_state = 4},
  [170] = {.lex_state = 46, .external_lex_state = 4},
  [171] = {.lex_state = 46, .external_lex_state = 3},
  [172] = {.lex_state = 37, .external_lex_state = 3},
  [173] = {.lex_state = 46, .external_lex_state = 4},
  [174] = {.lex_state = 46, .external_lex_state = 4},
  [175] = {.lex_state = 46, .external_lex_state = 4},
  [176] = {.lex_state = 46, .external_lex_state = 4},
  [177] = {.lex_state = 46, .external_lex_state = 4},
  [178] = {.lex_state = 46, .external_lex_state = 4},
  [179] = {.lex_state = 45, .external_lex_state = 4},
  [180] = {.lex_state = 46, .external_lex_state = 4},
  [181] = {.lex_state = 46, .external_lex_state = 4},
  [182] = {.lex_state = 45, .external_lex_state = 4},
  [183] = {.lex_state = 46, .external_lex_state = 3},
  [184] = {.lex_state = 46, .external_lex_state = 4},
  [185] = {.lex_state = 46, .external_lex_state = 4},
  [186] = {.lex_state = 46, .external_lex_state = 4},
  [187] = {.lex_state = 29},
  [188] = {.lex_state = 46, .external_lex_state = 4},
  [189] = {.lex_state = 46, .external_lex_state = 3},
  [190] = {.lex_state = 46, .external_lex_state = 3},
  [191] = {.lex_state = 46, .external_lex_state = 3},
  [192] = {.lex_state = 46, .external_lex_state = 3},
  [193] = {.lex_state = 46, .external_lex_state = 3},
  [194] = {.lex_state = 46, .external_lex_state = 3},
  [195] = {.lex_state = 46, .external_lex_state = 4},
  [196] = {.lex_state = 46, .external_lex_state = 3},
  [197] = {.lex_state = 46, .external_lex_state = 3},
  [198] = {.lex_state = 46, .external_lex_state = 3},
  [199] = {.lex_state = 46, .external_lex_state = 3},
  [200] = {.lex_state = 46, .external_lex_state = 3},
  [201] = {.lex_state = 46, .external_lex_state = 3},
  [202] = {.lex_state = 37, .external_lex_state = 4},
  [203] = {.lex_state = 46, .external_lex_state = 4},
  [204] = {.lex_state = 46, .external_lex_state = 3},
  [205] = {.lex_state = 46, .external_lex_state = 4},
  [206] = {.lex_state = 46, .external_lex_state = 4},
  [207] = {.lex_state = 46, .external_lex_state = 4},
  [208] = {.lex_state = 46, .external_lex_state = 4},
  [209] = {.lex_state = 46, .external_lex_state = 4},
  [210] = {.lex_state = 46, .external_lex_state = 4},
  [211] = {.lex_state = 46, .external_lex_state = 4},
  [212] = {.lex_state = 46, .external_lex_state = 4},
  [213] = {.lex_state = 46, .external_lex_state = 4},
  [214] = {.lex_state = 46, .external_lex_state = 4},
  [215] = {.lex_state = 46, .external_lex_state = 4},
  [216] = {.lex_state = 46, .external_lex_state = 4},
  [217] = {.lex_state = 46, .external_lex_state = 4},
  [218] = {.lex_state = 46, .external_lex_state = 4},
  [219] = {.lex_state = 0, .external_lex_state = 4},
  [220] = {.lex_state = 0, .external_lex_state = 4},
  [221] = {.lex_state = 0, .external_lex_state = 4},
  [222] = {.lex_state = 95, .external_lex_state = 4},
  [223] = {.lex_state = 0, .external_lex_state = 4},
  [224] = {.lex_state = 0, .external_lex_state = 4},
  [225] = {.lex_state = 4, .external_lex_state = 2},
  [226] = {.lex_state = 95, .external_lex_state = 4},
  [227] = {.lex_state = 95, .external_lex_state = 4},
  [228] = {.lex_state = 4, .external_lex_state = 2},
  [229] = {.lex_state = 95, .external_lex_state = 4},
  [230] = {.lex_state = 4, .external_lex_state = 3},
  [231] = {.lex_state = 95, .external_lex_state = 4},
  [232] = {.lex_state = 4, .external_lex_state = 3},
  [233] = {.lex_state = 4, .external_lex_state = 3},
  [234] = {.lex_state = 95, .external_lex_state = 4},
  [235] = {.lex_state = 95, .external_lex_state = 4},
  [236] = {.lex_state = 95, .external_lex_state = 4},
  [237] = {.lex_state = 4},
  [238] = {.lex_state = 4, .external_lex_state = 3},
  [239] = {.lex_state = 39, .external_lex_state = 3},
  [240] = {.lex_state = 4, .external_lex_state = 4},
  [241] = {.lex_state = 95, .external_lex_state = 4},
  [242] = {.lex_state = 4, .external_lex_state = 4},
  [243] = {.lex_state = 4, .external_lex_state = 3},
  [244] = {.lex_state = 95, .external_lex_state = 4},
  [245] = {.lex_state = 95, .external_lex_state = 4},
  [246] = {.lex_state = 95, .external_lex_state = 4},
  [247] = {.lex_state = 95, .external_lex_state = 4},
  [248] = {.lex_state = 95, .external_lex_state = 4},
  [249] = {.lex_state = 95, .external_lex_state = 4},
  [250] = {.lex_state = 95, .external_lex_state = 4},
  [251] = {.lex_state = 95, .external_lex_state = 4},
  [252] = {.lex_state = 4, .external_lex_state = 4},
  [253] = {.lex_state = 95, .external_lex_state = 4},
  [254] = {.lex_state = 95, .external_lex_state = 4},
  [255] = {.lex_state = 95, .external_lex_state = 4},
  [256] = {.lex_state = 4, .external_lex_state = 3},
  [257] = {.lex_state = 95, .external_lex_state = 4},
  [258] = {.lex_state = 95, .external_lex_state = 4},
  [259] = {.lex_state = 95, .external_lex_state = 4},
  [260] = {.lex_state = 95, .external_lex_state = 4},
  [261] = {.lex_state = 95, .external_lex_state = 4},
  [262] = {.lex_state = 4, .external_lex_state = 3},
  [263] = {.lex_state = 95, .external_lex_state = 4},
  [264] = {.lex_state = 95, .external_lex_state = 4},
  [265] = {.lex_state = 95, .external_lex_state = 4},
  [266] = {.lex_state = 4, .external_lex_state = 3},
  [267] = {.lex_state = 4, .external_lex_state = 2},
  [268] = {.lex_state = 95, .external_lex_state = 4},
  [269] = {.lex_state = 95, .external_lex_state = 4},
  [270] = {.lex_state = 4, .external_lex_state = 2},
  [271] = {.lex_state = 4, .external_lex_state = 2},
  [272] = {.lex_state = 4, .external_lex_state = 2},
  [273] = {.lex_state = 4},
  [274] = {.lex_state = 95, .external_lex_state = 4},
  [275] = {.lex_state = 4, .external_lex_state = 2},
  [276] = {.lex_state = 4},
  [277] = {.lex_state = 4},
  [278] = {.lex_state = 4, .external_lex_state = 2},
  [279] = {.lex_state = 4, .external_lex_state = 3},
  [280] = {.lex_state = 4, .external_lex_state = 3},
  [281] = {.lex_state = 4, .external_lex_state = 2},
  [282] = {.lex_state = 4, .external_lex_state = 3},
  [283] = {.lex_state = 4, .external_lex_state = 3},
  [284] = {.lex_state = 4, .external_lex_state = 3},
  [285] = {.lex_state = 4, .external_lex_state = 3},
  [286] = {.lex_state = 4, .external_lex_state = 3},
  [287] = {.lex_state = 4, .external_lex_state = 3},
  [288] = {.lex_state = 4, .external_lex_state = 4},
  [289] = {.lex_state = 4, .external_lex_state = 3},
  [290] = {.lex_state = 4, .external_lex_state = 4},
  [291] = {.lex_state = 100},
  [292] = {.lex_state = 39, .external_lex_state = 4},
  [293] = {.lex_state = 4, .external_lex_state = 3},
  [294] = {.lex_state = 4, .external_lex_state = 3},
  [295] = {.lex_state = 4, .external_lex_state = 3},
  [296] = {.lex_state = 4, .external_lex_state = 3},
  [297] = {.lex_state = 4, .external_lex_state = 3},
  [298] = {.lex_state = 4, .external_lex_state = 3},
  [299] = {.lex_state = 4, .external_lex_state = 3},
  [300] = {.lex_state = 4, .external_lex_state = 3},
  [301] = {.lex_state = 4, .external_lex_state = 3},
  [302] = {.lex_state = 4},
  [303] = {.lex_state = 4, .external_lex_state = 2},
  [304] = {.lex_state = 4, .external_lex_state = 3},
  [305] = {.lex_state = 100},
  [306] = {.lex_state = 4, .external_lex_state = 4},
  [307] = {.lex_state = 4, .external_lex_state = 3},
  [308] = {.lex_state = 4, .external_lex_state = 3},
  [309] = {.lex_state = 4, .external_lex_state = 3},
  [310] = {.lex_state = 4, .external_lex_state = 3},
  [311] = {.lex_state = 4, .external_lex_state = 3},
  [312] = {.lex_state = 4, .external_lex_state = 3},
  [313] = {.lex_state = 4, .external_lex_state = 3},
  [314] = {.lex_state = 4, .external_lex_state = 3},
  [315] = {.lex_state = 4, .external_lex_state = 3},
  [316] = {.lex_state = 4, .external_lex_state = 3},
  [317] = {.lex_state = 0, .external_lex_state = 4},
  [318] = {.lex_state = 39, .external_lex_state = 2},
  [319] = {.lex_state = 4, .external_lex_state = 3},
  [320] = {.lex_state = 4, .external_lex_state = 3},
  [321] = {.lex_state = 4, .external_lex_state = 3},
  [322] = {.lex_state = 0, .external_lex_state = 4},
  [323] = {.lex_state = 4},
  [324] = {.lex_state = 4, .external_lex_state = 3},
  [325] = {.lex_state = 4, .external_lex_state = 4},
  [326] = {.lex_state = 4, .external_lex_state = 4},
  [327] = {.lex_state = 4},
  [328] = {.lex_state = 0, .external_lex_state = 4},
  [329] = {.lex_state = 4, .external_lex_state = 2},
  [330] = {.lex_state = 4, .external_lex_state = 4},
  [331] = {.lex_state = 4, .external_lex_state = 4},
  [332] = {.lex_state = 4, .external_lex_state = 4},
  [333] = {.lex_state = 4, .external_lex_state = 4},
  [334] = {.lex_state = 4, .external_lex_state = 4},
  [335] = {.lex_state = 4, .external_lex_state = 4},
  [336] = {.lex_state = 4, .external_lex_state = 4},
  [337] = {.lex_state = 4, .external_lex_state = 4},
  [338] = {.lex_state = 4, .external_lex_state = 4},
  [339] = {.lex_state = 4, .external_lex_state = 4},
  [340] = {.lex_state = 4, .external_lex_state = 4},
  [341] = {.lex_state = 4, .external_lex_state = 4},
  [342] = {.lex_state = 4, .external_lex_state = 4},
  [343] = {.lex_state = 4, .external_lex_state = 4},
  [344] = {.lex_state = 4, .external_lex_state = 4},
  [345] = {.lex_state = 4, .external_lex_state = 4},
  [346] = {.lex_state = 4, .external_lex_state = 4},
  [347] = {.lex_state = 4, .external_lex_state = 2},
  [348] = {.lex_state = 0, .external_lex_state = 4},
  [349] = {.lex_state = 4, .external_lex_state = 4},
  [350] = {.lex_state = 4, .external_lex_state = 4},
  [351] = {.lex_state = 4, .external_lex_state = 4},
  [352] = {.lex_state = 0, .external_lex_state = 4},
  [353] = {.lex_state = 4, .external_lex_state = 2},
  [354] = {.lex_state = 4, .external_lex_state = 2},
  [355] = {.lex_state = 4, .external_lex_state = 2},
  [356] = {.lex_state = 4, .external_lex_state = 2},
  [357] = {.lex_state = 4, .external_lex_state = 2},
  [358] = {.lex_state = 4, .external_lex_state = 2},
  [359] = {.lex_state = 4, .external_lex_state = 2},
  [360] = {.lex_state = 4, .external_lex_state = 2},
  [361] = {.lex_state = 4, .external_lex_state = 4},
  [362] = {.lex_state = 4, .external_lex_state = 2},
  [363] = {.lex_state = 4, .external_lex_state = 2},
  [364] = {.lex_state = 4, .external_lex_state = 2},
  [365] = {.lex_state = 4},
  [366] = {.lex_state = 4, .external_lex_state = 2},
  [367] = {.lex_state = 4, .external_lex_state = 2},
  [368] = {.lex_state = 95, .external_lex_state = 4},
  [369] = {.lex_state = 4, .external_lex_state = 2},
  [370] = {.lex_state = 4, .external_lex_state = 2},
  [371] = {.lex_state = 4, .external_lex_state = 4},
  [372] = {.lex_state = 4, .external_lex_state = 4},
  [373] = {.lex_state = 4},
  [374] = {.lex_state = 4, .external_lex_state = 4},
  [375] = {.lex_state = 0, .external_lex_state = 4},
  [376] = {.lex_state = 4, .external_lex_state = 4},
  [377] = {.lex_state = 4},
  [378] = {.lex_state = 39},
  [379] = {.lex_state = 95, .external_lex_state = 4},
  [380] = {.lex_state = 4, .external_lex_state = 4},
  [381] = {.lex_state = 4, .external_lex_state = 4},
  [382] = {.lex_state = 4, .external_lex_state = 2},
  [383] = {.lex_state = 4, .external_lex_state = 4},
  [384] = {.lex_state = 4, .external_lex_state = 4},
  [385] = {.lex_state = 4, .external_lex_state = 4},
  [386] = {.lex_state = 4, .external_lex_state = 4},
  [387] = {.lex_state = 4, .external_lex_state = 4},
  [388] = {.lex_state = 4, .external_lex_state = 4},
  [389] = {.lex_state = 98, .external_lex_state = 4},
  [390] = {.lex_state = 4},
  [391] = {.lex_state = 4},
  [392] = {.lex_state = 4},
  [393] = {.lex_state = 4},
  [394] = {.lex_state = 95, .external_lex_state = 4},
  [395] = {.lex_state = 95, .external_lex_state = 4},
  [396] = {.lex_state = 4},
  [397] = {.lex_state = 4},
  [398] = {.lex_state = 4},
  [399] = {.lex_state = 4},
  [400] = {.lex_state = 4},
  [401] = {.lex_state = 4},
  [402] = {.lex_state = 4},
  [403] = {.lex_state = 4},
  [404] = {.lex_state = 4},
  [405] = {.lex_state = 4},
  [406] = {.lex_state = 4},
  [407] = {.lex_state = 4},
  [408] = {.lex_state = 4},
  [409] = {.lex_state = 95, .external_lex_state = 4},
  [410] = {.lex_state = 95, .external_lex_state = 4},
  [411] = {.lex_state = 4},
  [412] = {.lex_state = 95, .external_lex_state = 4},
  [413] = {.lex_state = 95, .external_lex_state = 4},
  [414] = {.lex_state = 95, .external_lex_state = 4},
  [415] = {.lex_state = 95, .external_lex_state = 4},
  [416] = {.lex_state = 95, .external_lex_state = 4},
  [417] = {.lex_state = 95, .external_lex_state = 4},
  [418] = {.lex_state = 95, .external_lex_state = 4},
  [419] = {.lex_state = 4, .external_lex_state = 2},
  [420] = {.lex_state = 95, .external_lex_state = 4},
  [421] = {.lex_state = 4, .external_lex_state = 2},
  [422] = {.lex_state = 95, .external_lex_state = 4},
  [423] = {.lex_state = 4, .external_lex_state = 2},
  [424] = {.lex_state = 4, .external_lex_state = 2},
  [425] = {.lex_state = 4, .external_lex_state = 2},
  [426] = {.lex_state = 95, .external_lex_state = 4},
  [427] = {.lex_state = 95, .external_lex_state = 4},
  [428] = {.lex_state = 95, .external_lex_state = 4},
  [429] = {.lex_state = 95, .external_lex_state = 4},
  [430] = {.lex_state = 29, .external_lex_state = 2},
  [431] = {.lex_state = 4},
  [432] = {.lex_state = 4},
  [433] = {.lex_state = 4},
  [434] = {.lex_state = 4},
  [435] = {.lex_state = 4},
  [436] = {.lex_state = 29},
  [437] = {.lex_state = 29, .external_lex_state = 2},
  [438] = {.lex_state = 29},
  [439] = {.lex_state = 100, .external_lex_state = 4},
  [440] = {.lex_state = 100, .external_lex_state = 4},
  [441] = {.lex_state = 100, .external_lex_state = 4},
  [442] = {.lex_state = 100},
  [443] = {.lex_state = 100, .external_lex_state = 4},
  [444] = {.lex_state = 100},
  [445] = {.lex_state = 100, .external_lex_state = 4},
  [446] = {.lex_state = 100, .external_lex_state = 4},
  [447] = {.lex_state = 100, .external_lex_state = 4},
  [448] = {.lex_state = 102, .external_lex_state = 4},
  [449] = {.lex_state = 100},
  [450] = {.lex_state = 100, .external_lex_state = 4},
  [451] = {.lex_state = 100},
  [452] = {.lex_state = 100},
  [453] = {.lex_state = 100, .external_lex_state = 4},
  [454] = {.lex_state = 100, .external_lex_state = 4},
  [455] = {.lex_state = 100},
  [456] = {.lex_state = 100},
  [457] = {.lex_state = 100, .external_lex_state = 4},
  [458] = {.lex_state = 100, .external_lex_state = 4},
  [459] = {.lex_state = 100, .external_lex_state = 4},
  [460] = {.lex_state = 100, .external_lex_state = 4},
  [461] = {.lex_state = 100, .external_lex_state = 4},
  [462] = {.lex_state = 100, .external_lex_state = 4},
  [463] = {.lex_state = 100, .external_lex_state = 4},
  [464] = {.lex_state = 100, .external_lex_state = 4},
  [465] = {.lex_state = 100, .external_lex_state = 4},
  [466] = {.lex_state = 100, .external_lex_state = 4},
  [467] = {.lex_state = 100, .external_lex_state = 4},
  [468] = {.lex_state = 100, .external_lex_state = 4},
  [469] = {.lex_state = 100, .external_lex_state = 4},
  [470] = {.lex_state = 100, .external_lex_state = 4},
  [471] = {.lex_state = 100, .external_lex_state = 4},
  [472] = {.lex_state = 100, .external_lex_state = 4},
  [473] = {.lex_state = 100, .external_lex_state = 4},
  [474] = {.lex_state = 100, .external_lex_state = 4},
  [475] = {.lex_state = 100, .external_lex_state = 4},
  [476] = {.lex_state = 100, .external_lex_state = 4},
  [477] = {.lex_state = 100, .external_lex_state = 4},
  [478] = {.lex_state = 100, .external_lex_state = 4},
  [479] = {.lex_state = 100, .external_lex_state = 4},
  [480] = {.lex_state = 100, .external_lex_state = 4},
  [481] = {.lex_state = 100},
  [482] = {.lex_state = 100, .external_lex_state = 4},
  [483] = {.lex_state = 100, .external_lex_state = 4},
  [484] = {.lex_state = 100, .external_lex_state = 4},
  [485] = {.lex_state = 100, .external_lex_state = 4},
  [486] = {.lex_state = 45, .external_lex_state = 3},
  [487] = {.lex_state = 100},
  [488] = {.lex_state = 100, .external_lex_state = 4},
  [489] = {.lex_state = 100, .external_lex_state = 4},
  [490] = {.lex_state = 100, .external_lex_state = 4},
  [491] = {.lex_state = 102},
  [492] = {.lex_state = 45, .external_lex_state = 3},
  [493] = {.lex_state = 45, .external_lex_state = 3},
  [494] = {.lex_state = 100},
  [495] = {.lex_state = 100},
  [496] = {.lex_state = 100},
  [497] = {.lex_state = 100},
  [498] = {.lex_state = 45, .external_lex_state = 4},
  [499] = {.lex_state = 100},
  [500] = {.lex_state = 100},
  [501] = {.lex_state = 100},
  [502] = {.lex_state = 100},
  [503] = {.lex_state = 100},
  [504] = {.lex_state = 45, .external_lex_state = 3},
  [505] = {.lex_state = 100},
  [506] = {.lex_state = 45, .external_lex_state = 4},
  [507] = {.lex_state = 100},
  [508] = {.lex_state = 45, .external_lex_state = 3},
  [509] = {.lex_state = 100},
  [510] = {.lex_state = 100},
  [511] = {.lex_state = 100},
  [512] = {.lex_state = 45, .external_lex_state = 3},
  [513] = {.lex_state = 100},
  [514] = {.lex_state = 100},
  [515] = {.lex_state = 45, .external_lex_state = 4},
  [516] = {.lex_state = 45, .external_lex_state = 3},
  [517] = {.lex_state = 45, .external_lex_state = 4},
  [518] = {.lex_state = 4, .external_lex_state = 2},
  [519] = {.lex_state = 4, .external_lex_state = 2},
  [520] = {.lex_state = 100},
  [521] = {.lex_state = 45, .external_lex_state = 4},
  [522] = {.lex_state = 45, .external_lex_state = 3},
  [523] = {.lex_state = 45, .external_lex_state = 4},
  [524] = {.lex_state = 4},
  [525] = {.lex_state = 37, .external_lex_state = 3},
  [526] = {.lex_state = 45, .external_lex_state = 4},
  [527] = {.lex_state = 45, .external_lex_state = 3},
  [528] = {.lex_state = 4},
  [529] = {.lex_state = 45, .external_lex_state = 3},
  [530] = {.lex_state = 45, .external_lex_state = 3},
  [531] = {.lex_state = 45, .external_lex_state = 3},
  [532] = {.lex_state = 45, .external_lex_state = 4},
  [533] = {.lex_state = 45, .external_lex_state = 3},
  [534] = {.lex_state = 45, .external_lex_state = 3},
  [535] = {.lex_state = 45, .external_lex_state = 4},
  [536] = {.lex_state = 45, .external_lex_state = 3},
  [537] = {.lex_state = 45, .external_lex_state = 3},
  [538] = {.lex_state = 45, .external_lex_state = 3},
  [539] = {.lex_state = 45, .external_lex_state = 3},
  [540] = {.lex_state = 4, .external_lex_state = 2},
  [541] = {.lex_state = 4, .external_lex_state = 2},
  [542] = {.lex_state = 45, .external_lex_state = 3},
  [543] = {.lex_state = 37, .external_lex_state = 4},
  [544] = {.lex_state = 45, .external_lex_state = 3},
  [545] = {.lex_state = 45, .external_lex_state = 3},
  [546] = {.lex_state = 45, .external_lex_state = 4},
  [547] = {.lex_state = 45, .external_lex_state = 3},
  [548] = {.lex_state = 45, .external_lex_state = 3},
  [549] = {.lex_state = 45, .external_lex_state = 4},
  [550] = {.lex_state = 45, .external_lex_state = 3},
  [551] = {.lex_state = 45, .external_lex_state = 3},
  [552] = {.lex_state = 45, .external_lex_state = 4},
  [553] = {.lex_state = 45, .external_lex_state = 4},
  [554] = {.lex_state = 45, .external_lex_state = 4},
  [555] = {.lex_state = 45, .external_lex_state = 3},
  [556] = {.lex_state = 45, .external_lex_state = 3},
  [557] = {.lex_state = 45, .external_lex_state = 3},
  [558] = {.lex_state = 45, .external_lex_state = 3},
  [559] = {.lex_state = 37, .external_lex_state = 3},
  [560] = {.lex_state = 45, .external_lex_state = 4},
  [561] = {.lex_state = 45, .external_lex_state = 4},
  [562] = {.lex_state = 4, .external_lex_state = 2},
  [563] = {.lex_state = 4},
  [564] = {.lex_state = 45, .external_lex_state = 4},
  [565] = {.lex_state = 4, .external_lex_state = 2},
  [566] = {.lex_state = 45, .external_lex_state = 3},
  [567] = {.lex_state = 45, .external_lex_state = 4},
  [568] = {.lex_state = 45, .external_lex_state = 4},
  [569] = {.lex_state = 0, .external_lex_state = 4},
  [570] = {.lex_state = 45, .external_lex_state = 4},
  [571] = {.lex_state = 45, .external_lex_state = 4},
  [572] = {.lex_state = 45, .external_lex_state = 4},
  [573] = {.lex_state = 0, .external_lex_state = 4},
  [574] = {.lex_state = 45, .external_lex_state = 4},
  [575] = {.lex_state = 4, .external_lex_state = 2},
  [576] = {.lex_state = 45, .external_lex_state = 3},
  [577] = {.lex_state = 4, .external_lex_state = 2},
  [578] = {.lex_state = 45, .external_lex_state = 4},
  [579] = {.lex_state = 4},
  [580] = {.lex_state = 45, .external_lex_state = 3},
  [581] = {.lex_state = 0, .external_lex_state = 4},
  [582] = {.lex_state = 45, .external_lex_state = 4},
  [583] = {.lex_state = 45, .external_lex_state = 4},
  [584] = {.lex_state = 0, .external_lex_state = 4},
  [585] = {.lex_state = 4, .external_lex_state = 2},
  [586] = {.lex_state = 0, .external_lex_state = 4},
  [587] = {.lex_state = 45, .external_lex_state = 4},
  [588] = {.lex_state = 45, .external_lex_state = 4},
  [589] = {.lex_state = 45, .external_lex_state = 4},
  [590] = {.lex_state = 49},
  [591] = {.lex_state = 0, .external_lex_state = 4},
  [592] = {.lex_state = 45, .external_lex_state = 3},
  [593] = {.lex_state = 4},
  [594] = {.lex_state = 45, .external_lex_state = 4},
  [595] = {.lex_state = 45, .external_lex_state = 3},
  [596] = {.lex_state = 45, .external_lex_state = 3},
  [597] = {.lex_state = 49},
  [598] = {.lex_state = 49},
  [599] = {.lex_state = 4},
  [600] = {.lex_state = 49},
  [601] = {.lex_state = 0, .external_lex_state = 4},
  [602] = {.lex_state = 49},
  [603] = {.lex_state = 45, .external_lex_state = 3},
  [604] = {.lex_state = 45, .external_lex_state = 3},
  [605] = {.lex_state = 4},
  [606] = {.lex_state = 0, .external_lex_state = 4},
  [607] = {.lex_state = 49},
  [608] = {.lex_state = 45, .external_lex_state = 4},
  [609] = {.lex_state = 45, .external_lex_state = 3},
  [610] = {.lex_state = 4},
  [611] = {.lex_state = 4},
  [612] = {.lex_state = 45, .external_lex_state = 3},
  [613] = {.lex_state = 49},
  [614] = {.lex_state = 49},
  [615] = {.lex_state = 49},
  [616] = {.lex_state = 45, .external_lex_state = 3},
  [617] = {.lex_state = 45, .external_lex_state = 3},
  [618] = {.lex_state = 45, .external_lex_state = 3},
  [619] = {.lex_state = 49},
  [620] = {.lex_state = 37, .external_lex_state = 4},
  [621] = {.lex_state = 45, .external_lex_state = 3},
  [622] = {.lex_state = 45, .external_lex_state = 3},
  [623] = {.lex_state = 45, .external_lex_state = 3},
  [624] = {.lex_state = 45, .external_lex_state = 4},
  [625] = {.lex_state = 49},
  [626] = {.lex_state = 49},
  [627] = {.lex_state = 49},
  [628] = {.lex_state = 49},
  [629] = {.lex_state = 45, .external_lex_state = 4},
  [630] = {.lex_state = 49},
  [631] = {.lex_state = 49},
  [632] = {.lex_state = 45, .external_lex_state = 4},
  [633] = {.lex_state = 49},
  [634] = {.lex_state = 49},
  [635] = {.lex_state = 49},
  [636] = {.lex_state = 49},
  [637] = {.lex_state = 49},
  [638] = {.lex_state = 0, .external_lex_state = 4},
  [639] = {.lex_state = 45, .external_lex_state = 4},
  [640] = {.lex_state = 49},
  [641] = {.lex_state = 0, .external_lex_state = 4},
  [642] = {.lex_state = 49},
  [643] = {.lex_state = 4, .external_lex_state = 2},
  [644] = {.lex_state = 45, .external_lex_state = 4},
  [645] = {.lex_state = 49},
  [646] = {.lex_state = 49},
  [647] = {.lex_state = 49},
  [648] = {.lex_state = 49},
  [649] = {.lex_state = 49},
  [650] = {.lex_state = 49},
  [651] = {.lex_state = 49},
  [652] = {.lex_state = 45, .external_lex_state = 4},
  [653] = {.lex_state = 49},
  [654] = {.lex_state = 49},
  [655] = {.lex_state = 49},
  [656] = {.lex_state = 49},
  [657] = {.lex_state = 49},
  [658] = {.lex_state = 45, .external_lex_state = 4},
  [659] = {.lex_state = 49},
  [660] = {.lex_state = 49},
  [661] = {.lex_state = 45, .external_lex_state = 4},
  [662] = {.lex_state = 49},
  [663] = {.lex_state = 98, .external_lex_state = 4},
  [664] = {.lex_state = 49},
  [665] = {.lex_state = 4, .external_lex_state = 2},
  [666] = {.lex_state = 45, .external_lex_state = 4},
  [667] = {.lex_state = 45, .external_lex_state = 4},
  [668] = {.lex_state = 45, .external_lex_state = 4},
  [669] = {.lex_state = 45, .external_lex_state = 4},
  [670] = {.lex_state = 45, .external_lex_state = 4},
  [671] = {.lex_state = 49},
  [672] = {.lex_state = 45, .external_lex_state = 4},
  [673] = {.lex_state = 0, .external_lex_state = 4},
  [674] = {.lex_state = 49},
  [675] = {.lex_state = 49},
  [676] = {.lex_state = 0, .external_lex_state = 4},
  [677] = {.lex_state = 49},
  [678] = {.lex_state = 49},
  [679] = {.lex_state = 0, .external_lex_state = 4},
  [680] = {.lex_state = 49},
  [681] = {.lex_state = 49},
  [682] = {.lex_state = 49},
  [683] = {.lex_state = 49},
  [684] = {.lex_state = 49},
  [685] = {.lex_state = 49},
  [686] = {.lex_state = 49},
  [687] = {.lex_state = 49},
  [688] = {.lex_state = 49},
  [689] = {.lex_state = 49},
  [690] = {.lex_state = 49},
  [691] = {.lex_state = 0, .external_lex_state = 4},
  [692] = {.lex_state = 49},
  [693] = {.lex_state = 49},
  [694] = {.lex_state = 49},
  [695] = {.lex_state = 49},
  [696] = {.lex_state = 49},
  [697] = {.lex_state = 49},
  [698] = {.lex_state = 0, .external_lex_state = 4},
  [699] = {.lex_state = 49},
  [700] = {.lex_state = 49},
  [701] = {.lex_state = 49},
  [702] = {.lex_state = 49},
  [703] = {.lex_state = 4},
  [704] = {.lex_state = 49},
  [705] = {.lex_state = 0, .external_lex_state = 4},
  [706] = {.lex_state = 49},
  [707] = {.lex_state = 0, .external_lex_state = 4},
  [708] = {.lex_state = 0, .external_lex_state = 4},
  [709] = {.lex_state = 49},
  [710] = {.lex_state = 49},
  [711] = {.lex_state = 4},
  [712] = {.lex_state = 49},
  [713] = {.lex_state = 49},
  [714] = {.lex_state = 49},
  [715] = {.lex_state = 0, .external_lex_state = 4},
  [716] = {.lex_state = 4, .external_lex_state = 2},
  [717] = {.lex_state = 49},
  [718] = {.lex_state = 49},
  [719] = {.lex_state = 0, .external_lex_state = 4},
  [720] = {.lex_state = 49},
  [721] = {.lex_state = 49},
  [722] = {.lex_state = 0, .external_lex_state = 4},
  [723] = {.lex_state = 49},
  [724] = {.lex_state = 49},
  [725] = {.lex_state = 0, .external_lex_state = 4},
  [726] = {.lex_state = 0, .external_lex_state = 4},
  [727] = {.lex_state = 49},
  [728] = {.lex_state = 49},
  [729] = {.lex_state = 49},
  [730] = {.lex_state = 49},
  [731] = {.lex_state = 49},
  [732] = {.lex_state = 49},
  [733] = {.lex_state = 49},
  [734] = {.lex_state = 49},
  [735] = {.lex_state = 0, .external_lex_state = 4},
  [736] = {.lex_state = 49},
  [737] = {.lex_state = 49},
  [738] = {.lex_state = 49},
  [739] = {.lex_state = 49},
  [740] = {.lex_state = 49},
  [741] = {.lex_state = 49},
  [742] = {.lex_state = 49},
  [743] = {.lex_state = 49},
  [744] = {.lex_state = 49},
  [745] = {.lex_state = 49},
  [746] = {.lex_state = 49},
  [747] = {.lex_state = 49},
  [748] = {.lex_state = 49},
  [749] = {.lex_state = 49},
  [750] = {.lex_state = 49},
  [751] = {.lex_state = 49},
  [752] = {.lex_state = 49},
  [753] = {.lex_state = 49},
  [754] = {.lex_state = 49},
  [755] = {.lex_state = 49},
  [756] = {.lex_state = 49},
  [757] = {.lex_state = 0, .external_lex_state = 4},
  [758] = {.lex_state = 49},
  [759] = {.lex_state = 49},
  [760] = {.lex_state = 0, .external_lex_state = 4},
  [761] = {.lex_state = 49},
  [762] = {.lex_state = 0, .external_lex_state = 4},
  [763] = {.lex_state = 49},
  [764] = {.lex_state = 49},
  [765] = {.lex_state = 49},
  [766] = {.lex_state = 49},
  [767] = {.lex_state = 49},
  [768] = {.lex_state = 49},
  [769] = {.lex_state = 49},
  [770] = {.lex_state = 49},
  [771] = {.lex_state = 49},
  [772] = {.lex_state = 49},
  [773] = {.lex_state = 49},
  [774] = {.lex_state = 49},
  [775] = {.lex_state = 49},
  [776] = {.lex_state = 49},
  [777] = {.lex_state = 49},
  [778] = {.lex_state = 49},
  [779] = {.lex_state = 49},
  [780] = {.lex_state = 49},
  [781] = {.lex_state = 49},
  [782] = {.lex_state = 49},
  [783] = {.lex_state = 49},
  [784] = {.lex_state = 49},
  [785] = {.lex_state = 49},
  [786] = {.lex_state = 49},
  [787] = {.lex_state = 49},
  [788] = {.lex_state = 49},
  [789] = {.lex_state = 49},
  [790] = {.lex_state = 49},
  [791] = {.lex_state = 49},
  [792] = {.lex_state = 49},
  [793] = {.lex_state = 49},
  [794] = {.lex_state = 49},
  [795] = {.lex_state = 49},
  [796] = {.lex_state = 49},
  [797] = {.lex_state = 49},
  [798] = {.lex_state = 49},
  [799] = {.lex_state = 49},
  [800] = {.lex_state = 49},
  [801] = {.lex_state = 49},
  [802] = {.lex_state = 49},
  [803] = {.lex_state = 49},
  [804] = {.lex_state = 49},
  [805] = {.lex_state = 49},
  [806] = {.lex_state = 49},
  [807] = {.lex_state = 49},
  [808] = {.lex_state = 49},
  [809] = {.lex_state = 49},
  [810] = {.lex_state = 49},
  [811] = {.lex_state = 49},
  [812] = {.lex_state = 49},
  [813] = {.lex_state = 49},
  [814] = {.lex_state = 49},
  [815] = {.lex_state = 49},
  [816] = {.lex_state = 49},
  [817] = {.lex_state = 49},
  [818] = {.lex_state = 49},
  [819] = {.lex_state = 49},
  [820] = {.lex_state = 49},
  [821] = {.lex_state = 49},
  [822] = {.lex_state = 0, .external_lex_state = 4},
  [823] = {.lex_state = 49},
  [824] = {.lex_state = 49},
  [825] = {.lex_state = 49},
  [826] = {.lex_state = 49},
  [827] = {.lex_state = 49},
  [828] = {.lex_state = 49},
  [829] = {.lex_state = 49},
  [830] = {.lex_state = 49},
  [831] = {.lex_state = 49},
  [832] = {.lex_state = 49},
  [833] = {.lex_state = 49},
  [834] = {.lex_state = 49},
  [835] = {.lex_state = 49},
  [836] = {.lex_state = 49},
  [837] = {.lex_state = 49},
  [838] = {.lex_state = 49},
  [839] = {.lex_state = 49},
  [840] = {.lex_state = 49},
  [841] = {.lex_state = 49},
  [842] = {.lex_state = 49},
  [843] = {.lex_state = 49},
  [844] = {.lex_state = 49},
  [845] = {.lex_state = 49},
  [846] = {.lex_state = 49},
  [847] = {.lex_state = 49},
  [848] = {.lex_state = 49},
  [849] = {.lex_state = 49},
  [850] = {.lex_state = 49},
  [851] = {.lex_state = 49},
  [852] = {.lex_state = 49},
  [853] = {.lex_state = 49},
  [854] = {.lex_state = 49},
  [855] = {.lex_state = 49},
  [856] = {.lex_state = 49},
  [857] = {.lex_state = 49},
  [858] = {.lex_state = 4},
  [859] = {.lex_state = 49},
  [860] = {.lex_state = 49},
  [861] = {.lex_state = 49},
  [862] = {.lex_state = 49},
  [863] = {.lex_state = 49},
  [864] = {.lex_state = 49},
  [865] = {.lex_state = 49},
  [866] = {.lex_state = 49},
  [867] = {.lex_state = 49},
  [868] = {.lex_state = 49},
  [869] = {.lex_state = 49},
  [870] = {.lex_state = 49},
  [871] = {.lex_state = 49},
  [872] = {.lex_state = 49},
  [873] = {.lex_state = 49},
  [874] = {.lex_state = 49},
  [875] = {.lex_state = 49},
  [876] = {.lex_state = 49},
  [877] = {.lex_state = 49},
  [878] = {.lex_state = 49},
  [879] = {.lex_state = 49},
  [880] = {.lex_state = 49},
  [881] = {.lex_state = 49},
  [882] = {.lex_state = 49},
  [883] = {.lex_state = 49},
  [884] = {.lex_state = 49},
  [885] = {.lex_state = 49},
  [886] = {.lex_state = 49},
  [887] = {.lex_state = 49},
  [888] = {.lex_state = 49},
  [889] = {.lex_state = 49},
  [890] = {.lex_state = 49},
  [891] = {.lex_state = 49},
  [892] = {.lex_state = 49},
  [893] = {.lex_state = 49},
  [894] = {.lex_state = 49},
  [895] = {.lex_state = 49},
  [896] = {.lex_state = 49},
  [897] = {.lex_state = 49},
  [898] = {.lex_state = 49},
  [899] = {.lex_state = 49},
  [900] = {.lex_state = 49},
  [901] = {.lex_state = 49},
  [902] = {.lex_state = 49},
  [903] = {.lex_state = 0, .external_lex_state = 4},
  [904] = {.lex_state = 49},
  [905] = {.lex_state = 49},
  [906] = {.lex_state = 49},
  [907] = {.lex_state = 49},
  [908] = {.lex_state = 49},
  [909] = {.lex_state = 49},
  [910] = {.lex_state = 49},
  [911] = {.lex_state = 49},
  [912] = {.lex_state = 49},
  [913] = {.lex_state = 49},
  [914] = {.lex_state = 49},
  [915] = {.lex_state = 49},
  [916] = {.lex_state = 49},
  [917] = {.lex_state = 49},
  [918] = {.lex_state = 49},
  [919] = {.lex_state = 49},
  [920] = {.lex_state = 49},
  [921] = {.lex_state = 49},
  [922] = {.lex_state = 49},
  [923] = {.lex_state = 49},
  [924] = {.lex_state = 49},
  [925] = {.lex_state = 49},
  [926] = {.lex_state = 49},
  [927] = {.lex_state = 49},
  [928] = {.lex_state = 49},
  [929] = {.lex_state = 49},
  [930] = {.lex_state = 49},
  [931] = {.lex_state = 49},
  [932] = {.lex_state = 49},
  [933] = {.lex_state = 4, .external_lex_state = 2},
  [934] = {.lex_state = 49},
  [935] = {.lex_state = 49},
  [936] = {.lex_state = 49},
  [937] = {.lex_state = 49},
  [938] = {.lex_state = 49},
  [939] = {.lex_state = 49},
  [940] = {.lex_state = 49},
  [941] = {.lex_state = 49},
  [942] = {.lex_state = 49},
  [943] = {.lex_state = 49},
  [944] = {.lex_state = 49},
  [945] = {.lex_state = 49},
  [946] = {.lex_state = 49},
  [947] = {.lex_state = 49},
  [948] = {.lex_state = 49},
  [949] = {.lex_state = 49},
  [950] = {.lex_state = 49},
  [951] = {.lex_state = 49},
  [952] = {.lex_state = 49},
  [953] = {.lex_state = 49},
  [954] = {.lex_state = 49},
  [955] = {.lex_state = 49},
  [956] = {.lex_state = 49},
  [957] = {.lex_state = 49},
  [958] = {.lex_state = 49},
  [959] = {.lex_state = 49},
  [960] = {.lex_state = 49},
  [961] = {.lex_state = 49},
  [962] = {.lex_state = 49},
  [963] = {.lex_state = 49},
  [964] = {.lex_state = 49},
  [965] = {.lex_state = 49},
  [966] = {.lex_state = 49},
  [967] = {.lex_state = 49},
  [968] = {.lex_state = 49},
  [969] = {.lex_state = 49},
  [970] = {.lex_state = 49},
  [971] = {.lex_state = 49},
  [972] = {.lex_state = 49},
  [973] = {.lex_state = 49},
  [974] = {.lex_state = 49},
  [975] = {.lex_state = 49},
  [976] = {.lex_state = 49},
  [977] = {.lex_state = 49},
  [978] = {.lex_state = 0, .external_lex_state = 4},
  [979] = {.lex_state = 49},
  [980] = {.lex_state = 49},
  [981] = {.lex_state = 49},
  [982] = {.lex_state = 49},
  [983] = {.lex_state = 49},
  [984] = {.lex_state = 49},
  [985] = {.lex_state = 49},
  [986] = {.lex_state = 49},
  [987] = {.lex_state = 49},
  [988] = {.lex_state = 49},
  [989] = {.lex_state = 49},
  [990] = {.lex_state = 49},
  [991] = {.lex_state = 49},
  [992] = {.lex_state = 49},
  [993] = {.lex_state = 49},
  [994] = {.lex_state = 49},
  [995] = {.lex_state = 49},
  [996] = {.lex_state = 49},
  [997] = {.lex_state = 49},
  [998] = {.lex_state = 49},
  [999] = {.lex_state = 49},
  [1000] = {.lex_state = 49},
  [1001] = {.lex_state = 4, .external_lex_state = 2},
  [1002] = {.lex_state = 49},
  [1003] = {.lex_state = 49},
  [1004] = {.lex_state = 41, .external_lex_state = 3},
  [1005] = {.lex_state = 49},
  [1006] = {.lex_state = 49},
  [1007] = {.lex_state = 49},
  [1008] = {.lex_state = 49},
  [1009] = {.lex_state = 49},
  [1010] = {.lex_state = 49},
  [1011] = {.lex_state = 49},
  [1012] = {.lex_state = 49},
  [1013] = {.lex_state = 49},
  [1014] = {.lex_state = 49},
  [1015] = {.lex_state = 49},
  [1016] = {.lex_state = 49},
  [1017] = {.lex_state = 49},
  [1018] = {.lex_state = 49},
  [1019] = {.lex_state = 49},
  [1020] = {.lex_state = 49},
  [1021] = {.lex_state = 49},
  [1022] = {.lex_state = 49},
  [1023] = {.lex_state = 49},
  [1024] = {.lex_state = 49},
  [1025] = {.lex_state = 49},
  [1026] = {.lex_state = 49},
  [1027] = {.lex_state = 49},
  [1028] = {.lex_state = 49},
  [1029] = {.lex_state = 49},
  [1030] = {.lex_state = 49},
  [1031] = {.lex_state = 49},
  [1032] = {.lex_state = 49},
  [1033] = {.lex_state = 49},
  [1034] = {.lex_state = 49},
  [1035] = {.lex_state = 49},
  [1036] = {.lex_state = 49},
  [1037] = {.lex_state = 4, .external_lex_state = 2},
  [1038] = {.lex_state = 49},
  [1039] = {.lex_state = 49},
  [1040] = {.lex_state = 49},
  [1041] = {.lex_state = 4, .external_lex_state = 2},
  [1042] = {.lex_state = 4, .external_lex_state = 2},
  [1043] = {.lex_state = 49},
  [1044] = {.lex_state = 4, .external_lex_state = 2},
  [1045] = {.lex_state = 49},
  [1046] = {.lex_state = 4, .external_lex_state = 2},
  [1047] = {.lex_state = 4, .external_lex_state = 2},
  [1048] = {.lex_state = 49},
  [1049] = {.lex_state = 49},
  [1050] = {.lex_state = 4, .external_lex_state = 2},
  [1051] = {.lex_state = 4, .external_lex_state = 2},
  [1052] = {.lex_state = 4, .external_lex_state = 2},
  [1053] = {.lex_state = 49},
  [1054] = {.lex_state = 49},
  [1055] = {.lex_state = 49},
  [1056] = {.lex_state = 49},
  [1057] = {.lex_state = 49},
  [1058] = {.lex_state = 49},
  [1059] = {.lex_state = 49},
  [1060] = {.lex_state = 4, .external_lex_state = 2},
  [1061] = {.lex_state = 4, .external_lex_state = 2},
  [1062] = {.lex_state = 4, .external_lex_state = 2},
  [1063] = {.lex_state = 49},
  [1064] = {.lex_state = 49},
  [1065] = {.lex_state = 4, .external_lex_state = 2},
  [1066] = {.lex_state = 49},
  [1067] = {.lex_state = 4, .external_lex_state = 2},
  [1068] = {.lex_state = 49},
  [1069] = {.lex_state = 49},
  [1070] = {.lex_state = 4, .external_lex_state = 2},
  [1071] = {.lex_state = 49},
  [1072] = {.lex_state = 4, .external_lex_state = 2},
  [1073] = {.lex_state = 4, .external_lex_state = 2},
  [1074] = {.lex_state = 4, .external_lex_state = 2},
  [1075] = {.lex_state = 49},
  [1076] = {.lex_state = 4, .external_lex_state = 2},
  [1077] = {.lex_state = 4, .external_lex_state = 2},
  [1078] = {.lex_state = 49},
  [1079] = {.lex_state = 4, .external_lex_state = 2},
  [1080] = {.lex_state = 49},
  [1081] = {.lex_state = 4, .external_lex_state = 2},
  [1082] = {.lex_state = 4, .external_lex_state = 2},
  [1083] = {.lex_state = 4, .external_lex_state = 2},
  [1084] = {.lex_state = 4, .external_lex_state = 2},
  [1085] = {.lex_state = 49},
  [1086] = {.lex_state = 4, .external_lex_state = 2},
  [1087] = {.lex_state = 4, .external_lex_state = 2},
  [1088] = {.lex_state = 4, .external_lex_state = 2},
  [1089] = {.lex_state = 4, .external_lex_state = 2},
  [1090] = {.lex_state = 4, .external_lex_state = 2},
  [1091] = {.lex_state = 4, .external_lex_state = 2},
  [1092] = {.lex_state = 4, .external_lex_state = 2},
  [1093] = {.lex_state = 4},
  [1094] = {.lex_state = 41, .external_lex_state = 4},
  [1095] = {.lex_state = 4},
  [1096] = {.lex_state = 4},
  [1097] = {.lex_state = 4},
  [1098] = {.lex_state = 4},
  [1099] = {.lex_state = 4},
  [1100] = {.lex_state = 4},
  [1101] = {.lex_state = 4},
  [1102] = {.lex_state = 4},
  [1103] = {.lex_state = 4},
  [1104] = {.lex_state = 4},
  [1105] = {.lex_state = 4},
  [1106] = {.lex_state = 41, .external_lex_state = 3},
  [1107] = {.lex_state = 4},
  [1108] = {.lex_state = 4},
  [1109] = {.lex_state = 4},
  [1110] = {.lex_state = 0, .external_lex_state = 4},
  [1111] = {.lex_state = 4},
  [1112] = {.lex_state = 4},
  [1113] = {.lex_state = 4},
  [1114] = {.lex_state = 4},
  [1115] = {.lex_state = 4},
  [1116] = {.lex_state = 4},
  [1117] = {.lex_state = 4},
  [1118] = {.lex_state = 4},
  [1119] = {.lex_state = 41, .external_lex_state = 2},
  [1120] = {.lex_state = 4},
  [1121] = {.lex_state = 0, .external_lex_state = 4},
  [1122] = {.lex_state = 4},
  [1123] = {.lex_state = 4},
  [1124] = {.lex_state = 0, .external_lex_state = 4},
  [1125] = {.lex_state = 4},
  [1126] = {.lex_state = 4},
  [1127] = {.lex_state = 4},
  [1128] = {.lex_state = 4},
  [1129] = {.lex_state = 4},
  [1130] = {.lex_state = 0, .external_lex_state = 4},
  [1131] = {.lex_state = 4},
  [1132] = {.lex_state = 4},
  [1133] = {.lex_state = 0, .external_lex_state = 4},
  [1134] = {.lex_state = 41, .external_lex_state = 3},
  [1135] = {.lex_state = 0, .external_lex_state = 4},
  [1136] = {.lex_state = 4},
  [1137] = {.lex_state = 41},
  [1138] = {.lex_state = 41, .external_lex_state = 4},
  [1139] = {.lex_state = 41, .external_lex_state = 3},
  [1140] = {.lex_state = 41, .external_lex_state = 4},
  [1141] = {.lex_state = 41, .external_lex_state = 3},
  [1142] = {.lex_state = 41, .external_lex_state = 2},
  [1143] = {.lex_state = 41, .external_lex_state = 3},
  [1144] = {.lex_state = 4, .external_lex_state = 2},
  [1145] = {.lex_state = 4, .external_lex_state = 2},
  [1146] = {.lex_state = 4, .external_lex_state = 2},
  [1147] = {.lex_state = 41, .external_lex_state = 3},
  [1148] = {.lex_state = 41, .external_lex_state = 2},
  [1149] = {.lex_state = 4, .external_lex_state = 2},
  [1150] = {.lex_state = 41, .external_lex_state = 3},
  [1151] = {.lex_state = 41, .external_lex_state = 3},
  [1152] = {.lex_state = 41, .external_lex_state = 3},
  [1153] = {.lex_state = 43, .external_lex_state = 3},
  [1154] = {.lex_state = 41, .external_lex_state = 3},
  [1155] = {.lex_state = 41, .external_lex_state = 3},
  [1156] = {.lex_state = 41},
  [1157] = {.lex_state = 41, .external_lex_state = 3},
  [1158] = {.lex_state = 41, .external_lex_state = 2},
  [1159] = {.lex_state = 41, .external_lex_state = 4},
  [1160] = {.lex_state = 41, .external_lex_state = 4},
  [1161] = {.lex_state = 41, .external_lex_state = 3},
  [1162] = {.lex_state = 41, .external_lex_state = 3},
  [1163] = {.lex_state = 41, .external_lex_state = 3},
  [1164] = {.lex_state = 41, .external_lex_state = 3},
  [1165] = {.lex_state = 41, .external_lex_state = 3},
  [1166] = {.lex_state = 41},
  [1167] = {.lex_state = 41, .external_lex_state = 3},
  [1168] = {.lex_state = 41, .external_lex_state = 3},
  [1169] = {.lex_state = 41, .external_lex_state = 3},
  [1170] = {.lex_state = 41, .external_lex_state = 2},
  [1171] = {.lex_state = 41, .external_lex_state = 3},
  [1172] = {.lex_state = 41, .external_lex_state = 3},
  [1173] = {.lex_state = 41, .external_lex_state = 4},
  [1174] = {.lex_state = 41, .external_lex_state = 3},
  [1175] = {.lex_state = 41, .external_lex_state = 3},
  [1176] = {.lex_state = 41, .external_lex_state = 3},
  [1177] = {.lex_state = 41, .external_lex_state = 3},
  [1178] = {.lex_state = 41, .external_lex_state = 3},
  [1179] = {.lex_state = 41, .external_lex_state = 3},
  [1180] = {.lex_state = 41, .external_lex_state = 3},
  [1181] = {.lex_state = 41, .external_lex_state = 4},
  [1182] = {.lex_state = 41, .external_lex_state = 2},
  [1183] = {.lex_state = 4},
  [1184] = {.lex_state = 41, .external_lex_state = 2},
  [1185] = {.lex_state = 41, .external_lex_state = 4},
  [1186] = {.lex_state = 41, .external_lex_state = 3},
  [1187] = {.lex_state = 41, .external_lex_state = 4},
  [1188] = {.lex_state = 41, .external_lex_state = 4},
  [1189] = {.lex_state = 41, .external_lex_state = 2},
  [1190] = {.lex_state = 41, .external_lex_state = 4},
  [1191] = {.lex_state = 41, .external_lex_state = 4},
  [1192] = {.lex_state = 41, .external_lex_state = 3},
  [1193] = {.lex_state = 41, .external_lex_state = 3},
  [1194] = {.lex_state = 41, .external_lex_state = 2},
  [1195] = {.lex_state = 41, .external_lex_state = 2},
  [1196] = {.lex_state = 41, .external_lex_state = 2},
  [1197] = {.lex_state = 41, .external_lex_state = 4},
  [1198] = {.lex_state = 41},
  [1199] = {.lex_state = 41, .external_lex_state = 4},
  [1200] = {.lex_state = 41, .external_lex_state = 4},
  [1201] = {.lex_state = 41, .external_lex_state = 4},
  [1202] = {.lex_state = 41, .external_lex_state = 4},
  [1203] = {.lex_state = 41, .external_lex_state = 2},
  [1204] = {.lex_state = 41, .external_lex_state = 4},
  [1205] = {.lex_state = 41, .external_lex_state = 4},
  [1206] = {.lex_state = 41, .external_lex_state = 3},
  [1207] = {.lex_state = 41, .external_lex_state = 3},
  [1208] = {.lex_state = 41, .external_lex_state = 4},
  [1209] = {.lex_state = 41, .external_lex_state = 2},
  [1210] = {.lex_state = 41, .external_lex_state = 4},
  [1211] = {.lex_state = 41, .external_lex_state = 3},
  [1212] = {.lex_state = 41},
  [1213] = {.lex_state = 41, .external_lex_state = 4},
  [1214] = {.lex_state = 41, .external_lex_state = 4},
  [1215] = {.lex_state = 41, .external_lex_state = 2},
  [1216] = {.lex_state = 43, .external_lex_state = 2},
  [1217] = {.lex_state = 41, .external_lex_state = 4},
  [1218] = {.lex_state = 41, .external_lex_state = 4},
  [1219] = {.lex_state = 41, .external_lex_state = 4},
  [1220] = {.lex_state = 41, .external_lex_state = 4},
  [1221] = {.lex_state = 41, .external_lex_state = 2},
  [1222] = {.lex_state = 41, .external_lex_state = 3},
  [1223] = {.lex_state = 41, .external_lex_state = 4},
  [1224] = {.lex_state = 41, .external_lex_state = 2},
  [1225] = {.lex_state = 43, .external_lex_state = 4},
  [1226] = {.lex_state = 41},
  [1227] = {.lex_state = 41, .external_lex_state = 2},
  [1228] = {.lex_state = 41, .external_lex_state = 2},
  [1229] = {.lex_state = 41, .external_lex_state = 2},
  [1230] = {.lex_state = 41, .external_lex_state = 2},
  [1231] = {.lex_state = 41, .external_lex_state = 3},
  [1232] = {.lex_state = 41, .external_lex_state = 4},
  [1233] = {.lex_state = 41, .external_lex_state = 3},
  [1234] = {.lex_state = 41, .external_lex_state = 3},
  [1235] = {.lex_state = 41, .external_lex_state = 4},
  [1236] = {.lex_state = 41, .external_lex_state = 2},
  [1237] = {.lex_state = 41, .external_lex_state = 3},
  [1238] = {.lex_state = 41, .external_lex_state = 3},
  [1239] = {.lex_state = 41, .external_lex_state = 2},
  [1240] = {.lex_state = 41, .external_lex_state = 2},
  [1241] = {.lex_state = 41},
  [1242] = {.lex_state = 41},
  [1243] = {.lex_state = 41, .external_lex_state = 2},
  [1244] = {.lex_state = 41, .external_lex_state = 4},
  [1245] = {.lex_state = 50, .external_lex_state = 4},
  [1246] = {.lex_state = 41, .external_lex_state = 4},
  [1247] = {.lex_state = 41},
  [1248] = {.lex_state = 41, .external_lex_state = 4},
  [1249] = {.lex_state = 41, .external_lex_state = 2},
  [1250] = {.lex_state = 41},
  [1251] = {.lex_state = 41, .external_lex_state = 4},
  [1252] = {.lex_state = 41},
  [1253] = {.lex_state = 41, .external_lex_state = 4},
  [1254] = {.lex_state = 41, .external_lex_state = 4},
  [1255] = {.lex_state = 41, .external_lex_state = 2},
  [1256] = {.lex_state = 41},
  [1257] = {.lex_state = 41, .external_lex_state = 4},
  [1258] = {.lex_state = 41},
  [1259] = {.lex_state = 41},
  [1260] = {.lex_state = 41, .external_lex_state = 3},
  [1261] = {.lex_state = 50, .external_lex_state = 4},
  [1262] = {.lex_state = 41, .external_lex_state = 4},
  [1263] = {.lex_state = 41, .external_lex_state = 4},
  [1264] = {.lex_state = 41, .external_lex_state = 4},
  [1265] = {.lex_state = 41, .external_lex_state = 4},
  [1266] = {.lex_state = 41},
  [1267] = {.lex_state = 41, .external_lex_state = 2},
  [1268] = {.lex_state = 43},
  [1269] = {.lex_state = 41},
  [1270] = {.lex_state = 43, .external_lex_state = 3},
  [1271] = {.lex_state = 41},
  [1272] = {.lex_state = 41},
  [1273] = {.lex_state = 41, .external_lex_state = 4},
  [1274] = {.lex_state = 41},
  [1275] = {.lex_state = 41},
  [1276] = {.lex_state = 41},
  [1277] = {.lex_state = 41},
  [1278] = {.lex_state = 41},
  [1279] = {.lex_state = 41, .external_lex_state = 3},
  [1280] = {.lex_state = 41, .external_lex_state = 3},
  [1281] = {.lex_state = 50, .external_lex_state = 4},
  [1282] = {.lex_state = 41, .external_lex_state = 3},
  [1283] = {.lex_state = 49},
  [1284] = {.lex_state = 41},
  [1285] = {.lex_state = 41, .external_lex_state = 3},
  [1286] = {.lex_state = 43, .external_lex_state = 2},
  [1287] = {.lex_state = 50},
  [1288] = {.lex_state = 41},
  [1289] = {.lex_state = 41, .external_lex_state = 3},
  [1290] = {.lex_state = 49},
  [1291] = {.lex_state = 49},
  [1292] = {.lex_state = 41, .external_lex_state = 3},
  [1293] = {.lex_state = 41, .external_lex_state = 3},
  [1294] = {.lex_state = 41, .external_lex_state = 3},
  [1295] = {.lex_state = 41, .external_lex_state = 3},
  [1296] = {.lex_state = 43, .external_lex_state = 4},
  [1297] = {.lex_state = 41, .external_lex_state = 3},
  [1298] = {.lex_state = 41, .external_lex_state = 4},
  [1299] = {.lex_state = 41, .external_lex_state = 3},
  [1300] = {.lex_state = 41, .external_lex_state = 3},
  [1301] = {.lex_state = 41, .external_lex_state = 2},
  [1302] = {.lex_state = 41},
  [1303] = {.lex_state = 49},
  [1304] = {.lex_state = 50},
  [1305] = {.lex_state = 41},
  [1306] = {.lex_state = 50, .external_lex_state = 4},
  [1307] = {.lex_state = 50, .external_lex_state = 4},
  [1308] = {.lex_state = 50},
  [1309] = {.lex_state = 50, .external_lex_state = 4},
  [1310] = {.lex_state = 41, .external_lex_state = 4},
  [1311] = {.lex_state = 41, .external_lex_state = 4},
  [1312] = {.lex_state = 41, .external_lex_state = 2},
  [1313] = {.lex_state = 41, .external_lex_state = 4},
  [1314] = {.lex_state = 41, .external_lex_state = 2},
  [1315] = {.lex_state = 41, .external_lex_state = 2},
  [1316] = {.lex_state = 41},
  [1317] = {.lex_state = 41, .external_lex_state = 2},
  [1318] = {.lex_state = 41, .external_lex_state = 2},
  [1319] = {.lex_state = 41, .external_lex_state = 4},
  [1320] = {.lex_state = 41, .external_lex_state = 4},
  [1321] = {.lex_state = 52, .external_lex_state = 4},
  [1322] = {.lex_state = 41, .external_lex_state = 4},
  [1323] = {.lex_state = 41, .external_lex_state = 2},
  [1324] = {.lex_state = 50, .external_lex_state = 4},
  [1325] = {.lex_state = 41, .external_lex_state = 2},
  [1326] = {.lex_state = 41, .external_lex_state = 2},
  [1327] = {.lex_state = 50, .external_lex_state = 4},
  [1328] = {.lex_state = 41, .external_lex_state = 4},
  [1329] = {.lex_state = 41, .external_lex_state = 4},
  [1330] = {.lex_state = 41, .external_lex_state = 4},
  [1331] = {.lex_state = 43},
  [1332] = {.lex_state = 50},
  [1333] = {.lex_state = 41, .external_lex_state = 4},
  [1334] = {.lex_state = 41, .external_lex_state = 4},
  [1335] = {.lex_state = 41, .external_lex_state = 4},
  [1336] = {.lex_state = 41, .external_lex_state = 2},
  [1337] = {.lex_state = 50, .external_lex_state = 4},
  [1338] = {.lex_state = 50, .external_lex_state = 4},
  [1339] = {.lex_state = 50, .external_lex_state = 4},
  [1340] = {.lex_state = 50},
  [1341] = {.lex_state = 41},
  [1342] = {.lex_state = 50, .external_lex_state = 4},
  [1343] = {.lex_state = 50, .external_lex_state = 4},
  [1344] = {.lex_state = 50, .external_lex_state = 4},
  [1345] = {.lex_state = 50},
  [1346] = {.lex_state = 50, .external_lex_state = 4},
  [1347] = {.lex_state = 41},
  [1348] = {.lex_state = 50},
  [1349] = {.lex_state = 50, .external_lex_state = 4},
  [1350] = {.lex_state = 50, .external_lex_state = 4},
  [1351] = {.lex_state = 50, .external_lex_state = 4},
  [1352] = {.lex_state = 50, .external_lex_state = 4},
  [1353] = {.lex_state = 50, .external_lex_state = 4},
  [1354] = {.lex_state = 41},
  [1355] = {.lex_state = 50, .external_lex_state = 4},
  [1356] = {.lex_state = 41},
  [1357] = {.lex_state = 50},
  [1358] = {.lex_state = 50, .external_lex_state = 4},
  [1359] = {.lex_state = 41},
  [1360] = {.lex_state = 41},
  [1361] = {.lex_state = 41},
  [1362] = {.lex_state = 50, .external_lex_state = 4},
  [1363] = {.lex_state = 50, .external_lex_state = 4},
  [1364] = {.lex_state = 50, .external_lex_state = 4},
  [1365] = {.lex_state = 52},
  [1366] = {.lex_state = 50, .external_lex_state = 4},
  [1367] = {.lex_state = 50, .external_lex_state = 4},
  [1368] = {.lex_state = 50, .external_lex_state = 4},
  [1369] = {.lex_state = 50, .external_lex_state = 4},
  [1370] = {.lex_state = 50, .external_lex_state = 4},
  [1371] = {.lex_state = 50, .external_lex_state = 4},
  [1372] = {.lex_state = 50, .external_lex_state = 4},
  [1373] = {.lex_state = 50, .external_lex_state = 4},
  [1374] = {.lex_state = 50, .external_lex_state = 4},
  [1375] = {.lex_state = 50, .external_lex_state = 4},
  [1376] = {.lex_state = 50, .external_lex_state = 4},
  [1377] = {.lex_state = 50, .external_lex_state = 4},
  [1378] = {.lex_state = 50, .external_lex_state = 4},
  [1379] = {.lex_state = 50, .external_lex_state = 4},
  [1380] = {.lex_state = 41},
  [1381] = {.lex_state = 41},
  [1382] = {.lex_state = 50, .external_lex_state = 4},
  [1383] = {.lex_state = 50, .external_lex_state = 4},
  [1384] = {.lex_state = 41, .external_lex_state = 2},
  [1385] = {.lex_state = 50},
  [1386] = {.lex_state = 50},
  [1387] = {.lex_state = 50},
  [1388] = {.lex_state = 50},
  [1389] = {.lex_state = 41, .external_lex_state = 2},
  [1390] = {.lex_state = 41, .external_lex_state = 2},
  [1391] = {.lex_state = 41, .external_lex_state = 2},
  [1392] = {.lex_state = 41, .external_lex_state = 2},
  [1393] = {.lex_state = 50},
  [1394] = {.lex_state = 50},
  [1395] = {.lex_state = 50},
  [1396] = {.lex_state = 50},
  [1397] = {.lex_state = 50},
  [1398] = {.lex_state = 50},
  [1399] = {.lex_state = 50},
  [1400] = {.lex_state = 50},
  [1401] = {.lex_state = 50},
  [1402] = {.lex_state = 50},
  [1403] = {.lex_state = 50},
  [1404] = {.lex_state = 50},
  [1405] = {.lex_state = 100},
  [1406] = {.lex_state = 41},
  [1407] = {.lex_state = 100},
  [1408] = {.lex_state = 100},
  [1409] = {.lex_state = 41},
  [1410] = {.lex_state = 41},
  [1411] = {.lex_state = 41},
  [1412] = {.lex_state = 100},
  [1413] = {.lex_state = 100},
  [1414] = {.lex_state = 41},
  [1415] = {.lex_state = 100},
  [1416] = {.lex_state = 100},
  [1417] = {.lex_state = 100},
  [1418] = {.lex_state = 100},
  [1419] = {.lex_state = 100},
  [1420] = {.lex_state = 100},
  [1421] = {.lex_state = 50},
  [1422] = {.lex_state = 100},
  [1423] = {.lex_state = 50},
  [1424] = {.lex_state = 100},
  [1425] = {.lex_state = 50},
  [1426] = {.lex_state = 50},
  [1427] = {.lex_state = 50},
  [1428] = {.lex_state = 50},
  [1429] = {.lex_state = 50},
  [1430] = {.lex_state = 50},
  [1431] = {.lex_state = 50},
  [1432] = {.lex_state = 50},
  [1433] = {.lex_state = 50},
  [1434] = {.lex_state = 50},
  [1435] = {.lex_state = 50},
  [1436] = {.lex_state = 50},
  [1437] = {.lex_state = 50},
  [1438] = {.lex_state = 50},
  [1439] = {.lex_state = 50},
  [1440] = {.lex_state = 50},
  [1441] = {.lex_state = 50},
  [1442] = {.lex_state = 50},
  [1443] = {.lex_state = 50},
  [1444] = {.lex_state = 50},
  [1445] = {.lex_state = 50},
  [1446] = {.lex_state = 50},
  [1447] = {.lex_state = 50},
  [1448] = {.lex_state = 50},
  [1449] = {.lex_state = 50},
  [1450] = {.lex_state = 50},
  [1451] = {.lex_state = 50},
  [1452] = {.lex_state = 50},
  [1453] = {.lex_state = 50},
  [1454] = {.lex_state = 50},
  [1455] = {.lex_state = 50},
  [1456] = {.lex_state = 50},
  [1457] = {.lex_state = 50},
  [1458] = {.lex_state = 50},
  [1459] = {.lex_state = 50},
  [1460] = {.lex_state = 50},
  [1461] = {.lex_state = 50},
  [1462] = {.lex_state = 50},
  [1463] = {.lex_state = 50},
  [1464] = {.lex_state = 50},
  [1465] = {.lex_state = 50},
  [1466] = {.lex_state = 50},
  [1467] = {.lex_state = 50},
  [1468] = {.lex_state = 50},
  [1469] = {.lex_state = 50},
  [1470] = {.lex_state = 50},
  [1471] = {.lex_state = 50},
  [1472] = {.lex_state = 50},
  [1473] = {.lex_state = 50},
  [1474] = {.lex_state = 50},
  [1475] = {.lex_state = 50},
  [1476] = {.lex_state = 50},
  [1477] = {.lex_state = 50},
  [1478] = {.lex_state = 50},
  [1479] = {.lex_state = 50},
  [1480] = {.lex_state = 50},
  [1481] = {.lex_state = 50},
  [1482] = {.lex_state = 50},
  [1483] = {.lex_state = 50},
  [1484] = {.lex_state = 50},
  [1485] = {.lex_state = 50},
  [1486] = {.lex_state = 50},
  [1487] = {.lex_state = 50},
  [1488] = {.lex_state = 50},
  [1489] = {.lex_state = 50},
  [1490] = {.lex_state = 50},
  [1491] = {.lex_state = 50},
  [1492] = {.lex_state = 50},
  [1493] = {.lex_state = 50},
  [1494] = {.lex_state = 50},
  [1495] = {.lex_state = 50},
  [1496] = {.lex_state = 50},
  [1497] = {.lex_state = 50},
  [1498] = {.lex_state = 50},
  [1499] = {.lex_state = 50},
  [1500] = {.lex_state = 50},
  [1501] = {.lex_state = 50},
  [1502] = {.lex_state = 50},
  [1503] = {.lex_state = 50},
  [1504] = {.lex_state = 50},
  [1505] = {.lex_state = 50},
  [1506] = {.lex_state = 50},
  [1507] = {.lex_state = 50},
  [1508] = {.lex_state = 50},
  [1509] = {.lex_state = 50},
  [1510] = {.lex_state = 50},
  [1511] = {.lex_state = 50},
  [1512] = {.lex_state = 50},
  [1513] = {.lex_state = 50},
  [1514] = {.lex_state = 50},
  [1515] = {.lex_state = 50},
  [1516] = {.lex_state = 50},
  [1517] = {.lex_state = 50},
  [1518] = {.lex_state = 50},
  [1519] = {.lex_state = 50},
  [1520] = {.lex_state = 50},
  [1521] = {.lex_state = 50},
  [1522] = {.lex_state = 50},
  [1523] = {.lex_state = 50},
  [1524] = {.lex_state = 50},
  [1525] = {.lex_state = 50},
  [1526] = {.lex_state = 50},
  [1527] = {.lex_state = 50},
  [1528] = {.lex_state = 50},
  [1529] = {.lex_state = 50},
  [1530] = {.lex_state = 50},
  [1531] = {.lex_state = 50},
  [1532] = {.lex_state = 50},
  [1533] = {.lex_state = 50},
  [1534] = {.lex_state = 50},
  [1535] = {.lex_state = 50},
  [1536] = {.lex_state = 50},
  [1537] = {.lex_state = 50},
  [1538] = {.lex_state = 50},
  [1539] = {.lex_state = 50},
  [1540] = {.lex_state = 50},
  [1541] = {.lex_state = 50},
  [1542] = {.lex_state = 50},
  [1543] = {.lex_state = 49},
  [1544] = {.lex_state = 4, .external_lex_state = 2},
  [1545] = {.lex_state = 4},
  [1546] = {.lex_state = 4, .external_lex_state = 2},
  [1547] = {.lex_state = 4},
  [1548] = {.lex_state = 4, .external_lex_state = 2},
  [1549] = {.lex_state = 4, .external_lex_state = 2},
  [1550] = {.lex_state = 4, .external_lex_state = 2},
  [1551] = {.lex_state = 4, .external_lex_state = 2},
  [1552] = {.lex_state = 4},
  [1553] = {.lex_state = 0},
  [1554] = {.lex_state = 0},
  [1555] = {.lex_state = 100},
  [1556] = {.lex_state = 0},
  [1557] = {.lex_state = 0},
  [1558] = {.lex_state = 0},
  [1559] = {.lex_state = 100},
  [1560] = {.lex_state = 0},
  [1561] = {.lex_state = 0},
  [1562] = {.lex_state = 100},
  [1563] = {.lex_state = 100},
  [1564] = {.lex_state = 100},
  [1565] = {.lex_state = 0},
  [1566] = {.lex_state = 100},
  [1567] = {.lex_state = 0},
  [1568] = {.lex_state = 0},
  [1569] = {.lex_state = 100},
  [1570] = {.lex_state = 4},
  [1571] = {.lex_state = 0},
  [1572] = {.lex_state = 100},
  [1573] = {.lex_state = 0},
  [1574] = {.lex_state = 0},
  [1575] = {.lex_state = 100},
  [1576] = {.lex_state = 0},
  [1577] = {.lex_state = 0},
  [1578] = {.lex_state = 100},
  [1579] = {.lex_state = 0},
  [1580] = {.lex_state = 0},
  [1581] = {.lex_state = 100},
  [1582] = {.lex_state = 100},
  [1583] = {.lex_state = 0},
  [1584] = {.lex_state = 100},
  [1585] = {.lex_state = 0},
  [1586] = {.lex_state = 0},
  [1587] = {.lex_state = 100},
  [1588] = {.lex_state = 100},
  [1589] = {.lex_state = 100},
  [1590] = {.lex_state = 0},
  [1591] = {.lex_state = 100},
  [1592] = {.lex_state = 0},
  [1593] = {.lex_state = 100},
  [1594] = {.lex_state = 0},
  [1595] = {.lex_state = 100},
  [1596] = {.lex_state = 100},
  [1597] = {.lex_state = 100},
  [1598] = {.lex_state = 100},
  [1599] = {.lex_state = 0},
  [1600] = {.lex_state = 0},
  [1601] = {.lex_state = 100},
  [1602] = {.lex_state = 0},
  [1603] = {.lex_state = 100},
  [1604] = {.lex_state = 100},
  [1605] = {.lex_state = 0},
  [1606] = {.lex_state = 0},
  [1607] = {.lex_state = 0},
  [1608] = {.lex_state = 54, .external_lex_state = 5},
  [1609] = {.lex_state = 54, .external_lex_state = 5},
  [1610] = {.lex_state = 54, .external_lex_state = 5},
  [1611] = {.lex_state = 54, .external_lex_state = 5},
  [1612] = {.lex_state = 54, .external_lex_state = 5},
  [1613] = {.lex_state = 54, .external_lex_state = 5},
  [1614] = {.lex_state = 4, .external_lex_state = 2},
  [1615] = {.lex_state = 4, .external_lex_state = 2},
  [1616] = {.lex_state = 54, .external_lex_state = 5},
  [1617] = {.lex_state = 54, .external_lex_state = 5},
  [1618] = {.lex_state = 54, .external_lex_state = 5},
  [1619] = {.lex_state = 54, .external_lex_state = 5},
  [1620] = {.lex_state = 4, .external_lex_state = 2},
  [1621] = {.lex_state = 4, .external_lex_state = 2},
  [1622] = {.lex_state = 54, .external_lex_state = 5},
  [1623] = {.lex_state = 54, .external_lex_state = 5},
  [1624] = {.lex_state = 54, .external_lex_state = 5},
  [1625] = {.lex_state = 54, .external_lex_state = 5},
  [1626] = {.lex_state = 54, .external_lex_state = 5},
  [1627] = {.lex_state = 54, .external_lex_state = 5},
  [1628] = {.lex_state = 54, .external_lex_state = 5},
  [1629] = {.lex_state = 54, .external_lex_state = 5},
  [1630] = {.lex_state = 54, .external_lex_state = 5},
  [1631] = {.lex_state = 54, .external_lex_state = 5},
  [1632] = {.lex_state = 54, .external_lex_state = 5},
  [1633] = {.lex_state = 0},
  [1634] = {.lex_state = 54, .external_lex_state = 5},
  [1635] = {.lex_state = 0},
  [1636] = {.lex_state = 0},
  [1637] = {.lex_state = 0},
  [1638] = {.lex_state = 0},
  [1639] = {.lex_state = 4},
  [1640] = {.lex_state = 0},
  [1641] = {.lex_state = 0},
  [1642] = {.lex_state = 0},
  [1643] = {.lex_state = 4},
  [1644] = {.lex_state = 0},
  [1645] = {.lex_state = 0},
  [1646] = {.lex_state = 0},
  [1647] = {.lex_state = 0},
  [1648] = {.lex_state = 0},
  [1649] = {.lex_state = 0},
  [1650] = {.lex_state = 0},
  [1651] = {.lex_state = 0},
  [1652] = {.lex_state = 0},
  [1653] = {.lex_state = 0},
  [1654] = {.lex_state = 0},
  [1655] = {.lex_state = 0},
  [1656] = {.lex_state = 0},
  [1657] = {.lex_state = 0},
  [1658] = {.lex_state = 0},
  [1659] = {.lex_state = 0},
  [1660] = {.lex_state = 0},
  [1661] = {.lex_state = 0},
  [1662] = {.lex_state = 0},
  [1663] = {.lex_state = 0},
  [1664] = {.lex_state = 0},
  [1665] = {.lex_state = 0},
  [1666] = {.lex_state = 0},
  [1667] = {.lex_state = 0},
  [1668] = {.lex_state = 0},
  [1669] = {.lex_state = 0},
  [1670] = {.lex_state = 0},
  [1671] = {.lex_state = 0},
  [1672] = {.lex_state = 0},
  [1673] = {.lex_state = 0},
  [1674] = {.lex_state = 0},
  [1675] = {.lex_state = 0},
  [1676] = {.lex_state = 0},
  [1677] = {.lex_state = 0},
  [1678] = {.lex_state = 0},
  [1679] = {.lex_state = 0},
  [1680] = {.lex_state = 0},
  [1681] = {.lex_state = 0},
  [1682] = {.lex_state = 0},
  [1683] = {.lex_state = 0},
  [1684] = {.lex_state = 0},
  [1685] = {.lex_state = 0},
  [1686] = {.lex_state = 0},
  [1687] = {.lex_state = 0},
  [1688] = {.lex_state = 0},
  [1689] = {.lex_state = 0},
  [1690] = {.lex_state = 0},
  [1691] = {.lex_state = 0},
  [1692] = {.lex_state = 0},
  [1693] = {.lex_state = 0},
  [1694] = {.lex_state = 0},
  [1695] = {.lex_state = 0},
  [1696] = {.lex_state = 0},
  [1697] = {.lex_state = 0},
  [1698] = {.lex_state = 0},
  [1699] = {.lex_state = 0},
  [1700] = {.lex_state = 0},
  [1701] = {.lex_state = 0},
  [1702] = {.lex_state = 100},
  [1703] = {.lex_state = 0},
  [1704] = {.lex_state = 0},
  [1705] = {.lex_state = 0},
  [1706] = {.lex_state = 0},
  [1707] = {.lex_state = 0},
  [1708] = {.lex_state = 0},
  [1709] = {.lex_state = 56},
  [1710] = {.lex_state = 0},
  [1711] = {.lex_state = 0},
  [1712] = {.lex_state = 0},
  [1713] = {.lex_state = 0},
  [1714] = {.lex_state = 0},
  [1715] = {.lex_state = 0},
  [1716] = {.lex_state = 0},
  [1717] = {.lex_state = 0, .external_lex_state = 6},
  [1718] = {.lex_state = 0, .external_lex_state = 6},
  [1719] = {.lex_state = 0},
  [1720] = {.lex_state = 100},
  [1721] = {.lex_state = 0},
  [1722] = {.lex_state = 0},
  [1723] = {.lex_state = 0},
  [1724] = {.lex_state = 0},
  [1725] = {.lex_state = 0},
  [1726] = {.lex_state = 100},
  [1727] = {.lex_state = 100},
  [1728] = {.lex_state = 100},
  [1729] = {.lex_state = 0},
  [1730] = {.lex_state = 171},
  [1731] = {.lex_state = 171},
  [1732] = {.lex_state = 171},
  [1733] = {.lex_state = 171},
  [1734] = {.lex_state = 171},
  [1735] = {.lex_state = 171},
  [1736] = {.lex_state = 171},
  [1737] = {.lex_state = 171},
  [1738] = {.lex_state = 171},
  [1739] = {.lex_state = 0, .external_lex_state = 6},
  [1740] = {.lex_state = 171},
  [1741] = {.lex_state = 0, .external_lex_state = 6},
  [1742] = {.lex_state = 171},
  [1743] = {.lex_state = 0, .external_lex_state = 6},
  [1744] = {.lex_state = 0},
  [1745] = {.lex_state = 171},
  [1746] = {.lex_state = 0, .external_lex_state = 6},
  [1747] = {.lex_state = 0},
  [1748] = {.lex_state = 171},
  [1749] = {.lex_state = 0, .external_lex_state = 6},
  [1750] = {.lex_state = 0},
  [1751] = {.lex_state = 100},
  [1752] = {.lex_state = 171},
  [1753] = {.lex_state = 0, .external_lex_state = 6},
  [1754] = {.lex_state = 0},
  [1755] = {.lex_state = 171},
  [1756] = {.lex_state = 0, .external_lex_state = 6},
  [1757] = {.lex_state = 0},
  [1758] = {.lex_state = 171},
  [1759] = {.lex_state = 0, .external_lex_state = 6},
  [1760] = {.lex_state = 0},
  [1761] = {.lex_state = 171},
  [1762] = {.lex_state = 0, .external_lex_state = 6},
  [1763] = {.lex_state = 0},
  [1764] = {.lex_state = 171},
  [1765] = {.lex_state = 0, .external_lex_state = 6},
  [1766] = {.lex_state = 0},
  [1767] = {.lex_state = 194},
  [1768] = {.lex_state = 171},
  [1769] = {.lex_state = 56},
  [1770] = {.lex_state = 0, .external_lex_state = 6},
  [1771] = {.lex_state = 0},
  [1772] = {.lex_state = 171},
  [1773] = {.lex_state = 0, .external_lex_state = 6},
  [1774] = {.lex_state = 0},
  [1775] = {.lex_state = 171},
  [1776] = {.lex_state = 0, .external_lex_state = 6},
  [1777] = {.lex_state = 0},
  [1778] = {.lex_state = 171},
  [1779] = {.lex_state = 0, .external_lex_state = 6},
  [1780] = {.lex_state = 0},
  [1781] = {.lex_state = 171},
  [1782] = {.lex_state = 0, .external_lex_state = 6},
  [1783] = {.lex_state = 0},
  [1784] = {.lex_state = 0},
  [1785] = {.lex_state = 56},
  [1786] = {.lex_state = 0},
  [1787] = {.lex_state = 0, .external_lex_state = 6},
  [1788] = {.lex_state = 0},
  [1789] = {.lex_state = 171},
  [1790] = {.lex_state = 56},
  [1791] = {.lex_state = 56},
  [1792] = {.lex_state = 56},
  [1793] = {.lex_state = 56},
  [1794] = {.lex_state = 0},
  [1795] = {.lex_state = 100},
  [1796] = {.lex_state = 56},
  [1797] = {.lex_state = 100},
  [1798] = {.lex_state = 56},
  [1799] = {.lex_state = 56},
  [1800] = {.lex_state = 0},
  [1801] = {.lex_state = 0},
  [1802] = {.lex_state = 56},
  [1803] = {.lex_state = 0},
  [1804] = {.lex_state = 0},
  [1805] = {.lex_state = 0},
  [1806] = {.lex_state = 0},
  [1807] = {.lex_state = 0},
  [1808] = {.lex_state = 0},
  [1809] = {.lex_state = 0},
  [1810] = {.lex_state = 0},
  [1811] = {.lex_state = 0},
  [1812] = {.lex_state = 0},
  [1813] = {.lex_state = 0},
  [1814] = {.lex_state = 0},
  [1815] = {.lex_state = 0},
  [1816] = {.lex_state = 100},
  [1817] = {.lex_state = 100},
  [1818] = {.lex_state = 100},
  [1819] = {.lex_state = 100},
  [1820] = {.lex_state = 0},
  [1821] = {.lex_state = 0},
  [1822] = {.lex_state = 56},
  [1823] = {.lex_state = 0},
  [1824] = {.lex_state = 56},
  [1825] = {.lex_state = 0},
  [1826] = {.lex_state = 0},
  [1827] = {.lex_state = 0},
  [1828] = {.lex_state = 56},
  [1829] = {.lex_state = 0},
  [1830] = {.lex_state = 0},
  [1831] = {.lex_state = 0},
  [1832] = {.lex_state = 56},
  [1833] = {.lex_state = 0},
  [1834] = {.lex_state = 0},
  [1835] = {.lex_state = 0},
  [1836] = {.lex_state = 56},
  [1837] = {.lex_state = 0},
  [1838] = {.lex_state = 0},
  [1839] = {.lex_state = 0},
  [1840] = {.lex_state = 100},
  [1841] = {.lex_state = 100},
  [1842] = {.lex_state = 56},
  [1843] = {.lex_state = 0},
  [1844] = {.lex_state = 0},
  [1845] = {.lex_state = 0},
  [1846] = {.lex_state = 100},
  [1847] = {.lex_state = 56},
  [1848] = {.lex_state = 0},
  [1849] = {.lex_state = 0},
  [1850] = {.lex_state = 56},
  [1851] = {.lex_state = 0},
  [1852] = {.lex_state = 0},
  [1853] = {.lex_state = 0},
  [1854] = {.lex_state = 0},
  [1855] = {.lex_state = 56},
  [1856] = {.lex_state = 0},
  [1857] = {.lex_state = 0},
  [1858] = {.lex_state = 0},
  [1859] = {.lex_state = 56},
  [1860] = {.lex_state = 0},
  [1861] = {.lex_state = 0},
  [1862] = {.lex_state = 0},
  [1863] = {.lex_state = 0},
  [1864] = {.lex_state = 56},
  [1865] = {.lex_state = 0},
  [1866] = {.lex_state = 0},
  [1867] = {.lex_state = 0},
  [1868] = {.lex_state = 56},
  [1869] = {.lex_state = 0},
  [1870] = {.lex_state = 0},
  [1871] = {.lex_state = 0},
  [1872] = {.lex_state = 56},
  [1873] = {.lex_state = 0},
  [1874] = {.lex_state = 100},
  [1875] = {.lex_state = 100},
  [1876] = {.lex_state = 100},
  [1877] = {.lex_state = 0},
  [1878] = {.lex_state = 0},
  [1879] = {.lex_state = 56},
  [1880] = {.lex_state = 56},
  [1881] = {.lex_state = 0},
  [1882] = {.lex_state = 0},
  [1883] = {.lex_state = 0},
  [1884] = {.lex_state = 0},
  [1885] = {.lex_state = 0},
  [1886] = {.lex_state = 171},
  [1887] = {.lex_state = 0},
  [1888] = {.lex_state = 0},
  [1889] = {.lex_state = 100},
  [1890] = {.lex_state = 100},
  [1891] = {.lex_state = 100},
  [1892] = {.lex_state = 0},
  [1893] = {.lex_state = 100},
  [1894] = {.lex_state = 0},
  [1895] = {.lex_state = 100},
  [1896] = {.lex_state = 100},
  [1897] = {(TSStateId)(-1)},
};

enum {
  ts_external_token_concatenating_space = 0,
  ts_external_token__if_else_separator = 1,
  ts_external_token__ambiguous_comment = 2,
  ts_external_token__no_space = 3,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_concatenating_space] = sym_concatenating_space,
  [ts_external_token__if_else_separator] = sym__if_else_separator,
  [ts_external_token__ambiguous_comment] = sym__ambiguous_comment,
  [ts_external_token__no_space] = sym__no_space,
};

static const bool ts_external_scanner_states[7][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_concatenating_space] = true,
    [ts_external_token__if_else_separator] = true,
    [ts_external_token__ambiguous_comment] = true,
    [ts_external_token__no_space] = true,
  },
  [2] = {
    [ts_external_token__if_else_separator] = true,
  },
  [3] = {
    [ts_external_token_concatenating_space] = true,
    [ts_external_token__if_else_separator] = true,
  },
  [4] = {
    [ts_external_token_concatenating_space] = true,
  },
  [5] = {
    [ts_external_token__ambiguous_comment] = true,
  },
  [6] = {
    [ts_external_token__no_space] = true,
  },
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [sym_comment] = STATE(0),
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_BEGIN] = ACTIONS(1),
    [anon_sym_END] = ACTIONS(1),
    [anon_sym_BEGINFILE] = ACTIONS(1),
    [anon_sym_ENDFILE] = ACTIONS(1),
    [anon_sym_ATinclude] = ACTIONS(1),
    [anon_sym_ATload] = ACTIONS(1),
    [anon_sym_ATnamespace] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [sym_break_statement] = ACTIONS(1),
    [sym_continue_statement] = ACTIONS(1),
    [anon_sym_delete] = ACTIONS(1),
    [anon_sym_exit] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [anon_sym_getline] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [sym_next_statement] = ACTIONS(1),
    [sym_nextfile_statement] = ACTIONS(1),
    [anon_sym_print] = ACTIONS(1),
    [anon_sym_LPAREN2] = ACTIONS(1),
    [anon_sym_printf] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_PIPE_AMP] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_STAR_STAR] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_BANG_TILDE] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [sym_number] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_func] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(3),
    [sym_concatenating_space] = ACTIONS(1),
    [sym__if_else_separator] = ACTIONS(1),
    [sym__ambiguous_comment] = ACTIONS(1),
    [sym__no_space] = ACTIONS(1),
  },
  [1] = {
    [sym_program] = STATE(1863),
    [sym_rule] = STATE(1418),
    [sym_pattern] = STATE(1408),
    [sym_range_pattern] = STATE(1415),
    [sym__special_pattern] = STATE(1415),
    [sym_directive] = STATE(1418),
    [sym__getline_exp] = STATE(503),
    [sym_getline_input] = STATE(513),
    [sym_getline_file] = STATE(513),
    [sym_block] = STATE(1422),
    [sym__exp] = STATE(514),
    [sym_ternary_exp] = STATE(471),
    [sym_binary_exp] = STATE(471),
    [sym_unary_exp] = STATE(471),
    [sym_update_exp] = STATE(503),
    [sym_assignment_exp] = STATE(503),
    [sym_piped_io_exp] = STATE(503),
    [sym_string_concat] = STATE(471),
    [sym_field_ref] = STATE(415),
    [sym_array_ref] = STATE(409),
    [sym_regex] = STATE(503),
    [sym_regex_constant] = STATE(503),
    [sym_grouping] = STATE(471),
    [sym__primitive] = STATE(471),
    [sym_namespace] = STATE(1853),
    [sym_ns_qualified_name] = STATE(348),
    [sym_string] = STATE(479),
    [sym_func_def] = STATE(1418),
    [sym_func_call] = STATE(471),
    [sym_indirect_func_call] = STATE(503),
    [sym_comment] = STATE(1),
    [aux_sym_program_repeat1] = STATE(305),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_BEGIN] = ACTIONS(9),
    [anon_sym_END] = ACTIONS(9),
    [anon_sym_BEGINFILE] = ACTIONS(9),
    [anon_sym_ENDFILE] = ACTIONS(9),
    [anon_sym_ATinclude] = ACTIONS(11),
    [anon_sym_ATload] = ACTIONS(11),
    [anon_sym_ATnamespace] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_getline] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(23),
    [anon_sym_PLUS_PLUS] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(25),
    [anon_sym_DOLLAR] = ACTIONS(27),
    [anon_sym_AT] = ACTIONS(29),
    [sym_number] = ACTIONS(31),
    [anon_sym_DQUOTE] = ACTIONS(33),
    [anon_sym_function] = ACTIONS(35),
    [anon_sym_func] = ACTIONS(35),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [2] = {
    [sym__statement] = STATE(1044),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(2),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LF] = ACTIONS(39),
    [anon_sym_CR_LF] = ACTIONS(39),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_case] = ACTIONS(39),
    [anon_sym_default] = ACTIONS(39),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(69),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(71),
    [anon_sym_PLUS_PLUS] = ACTIONS(73),
    [anon_sym_DASH_DASH] = ACTIONS(73),
    [anon_sym_DOLLAR] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [sym_number] = ACTIONS(79),
    [anon_sym_DQUOTE] = ACTIONS(81),
    [anon_sym_POUND] = ACTIONS(83),
    [sym__if_else_separator] = ACTIONS(85),
  },
  [3] = {
    [sym__statement] = STATE(1044),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(3),
    [sym_identifier] = ACTIONS(39),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LF] = ACTIONS(39),
    [anon_sym_CR_LF] = ACTIONS(39),
    [anon_sym_if] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(39),
    [sym_break_statement] = ACTIONS(39),
    [sym_continue_statement] = ACTIONS(39),
    [anon_sym_delete] = ACTIONS(39),
    [anon_sym_exit] = ACTIONS(39),
    [anon_sym_return] = ACTIONS(39),
    [anon_sym_switch] = ACTIONS(39),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_getline] = ACTIONS(39),
    [sym_next_statement] = ACTIONS(39),
    [sym_nextfile_statement] = ACTIONS(39),
    [anon_sym_print] = ACTIONS(39),
    [anon_sym_printf] = ACTIONS(39),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(39),
    [anon_sym_AT] = ACTIONS(39),
    [sym_number] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_POUND] = ACTIONS(83),
    [sym__if_else_separator] = ACTIONS(85),
  },
  [4] = {
    [sym__statement] = STATE(1098),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(4),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LF] = ACTIONS(39),
    [anon_sym_CR_LF] = ACTIONS(39),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(91),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_case] = ACTIONS(39),
    [anon_sym_default] = ACTIONS(39),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(117),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(119),
    [anon_sym_PLUS_PLUS] = ACTIONS(121),
    [anon_sym_DASH_DASH] = ACTIONS(121),
    [anon_sym_DOLLAR] = ACTIONS(123),
    [anon_sym_AT] = ACTIONS(125),
    [sym_number] = ACTIONS(127),
    [anon_sym_DQUOTE] = ACTIONS(129),
    [anon_sym_POUND] = ACTIONS(83),
  },
  [5] = {
    [sym__statement] = STATE(1183),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1283),
    [sym__block_content] = STATE(1290),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(5),
    [aux_sym_block_repeat1] = STATE(10),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(145),
    [anon_sym_RBRACE] = ACTIONS(147),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [6] = {
    [sym__statement] = STATE(1183),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1283),
    [sym__block_content] = STATE(1290),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(6),
    [aux_sym_block_repeat1] = STATE(8),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(145),
    [anon_sym_RBRACE] = ACTIONS(171),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [7] = {
    [sym__statement] = STATE(1183),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1283),
    [sym__block_content] = STATE(1290),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(7),
    [aux_sym_block_repeat1] = STATE(5),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(145),
    [anon_sym_RBRACE] = ACTIONS(173),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [8] = {
    [sym__statement] = STATE(1183),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1283),
    [sym__block_content] = STATE(1290),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(8),
    [aux_sym_block_repeat1] = STATE(10),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(145),
    [anon_sym_RBRACE] = ACTIONS(175),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [9] = {
    [sym__statement] = STATE(1183),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1283),
    [sym__block_content] = STATE(1290),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(9),
    [aux_sym_block_repeat1] = STATE(10),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(145),
    [anon_sym_RBRACE] = ACTIONS(177),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [10] = {
    [sym__statement] = STATE(1183),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1283),
    [sym__block_content] = STATE(1290),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(10),
    [aux_sym_block_repeat1] = STATE(10),
    [sym_identifier] = ACTIONS(179),
    [anon_sym_if] = ACTIONS(182),
    [anon_sym_LPAREN] = ACTIONS(185),
    [anon_sym_while] = ACTIONS(188),
    [anon_sym_do] = ACTIONS(191),
    [anon_sym_for] = ACTIONS(194),
    [sym_break_statement] = ACTIONS(197),
    [sym_continue_statement] = ACTIONS(197),
    [anon_sym_delete] = ACTIONS(200),
    [anon_sym_exit] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(206),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_LBRACE] = ACTIONS(212),
    [anon_sym_RBRACE] = ACTIONS(215),
    [anon_sym_getline] = ACTIONS(217),
    [sym_next_statement] = ACTIONS(220),
    [sym_nextfile_statement] = ACTIONS(220),
    [anon_sym_print] = ACTIONS(223),
    [anon_sym_printf] = ACTIONS(226),
    [anon_sym_SLASH] = ACTIONS(229),
    [anon_sym_PLUS] = ACTIONS(232),
    [anon_sym_DASH] = ACTIONS(232),
    [anon_sym_BANG] = ACTIONS(235),
    [anon_sym_PLUS_PLUS] = ACTIONS(238),
    [anon_sym_DASH_DASH] = ACTIONS(238),
    [anon_sym_DOLLAR] = ACTIONS(241),
    [anon_sym_AT] = ACTIONS(244),
    [sym_number] = ACTIONS(247),
    [anon_sym_DQUOTE] = ACTIONS(250),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [11] = {
    [sym__statement] = STATE(1183),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1283),
    [sym__block_content] = STATE(1290),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(11),
    [aux_sym_block_repeat1] = STATE(9),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(145),
    [anon_sym_RBRACE] = ACTIONS(253),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [12] = {
    [sym__statement] = STATE(1098),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(12),
    [sym_identifier] = ACTIONS(39),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LF] = ACTIONS(39),
    [anon_sym_CR_LF] = ACTIONS(39),
    [anon_sym_if] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(39),
    [sym_break_statement] = ACTIONS(39),
    [sym_continue_statement] = ACTIONS(39),
    [anon_sym_delete] = ACTIONS(39),
    [anon_sym_exit] = ACTIONS(39),
    [anon_sym_return] = ACTIONS(39),
    [anon_sym_switch] = ACTIONS(39),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_getline] = ACTIONS(39),
    [sym_next_statement] = ACTIONS(39),
    [sym_nextfile_statement] = ACTIONS(39),
    [anon_sym_print] = ACTIONS(39),
    [anon_sym_printf] = ACTIONS(39),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(39),
    [anon_sym_AT] = ACTIONS(39),
    [sym_number] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_POUND] = ACTIONS(83),
  },
  [13] = {
    [sym__statement] = STATE(1183),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1283),
    [sym__block_content] = STATE(1290),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(13),
    [aux_sym_block_repeat1] = STATE(10),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(145),
    [anon_sym_RBRACE] = ACTIONS(255),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [14] = {
    [sym__statement] = STATE(1183),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1283),
    [sym__block_content] = STATE(1290),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(14),
    [aux_sym_block_repeat1] = STATE(13),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(145),
    [anon_sym_RBRACE] = ACTIONS(257),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [15] = {
    [sym__statement] = STATE(1044),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(15),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LF] = ACTIONS(39),
    [anon_sym_CR_LF] = ACTIONS(39),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_PLUS_PLUS] = ACTIONS(279),
    [anon_sym_DASH_DASH] = ACTIONS(279),
    [anon_sym_DOLLAR] = ACTIONS(281),
    [anon_sym_AT] = ACTIONS(283),
    [sym_number] = ACTIONS(79),
    [anon_sym_DQUOTE] = ACTIONS(81),
    [anon_sym_POUND] = ACTIONS(83),
    [sym__if_else_separator] = ACTIONS(85),
  },
  [16] = {
    [sym__statement] = STATE(1621),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1620),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(16),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(289),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(293),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_PLUS_PLUS] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(297),
    [anon_sym_DOLLAR] = ACTIONS(299),
    [anon_sym_AT] = ACTIONS(301),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [17] = {
    [sym__statement] = STATE(1615),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1614),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(17),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_SEMI] = ACTIONS(307),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(289),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(293),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_PLUS_PLUS] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(297),
    [anon_sym_DOLLAR] = ACTIONS(299),
    [anon_sym_AT] = ACTIONS(301),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [18] = {
    [sym__statement] = STATE(1550),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1551),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(18),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_SEMI] = ACTIONS(309),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(313),
    [anon_sym_PLUS_PLUS] = ACTIONS(315),
    [anon_sym_DASH_DASH] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(319),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [19] = {
    [sym__statement] = STATE(1144),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1149),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(19),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_SEMI] = ACTIONS(323),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(331),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(333),
    [anon_sym_return] = ACTIONS(335),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(339),
    [anon_sym_printf] = ACTIONS(341),
    [anon_sym_SLASH] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_DOLLAR] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [sym_number] = ACTIONS(355),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [20] = {
    [sym__statement] = STATE(1570),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(20),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(361),
    [anon_sym_case] = ACTIONS(363),
    [anon_sym_default] = ACTIONS(363),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_DOLLAR] = ACTIONS(371),
    [anon_sym_AT] = ACTIONS(373),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [21] = {
    [sym__statement] = STATE(1145),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1146),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(21),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_SEMI] = ACTIONS(379),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(331),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(333),
    [anon_sym_return] = ACTIONS(335),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(339),
    [anon_sym_printf] = ACTIONS(341),
    [anon_sym_SLASH] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_DOLLAR] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [sym_number] = ACTIONS(355),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [22] = {
    [sym__statement] = STATE(1549),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1548),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(22),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_SEMI] = ACTIONS(381),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(313),
    [anon_sym_PLUS_PLUS] = ACTIONS(315),
    [anon_sym_DASH_DASH] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(319),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [23] = {
    [sym__statement] = STATE(1098),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(23),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LF] = ACTIONS(39),
    [anon_sym_CR_LF] = ACTIONS(39),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(91),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(401),
    [anon_sym_PLUS_PLUS] = ACTIONS(403),
    [anon_sym_DASH_DASH] = ACTIONS(403),
    [anon_sym_DOLLAR] = ACTIONS(405),
    [anon_sym_AT] = ACTIONS(407),
    [sym_number] = ACTIONS(127),
    [anon_sym_DQUOTE] = ACTIONS(129),
    [anon_sym_POUND] = ACTIONS(83),
  },
  [24] = {
    [sym__statement] = STATE(1050),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1047),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(24),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(289),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(293),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_PLUS_PLUS] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(297),
    [anon_sym_DOLLAR] = ACTIONS(299),
    [anon_sym_AT] = ACTIONS(301),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [25] = {
    [sym__statement] = STATE(1092),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1091),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(25),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(289),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(293),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_PLUS_PLUS] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(297),
    [anon_sym_DOLLAR] = ACTIONS(299),
    [anon_sym_AT] = ACTIONS(301),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [26] = {
    [sym__statement] = STATE(1104),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1105),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(26),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [27] = {
    [sym__statement] = STATE(1102),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1103),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(27),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [28] = {
    [sym__statement] = STATE(1060),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1051),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(28),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(313),
    [anon_sym_PLUS_PLUS] = ACTIONS(315),
    [anon_sym_DASH_DASH] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(319),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [29] = {
    [sym__statement] = STATE(1062),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1061),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(29),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(313),
    [anon_sym_PLUS_PLUS] = ACTIONS(315),
    [anon_sym_DASH_DASH] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(319),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [30] = {
    [sym__statement] = STATE(1067),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1065),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(30),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(313),
    [anon_sym_PLUS_PLUS] = ACTIONS(315),
    [anon_sym_DASH_DASH] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(319),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [31] = {
    [sym__statement] = STATE(1074),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1073),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(31),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(313),
    [anon_sym_PLUS_PLUS] = ACTIONS(315),
    [anon_sym_DASH_DASH] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(319),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [32] = {
    [sym__statement] = STATE(1129),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1093),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(32),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [33] = {
    [sym__statement] = STATE(1077),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1076),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(33),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(313),
    [anon_sym_PLUS_PLUS] = ACTIONS(315),
    [anon_sym_DASH_DASH] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(319),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [34] = {
    [sym__statement] = STATE(1081),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1079),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(34),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(313),
    [anon_sym_PLUS_PLUS] = ACTIONS(315),
    [anon_sym_DASH_DASH] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(319),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [35] = {
    [sym__statement] = STATE(1083),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1082),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(35),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(313),
    [anon_sym_PLUS_PLUS] = ACTIONS(315),
    [anon_sym_DASH_DASH] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(319),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [36] = {
    [sym__statement] = STATE(1088),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1087),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(36),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(313),
    [anon_sym_PLUS_PLUS] = ACTIONS(315),
    [anon_sym_DASH_DASH] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(319),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [37] = {
    [sym__statement] = STATE(1136),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1132),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(37),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [38] = {
    [sym__statement] = STATE(1109),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1117),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(38),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [39] = {
    [sym__statement] = STATE(1092),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1091),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(39),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(313),
    [anon_sym_PLUS_PLUS] = ACTIONS(315),
    [anon_sym_DASH_DASH] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(319),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [40] = {
    [sym__statement] = STATE(1129),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1093),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(40),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_DOLLAR] = ACTIONS(371),
    [anon_sym_AT] = ACTIONS(373),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [41] = {
    [sym__statement] = STATE(1128),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1113),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(41),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [42] = {
    [sym__statement] = STATE(1639),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1713),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(42),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(415),
    [anon_sym_PLUS_PLUS] = ACTIONS(417),
    [anon_sym_DASH_DASH] = ACTIONS(417),
    [anon_sym_DOLLAR] = ACTIONS(419),
    [anon_sym_AT] = ACTIONS(421),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [43] = {
    [sym__statement] = STATE(1136),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1132),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(43),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_DOLLAR] = ACTIONS(371),
    [anon_sym_AT] = ACTIONS(373),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [44] = {
    [sym__statement] = STATE(1128),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1113),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(44),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_DOLLAR] = ACTIONS(371),
    [anon_sym_AT] = ACTIONS(373),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [45] = {
    [sym__statement] = STATE(1109),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1117),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(45),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_DOLLAR] = ACTIONS(371),
    [anon_sym_AT] = ACTIONS(373),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [46] = {
    [sym__statement] = STATE(1111),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1120),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(46),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [47] = {
    [sym__statement] = STATE(1123),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1112),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(47),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_DOLLAR] = ACTIONS(371),
    [anon_sym_AT] = ACTIONS(373),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [48] = {
    [sym__statement] = STATE(1115),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1116),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(48),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_DOLLAR] = ACTIONS(371),
    [anon_sym_AT] = ACTIONS(373),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [49] = {
    [sym__statement] = STATE(1107),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1100),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(49),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_DOLLAR] = ACTIONS(371),
    [anon_sym_AT] = ACTIONS(373),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [50] = {
    [sym__statement] = STATE(1001),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1042),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(50),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(331),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(333),
    [anon_sym_return] = ACTIONS(335),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(339),
    [anon_sym_printf] = ACTIONS(341),
    [anon_sym_SLASH] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_DOLLAR] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [sym_number] = ACTIONS(355),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [51] = {
    [sym__statement] = STATE(1104),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1105),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(51),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_DOLLAR] = ACTIONS(371),
    [anon_sym_AT] = ACTIONS(373),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [52] = {
    [sym__statement] = STATE(1102),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1103),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(52),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_DOLLAR] = ACTIONS(371),
    [anon_sym_AT] = ACTIONS(373),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [53] = {
    [sym__statement] = STATE(1111),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1120),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(53),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_DOLLAR] = ACTIONS(371),
    [anon_sym_AT] = ACTIONS(373),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [54] = {
    [sym__statement] = STATE(1127),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1122),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(54),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_DOLLAR] = ACTIONS(371),
    [anon_sym_AT] = ACTIONS(373),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [55] = {
    [sym__statement] = STATE(1001),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1042),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(55),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(289),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(293),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_PLUS_PLUS] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(297),
    [anon_sym_DOLLAR] = ACTIONS(299),
    [anon_sym_AT] = ACTIONS(301),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [56] = {
    [sym__statement] = STATE(1643),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1821),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(56),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(415),
    [anon_sym_PLUS_PLUS] = ACTIONS(417),
    [anon_sym_DASH_DASH] = ACTIONS(417),
    [anon_sym_DOLLAR] = ACTIONS(419),
    [anon_sym_AT] = ACTIONS(421),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [57] = {
    [sym__statement] = STATE(1060),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1051),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(57),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(289),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(293),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_PLUS_PLUS] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(297),
    [anon_sym_DOLLAR] = ACTIONS(299),
    [anon_sym_AT] = ACTIONS(301),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [58] = {
    [sym__statement] = STATE(1062),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1061),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(58),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(289),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(293),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_PLUS_PLUS] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(297),
    [anon_sym_DOLLAR] = ACTIONS(299),
    [anon_sym_AT] = ACTIONS(301),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [59] = {
    [sym__statement] = STATE(1067),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1065),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(59),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(289),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(293),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_PLUS_PLUS] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(297),
    [anon_sym_DOLLAR] = ACTIONS(299),
    [anon_sym_AT] = ACTIONS(301),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [60] = {
    [sym__statement] = STATE(1074),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1073),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(60),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(289),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(293),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_PLUS_PLUS] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(297),
    [anon_sym_DOLLAR] = ACTIONS(299),
    [anon_sym_AT] = ACTIONS(301),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [61] = {
    [sym__statement] = STATE(1127),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1122),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(61),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [62] = {
    [sym__statement] = STATE(1115),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1116),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(62),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [63] = {
    [sym__statement] = STATE(1077),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1076),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(63),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(289),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(293),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_PLUS_PLUS] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(297),
    [anon_sym_DOLLAR] = ACTIONS(299),
    [anon_sym_AT] = ACTIONS(301),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [64] = {
    [sym__statement] = STATE(1081),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1079),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(64),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(289),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(293),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_PLUS_PLUS] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(297),
    [anon_sym_DOLLAR] = ACTIONS(299),
    [anon_sym_AT] = ACTIONS(301),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [65] = {
    [sym__statement] = STATE(1083),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1082),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(65),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(289),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(293),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_PLUS_PLUS] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(297),
    [anon_sym_DOLLAR] = ACTIONS(299),
    [anon_sym_AT] = ACTIONS(301),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [66] = {
    [sym__statement] = STATE(1123),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1112),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(66),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [67] = {
    [sym__statement] = STATE(1127),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1122),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(67),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(415),
    [anon_sym_PLUS_PLUS] = ACTIONS(417),
    [anon_sym_DASH_DASH] = ACTIONS(417),
    [anon_sym_DOLLAR] = ACTIONS(419),
    [anon_sym_AT] = ACTIONS(421),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [68] = {
    [sym__statement] = STATE(1088),
    [sym__statement_separated] = STATE(15),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1546),
    [sym_printf_statement] = STATE(1546),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1087),
    [sym__exp] = STATE(1391),
    [sym_ternary_exp] = STATE(1279),
    [sym_binary_exp] = STATE(1279),
    [sym_unary_exp] = STATE(1279),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1279),
    [sym_field_ref] = STATE(595),
    [sym_array_ref] = STATE(576),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1279),
    [sym__primitive] = STATE(1279),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(551),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1279),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(68),
    [sym_identifier] = ACTIONS(259),
    [anon_sym_if] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(289),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(263),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(265),
    [anon_sym_return] = ACTIONS(267),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(269),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(271),
    [anon_sym_printf] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(293),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_PLUS_PLUS] = ACTIONS(297),
    [anon_sym_DASH_DASH] = ACTIONS(297),
    [anon_sym_DOLLAR] = ACTIONS(299),
    [anon_sym_AT] = ACTIONS(301),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [69] = {
    [sym__statement] = STATE(1107),
    [sym__statement_separated] = STATE(12),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(391),
    [sym_getline_input] = STATE(392),
    [sym_getline_file] = STATE(392),
    [sym_print_statement] = STATE(703),
    [sym_printf_statement] = STATE(703),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1100),
    [sym__exp] = STATE(435),
    [sym_ternary_exp] = STATE(381),
    [sym_binary_exp] = STATE(381),
    [sym_unary_exp] = STATE(381),
    [sym_update_exp] = STATE(391),
    [sym_assignment_exp] = STATE(391),
    [sym_piped_io_exp] = STATE(391),
    [sym_string_concat] = STATE(381),
    [sym_field_ref] = STATE(208),
    [sym_array_ref] = STATE(203),
    [sym_regex] = STATE(391),
    [sym_regex_constant] = STATE(391),
    [sym_grouping] = STATE(381),
    [sym__primitive] = STATE(381),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(182),
    [sym_string] = STATE(330),
    [sym_func_call] = STATE(381),
    [sym_indirect_func_call] = STATE(391),
    [sym_comment] = STATE(69),
    [sym_identifier] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(133),
    [anon_sym_LPAREN] = ACTIONS(135),
    [anon_sym_while] = ACTIONS(137),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(139),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(149),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(151),
    [anon_sym_printf] = ACTIONS(153),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(159),
    [anon_sym_PLUS_PLUS] = ACTIONS(161),
    [anon_sym_DASH_DASH] = ACTIONS(161),
    [anon_sym_DOLLAR] = ACTIONS(163),
    [anon_sym_AT] = ACTIONS(165),
    [sym_number] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(169),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [70] = {
    [sym__statement] = STATE(1001),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1042),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(70),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(313),
    [anon_sym_PLUS_PLUS] = ACTIONS(315),
    [anon_sym_DASH_DASH] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(319),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [71] = {
    [sym__statement] = STATE(1111),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1120),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(71),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(415),
    [anon_sym_PLUS_PLUS] = ACTIONS(417),
    [anon_sym_DASH_DASH] = ACTIONS(417),
    [anon_sym_DOLLAR] = ACTIONS(419),
    [anon_sym_AT] = ACTIONS(421),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [72] = {
    [sym__statement] = STATE(1092),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1091),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(72),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(331),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(333),
    [anon_sym_return] = ACTIONS(335),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(339),
    [anon_sym_printf] = ACTIONS(341),
    [anon_sym_SLASH] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_DOLLAR] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [sym_number] = ACTIONS(355),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [73] = {
    [sym__statement] = STATE(1088),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1087),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(73),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(331),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(333),
    [anon_sym_return] = ACTIONS(335),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(339),
    [anon_sym_printf] = ACTIONS(341),
    [anon_sym_SLASH] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_DOLLAR] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [sym_number] = ACTIONS(355),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [74] = {
    [sym__statement] = STATE(1129),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1093),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(74),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(415),
    [anon_sym_PLUS_PLUS] = ACTIONS(417),
    [anon_sym_DASH_DASH] = ACTIONS(417),
    [anon_sym_DOLLAR] = ACTIONS(419),
    [anon_sym_AT] = ACTIONS(421),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [75] = {
    [sym__statement] = STATE(1083),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1082),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(75),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(331),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(333),
    [anon_sym_return] = ACTIONS(335),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(339),
    [anon_sym_printf] = ACTIONS(341),
    [anon_sym_SLASH] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_DOLLAR] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [sym_number] = ACTIONS(355),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [76] = {
    [sym__statement] = STATE(1081),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1079),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(76),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(331),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(333),
    [anon_sym_return] = ACTIONS(335),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(339),
    [anon_sym_printf] = ACTIONS(341),
    [anon_sym_SLASH] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_DOLLAR] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [sym_number] = ACTIONS(355),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [77] = {
    [sym__statement] = STATE(1050),
    [sym__statement_separated] = STATE(2),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(1194),
    [sym_getline_input] = STATE(1196),
    [sym_getline_file] = STATE(1196),
    [sym_print_statement] = STATE(1544),
    [sym_printf_statement] = STATE(1544),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1047),
    [sym__exp] = STATE(1325),
    [sym_ternary_exp] = STATE(1222),
    [sym_binary_exp] = STATE(1222),
    [sym_unary_exp] = STATE(1222),
    [sym_update_exp] = STATE(1194),
    [sym_assignment_exp] = STATE(1194),
    [sym_piped_io_exp] = STATE(1194),
    [sym_string_concat] = STATE(1222),
    [sym_field_ref] = STATE(550),
    [sym_array_ref] = STATE(534),
    [sym_regex] = STATE(1194),
    [sym_regex_constant] = STATE(1194),
    [sym_grouping] = STATE(1222),
    [sym__primitive] = STATE(1222),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(522),
    [sym_string] = STATE(1178),
    [sym_func_call] = STATE(1222),
    [sym_indirect_func_call] = STATE(1194),
    [sym_comment] = STATE(77),
    [sym_identifier] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(49),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(55),
    [anon_sym_return] = ACTIONS(57),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(61),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(65),
    [anon_sym_printf] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_BANG] = ACTIONS(313),
    [anon_sym_PLUS_PLUS] = ACTIONS(315),
    [anon_sym_DASH_DASH] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(319),
    [sym_number] = ACTIONS(303),
    [anon_sym_DQUOTE] = ACTIONS(305),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [78] = {
    [sym__statement] = STATE(1050),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1047),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(78),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(331),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(333),
    [anon_sym_return] = ACTIONS(335),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(339),
    [anon_sym_printf] = ACTIONS(341),
    [anon_sym_SLASH] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_DOLLAR] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [sym_number] = ACTIONS(355),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [79] = {
    [sym__statement] = STATE(1077),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1076),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(79),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(331),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(333),
    [anon_sym_return] = ACTIONS(335),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(339),
    [anon_sym_printf] = ACTIONS(341),
    [anon_sym_SLASH] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_DOLLAR] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [sym_number] = ACTIONS(355),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [80] = {
    [sym__statement] = STATE(1074),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1073),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(80),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(331),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(333),
    [anon_sym_return] = ACTIONS(335),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(339),
    [anon_sym_printf] = ACTIONS(341),
    [anon_sym_SLASH] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_DOLLAR] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [sym_number] = ACTIONS(355),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [81] = {
    [sym__statement] = STATE(1136),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1132),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(81),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(415),
    [anon_sym_PLUS_PLUS] = ACTIONS(417),
    [anon_sym_DASH_DASH] = ACTIONS(417),
    [anon_sym_DOLLAR] = ACTIONS(419),
    [anon_sym_AT] = ACTIONS(421),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [82] = {
    [sym__statement] = STATE(1060),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1051),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(82),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(331),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(333),
    [anon_sym_return] = ACTIONS(335),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(339),
    [anon_sym_printf] = ACTIONS(341),
    [anon_sym_SLASH] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_DOLLAR] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [sym_number] = ACTIONS(355),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [83] = {
    [sym__statement] = STATE(1102),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1103),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(83),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(415),
    [anon_sym_PLUS_PLUS] = ACTIONS(417),
    [anon_sym_DASH_DASH] = ACTIONS(417),
    [anon_sym_DOLLAR] = ACTIONS(419),
    [anon_sym_AT] = ACTIONS(421),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [84] = {
    [sym__statement] = STATE(1067),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1065),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(84),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(331),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(333),
    [anon_sym_return] = ACTIONS(335),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(339),
    [anon_sym_printf] = ACTIONS(341),
    [anon_sym_SLASH] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_DOLLAR] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [sym_number] = ACTIONS(355),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [85] = {
    [sym__statement] = STATE(1128),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1113),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(85),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(415),
    [anon_sym_PLUS_PLUS] = ACTIONS(417),
    [anon_sym_DASH_DASH] = ACTIONS(417),
    [anon_sym_DOLLAR] = ACTIONS(419),
    [anon_sym_AT] = ACTIONS(421),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [86] = {
    [sym__statement] = STATE(1109),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1117),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(86),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(415),
    [anon_sym_PLUS_PLUS] = ACTIONS(417),
    [anon_sym_DASH_DASH] = ACTIONS(417),
    [anon_sym_DOLLAR] = ACTIONS(419),
    [anon_sym_AT] = ACTIONS(421),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [87] = {
    [sym__statement] = STATE(1123),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1112),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(87),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(415),
    [anon_sym_PLUS_PLUS] = ACTIONS(417),
    [anon_sym_DASH_DASH] = ACTIONS(417),
    [anon_sym_DOLLAR] = ACTIONS(419),
    [anon_sym_AT] = ACTIONS(421),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [88] = {
    [sym__statement] = STATE(1115),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1116),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(88),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(415),
    [anon_sym_PLUS_PLUS] = ACTIONS(417),
    [anon_sym_DASH_DASH] = ACTIONS(417),
    [anon_sym_DOLLAR] = ACTIONS(419),
    [anon_sym_AT] = ACTIONS(421),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [89] = {
    [sym__statement] = STATE(1104),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1105),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(89),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(415),
    [anon_sym_PLUS_PLUS] = ACTIONS(417),
    [anon_sym_DASH_DASH] = ACTIONS(417),
    [anon_sym_DOLLAR] = ACTIONS(419),
    [anon_sym_AT] = ACTIONS(421),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [90] = {
    [sym__statement] = STATE(1062),
    [sym__statement_separated] = STATE(3),
    [sym__control_statement] = STATE(1052),
    [sym_if_statement] = STATE(1037),
    [sym_while_statement] = STATE(1037),
    [sym_do_while_statement] = STATE(1037),
    [sym_for_statement] = STATE(1037),
    [sym_for_in_statement] = STATE(1037),
    [sym_delete_statement] = STATE(1037),
    [sym_exit_statement] = STATE(1037),
    [sym_return_statement] = STATE(1037),
    [sym_switch_statement] = STATE(1037),
    [sym__io_statement] = STATE(1052),
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym_print_statement] = STATE(665),
    [sym_printf_statement] = STATE(665),
    [sym_redirected_io_statement] = STATE(1046),
    [sym_piped_io_statement] = STATE(1046),
    [sym_block] = STATE(1061),
    [sym__exp] = STATE(419),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(90),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_if] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(327),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_do] = ACTIONS(47),
    [anon_sym_for] = ACTIONS(331),
    [sym_break_statement] = ACTIONS(51),
    [sym_continue_statement] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(53),
    [anon_sym_exit] = ACTIONS(333),
    [anon_sym_return] = ACTIONS(335),
    [anon_sym_switch] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(291),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(63),
    [sym_nextfile_statement] = ACTIONS(63),
    [anon_sym_print] = ACTIONS(339),
    [anon_sym_printf] = ACTIONS(341),
    [anon_sym_SLASH] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(347),
    [anon_sym_PLUS_PLUS] = ACTIONS(349),
    [anon_sym_DASH_DASH] = ACTIONS(349),
    [anon_sym_DOLLAR] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [sym_number] = ACTIONS(355),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [91] = {
    [sym__statement] = STATE(1107),
    [sym__statement_separated] = STATE(23),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1547),
    [sym_printf_statement] = STATE(1547),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym_block] = STATE(1100),
    [sym__exp] = STATE(1411),
    [sym_ternary_exp] = STATE(1320),
    [sym_binary_exp] = STATE(1320),
    [sym_unary_exp] = STATE(1320),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1320),
    [sym_field_ref] = STATE(669),
    [sym_array_ref] = STATE(624),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1320),
    [sym__primitive] = STATE(1320),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(587),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1320),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(91),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(411),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(387),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(389),
    [anon_sym_return] = ACTIONS(391),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_LBRACE] = ACTIONS(409),
    [anon_sym_getline] = ACTIONS(393),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(395),
    [anon_sym_printf] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_BANG] = ACTIONS(415),
    [anon_sym_PLUS_PLUS] = ACTIONS(417),
    [anon_sym_DASH_DASH] = ACTIONS(417),
    [anon_sym_DOLLAR] = ACTIONS(419),
    [anon_sym_AT] = ACTIONS(421),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [92] = {
    [sym__statement] = STATE(1552),
    [sym__statement_separated] = STATE(4),
    [sym__control_statement] = STATE(1095),
    [sym_if_statement] = STATE(1108),
    [sym_while_statement] = STATE(1108),
    [sym_do_while_statement] = STATE(1108),
    [sym_for_statement] = STATE(1108),
    [sym_for_in_statement] = STATE(1108),
    [sym_delete_statement] = STATE(1108),
    [sym_exit_statement] = STATE(1108),
    [sym_return_statement] = STATE(1108),
    [sym_switch_statement] = STATE(1108),
    [sym__io_statement] = STATE(1095),
    [sym__getline_exp] = STATE(1256),
    [sym_getline_input] = STATE(1247),
    [sym_getline_file] = STATE(1247),
    [sym_print_statement] = STATE(1545),
    [sym_printf_statement] = STATE(1545),
    [sym_redirected_io_statement] = STATE(1131),
    [sym_piped_io_statement] = STATE(1131),
    [sym__exp] = STATE(1341),
    [sym_ternary_exp] = STATE(1248),
    [sym_binary_exp] = STATE(1248),
    [sym_unary_exp] = STATE(1248),
    [sym_update_exp] = STATE(1256),
    [sym_assignment_exp] = STATE(1256),
    [sym_piped_io_exp] = STATE(1256),
    [sym_string_concat] = STATE(1248),
    [sym_field_ref] = STATE(572),
    [sym_array_ref] = STATE(552),
    [sym_regex] = STATE(1256),
    [sym_regex_constant] = STATE(1256),
    [sym_grouping] = STATE(1248),
    [sym__primitive] = STATE(1248),
    [sym_namespace] = STATE(1729),
    [sym_ns_qualified_name] = STATE(532),
    [sym_string] = STATE(1232),
    [sym_func_call] = STATE(1248),
    [sym_indirect_func_call] = STATE(1256),
    [sym_comment] = STATE(92),
    [sym_identifier] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_do] = ACTIONS(95),
    [anon_sym_for] = ACTIONS(97),
    [sym_break_statement] = ACTIONS(99),
    [sym_continue_statement] = ACTIONS(99),
    [anon_sym_delete] = ACTIONS(101),
    [anon_sym_exit] = ACTIONS(103),
    [anon_sym_return] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_getline] = ACTIONS(109),
    [sym_next_statement] = ACTIONS(111),
    [sym_nextfile_statement] = ACTIONS(111),
    [anon_sym_print] = ACTIONS(113),
    [anon_sym_printf] = ACTIONS(115),
    [anon_sym_SLASH] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(119),
    [anon_sym_DASH] = ACTIONS(119),
    [anon_sym_BANG] = ACTIONS(367),
    [anon_sym_PLUS_PLUS] = ACTIONS(369),
    [anon_sym_DASH_DASH] = ACTIONS(369),
    [anon_sym_DOLLAR] = ACTIONS(371),
    [anon_sym_AT] = ACTIONS(373),
    [sym_number] = ACTIONS(375),
    [anon_sym_DQUOTE] = ACTIONS(377),
    [anon_sym_POUND] = ACTIONS(3),
  },
  [93] = {
    [sym_comment] = STATE(93),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_case] = ACTIONS(423),
    [anon_sym_default] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_LPAREN2] = ACTIONS(425),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(427),
    [anon_sym_DASH_DASH] = ACTIONS(427),
    [anon_sym_EQ] = ACTIONS(423),
    [anon_sym_PLUS_EQ] = ACTIONS(423),
    [anon_sym_DASH_EQ] = ACTIONS(423),
    [anon_sym_STAR_EQ] = ACTIONS(423),
    [anon_sym_SLASH_EQ] = ACTIONS(423),
    [anon_sym_PERCENT_EQ] = ACTIONS(423),
    [anon_sym_CARET_EQ] = ACTIONS(423),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(423),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(433),
    [sym__if_else_separator] = ACTIONS(433),
  },
  [94] = {
    [sym_comment] = STATE(94),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_case] = ACTIONS(435),
    [anon_sym_default] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_LPAREN2] = ACTIONS(425),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(437),
    [anon_sym_DASH_DASH] = ACTIONS(437),
    [anon_sym_EQ] = ACTIONS(435),
    [anon_sym_PLUS_EQ] = ACTIONS(435),
    [anon_sym_DASH_EQ] = ACTIONS(435),
    [anon_sym_STAR_EQ] = ACTIONS(435),
    [anon_sym_SLASH_EQ] = ACTIONS(435),
    [anon_sym_PERCENT_EQ] = ACTIONS(435),
    [anon_sym_CARET_EQ] = ACTIONS(435),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(435),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
    [sym__if_else_separator] = ACTIONS(439),
  },
  [95] = {
    [sym_comment] = STATE(95),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_COMMA] = ACTIONS(441),
    [anon_sym_SEMI] = ACTIONS(441),
    [anon_sym_LF] = ACTIONS(441),
    [anon_sym_CR_LF] = ACTIONS(441),
    [anon_sym_if] = ACTIONS(441),
    [anon_sym_LPAREN] = ACTIONS(441),
    [anon_sym_while] = ACTIONS(441),
    [anon_sym_do] = ACTIONS(441),
    [anon_sym_for] = ACTIONS(441),
    [anon_sym_in] = ACTIONS(441),
    [sym_break_statement] = ACTIONS(441),
    [sym_continue_statement] = ACTIONS(441),
    [anon_sym_delete] = ACTIONS(441),
    [anon_sym_exit] = ACTIONS(441),
    [anon_sym_return] = ACTIONS(441),
    [anon_sym_switch] = ACTIONS(441),
    [anon_sym_LBRACE] = ACTIONS(441),
    [anon_sym_RBRACE] = ACTIONS(441),
    [anon_sym_case] = ACTIONS(441),
    [anon_sym_default] = ACTIONS(441),
    [anon_sym_getline] = ACTIONS(441),
    [anon_sym_LT] = ACTIONS(441),
    [sym_next_statement] = ACTIONS(441),
    [sym_nextfile_statement] = ACTIONS(441),
    [anon_sym_print] = ACTIONS(441),
    [anon_sym_printf] = ACTIONS(441),
    [anon_sym_GT] = ACTIONS(441),
    [anon_sym_GT_GT] = ACTIONS(441),
    [anon_sym_PIPE] = ACTIONS(441),
    [anon_sym_PIPE_AMP] = ACTIONS(441),
    [anon_sym_QMARK] = ACTIONS(441),
    [anon_sym_CARET] = ACTIONS(441),
    [anon_sym_STAR_STAR] = ACTIONS(441),
    [anon_sym_STAR] = ACTIONS(441),
    [anon_sym_SLASH] = ACTIONS(441),
    [anon_sym_PERCENT] = ACTIONS(441),
    [anon_sym_PLUS] = ACTIONS(441),
    [anon_sym_DASH] = ACTIONS(441),
    [anon_sym_LT_EQ] = ACTIONS(441),
    [anon_sym_GT_EQ] = ACTIONS(441),
    [anon_sym_EQ_EQ] = ACTIONS(441),
    [anon_sym_BANG_EQ] = ACTIONS(441),
    [anon_sym_TILDE] = ACTIONS(441),
    [anon_sym_BANG_TILDE] = ACTIONS(441),
    [anon_sym_AMP_AMP] = ACTIONS(441),
    [anon_sym_PIPE_PIPE] = ACTIONS(441),
    [anon_sym_BANG] = ACTIONS(441),
    [anon_sym_PLUS_PLUS] = ACTIONS(441),
    [anon_sym_DASH_DASH] = ACTIONS(441),
    [anon_sym_EQ] = ACTIONS(441),
    [anon_sym_PLUS_EQ] = ACTIONS(441),
    [anon_sym_DASH_EQ] = ACTIONS(441),
    [anon_sym_STAR_EQ] = ACTIONS(441),
    [anon_sym_SLASH_EQ] = ACTIONS(441),
    [anon_sym_PERCENT_EQ] = ACTIONS(441),
    [anon_sym_CARET_EQ] = ACTIONS(441),
    [anon_sym_DOLLAR] = ACTIONS(441),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(441),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(441),
    [anon_sym_DQUOTE] = ACTIONS(441),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(443),
    [sym__if_else_separator] = ACTIONS(443),
  },
  [96] = {
    [sym_comment] = STATE(96),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_case] = ACTIONS(435),
    [anon_sym_default] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_LPAREN2] = ACTIONS(445),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(437),
    [anon_sym_DASH_DASH] = ACTIONS(437),
    [anon_sym_EQ] = ACTIONS(435),
    [anon_sym_PLUS_EQ] = ACTIONS(435),
    [anon_sym_DASH_EQ] = ACTIONS(435),
    [anon_sym_STAR_EQ] = ACTIONS(435),
    [anon_sym_SLASH_EQ] = ACTIONS(435),
    [anon_sym_PERCENT_EQ] = ACTIONS(435),
    [anon_sym_CARET_EQ] = ACTIONS(435),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_LBRACK] = ACTIONS(447),
    [anon_sym_AT] = ACTIONS(435),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
  },
  [97] = {
    [sym_comment] = STATE(97),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_case] = ACTIONS(423),
    [anon_sym_default] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_LPAREN2] = ACTIONS(445),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(449),
    [anon_sym_DASH_DASH] = ACTIONS(449),
    [anon_sym_EQ] = ACTIONS(423),
    [anon_sym_PLUS_EQ] = ACTIONS(423),
    [anon_sym_DASH_EQ] = ACTIONS(423),
    [anon_sym_STAR_EQ] = ACTIONS(423),
    [anon_sym_SLASH_EQ] = ACTIONS(423),
    [anon_sym_PERCENT_EQ] = ACTIONS(423),
    [anon_sym_CARET_EQ] = ACTIONS(423),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_LBRACK] = ACTIONS(447),
    [anon_sym_AT] = ACTIONS(423),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(433),
  },
  [98] = {
    [sym_comment] = STATE(98),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_case] = ACTIONS(423),
    [anon_sym_default] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_LPAREN2] = ACTIONS(425),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(427),
    [anon_sym_DASH_DASH] = ACTIONS(427),
    [anon_sym_EQ] = ACTIONS(423),
    [anon_sym_PLUS_EQ] = ACTIONS(423),
    [anon_sym_DASH_EQ] = ACTIONS(423),
    [anon_sym_STAR_EQ] = ACTIONS(423),
    [anon_sym_SLASH_EQ] = ACTIONS(423),
    [anon_sym_PERCENT_EQ] = ACTIONS(423),
    [anon_sym_CARET_EQ] = ACTIONS(423),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(423),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(433),
    [sym__if_else_separator] = ACTIONS(433),
  },
  [99] = {
    [sym_comment] = STATE(99),
    [sym_identifier] = ACTIONS(451),
    [anon_sym_COMMA] = ACTIONS(451),
    [anon_sym_SEMI] = ACTIONS(451),
    [anon_sym_LF] = ACTIONS(451),
    [anon_sym_CR_LF] = ACTIONS(451),
    [anon_sym_if] = ACTIONS(451),
    [anon_sym_LPAREN] = ACTIONS(451),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_do] = ACTIONS(451),
    [anon_sym_for] = ACTIONS(451),
    [anon_sym_in] = ACTIONS(451),
    [sym_break_statement] = ACTIONS(451),
    [sym_continue_statement] = ACTIONS(451),
    [anon_sym_delete] = ACTIONS(451),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_return] = ACTIONS(451),
    [anon_sym_switch] = ACTIONS(451),
    [anon_sym_LBRACE] = ACTIONS(451),
    [anon_sym_RBRACE] = ACTIONS(451),
    [anon_sym_case] = ACTIONS(451),
    [anon_sym_default] = ACTIONS(451),
    [anon_sym_getline] = ACTIONS(451),
    [anon_sym_LT] = ACTIONS(451),
    [sym_next_statement] = ACTIONS(451),
    [sym_nextfile_statement] = ACTIONS(451),
    [anon_sym_print] = ACTIONS(451),
    [anon_sym_LPAREN2] = ACTIONS(453),
    [anon_sym_printf] = ACTIONS(451),
    [anon_sym_GT] = ACTIONS(451),
    [anon_sym_GT_GT] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_PIPE_AMP] = ACTIONS(451),
    [anon_sym_QMARK] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_STAR_STAR] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_PERCENT] = ACTIONS(451),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_LT_EQ] = ACTIONS(451),
    [anon_sym_GT_EQ] = ACTIONS(451),
    [anon_sym_EQ_EQ] = ACTIONS(451),
    [anon_sym_BANG_EQ] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(451),
    [anon_sym_BANG_TILDE] = ACTIONS(451),
    [anon_sym_AMP_AMP] = ACTIONS(451),
    [anon_sym_PIPE_PIPE] = ACTIONS(451),
    [anon_sym_BANG] = ACTIONS(451),
    [anon_sym_PLUS_PLUS] = ACTIONS(451),
    [anon_sym_DASH_DASH] = ACTIONS(451),
    [anon_sym_EQ] = ACTIONS(451),
    [anon_sym_PLUS_EQ] = ACTIONS(451),
    [anon_sym_DASH_EQ] = ACTIONS(451),
    [anon_sym_STAR_EQ] = ACTIONS(451),
    [anon_sym_SLASH_EQ] = ACTIONS(451),
    [anon_sym_PERCENT_EQ] = ACTIONS(451),
    [anon_sym_CARET_EQ] = ACTIONS(451),
    [anon_sym_DOLLAR] = ACTIONS(451),
    [anon_sym_LBRACK] = ACTIONS(451),
    [anon_sym_AT] = ACTIONS(451),
    [sym_number] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(451),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(453),
    [sym__if_else_separator] = ACTIONS(453),
  },
  [100] = {
    [sym_comment] = STATE(100),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_case] = ACTIONS(435),
    [anon_sym_default] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_LPAREN2] = ACTIONS(425),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(437),
    [anon_sym_DASH_DASH] = ACTIONS(437),
    [anon_sym_EQ] = ACTIONS(435),
    [anon_sym_PLUS_EQ] = ACTIONS(435),
    [anon_sym_DASH_EQ] = ACTIONS(435),
    [anon_sym_STAR_EQ] = ACTIONS(435),
    [anon_sym_SLASH_EQ] = ACTIONS(435),
    [anon_sym_PERCENT_EQ] = ACTIONS(435),
    [anon_sym_CARET_EQ] = ACTIONS(435),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(435),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
    [sym__if_else_separator] = ACTIONS(439),
  },
  [101] = {
    [sym_comment] = STATE(101),
    [sym_identifier] = ACTIONS(451),
    [anon_sym_COMMA] = ACTIONS(451),
    [anon_sym_SEMI] = ACTIONS(451),
    [anon_sym_LF] = ACTIONS(451),
    [anon_sym_CR_LF] = ACTIONS(451),
    [anon_sym_if] = ACTIONS(451),
    [anon_sym_LPAREN] = ACTIONS(451),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_do] = ACTIONS(451),
    [anon_sym_for] = ACTIONS(451),
    [anon_sym_in] = ACTIONS(451),
    [sym_break_statement] = ACTIONS(451),
    [sym_continue_statement] = ACTIONS(451),
    [anon_sym_delete] = ACTIONS(451),
    [anon_sym_exit] = ACTIONS(451),
    [anon_sym_return] = ACTIONS(451),
    [anon_sym_switch] = ACTIONS(451),
    [anon_sym_LBRACE] = ACTIONS(451),
    [anon_sym_RBRACE] = ACTIONS(451),
    [anon_sym_case] = ACTIONS(451),
    [anon_sym_default] = ACTIONS(451),
    [anon_sym_getline] = ACTIONS(451),
    [anon_sym_LT] = ACTIONS(451),
    [sym_next_statement] = ACTIONS(451),
    [sym_nextfile_statement] = ACTIONS(451),
    [anon_sym_print] = ACTIONS(451),
    [anon_sym_LPAREN2] = ACTIONS(453),
    [anon_sym_printf] = ACTIONS(451),
    [anon_sym_GT] = ACTIONS(451),
    [anon_sym_GT_GT] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_PIPE_AMP] = ACTIONS(451),
    [anon_sym_QMARK] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_STAR_STAR] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_PERCENT] = ACTIONS(451),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_LT_EQ] = ACTIONS(451),
    [anon_sym_GT_EQ] = ACTIONS(451),
    [anon_sym_EQ_EQ] = ACTIONS(451),
    [anon_sym_BANG_EQ] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(451),
    [anon_sym_BANG_TILDE] = ACTIONS(451),
    [anon_sym_AMP_AMP] = ACTIONS(451),
    [anon_sym_PIPE_PIPE] = ACTIONS(451),
    [anon_sym_BANG] = ACTIONS(451),
    [anon_sym_PLUS_PLUS] = ACTIONS(451),
    [anon_sym_DASH_DASH] = ACTIONS(451),
    [anon_sym_EQ] = ACTIONS(451),
    [anon_sym_PLUS_EQ] = ACTIONS(451),
    [anon_sym_DASH_EQ] = ACTIONS(451),
    [anon_sym_STAR_EQ] = ACTIONS(451),
    [anon_sym_SLASH_EQ] = ACTIONS(451),
    [anon_sym_PERCENT_EQ] = ACTIONS(451),
    [anon_sym_CARET_EQ] = ACTIONS(451),
    [anon_sym_DOLLAR] = ACTIONS(451),
    [anon_sym_LBRACK] = ACTIONS(451),
    [anon_sym_AT] = ACTIONS(451),
    [sym_number] = ACTIONS(451),
    [anon_sym_DQUOTE] = ACTIONS(451),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(453),
  },
  [102] = {
    [sym_comment] = STATE(102),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_LPAREN2] = ACTIONS(455),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(457),
    [anon_sym_DASH_DASH] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(459),
    [anon_sym_PLUS_EQ] = ACTIONS(459),
    [anon_sym_DASH_EQ] = ACTIONS(459),
    [anon_sym_STAR_EQ] = ACTIONS(459),
    [anon_sym_SLASH_EQ] = ACTIONS(459),
    [anon_sym_PERCENT_EQ] = ACTIONS(459),
    [anon_sym_CARET_EQ] = ACTIONS(459),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(423),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(433),
    [sym__if_else_separator] = ACTIONS(433),
  },
  [103] = {
    [sym_comment] = STATE(103),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_case] = ACTIONS(435),
    [anon_sym_default] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(437),
    [anon_sym_DASH_DASH] = ACTIONS(437),
    [anon_sym_EQ] = ACTIONS(461),
    [anon_sym_PLUS_EQ] = ACTIONS(461),
    [anon_sym_DASH_EQ] = ACTIONS(461),
    [anon_sym_STAR_EQ] = ACTIONS(461),
    [anon_sym_SLASH_EQ] = ACTIONS(461),
    [anon_sym_PERCENT_EQ] = ACTIONS(461),
    [anon_sym_CARET_EQ] = ACTIONS(461),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(435),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
    [sym__if_else_separator] = ACTIONS(439),
  },
  [104] = {
    [sym_comment] = STATE(104),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_COMMA] = ACTIONS(441),
    [anon_sym_SEMI] = ACTIONS(441),
    [anon_sym_LF] = ACTIONS(441),
    [anon_sym_CR_LF] = ACTIONS(441),
    [anon_sym_if] = ACTIONS(441),
    [anon_sym_LPAREN] = ACTIONS(441),
    [anon_sym_while] = ACTIONS(441),
    [anon_sym_do] = ACTIONS(441),
    [anon_sym_for] = ACTIONS(441),
    [anon_sym_in] = ACTIONS(441),
    [sym_break_statement] = ACTIONS(441),
    [sym_continue_statement] = ACTIONS(441),
    [anon_sym_delete] = ACTIONS(441),
    [anon_sym_exit] = ACTIONS(441),
    [anon_sym_return] = ACTIONS(441),
    [anon_sym_switch] = ACTIONS(441),
    [anon_sym_LBRACE] = ACTIONS(441),
    [anon_sym_RBRACE] = ACTIONS(441),
    [anon_sym_case] = ACTIONS(441),
    [anon_sym_default] = ACTIONS(441),
    [anon_sym_getline] = ACTIONS(441),
    [anon_sym_LT] = ACTIONS(441),
    [sym_next_statement] = ACTIONS(441),
    [sym_nextfile_statement] = ACTIONS(441),
    [anon_sym_print] = ACTIONS(441),
    [anon_sym_printf] = ACTIONS(441),
    [anon_sym_GT] = ACTIONS(441),
    [anon_sym_GT_GT] = ACTIONS(441),
    [anon_sym_PIPE] = ACTIONS(441),
    [anon_sym_PIPE_AMP] = ACTIONS(441),
    [anon_sym_QMARK] = ACTIONS(441),
    [anon_sym_CARET] = ACTIONS(441),
    [anon_sym_STAR_STAR] = ACTIONS(441),
    [anon_sym_STAR] = ACTIONS(441),
    [anon_sym_SLASH] = ACTIONS(441),
    [anon_sym_PERCENT] = ACTIONS(441),
    [anon_sym_PLUS] = ACTIONS(441),
    [anon_sym_DASH] = ACTIONS(441),
    [anon_sym_LT_EQ] = ACTIONS(441),
    [anon_sym_GT_EQ] = ACTIONS(441),
    [anon_sym_EQ_EQ] = ACTIONS(441),
    [anon_sym_BANG_EQ] = ACTIONS(441),
    [anon_sym_TILDE] = ACTIONS(441),
    [anon_sym_BANG_TILDE] = ACTIONS(441),
    [anon_sym_AMP_AMP] = ACTIONS(441),
    [anon_sym_PIPE_PIPE] = ACTIONS(441),
    [anon_sym_BANG] = ACTIONS(441),
    [anon_sym_PLUS_PLUS] = ACTIONS(441),
    [anon_sym_DASH_DASH] = ACTIONS(441),
    [anon_sym_EQ] = ACTIONS(441),
    [anon_sym_PLUS_EQ] = ACTIONS(441),
    [anon_sym_DASH_EQ] = ACTIONS(441),
    [anon_sym_STAR_EQ] = ACTIONS(441),
    [anon_sym_SLASH_EQ] = ACTIONS(441),
    [anon_sym_PERCENT_EQ] = ACTIONS(441),
    [anon_sym_CARET_EQ] = ACTIONS(441),
    [anon_sym_DOLLAR] = ACTIONS(441),
    [anon_sym_LBRACK] = ACTIONS(447),
    [anon_sym_AT] = ACTIONS(441),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(441),
    [anon_sym_DQUOTE] = ACTIONS(441),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(443),
  },
  [105] = {
    [sym_comment] = STATE(105),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_LPAREN2] = ACTIONS(455),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(463),
    [anon_sym_DASH_DASH] = ACTIONS(463),
    [anon_sym_EQ] = ACTIONS(465),
    [anon_sym_PLUS_EQ] = ACTIONS(465),
    [anon_sym_DASH_EQ] = ACTIONS(465),
    [anon_sym_STAR_EQ] = ACTIONS(465),
    [anon_sym_SLASH_EQ] = ACTIONS(465),
    [anon_sym_PERCENT_EQ] = ACTIONS(465),
    [anon_sym_CARET_EQ] = ACTIONS(465),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(423),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(467),
    [sym__if_else_separator] = ACTIONS(433),
  },
  [106] = {
    [sym_comment] = STATE(106),
    [sym_identifier] = ACTIONS(469),
    [anon_sym_COMMA] = ACTIONS(469),
    [anon_sym_SEMI] = ACTIONS(469),
    [anon_sym_LF] = ACTIONS(469),
    [anon_sym_CR_LF] = ACTIONS(469),
    [anon_sym_if] = ACTIONS(469),
    [anon_sym_LPAREN] = ACTIONS(469),
    [anon_sym_while] = ACTIONS(469),
    [anon_sym_do] = ACTIONS(469),
    [anon_sym_for] = ACTIONS(469),
    [anon_sym_in] = ACTIONS(469),
    [sym_break_statement] = ACTIONS(469),
    [sym_continue_statement] = ACTIONS(469),
    [anon_sym_delete] = ACTIONS(469),
    [anon_sym_exit] = ACTIONS(469),
    [anon_sym_return] = ACTIONS(469),
    [anon_sym_switch] = ACTIONS(469),
    [anon_sym_LBRACE] = ACTIONS(469),
    [anon_sym_RBRACE] = ACTIONS(469),
    [anon_sym_case] = ACTIONS(469),
    [anon_sym_default] = ACTIONS(469),
    [anon_sym_getline] = ACTIONS(469),
    [anon_sym_LT] = ACTIONS(469),
    [sym_next_statement] = ACTIONS(469),
    [sym_nextfile_statement] = ACTIONS(469),
    [anon_sym_print] = ACTIONS(469),
    [anon_sym_printf] = ACTIONS(469),
    [anon_sym_GT] = ACTIONS(469),
    [anon_sym_GT_GT] = ACTIONS(469),
    [anon_sym_PIPE] = ACTIONS(469),
    [anon_sym_PIPE_AMP] = ACTIONS(469),
    [anon_sym_QMARK] = ACTIONS(469),
    [anon_sym_CARET] = ACTIONS(469),
    [anon_sym_STAR_STAR] = ACTIONS(469),
    [anon_sym_STAR] = ACTIONS(469),
    [anon_sym_SLASH] = ACTIONS(469),
    [anon_sym_PERCENT] = ACTIONS(469),
    [anon_sym_PLUS] = ACTIONS(469),
    [anon_sym_DASH] = ACTIONS(469),
    [anon_sym_LT_EQ] = ACTIONS(469),
    [anon_sym_GT_EQ] = ACTIONS(469),
    [anon_sym_EQ_EQ] = ACTIONS(469),
    [anon_sym_BANG_EQ] = ACTIONS(469),
    [anon_sym_TILDE] = ACTIONS(469),
    [anon_sym_BANG_TILDE] = ACTIONS(469),
    [anon_sym_AMP_AMP] = ACTIONS(469),
    [anon_sym_PIPE_PIPE] = ACTIONS(469),
    [anon_sym_BANG] = ACTIONS(469),
    [anon_sym_PLUS_PLUS] = ACTIONS(469),
    [anon_sym_DASH_DASH] = ACTIONS(469),
    [anon_sym_EQ] = ACTIONS(469),
    [anon_sym_PLUS_EQ] = ACTIONS(469),
    [anon_sym_DASH_EQ] = ACTIONS(469),
    [anon_sym_STAR_EQ] = ACTIONS(469),
    [anon_sym_SLASH_EQ] = ACTIONS(469),
    [anon_sym_PERCENT_EQ] = ACTIONS(469),
    [anon_sym_CARET_EQ] = ACTIONS(469),
    [anon_sym_DOLLAR] = ACTIONS(469),
    [anon_sym_AT] = ACTIONS(469),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(469),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(471),
    [sym__if_else_separator] = ACTIONS(471),
  },
  [107] = {
    [sym_comment] = STATE(107),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_case] = ACTIONS(435),
    [anon_sym_default] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(437),
    [anon_sym_DASH_DASH] = ACTIONS(437),
    [anon_sym_EQ] = ACTIONS(435),
    [anon_sym_PLUS_EQ] = ACTIONS(435),
    [anon_sym_DASH_EQ] = ACTIONS(435),
    [anon_sym_STAR_EQ] = ACTIONS(435),
    [anon_sym_SLASH_EQ] = ACTIONS(435),
    [anon_sym_PERCENT_EQ] = ACTIONS(435),
    [anon_sym_CARET_EQ] = ACTIONS(435),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(435),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
    [sym__if_else_separator] = ACTIONS(439),
  },
  [108] = {
    [sym_comment] = STATE(108),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_case] = ACTIONS(435),
    [anon_sym_default] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_LPAREN2] = ACTIONS(445),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(437),
    [anon_sym_DASH_DASH] = ACTIONS(437),
    [anon_sym_EQ] = ACTIONS(435),
    [anon_sym_PLUS_EQ] = ACTIONS(435),
    [anon_sym_DASH_EQ] = ACTIONS(435),
    [anon_sym_STAR_EQ] = ACTIONS(435),
    [anon_sym_SLASH_EQ] = ACTIONS(435),
    [anon_sym_PERCENT_EQ] = ACTIONS(435),
    [anon_sym_CARET_EQ] = ACTIONS(435),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_LBRACK] = ACTIONS(447),
    [anon_sym_AT] = ACTIONS(435),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
  },
  [109] = {
    [sym_comment] = STATE(109),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_case] = ACTIONS(423),
    [anon_sym_default] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(427),
    [anon_sym_DASH_DASH] = ACTIONS(427),
    [anon_sym_EQ] = ACTIONS(423),
    [anon_sym_PLUS_EQ] = ACTIONS(423),
    [anon_sym_DASH_EQ] = ACTIONS(423),
    [anon_sym_STAR_EQ] = ACTIONS(423),
    [anon_sym_SLASH_EQ] = ACTIONS(423),
    [anon_sym_PERCENT_EQ] = ACTIONS(423),
    [anon_sym_CARET_EQ] = ACTIONS(423),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(423),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(433),
    [sym__if_else_separator] = ACTIONS(433),
  },
  [110] = {
    [sym_comment] = STATE(110),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_LPAREN2] = ACTIONS(455),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(437),
    [anon_sym_DASH_DASH] = ACTIONS(437),
    [anon_sym_EQ] = ACTIONS(461),
    [anon_sym_PLUS_EQ] = ACTIONS(461),
    [anon_sym_DASH_EQ] = ACTIONS(461),
    [anon_sym_STAR_EQ] = ACTIONS(461),
    [anon_sym_SLASH_EQ] = ACTIONS(461),
    [anon_sym_PERCENT_EQ] = ACTIONS(461),
    [anon_sym_CARET_EQ] = ACTIONS(461),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(435),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
    [sym__if_else_separator] = ACTIONS(439),
  },
  [111] = {
    [sym_comment] = STATE(111),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_COMMA] = ACTIONS(441),
    [anon_sym_SEMI] = ACTIONS(441),
    [anon_sym_LF] = ACTIONS(441),
    [anon_sym_CR_LF] = ACTIONS(441),
    [anon_sym_if] = ACTIONS(441),
    [anon_sym_LPAREN] = ACTIONS(441),
    [anon_sym_while] = ACTIONS(441),
    [anon_sym_do] = ACTIONS(441),
    [anon_sym_for] = ACTIONS(441),
    [anon_sym_in] = ACTIONS(441),
    [sym_break_statement] = ACTIONS(441),
    [sym_continue_statement] = ACTIONS(441),
    [anon_sym_delete] = ACTIONS(441),
    [anon_sym_exit] = ACTIONS(441),
    [anon_sym_return] = ACTIONS(441),
    [anon_sym_switch] = ACTIONS(441),
    [anon_sym_LBRACE] = ACTIONS(441),
    [anon_sym_RBRACE] = ACTIONS(441),
    [anon_sym_case] = ACTIONS(441),
    [anon_sym_default] = ACTIONS(441),
    [anon_sym_getline] = ACTIONS(441),
    [anon_sym_LT] = ACTIONS(441),
    [sym_next_statement] = ACTIONS(441),
    [sym_nextfile_statement] = ACTIONS(441),
    [anon_sym_print] = ACTIONS(441),
    [anon_sym_printf] = ACTIONS(441),
    [anon_sym_GT] = ACTIONS(441),
    [anon_sym_GT_GT] = ACTIONS(441),
    [anon_sym_PIPE] = ACTIONS(441),
    [anon_sym_PIPE_AMP] = ACTIONS(441),
    [anon_sym_QMARK] = ACTIONS(441),
    [anon_sym_CARET] = ACTIONS(441),
    [anon_sym_STAR_STAR] = ACTIONS(441),
    [anon_sym_STAR] = ACTIONS(441),
    [anon_sym_SLASH] = ACTIONS(441),
    [anon_sym_PERCENT] = ACTIONS(441),
    [anon_sym_PLUS] = ACTIONS(441),
    [anon_sym_DASH] = ACTIONS(441),
    [anon_sym_LT_EQ] = ACTIONS(441),
    [anon_sym_GT_EQ] = ACTIONS(441),
    [anon_sym_EQ_EQ] = ACTIONS(441),
    [anon_sym_BANG_EQ] = ACTIONS(441),
    [anon_sym_TILDE] = ACTIONS(441),
    [anon_sym_BANG_TILDE] = ACTIONS(441),
    [anon_sym_AMP_AMP] = ACTIONS(441),
    [anon_sym_PIPE_PIPE] = ACTIONS(441),
    [anon_sym_BANG] = ACTIONS(441),
    [anon_sym_PLUS_PLUS] = ACTIONS(441),
    [anon_sym_DASH_DASH] = ACTIONS(441),
    [anon_sym_EQ] = ACTIONS(441),
    [anon_sym_PLUS_EQ] = ACTIONS(441),
    [anon_sym_DASH_EQ] = ACTIONS(441),
    [anon_sym_STAR_EQ] = ACTIONS(441),
    [anon_sym_SLASH_EQ] = ACTIONS(441),
    [anon_sym_PERCENT_EQ] = ACTIONS(441),
    [anon_sym_CARET_EQ] = ACTIONS(441),
    [anon_sym_DOLLAR] = ACTIONS(441),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(441),
    [sym_number] = ACTIONS(441),
    [anon_sym_DQUOTE] = ACTIONS(441),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(443),
    [sym__if_else_separator] = ACTIONS(443),
  },
  [112] = {
    [sym_comment] = STATE(112),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_case] = ACTIONS(423),
    [anon_sym_default] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_LPAREN2] = ACTIONS(445),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(449),
    [anon_sym_DASH_DASH] = ACTIONS(449),
    [anon_sym_EQ] = ACTIONS(423),
    [anon_sym_PLUS_EQ] = ACTIONS(423),
    [anon_sym_DASH_EQ] = ACTIONS(423),
    [anon_sym_STAR_EQ] = ACTIONS(423),
    [anon_sym_SLASH_EQ] = ACTIONS(423),
    [anon_sym_PERCENT_EQ] = ACTIONS(423),
    [anon_sym_CARET_EQ] = ACTIONS(423),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_LBRACK] = ACTIONS(447),
    [anon_sym_AT] = ACTIONS(423),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(433),
  },
  [113] = {
    [sym_comment] = STATE(113),
    [sym_identifier] = ACTIONS(473),
    [anon_sym_COMMA] = ACTIONS(473),
    [anon_sym_SEMI] = ACTIONS(473),
    [anon_sym_LF] = ACTIONS(473),
    [anon_sym_CR_LF] = ACTIONS(473),
    [anon_sym_if] = ACTIONS(473),
    [anon_sym_LPAREN] = ACTIONS(473),
    [anon_sym_while] = ACTIONS(473),
    [anon_sym_do] = ACTIONS(473),
    [anon_sym_for] = ACTIONS(473),
    [anon_sym_in] = ACTIONS(473),
    [sym_break_statement] = ACTIONS(473),
    [sym_continue_statement] = ACTIONS(473),
    [anon_sym_delete] = ACTIONS(473),
    [anon_sym_exit] = ACTIONS(473),
    [anon_sym_return] = ACTIONS(473),
    [anon_sym_switch] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(473),
    [anon_sym_RBRACE] = ACTIONS(473),
    [anon_sym_case] = ACTIONS(473),
    [anon_sym_default] = ACTIONS(473),
    [anon_sym_getline] = ACTIONS(473),
    [anon_sym_LT] = ACTIONS(473),
    [sym_next_statement] = ACTIONS(473),
    [sym_nextfile_statement] = ACTIONS(473),
    [anon_sym_print] = ACTIONS(473),
    [anon_sym_printf] = ACTIONS(473),
    [anon_sym_GT] = ACTIONS(473),
    [anon_sym_GT_GT] = ACTIONS(473),
    [anon_sym_PIPE] = ACTIONS(473),
    [anon_sym_PIPE_AMP] = ACTIONS(473),
    [anon_sym_QMARK] = ACTIONS(473),
    [anon_sym_CARET] = ACTIONS(473),
    [anon_sym_STAR_STAR] = ACTIONS(473),
    [anon_sym_STAR] = ACTIONS(473),
    [anon_sym_SLASH] = ACTIONS(473),
    [anon_sym_PERCENT] = ACTIONS(473),
    [anon_sym_PLUS] = ACTIONS(473),
    [anon_sym_DASH] = ACTIONS(473),
    [anon_sym_LT_EQ] = ACTIONS(473),
    [anon_sym_GT_EQ] = ACTIONS(473),
    [anon_sym_EQ_EQ] = ACTIONS(473),
    [anon_sym_BANG_EQ] = ACTIONS(473),
    [anon_sym_TILDE] = ACTIONS(473),
    [anon_sym_BANG_TILDE] = ACTIONS(473),
    [anon_sym_AMP_AMP] = ACTIONS(473),
    [anon_sym_PIPE_PIPE] = ACTIONS(473),
    [anon_sym_BANG] = ACTIONS(473),
    [anon_sym_PLUS_PLUS] = ACTIONS(473),
    [anon_sym_DASH_DASH] = ACTIONS(473),
    [anon_sym_EQ] = ACTIONS(473),
    [anon_sym_PLUS_EQ] = ACTIONS(473),
    [anon_sym_DASH_EQ] = ACTIONS(473),
    [anon_sym_STAR_EQ] = ACTIONS(473),
    [anon_sym_SLASH_EQ] = ACTIONS(473),
    [anon_sym_PERCENT_EQ] = ACTIONS(473),
    [anon_sym_CARET_EQ] = ACTIONS(473),
    [anon_sym_DOLLAR] = ACTIONS(473),
    [anon_sym_LBRACK] = ACTIONS(473),
    [anon_sym_AT] = ACTIONS(473),
    [sym_number] = ACTIONS(473),
    [anon_sym_DQUOTE] = ACTIONS(473),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(475),
    [sym__if_else_separator] = ACTIONS(475),
  },
  [114] = {
    [sym_comment] = STATE(114),
    [sym_identifier] = ACTIONS(477),
    [anon_sym_COMMA] = ACTIONS(477),
    [anon_sym_SEMI] = ACTIONS(477),
    [anon_sym_LF] = ACTIONS(477),
    [anon_sym_CR_LF] = ACTIONS(477),
    [anon_sym_if] = ACTIONS(477),
    [anon_sym_LPAREN] = ACTIONS(477),
    [anon_sym_while] = ACTIONS(477),
    [anon_sym_do] = ACTIONS(477),
    [anon_sym_for] = ACTIONS(477),
    [anon_sym_in] = ACTIONS(477),
    [sym_break_statement] = ACTIONS(477),
    [sym_continue_statement] = ACTIONS(477),
    [anon_sym_delete] = ACTIONS(477),
    [anon_sym_exit] = ACTIONS(477),
    [anon_sym_return] = ACTIONS(477),
    [anon_sym_switch] = ACTIONS(477),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_RBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(477),
    [anon_sym_default] = ACTIONS(477),
    [anon_sym_getline] = ACTIONS(477),
    [anon_sym_LT] = ACTIONS(477),
    [sym_next_statement] = ACTIONS(477),
    [sym_nextfile_statement] = ACTIONS(477),
    [anon_sym_print] = ACTIONS(477),
    [anon_sym_printf] = ACTIONS(477),
    [anon_sym_GT] = ACTIONS(477),
    [anon_sym_GT_GT] = ACTIONS(477),
    [anon_sym_PIPE] = ACTIONS(477),
    [anon_sym_PIPE_AMP] = ACTIONS(477),
    [anon_sym_QMARK] = ACTIONS(477),
    [anon_sym_CARET] = ACTIONS(477),
    [anon_sym_STAR_STAR] = ACTIONS(477),
    [anon_sym_STAR] = ACTIONS(477),
    [anon_sym_SLASH] = ACTIONS(477),
    [anon_sym_PERCENT] = ACTIONS(477),
    [anon_sym_PLUS] = ACTIONS(477),
    [anon_sym_DASH] = ACTIONS(477),
    [anon_sym_LT_EQ] = ACTIONS(477),
    [anon_sym_GT_EQ] = ACTIONS(477),
    [anon_sym_EQ_EQ] = ACTIONS(477),
    [anon_sym_BANG_EQ] = ACTIONS(477),
    [anon_sym_TILDE] = ACTIONS(477),
    [anon_sym_BANG_TILDE] = ACTIONS(477),
    [anon_sym_AMP_AMP] = ACTIONS(477),
    [anon_sym_PIPE_PIPE] = ACTIONS(477),
    [anon_sym_BANG] = ACTIONS(477),
    [anon_sym_PLUS_PLUS] = ACTIONS(477),
    [anon_sym_DASH_DASH] = ACTIONS(477),
    [anon_sym_EQ] = ACTIONS(477),
    [anon_sym_PLUS_EQ] = ACTIONS(477),
    [anon_sym_DASH_EQ] = ACTIONS(477),
    [anon_sym_STAR_EQ] = ACTIONS(477),
    [anon_sym_SLASH_EQ] = ACTIONS(477),
    [anon_sym_PERCENT_EQ] = ACTIONS(477),
    [anon_sym_CARET_EQ] = ACTIONS(477),
    [anon_sym_DOLLAR] = ACTIONS(477),
    [anon_sym_AT] = ACTIONS(477),
    [sym_number] = ACTIONS(477),
    [anon_sym_DQUOTE] = ACTIONS(477),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(479),
    [sym__if_else_separator] = ACTIONS(479),
  },
  [115] = {
    [sym_comment] = STATE(115),
    [sym_identifier] = ACTIONS(469),
    [anon_sym_COMMA] = ACTIONS(469),
    [anon_sym_SEMI] = ACTIONS(469),
    [anon_sym_LF] = ACTIONS(469),
    [anon_sym_CR_LF] = ACTIONS(469),
    [anon_sym_if] = ACTIONS(469),
    [anon_sym_LPAREN] = ACTIONS(469),
    [anon_sym_while] = ACTIONS(469),
    [anon_sym_do] = ACTIONS(469),
    [anon_sym_for] = ACTIONS(469),
    [anon_sym_in] = ACTIONS(469),
    [sym_break_statement] = ACTIONS(469),
    [sym_continue_statement] = ACTIONS(469),
    [anon_sym_delete] = ACTIONS(469),
    [anon_sym_exit] = ACTIONS(469),
    [anon_sym_return] = ACTIONS(469),
    [anon_sym_switch] = ACTIONS(469),
    [anon_sym_LBRACE] = ACTIONS(469),
    [anon_sym_RBRACE] = ACTIONS(469),
    [anon_sym_case] = ACTIONS(469),
    [anon_sym_default] = ACTIONS(469),
    [anon_sym_getline] = ACTIONS(469),
    [anon_sym_LT] = ACTIONS(469),
    [sym_next_statement] = ACTIONS(469),
    [sym_nextfile_statement] = ACTIONS(469),
    [anon_sym_print] = ACTIONS(469),
    [anon_sym_printf] = ACTIONS(469),
    [anon_sym_GT] = ACTIONS(469),
    [anon_sym_GT_GT] = ACTIONS(469),
    [anon_sym_PIPE] = ACTIONS(469),
    [anon_sym_PIPE_AMP] = ACTIONS(469),
    [anon_sym_QMARK] = ACTIONS(469),
    [anon_sym_CARET] = ACTIONS(469),
    [anon_sym_STAR_STAR] = ACTIONS(469),
    [anon_sym_STAR] = ACTIONS(469),
    [anon_sym_SLASH] = ACTIONS(469),
    [anon_sym_PERCENT] = ACTIONS(469),
    [anon_sym_PLUS] = ACTIONS(469),
    [anon_sym_DASH] = ACTIONS(469),
    [anon_sym_LT_EQ] = ACTIONS(469),
    [anon_sym_GT_EQ] = ACTIONS(469),
    [anon_sym_EQ_EQ] = ACTIONS(469),
    [anon_sym_BANG_EQ] = ACTIONS(469),
    [anon_sym_TILDE] = ACTIONS(469),
    [anon_sym_BANG_TILDE] = ACTIONS(469),
    [anon_sym_AMP_AMP] = ACTIONS(469),
    [anon_sym_PIPE_PIPE] = ACTIONS(469),
    [anon_sym_BANG] = ACTIONS(469),
    [anon_sym_PLUS_PLUS] = ACTIONS(469),
    [anon_sym_DASH_DASH] = ACTIONS(469),
    [anon_sym_EQ] = ACTIONS(469),
    [anon_sym_PLUS_EQ] = ACTIONS(469),
    [anon_sym_DASH_EQ] = ACTIONS(469),
    [anon_sym_STAR_EQ] = ACTIONS(469),
    [anon_sym_SLASH_EQ] = ACTIONS(469),
    [anon_sym_PERCENT_EQ] = ACTIONS(469),
    [anon_sym_CARET_EQ] = ACTIONS(469),
    [anon_sym_DOLLAR] = ACTIONS(469),
    [anon_sym_AT] = ACTIONS(469),
    [sym_number] = ACTIONS(469),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(471),
    [sym__if_else_separator] = ACTIONS(471),
  },
  [116] = {
    [sym_comment] = STATE(116),
    [sym_identifier] = ACTIONS(481),
    [anon_sym_COMMA] = ACTIONS(481),
    [anon_sym_SEMI] = ACTIONS(481),
    [anon_sym_LF] = ACTIONS(481),
    [anon_sym_CR_LF] = ACTIONS(481),
    [anon_sym_if] = ACTIONS(481),
    [anon_sym_LPAREN] = ACTIONS(481),
    [anon_sym_while] = ACTIONS(481),
    [anon_sym_do] = ACTIONS(481),
    [anon_sym_for] = ACTIONS(481),
    [anon_sym_in] = ACTIONS(481),
    [sym_break_statement] = ACTIONS(481),
    [sym_continue_statement] = ACTIONS(481),
    [anon_sym_delete] = ACTIONS(481),
    [anon_sym_exit] = ACTIONS(481),
    [anon_sym_return] = ACTIONS(481),
    [anon_sym_switch] = ACTIONS(481),
    [anon_sym_LBRACE] = ACTIONS(481),
    [anon_sym_RBRACE] = ACTIONS(481),
    [anon_sym_case] = ACTIONS(481),
    [anon_sym_default] = ACTIONS(481),
    [anon_sym_getline] = ACTIONS(481),
    [anon_sym_LT] = ACTIONS(481),
    [sym_next_statement] = ACTIONS(481),
    [sym_nextfile_statement] = ACTIONS(481),
    [anon_sym_print] = ACTIONS(481),
    [anon_sym_printf] = ACTIONS(481),
    [anon_sym_GT] = ACTIONS(481),
    [anon_sym_GT_GT] = ACTIONS(481),
    [anon_sym_PIPE] = ACTIONS(481),
    [anon_sym_PIPE_AMP] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(481),
    [anon_sym_CARET] = ACTIONS(481),
    [anon_sym_STAR_STAR] = ACTIONS(481),
    [anon_sym_STAR] = ACTIONS(481),
    [anon_sym_SLASH] = ACTIONS(481),
    [anon_sym_PERCENT] = ACTIONS(481),
    [anon_sym_PLUS] = ACTIONS(481),
    [anon_sym_DASH] = ACTIONS(481),
    [anon_sym_LT_EQ] = ACTIONS(481),
    [anon_sym_GT_EQ] = ACTIONS(481),
    [anon_sym_EQ_EQ] = ACTIONS(481),
    [anon_sym_BANG_EQ] = ACTIONS(481),
    [anon_sym_TILDE] = ACTIONS(481),
    [anon_sym_BANG_TILDE] = ACTIONS(481),
    [anon_sym_AMP_AMP] = ACTIONS(481),
    [anon_sym_PIPE_PIPE] = ACTIONS(481),
    [anon_sym_BANG] = ACTIONS(481),
    [anon_sym_PLUS_PLUS] = ACTIONS(481),
    [anon_sym_DASH_DASH] = ACTIONS(481),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_PLUS_EQ] = ACTIONS(481),
    [anon_sym_DASH_EQ] = ACTIONS(481),
    [anon_sym_STAR_EQ] = ACTIONS(481),
    [anon_sym_SLASH_EQ] = ACTIONS(481),
    [anon_sym_PERCENT_EQ] = ACTIONS(481),
    [anon_sym_CARET_EQ] = ACTIONS(481),
    [anon_sym_DOLLAR] = ACTIONS(481),
    [anon_sym_AT] = ACTIONS(481),
    [sym_number] = ACTIONS(481),
    [anon_sym_DQUOTE] = ACTIONS(481),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(483),
    [sym__if_else_separator] = ACTIONS(483),
  },
  [117] = {
    [sym_comment] = STATE(117),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_COMMA] = ACTIONS(441),
    [anon_sym_SEMI] = ACTIONS(441),
    [anon_sym_LF] = ACTIONS(441),
    [anon_sym_CR_LF] = ACTIONS(441),
    [anon_sym_if] = ACTIONS(441),
    [anon_sym_LPAREN] = ACTIONS(441),
    [anon_sym_while] = ACTIONS(441),
    [anon_sym_do] = ACTIONS(441),
    [anon_sym_for] = ACTIONS(441),
    [anon_sym_in] = ACTIONS(441),
    [sym_break_statement] = ACTIONS(441),
    [sym_continue_statement] = ACTIONS(441),
    [anon_sym_delete] = ACTIONS(441),
    [anon_sym_exit] = ACTIONS(441),
    [anon_sym_return] = ACTIONS(441),
    [anon_sym_switch] = ACTIONS(441),
    [anon_sym_LBRACE] = ACTIONS(441),
    [anon_sym_RBRACE] = ACTIONS(441),
    [anon_sym_case] = ACTIONS(441),
    [anon_sym_default] = ACTIONS(441),
    [anon_sym_getline] = ACTIONS(441),
    [anon_sym_LT] = ACTIONS(441),
    [sym_next_statement] = ACTIONS(441),
    [sym_nextfile_statement] = ACTIONS(441),
    [anon_sym_print] = ACTIONS(441),
    [anon_sym_printf] = ACTIONS(441),
    [anon_sym_GT] = ACTIONS(441),
    [anon_sym_GT_GT] = ACTIONS(441),
    [anon_sym_PIPE] = ACTIONS(441),
    [anon_sym_PIPE_AMP] = ACTIONS(441),
    [anon_sym_QMARK] = ACTIONS(441),
    [anon_sym_CARET] = ACTIONS(441),
    [anon_sym_STAR_STAR] = ACTIONS(441),
    [anon_sym_STAR] = ACTIONS(441),
    [anon_sym_SLASH] = ACTIONS(441),
    [anon_sym_PERCENT] = ACTIONS(441),
    [anon_sym_PLUS] = ACTIONS(441),
    [anon_sym_DASH] = ACTIONS(441),
    [anon_sym_LT_EQ] = ACTIONS(441),
    [anon_sym_GT_EQ] = ACTIONS(441),
    [anon_sym_EQ_EQ] = ACTIONS(441),
    [anon_sym_BANG_EQ] = ACTIONS(441),
    [anon_sym_TILDE] = ACTIONS(441),
    [anon_sym_BANG_TILDE] = ACTIONS(441),
    [anon_sym_AMP_AMP] = ACTIONS(441),
    [anon_sym_PIPE_PIPE] = ACTIONS(441),
    [anon_sym_BANG] = ACTIONS(441),
    [anon_sym_PLUS_PLUS] = ACTIONS(441),
    [anon_sym_DASH_DASH] = ACTIONS(441),
    [anon_sym_EQ] = ACTIONS(441),
    [anon_sym_PLUS_EQ] = ACTIONS(441),
    [anon_sym_DASH_EQ] = ACTIONS(441),
    [anon_sym_STAR_EQ] = ACTIONS(441),
    [anon_sym_SLASH_EQ] = ACTIONS(441),
    [anon_sym_PERCENT_EQ] = ACTIONS(441),
    [anon_sym_CARET_EQ] = ACTIONS(441),
    [anon_sym_DOLLAR] = ACTIONS(441),
    [anon_sym_AT] = ACTIONS(441),
    [sym_number] = ACTIONS(441),
    [anon_sym_DQUOTE] = ACTIONS(441),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(443),
    [sym__if_else_separator] = ACTIONS(443),
  },
  [118] = {
    [sym_comment] = STATE(118),
    [sym_identifier] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_CR_LF] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_do] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_in] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [anon_sym_delete] = ACTIONS(485),
    [anon_sym_exit] = ACTIONS(485),
    [anon_sym_return] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_RBRACE] = ACTIONS(485),
    [anon_sym_case] = ACTIONS(485),
    [anon_sym_default] = ACTIONS(485),
    [anon_sym_getline] = ACTIONS(485),
    [anon_sym_LT] = ACTIONS(485),
    [sym_next_statement] = ACTIONS(485),
    [sym_nextfile_statement] = ACTIONS(485),
    [anon_sym_print] = ACTIONS(485),
    [anon_sym_printf] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_GT_GT] = ACTIONS(485),
    [anon_sym_PIPE] = ACTIONS(485),
    [anon_sym_PIPE_AMP] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_CARET] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_STAR] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(485),
    [anon_sym_PERCENT] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(485),
    [anon_sym_DASH] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_BANG] = ACTIONS(485),
    [anon_sym_PLUS_PLUS] = ACTIONS(485),
    [anon_sym_DASH_DASH] = ACTIONS(485),
    [anon_sym_EQ] = ACTIONS(485),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_SLASH_EQ] = ACTIONS(485),
    [anon_sym_PERCENT_EQ] = ACTIONS(485),
    [anon_sym_CARET_EQ] = ACTIONS(485),
    [anon_sym_DOLLAR] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_DQUOTE] = ACTIONS(485),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(487),
    [sym__if_else_separator] = ACTIONS(487),
  },
  [119] = {
    [sym_comment] = STATE(119),
    [sym_identifier] = ACTIONS(489),
    [anon_sym_COMMA] = ACTIONS(489),
    [anon_sym_SEMI] = ACTIONS(489),
    [anon_sym_LF] = ACTIONS(489),
    [anon_sym_CR_LF] = ACTIONS(489),
    [anon_sym_if] = ACTIONS(489),
    [anon_sym_LPAREN] = ACTIONS(489),
    [anon_sym_while] = ACTIONS(489),
    [anon_sym_do] = ACTIONS(489),
    [anon_sym_for] = ACTIONS(489),
    [anon_sym_in] = ACTIONS(489),
    [sym_break_statement] = ACTIONS(489),
    [sym_continue_statement] = ACTIONS(489),
    [anon_sym_delete] = ACTIONS(489),
    [anon_sym_exit] = ACTIONS(489),
    [anon_sym_return] = ACTIONS(489),
    [anon_sym_switch] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(489),
    [anon_sym_RBRACE] = ACTIONS(489),
    [anon_sym_case] = ACTIONS(489),
    [anon_sym_default] = ACTIONS(489),
    [anon_sym_getline] = ACTIONS(489),
    [anon_sym_LT] = ACTIONS(489),
    [sym_next_statement] = ACTIONS(489),
    [sym_nextfile_statement] = ACTIONS(489),
    [anon_sym_print] = ACTIONS(489),
    [anon_sym_printf] = ACTIONS(489),
    [anon_sym_GT] = ACTIONS(489),
    [anon_sym_GT_GT] = ACTIONS(489),
    [anon_sym_PIPE] = ACTIONS(489),
    [anon_sym_PIPE_AMP] = ACTIONS(489),
    [anon_sym_QMARK] = ACTIONS(489),
    [anon_sym_CARET] = ACTIONS(489),
    [anon_sym_STAR_STAR] = ACTIONS(489),
    [anon_sym_STAR] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(489),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_PLUS] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(489),
    [anon_sym_LT_EQ] = ACTIONS(489),
    [anon_sym_GT_EQ] = ACTIONS(489),
    [anon_sym_EQ_EQ] = ACTIONS(489),
    [anon_sym_BANG_EQ] = ACTIONS(489),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_BANG_TILDE] = ACTIONS(489),
    [anon_sym_AMP_AMP] = ACTIONS(489),
    [anon_sym_PIPE_PIPE] = ACTIONS(489),
    [anon_sym_BANG] = ACTIONS(489),
    [anon_sym_PLUS_PLUS] = ACTIONS(489),
    [anon_sym_DASH_DASH] = ACTIONS(489),
    [anon_sym_EQ] = ACTIONS(489),
    [anon_sym_PLUS_EQ] = ACTIONS(489),
    [anon_sym_DASH_EQ] = ACTIONS(489),
    [anon_sym_STAR_EQ] = ACTIONS(489),
    [anon_sym_SLASH_EQ] = ACTIONS(489),
    [anon_sym_PERCENT_EQ] = ACTIONS(489),
    [anon_sym_CARET_EQ] = ACTIONS(489),
    [anon_sym_DOLLAR] = ACTIONS(489),
    [anon_sym_AT] = ACTIONS(489),
    [sym_number] = ACTIONS(489),
    [anon_sym_DQUOTE] = ACTIONS(489),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(491),
    [sym__if_else_separator] = ACTIONS(491),
  },
  [120] = {
    [sym_comment] = STATE(120),
    [sym_identifier] = ACTIONS(493),
    [anon_sym_COMMA] = ACTIONS(493),
    [anon_sym_SEMI] = ACTIONS(493),
    [anon_sym_LF] = ACTIONS(493),
    [anon_sym_CR_LF] = ACTIONS(493),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_LPAREN] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(493),
    [anon_sym_do] = ACTIONS(493),
    [anon_sym_for] = ACTIONS(493),
    [anon_sym_in] = ACTIONS(493),
    [sym_break_statement] = ACTIONS(493),
    [sym_continue_statement] = ACTIONS(493),
    [anon_sym_delete] = ACTIONS(493),
    [anon_sym_exit] = ACTIONS(493),
    [anon_sym_return] = ACTIONS(493),
    [anon_sym_switch] = ACTIONS(493),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_RBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(493),
    [anon_sym_default] = ACTIONS(493),
    [anon_sym_getline] = ACTIONS(493),
    [anon_sym_LT] = ACTIONS(493),
    [sym_next_statement] = ACTIONS(493),
    [sym_nextfile_statement] = ACTIONS(493),
    [anon_sym_print] = ACTIONS(493),
    [anon_sym_printf] = ACTIONS(493),
    [anon_sym_GT] = ACTIONS(493),
    [anon_sym_GT_GT] = ACTIONS(493),
    [anon_sym_PIPE] = ACTIONS(493),
    [anon_sym_PIPE_AMP] = ACTIONS(493),
    [anon_sym_QMARK] = ACTIONS(493),
    [anon_sym_CARET] = ACTIONS(493),
    [anon_sym_STAR_STAR] = ACTIONS(493),
    [anon_sym_STAR] = ACTIONS(493),
    [anon_sym_SLASH] = ACTIONS(493),
    [anon_sym_PERCENT] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(493),
    [anon_sym_DASH] = ACTIONS(493),
    [anon_sym_LT_EQ] = ACTIONS(493),
    [anon_sym_GT_EQ] = ACTIONS(493),
    [anon_sym_EQ_EQ] = ACTIONS(493),
    [anon_sym_BANG_EQ] = ACTIONS(493),
    [anon_sym_TILDE] = ACTIONS(493),
    [anon_sym_BANG_TILDE] = ACTIONS(493),
    [anon_sym_AMP_AMP] = ACTIONS(493),
    [anon_sym_PIPE_PIPE] = ACTIONS(493),
    [anon_sym_BANG] = ACTIONS(493),
    [anon_sym_PLUS_PLUS] = ACTIONS(493),
    [anon_sym_DASH_DASH] = ACTIONS(493),
    [anon_sym_EQ] = ACTIONS(493),
    [anon_sym_PLUS_EQ] = ACTIONS(493),
    [anon_sym_DASH_EQ] = ACTIONS(493),
    [anon_sym_STAR_EQ] = ACTIONS(493),
    [anon_sym_SLASH_EQ] = ACTIONS(493),
    [anon_sym_PERCENT_EQ] = ACTIONS(493),
    [anon_sym_CARET_EQ] = ACTIONS(493),
    [anon_sym_DOLLAR] = ACTIONS(493),
    [anon_sym_AT] = ACTIONS(493),
    [sym_number] = ACTIONS(493),
    [anon_sym_DQUOTE] = ACTIONS(493),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(495),
    [sym__if_else_separator] = ACTIONS(495),
  },
  [121] = {
    [sym_comment] = STATE(121),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_LPAREN2] = ACTIONS(455),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(457),
    [anon_sym_DASH_DASH] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(459),
    [anon_sym_PLUS_EQ] = ACTIONS(459),
    [anon_sym_DASH_EQ] = ACTIONS(459),
    [anon_sym_STAR_EQ] = ACTIONS(459),
    [anon_sym_SLASH_EQ] = ACTIONS(459),
    [anon_sym_PERCENT_EQ] = ACTIONS(459),
    [anon_sym_CARET_EQ] = ACTIONS(459),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(423),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(433),
    [sym__if_else_separator] = ACTIONS(433),
  },
  [122] = {
    [sym_namespace] = STATE(1813),
    [sym_ns_qualified_name] = STATE(115),
    [sym_comment] = STATE(122),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_COMMA] = ACTIONS(499),
    [anon_sym_SEMI] = ACTIONS(499),
    [anon_sym_LF] = ACTIONS(499),
    [anon_sym_CR_LF] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_LPAREN] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(499),
    [anon_sym_do] = ACTIONS(499),
    [anon_sym_for] = ACTIONS(499),
    [anon_sym_in] = ACTIONS(499),
    [sym_break_statement] = ACTIONS(499),
    [sym_continue_statement] = ACTIONS(499),
    [anon_sym_delete] = ACTIONS(499),
    [anon_sym_exit] = ACTIONS(499),
    [anon_sym_return] = ACTIONS(499),
    [anon_sym_switch] = ACTIONS(499),
    [anon_sym_LBRACE] = ACTIONS(499),
    [anon_sym_RBRACE] = ACTIONS(499),
    [anon_sym_getline] = ACTIONS(499),
    [anon_sym_LT] = ACTIONS(499),
    [sym_next_statement] = ACTIONS(499),
    [sym_nextfile_statement] = ACTIONS(499),
    [anon_sym_print] = ACTIONS(499),
    [anon_sym_printf] = ACTIONS(499),
    [anon_sym_GT] = ACTIONS(499),
    [anon_sym_GT_GT] = ACTIONS(499),
    [anon_sym_PIPE] = ACTIONS(499),
    [anon_sym_PIPE_AMP] = ACTIONS(499),
    [anon_sym_QMARK] = ACTIONS(499),
    [anon_sym_CARET] = ACTIONS(499),
    [anon_sym_STAR_STAR] = ACTIONS(499),
    [anon_sym_STAR] = ACTIONS(499),
    [anon_sym_SLASH] = ACTIONS(499),
    [anon_sym_PERCENT] = ACTIONS(499),
    [anon_sym_PLUS] = ACTIONS(499),
    [anon_sym_DASH] = ACTIONS(499),
    [anon_sym_LT_EQ] = ACTIONS(499),
    [anon_sym_GT_EQ] = ACTIONS(499),
    [anon_sym_EQ_EQ] = ACTIONS(499),
    [anon_sym_BANG_EQ] = ACTIONS(499),
    [anon_sym_TILDE] = ACTIONS(499),
    [anon_sym_BANG_TILDE] = ACTIONS(499),
    [anon_sym_AMP_AMP] = ACTIONS(499),
    [anon_sym_PIPE_PIPE] = ACTIONS(499),
    [anon_sym_BANG] = ACTIONS(499),
    [anon_sym_PLUS_PLUS] = ACTIONS(499),
    [anon_sym_DASH_DASH] = ACTIONS(499),
    [anon_sym_EQ] = ACTIONS(499),
    [anon_sym_PLUS_EQ] = ACTIONS(499),
    [anon_sym_DASH_EQ] = ACTIONS(499),
    [anon_sym_STAR_EQ] = ACTIONS(499),
    [anon_sym_SLASH_EQ] = ACTIONS(499),
    [anon_sym_PERCENT_EQ] = ACTIONS(499),
    [anon_sym_CARET_EQ] = ACTIONS(499),
    [anon_sym_DOLLAR] = ACTIONS(499),
    [anon_sym_AT] = ACTIONS(499),
    [sym_number] = ACTIONS(499),
    [anon_sym_DQUOTE] = ACTIONS(499),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(501),
    [sym__if_else_separator] = ACTIONS(501),
  },
  [123] = {
    [sym_comment] = STATE(123),
    [sym_identifier] = ACTIONS(503),
    [anon_sym_COMMA] = ACTIONS(503),
    [anon_sym_SEMI] = ACTIONS(503),
    [anon_sym_LF] = ACTIONS(503),
    [anon_sym_CR_LF] = ACTIONS(503),
    [anon_sym_if] = ACTIONS(503),
    [anon_sym_LPAREN] = ACTIONS(503),
    [anon_sym_while] = ACTIONS(503),
    [anon_sym_do] = ACTIONS(503),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_in] = ACTIONS(503),
    [sym_break_statement] = ACTIONS(503),
    [sym_continue_statement] = ACTIONS(503),
    [anon_sym_delete] = ACTIONS(503),
    [anon_sym_exit] = ACTIONS(503),
    [anon_sym_return] = ACTIONS(503),
    [anon_sym_switch] = ACTIONS(503),
    [anon_sym_LBRACE] = ACTIONS(503),
    [anon_sym_RBRACE] = ACTIONS(503),
    [anon_sym_case] = ACTIONS(503),
    [anon_sym_default] = ACTIONS(503),
    [anon_sym_getline] = ACTIONS(503),
    [anon_sym_LT] = ACTIONS(503),
    [sym_next_statement] = ACTIONS(503),
    [sym_nextfile_statement] = ACTIONS(503),
    [anon_sym_print] = ACTIONS(503),
    [anon_sym_printf] = ACTIONS(503),
    [anon_sym_GT] = ACTIONS(503),
    [anon_sym_GT_GT] = ACTIONS(503),
    [anon_sym_PIPE] = ACTIONS(503),
    [anon_sym_PIPE_AMP] = ACTIONS(503),
    [anon_sym_QMARK] = ACTIONS(503),
    [anon_sym_CARET] = ACTIONS(503),
    [anon_sym_STAR_STAR] = ACTIONS(503),
    [anon_sym_STAR] = ACTIONS(503),
    [anon_sym_SLASH] = ACTIONS(503),
    [anon_sym_PERCENT] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(503),
    [anon_sym_LT_EQ] = ACTIONS(503),
    [anon_sym_GT_EQ] = ACTIONS(503),
    [anon_sym_EQ_EQ] = ACTIONS(503),
    [anon_sym_BANG_EQ] = ACTIONS(503),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG_TILDE] = ACTIONS(503),
    [anon_sym_AMP_AMP] = ACTIONS(503),
    [anon_sym_PIPE_PIPE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_PLUS_PLUS] = ACTIONS(503),
    [anon_sym_DASH_DASH] = ACTIONS(503),
    [anon_sym_EQ] = ACTIONS(503),
    [anon_sym_PLUS_EQ] = ACTIONS(503),
    [anon_sym_DASH_EQ] = ACTIONS(503),
    [anon_sym_STAR_EQ] = ACTIONS(503),
    [anon_sym_SLASH_EQ] = ACTIONS(503),
    [anon_sym_PERCENT_EQ] = ACTIONS(503),
    [anon_sym_CARET_EQ] = ACTIONS(503),
    [anon_sym_DOLLAR] = ACTIONS(503),
    [anon_sym_AT] = ACTIONS(503),
    [sym_number] = ACTIONS(503),
    [anon_sym_DQUOTE] = ACTIONS(503),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(505),
    [sym__if_else_separator] = ACTIONS(505),
  },
  [124] = {
    [sym_comment] = STATE(124),
    [sym_identifier] = ACTIONS(507),
    [anon_sym_COMMA] = ACTIONS(507),
    [anon_sym_SEMI] = ACTIONS(507),
    [anon_sym_LF] = ACTIONS(507),
    [anon_sym_CR_LF] = ACTIONS(507),
    [anon_sym_if] = ACTIONS(507),
    [anon_sym_LPAREN] = ACTIONS(507),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_do] = ACTIONS(507),
    [anon_sym_for] = ACTIONS(507),
    [anon_sym_in] = ACTIONS(507),
    [sym_break_statement] = ACTIONS(507),
    [sym_continue_statement] = ACTIONS(507),
    [anon_sym_delete] = ACTIONS(507),
    [anon_sym_exit] = ACTIONS(507),
    [anon_sym_return] = ACTIONS(507),
    [anon_sym_switch] = ACTIONS(507),
    [anon_sym_LBRACE] = ACTIONS(507),
    [anon_sym_RBRACE] = ACTIONS(507),
    [anon_sym_case] = ACTIONS(507),
    [anon_sym_default] = ACTIONS(507),
    [anon_sym_getline] = ACTIONS(507),
    [anon_sym_LT] = ACTIONS(507),
    [sym_next_statement] = ACTIONS(507),
    [sym_nextfile_statement] = ACTIONS(507),
    [anon_sym_print] = ACTIONS(507),
    [anon_sym_printf] = ACTIONS(507),
    [anon_sym_GT] = ACTIONS(507),
    [anon_sym_GT_GT] = ACTIONS(507),
    [anon_sym_PIPE] = ACTIONS(507),
    [anon_sym_PIPE_AMP] = ACTIONS(507),
    [anon_sym_QMARK] = ACTIONS(507),
    [anon_sym_CARET] = ACTIONS(507),
    [anon_sym_STAR_STAR] = ACTIONS(507),
    [anon_sym_STAR] = ACTIONS(507),
    [anon_sym_SLASH] = ACTIONS(507),
    [anon_sym_PERCENT] = ACTIONS(507),
    [anon_sym_PLUS] = ACTIONS(507),
    [anon_sym_DASH] = ACTIONS(507),
    [anon_sym_LT_EQ] = ACTIONS(507),
    [anon_sym_GT_EQ] = ACTIONS(507),
    [anon_sym_EQ_EQ] = ACTIONS(507),
    [anon_sym_BANG_EQ] = ACTIONS(507),
    [anon_sym_TILDE] = ACTIONS(507),
    [anon_sym_BANG_TILDE] = ACTIONS(507),
    [anon_sym_AMP_AMP] = ACTIONS(507),
    [anon_sym_PIPE_PIPE] = ACTIONS(507),
    [anon_sym_BANG] = ACTIONS(507),
    [anon_sym_PLUS_PLUS] = ACTIONS(507),
    [anon_sym_DASH_DASH] = ACTIONS(507),
    [anon_sym_EQ] = ACTIONS(507),
    [anon_sym_PLUS_EQ] = ACTIONS(507),
    [anon_sym_DASH_EQ] = ACTIONS(507),
    [anon_sym_STAR_EQ] = ACTIONS(507),
    [anon_sym_SLASH_EQ] = ACTIONS(507),
    [anon_sym_PERCENT_EQ] = ACTIONS(507),
    [anon_sym_CARET_EQ] = ACTIONS(507),
    [anon_sym_DOLLAR] = ACTIONS(507),
    [anon_sym_AT] = ACTIONS(507),
    [sym_number] = ACTIONS(507),
    [anon_sym_DQUOTE] = ACTIONS(507),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(509),
    [sym__if_else_separator] = ACTIONS(509),
  },
  [125] = {
    [sym_comment] = STATE(125),
    [sym_identifier] = ACTIONS(511),
    [anon_sym_COMMA] = ACTIONS(511),
    [anon_sym_SEMI] = ACTIONS(511),
    [anon_sym_LF] = ACTIONS(511),
    [anon_sym_CR_LF] = ACTIONS(511),
    [anon_sym_if] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(511),
    [anon_sym_while] = ACTIONS(511),
    [anon_sym_do] = ACTIONS(511),
    [anon_sym_for] = ACTIONS(511),
    [anon_sym_in] = ACTIONS(511),
    [sym_break_statement] = ACTIONS(511),
    [sym_continue_statement] = ACTIONS(511),
    [anon_sym_delete] = ACTIONS(511),
    [anon_sym_exit] = ACTIONS(511),
    [anon_sym_return] = ACTIONS(511),
    [anon_sym_switch] = ACTIONS(511),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_RBRACE] = ACTIONS(511),
    [anon_sym_case] = ACTIONS(511),
    [anon_sym_default] = ACTIONS(511),
    [anon_sym_getline] = ACTIONS(511),
    [anon_sym_LT] = ACTIONS(511),
    [sym_next_statement] = ACTIONS(511),
    [sym_nextfile_statement] = ACTIONS(511),
    [anon_sym_print] = ACTIONS(511),
    [anon_sym_printf] = ACTIONS(511),
    [anon_sym_GT] = ACTIONS(511),
    [anon_sym_GT_GT] = ACTIONS(511),
    [anon_sym_PIPE] = ACTIONS(511),
    [anon_sym_PIPE_AMP] = ACTIONS(511),
    [anon_sym_QMARK] = ACTIONS(511),
    [anon_sym_CARET] = ACTIONS(511),
    [anon_sym_STAR_STAR] = ACTIONS(511),
    [anon_sym_STAR] = ACTIONS(511),
    [anon_sym_SLASH] = ACTIONS(511),
    [anon_sym_PERCENT] = ACTIONS(511),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_LT_EQ] = ACTIONS(511),
    [anon_sym_GT_EQ] = ACTIONS(511),
    [anon_sym_EQ_EQ] = ACTIONS(511),
    [anon_sym_BANG_EQ] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_BANG_TILDE] = ACTIONS(511),
    [anon_sym_AMP_AMP] = ACTIONS(511),
    [anon_sym_PIPE_PIPE] = ACTIONS(511),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_PLUS_PLUS] = ACTIONS(511),
    [anon_sym_DASH_DASH] = ACTIONS(511),
    [anon_sym_EQ] = ACTIONS(511),
    [anon_sym_PLUS_EQ] = ACTIONS(511),
    [anon_sym_DASH_EQ] = ACTIONS(511),
    [anon_sym_STAR_EQ] = ACTIONS(511),
    [anon_sym_SLASH_EQ] = ACTIONS(511),
    [anon_sym_PERCENT_EQ] = ACTIONS(511),
    [anon_sym_CARET_EQ] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(511),
    [anon_sym_AT] = ACTIONS(511),
    [sym_number] = ACTIONS(511),
    [anon_sym_DQUOTE] = ACTIONS(511),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(513),
    [sym__if_else_separator] = ACTIONS(513),
  },
  [126] = {
    [sym_comment] = STATE(126),
    [sym_identifier] = ACTIONS(515),
    [anon_sym_COMMA] = ACTIONS(515),
    [anon_sym_SEMI] = ACTIONS(515),
    [anon_sym_LF] = ACTIONS(515),
    [anon_sym_CR_LF] = ACTIONS(515),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_LPAREN] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(515),
    [anon_sym_do] = ACTIONS(515),
    [anon_sym_for] = ACTIONS(515),
    [anon_sym_in] = ACTIONS(515),
    [sym_break_statement] = ACTIONS(515),
    [sym_continue_statement] = ACTIONS(515),
    [anon_sym_delete] = ACTIONS(515),
    [anon_sym_exit] = ACTIONS(515),
    [anon_sym_return] = ACTIONS(515),
    [anon_sym_switch] = ACTIONS(515),
    [anon_sym_LBRACE] = ACTIONS(515),
    [anon_sym_RBRACE] = ACTIONS(515),
    [anon_sym_case] = ACTIONS(515),
    [anon_sym_default] = ACTIONS(515),
    [anon_sym_getline] = ACTIONS(515),
    [anon_sym_LT] = ACTIONS(515),
    [sym_next_statement] = ACTIONS(515),
    [sym_nextfile_statement] = ACTIONS(515),
    [anon_sym_print] = ACTIONS(515),
    [anon_sym_printf] = ACTIONS(515),
    [anon_sym_GT] = ACTIONS(515),
    [anon_sym_GT_GT] = ACTIONS(515),
    [anon_sym_PIPE] = ACTIONS(515),
    [anon_sym_PIPE_AMP] = ACTIONS(515),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_CARET] = ACTIONS(515),
    [anon_sym_STAR_STAR] = ACTIONS(515),
    [anon_sym_STAR] = ACTIONS(515),
    [anon_sym_SLASH] = ACTIONS(515),
    [anon_sym_PERCENT] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(515),
    [anon_sym_DASH] = ACTIONS(515),
    [anon_sym_LT_EQ] = ACTIONS(515),
    [anon_sym_GT_EQ] = ACTIONS(515),
    [anon_sym_EQ_EQ] = ACTIONS(515),
    [anon_sym_BANG_EQ] = ACTIONS(515),
    [anon_sym_TILDE] = ACTIONS(515),
    [anon_sym_BANG_TILDE] = ACTIONS(515),
    [anon_sym_AMP_AMP] = ACTIONS(515),
    [anon_sym_PIPE_PIPE] = ACTIONS(515),
    [anon_sym_BANG] = ACTIONS(515),
    [anon_sym_PLUS_PLUS] = ACTIONS(515),
    [anon_sym_DASH_DASH] = ACTIONS(515),
    [anon_sym_EQ] = ACTIONS(515),
    [anon_sym_PLUS_EQ] = ACTIONS(515),
    [anon_sym_DASH_EQ] = ACTIONS(515),
    [anon_sym_STAR_EQ] = ACTIONS(515),
    [anon_sym_SLASH_EQ] = ACTIONS(515),
    [anon_sym_PERCENT_EQ] = ACTIONS(515),
    [anon_sym_CARET_EQ] = ACTIONS(515),
    [anon_sym_DOLLAR] = ACTIONS(515),
    [anon_sym_AT] = ACTIONS(515),
    [sym_number] = ACTIONS(515),
    [anon_sym_DQUOTE] = ACTIONS(515),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(517),
    [sym__if_else_separator] = ACTIONS(517),
  },
  [127] = {
    [sym_comment] = STATE(127),
    [sym_identifier] = ACTIONS(519),
    [anon_sym_COMMA] = ACTIONS(519),
    [anon_sym_SEMI] = ACTIONS(519),
    [anon_sym_LF] = ACTIONS(519),
    [anon_sym_CR_LF] = ACTIONS(519),
    [anon_sym_if] = ACTIONS(519),
    [anon_sym_LPAREN] = ACTIONS(519),
    [anon_sym_while] = ACTIONS(519),
    [anon_sym_do] = ACTIONS(519),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_in] = ACTIONS(519),
    [sym_break_statement] = ACTIONS(519),
    [sym_continue_statement] = ACTIONS(519),
    [anon_sym_delete] = ACTIONS(519),
    [anon_sym_exit] = ACTIONS(519),
    [anon_sym_return] = ACTIONS(519),
    [anon_sym_switch] = ACTIONS(519),
    [anon_sym_LBRACE] = ACTIONS(519),
    [anon_sym_RBRACE] = ACTIONS(519),
    [anon_sym_case] = ACTIONS(519),
    [anon_sym_default] = ACTIONS(519),
    [anon_sym_getline] = ACTIONS(519),
    [anon_sym_LT] = ACTIONS(519),
    [sym_next_statement] = ACTIONS(519),
    [sym_nextfile_statement] = ACTIONS(519),
    [anon_sym_print] = ACTIONS(519),
    [anon_sym_printf] = ACTIONS(519),
    [anon_sym_GT] = ACTIONS(519),
    [anon_sym_GT_GT] = ACTIONS(519),
    [anon_sym_PIPE] = ACTIONS(519),
    [anon_sym_PIPE_AMP] = ACTIONS(519),
    [anon_sym_QMARK] = ACTIONS(519),
    [anon_sym_CARET] = ACTIONS(519),
    [anon_sym_STAR_STAR] = ACTIONS(519),
    [anon_sym_STAR] = ACTIONS(519),
    [anon_sym_SLASH] = ACTIONS(519),
    [anon_sym_PERCENT] = ACTIONS(519),
    [anon_sym_PLUS] = ACTIONS(519),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_LT_EQ] = ACTIONS(519),
    [anon_sym_GT_EQ] = ACTIONS(519),
    [anon_sym_EQ_EQ] = ACTIONS(519),
    [anon_sym_BANG_EQ] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(519),
    [anon_sym_BANG_TILDE] = ACTIONS(519),
    [anon_sym_AMP_AMP] = ACTIONS(519),
    [anon_sym_PIPE_PIPE] = ACTIONS(519),
    [anon_sym_BANG] = ACTIONS(519),
    [anon_sym_PLUS_PLUS] = ACTIONS(519),
    [anon_sym_DASH_DASH] = ACTIONS(519),
    [anon_sym_EQ] = ACTIONS(519),
    [anon_sym_PLUS_EQ] = ACTIONS(519),
    [anon_sym_DASH_EQ] = ACTIONS(519),
    [anon_sym_STAR_EQ] = ACTIONS(519),
    [anon_sym_SLASH_EQ] = ACTIONS(519),
    [anon_sym_PERCENT_EQ] = ACTIONS(519),
    [anon_sym_CARET_EQ] = ACTIONS(519),
    [anon_sym_DOLLAR] = ACTIONS(519),
    [anon_sym_AT] = ACTIONS(519),
    [sym_number] = ACTIONS(519),
    [anon_sym_DQUOTE] = ACTIONS(519),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(521),
    [sym__if_else_separator] = ACTIONS(521),
  },
  [128] = {
    [sym_comment] = STATE(128),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_case] = ACTIONS(435),
    [anon_sym_default] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(437),
    [anon_sym_DASH_DASH] = ACTIONS(437),
    [anon_sym_EQ] = ACTIONS(435),
    [anon_sym_PLUS_EQ] = ACTIONS(435),
    [anon_sym_DASH_EQ] = ACTIONS(435),
    [anon_sym_STAR_EQ] = ACTIONS(435),
    [anon_sym_SLASH_EQ] = ACTIONS(435),
    [anon_sym_PERCENT_EQ] = ACTIONS(435),
    [anon_sym_CARET_EQ] = ACTIONS(435),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_LBRACK] = ACTIONS(447),
    [anon_sym_AT] = ACTIONS(435),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
  },
  [129] = {
    [sym_comment] = STATE(129),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_LPAREN2] = ACTIONS(523),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(525),
    [anon_sym_DASH_DASH] = ACTIONS(525),
    [anon_sym_EQ] = ACTIONS(527),
    [anon_sym_PLUS_EQ] = ACTIONS(527),
    [anon_sym_DASH_EQ] = ACTIONS(527),
    [anon_sym_STAR_EQ] = ACTIONS(527),
    [anon_sym_SLASH_EQ] = ACTIONS(527),
    [anon_sym_PERCENT_EQ] = ACTIONS(527),
    [anon_sym_CARET_EQ] = ACTIONS(527),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_LBRACK] = ACTIONS(447),
    [anon_sym_AT] = ACTIONS(423),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(529),
  },
  [130] = {
    [sym_comment] = STATE(130),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_case] = ACTIONS(435),
    [anon_sym_default] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(435),
    [anon_sym_DASH_DASH] = ACTIONS(435),
    [anon_sym_EQ] = ACTIONS(435),
    [anon_sym_PLUS_EQ] = ACTIONS(435),
    [anon_sym_DASH_EQ] = ACTIONS(435),
    [anon_sym_STAR_EQ] = ACTIONS(435),
    [anon_sym_SLASH_EQ] = ACTIONS(435),
    [anon_sym_PERCENT_EQ] = ACTIONS(435),
    [anon_sym_CARET_EQ] = ACTIONS(435),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_AT] = ACTIONS(435),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
    [sym__if_else_separator] = ACTIONS(439),
  },
  [131] = {
    [sym_comment] = STATE(131),
    [sym_identifier] = ACTIONS(531),
    [anon_sym_COMMA] = ACTIONS(531),
    [anon_sym_SEMI] = ACTIONS(531),
    [anon_sym_LF] = ACTIONS(531),
    [anon_sym_CR_LF] = ACTIONS(531),
    [anon_sym_if] = ACTIONS(531),
    [anon_sym_LPAREN] = ACTIONS(531),
    [anon_sym_while] = ACTIONS(531),
    [anon_sym_do] = ACTIONS(531),
    [anon_sym_for] = ACTIONS(531),
    [anon_sym_in] = ACTIONS(531),
    [sym_break_statement] = ACTIONS(531),
    [sym_continue_statement] = ACTIONS(531),
    [anon_sym_delete] = ACTIONS(531),
    [anon_sym_exit] = ACTIONS(531),
    [anon_sym_return] = ACTIONS(531),
    [anon_sym_switch] = ACTIONS(531),
    [anon_sym_LBRACE] = ACTIONS(531),
    [anon_sym_RBRACE] = ACTIONS(531),
    [anon_sym_case] = ACTIONS(531),
    [anon_sym_default] = ACTIONS(531),
    [anon_sym_getline] = ACTIONS(531),
    [anon_sym_LT] = ACTIONS(531),
    [sym_next_statement] = ACTIONS(531),
    [sym_nextfile_statement] = ACTIONS(531),
    [anon_sym_print] = ACTIONS(531),
    [anon_sym_printf] = ACTIONS(531),
    [anon_sym_GT] = ACTIONS(531),
    [anon_sym_GT_GT] = ACTIONS(531),
    [anon_sym_PIPE] = ACTIONS(531),
    [anon_sym_PIPE_AMP] = ACTIONS(531),
    [anon_sym_QMARK] = ACTIONS(531),
    [anon_sym_CARET] = ACTIONS(531),
    [anon_sym_STAR_STAR] = ACTIONS(531),
    [anon_sym_STAR] = ACTIONS(531),
    [anon_sym_SLASH] = ACTIONS(531),
    [anon_sym_PERCENT] = ACTIONS(531),
    [anon_sym_PLUS] = ACTIONS(531),
    [anon_sym_DASH] = ACTIONS(531),
    [anon_sym_LT_EQ] = ACTIONS(531),
    [anon_sym_GT_EQ] = ACTIONS(531),
    [anon_sym_EQ_EQ] = ACTIONS(531),
    [anon_sym_BANG_EQ] = ACTIONS(531),
    [anon_sym_TILDE] = ACTIONS(531),
    [anon_sym_BANG_TILDE] = ACTIONS(531),
    [anon_sym_AMP_AMP] = ACTIONS(531),
    [anon_sym_PIPE_PIPE] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(531),
    [anon_sym_PLUS_PLUS] = ACTIONS(531),
    [anon_sym_DASH_DASH] = ACTIONS(531),
    [anon_sym_EQ] = ACTIONS(531),
    [anon_sym_PLUS_EQ] = ACTIONS(531),
    [anon_sym_DASH_EQ] = ACTIONS(531),
    [anon_sym_STAR_EQ] = ACTIONS(531),
    [anon_sym_SLASH_EQ] = ACTIONS(531),
    [anon_sym_PERCENT_EQ] = ACTIONS(531),
    [anon_sym_CARET_EQ] = ACTIONS(531),
    [anon_sym_DOLLAR] = ACTIONS(531),
    [anon_sym_AT] = ACTIONS(531),
    [sym_number] = ACTIONS(531),
    [anon_sym_DQUOTE] = ACTIONS(531),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(533),
    [sym__if_else_separator] = ACTIONS(533),
  },
  [132] = {
    [sym_comment] = STATE(132),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_LPAREN2] = ACTIONS(523),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(437),
    [anon_sym_DASH_DASH] = ACTIONS(437),
    [anon_sym_EQ] = ACTIONS(461),
    [anon_sym_PLUS_EQ] = ACTIONS(461),
    [anon_sym_DASH_EQ] = ACTIONS(461),
    [anon_sym_STAR_EQ] = ACTIONS(461),
    [anon_sym_SLASH_EQ] = ACTIONS(461),
    [anon_sym_PERCENT_EQ] = ACTIONS(461),
    [anon_sym_CARET_EQ] = ACTIONS(461),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_LBRACK] = ACTIONS(447),
    [anon_sym_AT] = ACTIONS(435),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
  },
  [133] = {
    [sym_comment] = STATE(133),
    [sym_identifier] = ACTIONS(535),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_SEMI] = ACTIONS(535),
    [anon_sym_LF] = ACTIONS(535),
    [anon_sym_CR_LF] = ACTIONS(535),
    [anon_sym_if] = ACTIONS(535),
    [anon_sym_LPAREN] = ACTIONS(535),
    [anon_sym_while] = ACTIONS(535),
    [anon_sym_do] = ACTIONS(535),
    [anon_sym_for] = ACTIONS(535),
    [anon_sym_in] = ACTIONS(535),
    [sym_break_statement] = ACTIONS(535),
    [sym_continue_statement] = ACTIONS(535),
    [anon_sym_delete] = ACTIONS(535),
    [anon_sym_exit] = ACTIONS(535),
    [anon_sym_return] = ACTIONS(535),
    [anon_sym_switch] = ACTIONS(535),
    [anon_sym_LBRACE] = ACTIONS(535),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_case] = ACTIONS(535),
    [anon_sym_default] = ACTIONS(535),
    [anon_sym_getline] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(535),
    [sym_next_statement] = ACTIONS(535),
    [sym_nextfile_statement] = ACTIONS(535),
    [anon_sym_print] = ACTIONS(535),
    [anon_sym_printf] = ACTIONS(535),
    [anon_sym_GT] = ACTIONS(535),
    [anon_sym_GT_GT] = ACTIONS(535),
    [anon_sym_PIPE] = ACTIONS(535),
    [anon_sym_PIPE_AMP] = ACTIONS(535),
    [anon_sym_QMARK] = ACTIONS(535),
    [anon_sym_CARET] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(535),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(535),
    [anon_sym_DASH] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_BANG] = ACTIONS(535),
    [anon_sym_PLUS_PLUS] = ACTIONS(535),
    [anon_sym_DASH_DASH] = ACTIONS(535),
    [anon_sym_EQ] = ACTIONS(535),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_SLASH_EQ] = ACTIONS(535),
    [anon_sym_PERCENT_EQ] = ACTIONS(535),
    [anon_sym_CARET_EQ] = ACTIONS(535),
    [anon_sym_DOLLAR] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(535),
    [sym_number] = ACTIONS(535),
    [anon_sym_DQUOTE] = ACTIONS(535),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(537),
    [sym__if_else_separator] = ACTIONS(537),
  },
  [134] = {
    [sym_comment] = STATE(134),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_case] = ACTIONS(435),
    [anon_sym_default] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(437),
    [anon_sym_DASH_DASH] = ACTIONS(437),
    [anon_sym_EQ] = ACTIONS(461),
    [anon_sym_PLUS_EQ] = ACTIONS(461),
    [anon_sym_DASH_EQ] = ACTIONS(461),
    [anon_sym_STAR_EQ] = ACTIONS(461),
    [anon_sym_SLASH_EQ] = ACTIONS(461),
    [anon_sym_PERCENT_EQ] = ACTIONS(461),
    [anon_sym_CARET_EQ] = ACTIONS(461),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_LBRACK] = ACTIONS(447),
    [anon_sym_AT] = ACTIONS(435),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
  },
  [135] = {
    [sym_comment] = STATE(135),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_case] = ACTIONS(435),
    [anon_sym_default] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(437),
    [anon_sym_DASH_DASH] = ACTIONS(437),
    [anon_sym_EQ] = ACTIONS(435),
    [anon_sym_PLUS_EQ] = ACTIONS(435),
    [anon_sym_DASH_EQ] = ACTIONS(435),
    [anon_sym_STAR_EQ] = ACTIONS(435),
    [anon_sym_SLASH_EQ] = ACTIONS(435),
    [anon_sym_PERCENT_EQ] = ACTIONS(435),
    [anon_sym_CARET_EQ] = ACTIONS(435),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_AT] = ACTIONS(435),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
    [sym__if_else_separator] = ACTIONS(439),
  },
  [136] = {
    [sym_comment] = STATE(136),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_case] = ACTIONS(423),
    [anon_sym_default] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(423),
    [anon_sym_DASH_DASH] = ACTIONS(423),
    [anon_sym_EQ] = ACTIONS(423),
    [anon_sym_PLUS_EQ] = ACTIONS(423),
    [anon_sym_DASH_EQ] = ACTIONS(423),
    [anon_sym_STAR_EQ] = ACTIONS(423),
    [anon_sym_SLASH_EQ] = ACTIONS(423),
    [anon_sym_PERCENT_EQ] = ACTIONS(423),
    [anon_sym_CARET_EQ] = ACTIONS(423),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_AT] = ACTIONS(423),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(433),
    [sym__if_else_separator] = ACTIONS(433),
  },
  [137] = {
    [sym_comment] = STATE(137),
    [sym_identifier] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(539),
    [anon_sym_SEMI] = ACTIONS(539),
    [anon_sym_LF] = ACTIONS(539),
    [anon_sym_CR_LF] = ACTIONS(539),
    [anon_sym_if] = ACTIONS(539),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_while] = ACTIONS(539),
    [anon_sym_do] = ACTIONS(539),
    [anon_sym_for] = ACTIONS(539),
    [anon_sym_in] = ACTIONS(539),
    [sym_break_statement] = ACTIONS(539),
    [sym_continue_statement] = ACTIONS(539),
    [anon_sym_delete] = ACTIONS(539),
    [anon_sym_exit] = ACTIONS(539),
    [anon_sym_return] = ACTIONS(539),
    [anon_sym_switch] = ACTIONS(539),
    [anon_sym_LBRACE] = ACTIONS(539),
    [anon_sym_RBRACE] = ACTIONS(539),
    [anon_sym_case] = ACTIONS(539),
    [anon_sym_default] = ACTIONS(539),
    [anon_sym_getline] = ACTIONS(539),
    [anon_sym_LT] = ACTIONS(539),
    [sym_next_statement] = ACTIONS(539),
    [sym_nextfile_statement] = ACTIONS(539),
    [anon_sym_print] = ACTIONS(539),
    [anon_sym_printf] = ACTIONS(539),
    [anon_sym_GT] = ACTIONS(539),
    [anon_sym_GT_GT] = ACTIONS(539),
    [anon_sym_PIPE] = ACTIONS(539),
    [anon_sym_PIPE_AMP] = ACTIONS(539),
    [anon_sym_QMARK] = ACTIONS(539),
    [anon_sym_CARET] = ACTIONS(539),
    [anon_sym_STAR_STAR] = ACTIONS(539),
    [anon_sym_STAR] = ACTIONS(539),
    [anon_sym_SLASH] = ACTIONS(539),
    [anon_sym_PERCENT] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(539),
    [anon_sym_DASH] = ACTIONS(539),
    [anon_sym_LT_EQ] = ACTIONS(539),
    [anon_sym_GT_EQ] = ACTIONS(539),
    [anon_sym_EQ_EQ] = ACTIONS(539),
    [anon_sym_BANG_EQ] = ACTIONS(539),
    [anon_sym_TILDE] = ACTIONS(539),
    [anon_sym_BANG_TILDE] = ACTIONS(539),
    [anon_sym_AMP_AMP] = ACTIONS(539),
    [anon_sym_PIPE_PIPE] = ACTIONS(539),
    [anon_sym_BANG] = ACTIONS(539),
    [anon_sym_PLUS_PLUS] = ACTIONS(539),
    [anon_sym_DASH_DASH] = ACTIONS(539),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_PLUS_EQ] = ACTIONS(539),
    [anon_sym_DASH_EQ] = ACTIONS(539),
    [anon_sym_STAR_EQ] = ACTIONS(539),
    [anon_sym_SLASH_EQ] = ACTIONS(539),
    [anon_sym_PERCENT_EQ] = ACTIONS(539),
    [anon_sym_CARET_EQ] = ACTIONS(539),
    [anon_sym_DOLLAR] = ACTIONS(539),
    [anon_sym_AT] = ACTIONS(539),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(539),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(541),
    [sym__if_else_separator] = ACTIONS(541),
  },
  [138] = {
    [sym__getline_exp] = STATE(353),
    [sym_getline_input] = STATE(354),
    [sym_getline_file] = STATE(354),
    [sym__print_args] = STATE(585),
    [sym__exp] = STATE(369),
    [sym_ternary_exp] = STATE(286),
    [sym_binary_exp] = STATE(286),
    [sym_unary_exp] = STATE(286),
    [sym_update_exp] = STATE(353),
    [sym_assignment_exp] = STATE(353),
    [sym_piped_io_exp] = STATE(353),
    [sym_string_concat] = STATE(286),
    [sym_field_ref] = STATE(199),
    [sym_array_ref] = STATE(168),
    [sym_exp_list] = STATE(562),
    [sym_regex] = STATE(353),
    [sym_regex_constant] = STATE(353),
    [sym_grouping] = STATE(286),
    [sym__primitive] = STATE(286),
    [sym_namespace] = STATE(1810),
    [sym_ns_qualified_name] = STATE(145),
    [sym_string] = STATE(294),
    [sym_func_call] = STATE(286),
    [sym_indirect_func_call] = STATE(353),
    [sym_comment] = STATE(138),
    [aux_sym_exp_list_repeat1] = STATE(710),
    [sym_identifier] = ACTIONS(321),
    [anon_sym_SEMI] = ACTIONS(543),
    [anon_sym_LF] = ACTIONS(543),
    [anon_sym_CR_LF] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(543),
    [anon_sym_LPAREN] = ACTIONS(545),
    [anon_sym_while] = ACTIONS(543),
    [anon_sym_do] = ACTIONS(543),
    [anon_sym_for] = ACTIONS(543),
    [sym_break_statement] = ACTIONS(543),
    [sym_continue_statement] = ACTIONS(543),
    [anon_sym_delete] = ACTIONS(543),
    [anon_sym_exit] = ACTIONS(543),
    [anon_sym_return] = ACTIONS(543),
    [anon_sym_switch] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(543),
    [anon_sym_RBRACE] = ACTIONS(543),
    [anon_sym_getline] = ACTIONS(337),
    [sym_next_statement] = ACTIONS(543),
    [sym_nextfile_statement] = ACTIONS(543),
    [anon_sym_print] = ACTIONS(543),
    [anon_sym_LPAREN2] = ACTIONS(547),
    [anon_sym_printf] = ACTIONS(543),
    [anon_sym_GT] = ACTIONS(543),
    [anon_sym_GT_GT] = ACTIONS(543),
    [anon_sym_PIPE] = ACTIONS(543),
    [anon_sym_PIPE_AMP] = ACTIONS(543),
    [anon_sym_SLASH] = ACTIONS(549),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_BANG] = ACTIONS(345),
    [anon_sym_PLUS_PLUS] = ACTIONS(551),
    [anon_sym_DASH_DASH] = ACTIONS(551),
    [anon_sym_DOLLAR] = ACTIONS(553),
    [anon_sym_AT] = ACTIONS(555),
    [sym_number] = ACTIONS(557),
    [anon_sym_DQUOTE] = ACTIONS(559),
    [anon_sym_POUND] = ACTIONS(83),
    [sym__if_else_separator] = ACTIONS(561),
  },
  [139] = {
    [sym_comment] = STATE(139),
    [sym_identifier] = ACTIONS(473),
    [anon_sym_COMMA] = ACTIONS(473),
    [anon_sym_SEMI] = ACTIONS(473),
    [anon_sym_LF] = ACTIONS(473),
    [anon_sym_CR_LF] = ACTIONS(473),
    [anon_sym_if] = ACTIONS(473),
    [anon_sym_LPAREN] = ACTIONS(473),
    [anon_sym_while] = ACTIONS(473),
    [anon_sym_do] = ACTIONS(473),
    [anon_sym_for] = ACTIONS(473),
    [anon_sym_in] = ACTIONS(473),
    [sym_break_statement] = ACTIONS(473),
    [sym_continue_statement] = ACTIONS(473),
    [anon_sym_delete] = ACTIONS(473),
    [anon_sym_exit] = ACTIONS(473),
    [anon_sym_return] = ACTIONS(473),
    [anon_sym_switch] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(473),
    [anon_sym_RBRACE] = ACTIONS(473),
    [anon_sym_case] = ACTIONS(473),
    [anon_sym_default] = ACTIONS(473),
    [anon_sym_getline] = ACTIONS(473),
    [anon_sym_LT] = ACTIONS(473),
    [sym_next_statement] = ACTIONS(473),
    [sym_nextfile_statement] = ACTIONS(473),
    [anon_sym_print] = ACTIONS(473),
    [anon_sym_printf] = ACTIONS(473),
    [anon_sym_GT] = ACTIONS(473),
    [anon_sym_GT_GT] = ACTIONS(473),
    [anon_sym_PIPE] = ACTIONS(473),
    [anon_sym_PIPE_AMP] = ACTIONS(473),
    [anon_sym_QMARK] = ACTIONS(473),
    [anon_sym_CARET] = ACTIONS(473),
    [anon_sym_STAR_STAR] = ACTIONS(473),
    [anon_sym_STAR] = ACTIONS(473),
    [anon_sym_SLASH] = ACTIONS(473),
    [anon_sym_PERCENT] = ACTIONS(473),
    [anon_sym_PLUS] = ACTIONS(473),
    [anon_sym_DASH] = ACTIONS(473),
    [anon_sym_LT_EQ] = ACTIONS(473),
    [anon_sym_GT_EQ] = ACTIONS(473),
    [anon_sym_EQ_EQ] = ACTIONS(473),
    [anon_sym_BANG_EQ] = ACTIONS(473),
    [anon_sym_TILDE] = ACTIONS(473),
    [anon_sym_BANG_TILDE] = ACTIONS(473),
    [anon_sym_AMP_AMP] = ACTIONS(473),
    [anon_sym_PIPE_PIPE] = ACTIONS(473),
    [anon_sym_BANG] = ACTIONS(473),
    [anon_sym_PLUS_PLUS] = ACTIONS(473),
    [anon_sym_DASH_DASH] = ACTIONS(473),
    [anon_sym_EQ] = ACTIONS(473),
    [anon_sym_PLUS_EQ] = ACTIONS(473),
    [anon_sym_DASH_EQ] = ACTIONS(473),
    [anon_sym_STAR_EQ] = ACTIONS(473),
    [anon_sym_SLASH_EQ] = ACTIONS(473),
    [anon_sym_PERCENT_EQ] = ACTIONS(473),
    [anon_sym_CARET_EQ] = ACTIONS(473),
    [anon_sym_DOLLAR] = ACTIONS(473),
    [anon_sym_LBRACK] = ACTIONS(473),
    [anon_sym_AT] = ACTIONS(473),
    [sym_number] = ACTIONS(473),
    [anon_sym_DQUOTE] = ACTIONS(473),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(475),
  },
  [140] = {
    [sym_comment] = STATE(140),
    [sym_identifier] = ACTIONS(469),
    [anon_sym_COMMA] = ACTIONS(469),
    [anon_sym_SEMI] = ACTIONS(469),
    [anon_sym_LF] = ACTIONS(469),
    [anon_sym_CR_LF] = ACTIONS(469),
    [anon_sym_if] = ACTIONS(469),
    [anon_sym_LPAREN] = ACTIONS(469),
    [anon_sym_while] = ACTIONS(469),
    [anon_sym_do] = ACTIONS(469),
    [anon_sym_for] = ACTIONS(469),
    [anon_sym_in] = ACTIONS(469),
    [sym_break_statement] = ACTIONS(469),
    [sym_continue_statement] = ACTIONS(469),
    [anon_sym_delete] = ACTIONS(469),
    [anon_sym_exit] = ACTIONS(469),
    [anon_sym_return] = ACTIONS(469),
    [anon_sym_switch] = ACTIONS(469),
    [anon_sym_LBRACE] = ACTIONS(469),
    [anon_sym_RBRACE] = ACTIONS(469),
    [anon_sym_case] = ACTIONS(469),
    [anon_sym_default] = ACTIONS(469),
    [anon_sym_getline] = ACTIONS(469),
    [anon_sym_LT] = ACTIONS(469),
    [sym_next_statement] = ACTIONS(469),
    [sym_nextfile_statement] = ACTIONS(469),
    [anon_sym_print] = ACTIONS(469),
    [anon_sym_printf] = ACTIONS(469),
    [anon_sym_GT] = ACTIONS(469),
    [anon_sym_GT_GT] = ACTIONS(469),
    [anon_sym_PIPE] = ACTIONS(469),
    [anon_sym_PIPE_AMP] = ACTIONS(469),
    [anon_sym_QMARK] = ACTIONS(469),
    [anon_sym_CARET] = ACTIONS(469),
    [anon_sym_STAR_STAR] = ACTIONS(469),
    [anon_sym_STAR] = ACTIONS(469),
    [anon_sym_SLASH] = ACTIONS(469),
    [anon_sym_PERCENT] = ACTIONS(469),
    [anon_sym_PLUS] = ACTIONS(469),
    [anon_sym_DASH] = ACTIONS(469),
    [anon_sym_LT_EQ] = ACTIONS(469),
    [anon_sym_GT_EQ] = ACTIONS(469),
    [anon_sym_EQ_EQ] = ACTIONS(469),
    [anon_sym_BANG_EQ] = ACTIONS(469),
    [anon_sym_TILDE] = ACTIONS(469),
    [anon_sym_BANG_TILDE] = ACTIONS(469),
    [anon_sym_AMP_AMP] = ACTIONS(469),
    [anon_sym_PIPE_PIPE] = ACTIONS(469),
    [anon_sym_BANG] = ACTIONS(469),
    [anon_sym_PLUS_PLUS] = ACTIONS(469),
    [anon_sym_DASH_DASH] = ACTIONS(469),
    [anon_sym_EQ] = ACTIONS(469),
    [anon_sym_PLUS_EQ] = ACTIONS(469),
    [anon_sym_DASH_EQ] = ACTIONS(469),
    [anon_sym_STAR_EQ] = ACTIONS(469),
    [anon_sym_SLASH_EQ] = ACTIONS(469),
    [anon_sym_PERCENT_EQ] = ACTIONS(469),
    [anon_sym_CARET_EQ] = ACTIONS(469),
    [anon_sym_DOLLAR] = ACTIONS(469),
    [anon_sym_AT] = ACTIONS(469),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(469),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(471),
  },
  [141] = {
    [sym_comment] = STATE(141),
    [sym_identifier] = ACTIONS(563),
    [anon_sym_COMMA] = ACTIONS(563),
    [anon_sym_SEMI] = ACTIONS(563),
    [anon_sym_LF] = ACTIONS(563),
    [anon_sym_CR_LF] = ACTIONS(563),
    [anon_sym_if] = ACTIONS(563),
    [anon_sym_LPAREN] = ACTIONS(563),
    [anon_sym_while] = ACTIONS(563),
    [anon_sym_do] = ACTIONS(563),
    [anon_sym_for] = ACTIONS(563),
    [anon_sym_in] = ACTIONS(563),
    [sym_break_statement] = ACTIONS(563),
    [sym_continue_statement] = ACTIONS(563),
    [anon_sym_delete] = ACTIONS(563),
    [anon_sym_exit] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(563),
    [anon_sym_switch] = ACTIONS(563),
    [anon_sym_LBRACE] = ACTIONS(563),
    [anon_sym_RBRACE] = ACTIONS(563),
    [anon_sym_case] = ACTIONS(563),
    [anon_sym_default] = ACTIONS(563),
    [anon_sym_getline] = ACTIONS(563),
    [anon_sym_LT] = ACTIONS(563),
    [sym_next_statement] = ACTIONS(563),
    [sym_nextfile_statement] = ACTIONS(563),
    [anon_sym_print] = ACTIONS(563),
    [anon_sym_printf] = ACTIONS(563),
    [anon_sym_GT] = ACTIONS(563),
    [anon_sym_GT_GT] = ACTIONS(563),
    [anon_sym_PIPE] = ACTIONS(563),
    [anon_sym_PIPE_AMP] = ACTIONS(563),
    [anon_sym_QMARK] = ACTIONS(563),
    [anon_sym_CARET] = ACTIONS(563),
    [anon_sym_STAR_STAR] = ACTIONS(563),
    [anon_sym_STAR] = ACTIONS(563),
    [anon_sym_SLASH] = ACTIONS(563),
    [anon_sym_PERCENT] = ACTIONS(563),
    [anon_sym_PLUS] = ACTIONS(563),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_LT_EQ] = ACTIONS(563),
    [anon_sym_GT_EQ] = ACTIONS(563),
    [anon_sym_EQ_EQ] = ACTIONS(563),
    [anon_sym_BANG_EQ] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(563),
    [anon_sym_BANG_TILDE] = ACTIONS(563),
    [anon_sym_AMP_AMP] = ACTIONS(563),
    [anon_sym_PIPE_PIPE] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(563),
    [anon_sym_PLUS_PLUS] = ACTIONS(563),
    [anon_sym_DASH_DASH] = ACTIONS(563),
    [anon_sym_EQ] = ACTIONS(563),
    [anon_sym_PLUS_EQ] = ACTIONS(563),
    [anon_sym_DASH_EQ] = ACTIONS(563),
    [anon_sym_STAR_EQ] = ACTIONS(563),
    [anon_sym_SLASH_EQ] = ACTIONS(563),
    [anon_sym_PERCENT_EQ] = ACTIONS(563),
    [anon_sym_CARET_EQ] = ACTIONS(563),
    [anon_sym_DOLLAR] = ACTIONS(563),
    [anon_sym_AT] = ACTIONS(563),
    [sym_number] = ACTIONS(563),
    [anon_sym_DQUOTE] = ACTIONS(563),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(565),
    [sym__if_else_separator] = ACTIONS(565),
  },
  [142] = {
    [sym_comment] = STATE(142),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_case] = ACTIONS(423),
    [anon_sym_default] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(423),
    [anon_sym_DASH_DASH] = ACTIONS(423),
    [anon_sym_EQ] = ACTIONS(423),
    [anon_sym_PLUS_EQ] = ACTIONS(423),
    [anon_sym_DASH_EQ] = ACTIONS(423),
    [anon_sym_STAR_EQ] = ACTIONS(423),
    [anon_sym_SLASH_EQ] = ACTIONS(423),
    [anon_sym_PERCENT_EQ] = ACTIONS(423),
    [anon_sym_CARET_EQ] = ACTIONS(423),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_AT] = ACTIONS(423),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(433),
    [sym__if_else_separator] = ACTIONS(433),
  },
  [143] = {
    [sym_namespace] = STATE(1813),
    [sym_ns_qualified_name] = STATE(198),
    [sym_comment] = STATE(143),
    [sym_identifier] = ACTIONS(567),
    [anon_sym_COMMA] = ACTIONS(499),
    [anon_sym_SEMI] = ACTIONS(499),
    [anon_sym_LF] = ACTIONS(499),
    [anon_sym_CR_LF] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_LPAREN] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(499),
    [anon_sym_do] = ACTIONS(499),
    [anon_sym_for] = ACTIONS(499),
    [anon_sym_in] = ACTIONS(499),
    [sym_break_statement] = ACTIONS(499),
    [sym_continue_statement] = ACTIONS(499),
    [anon_sym_delete] = ACTIONS(499),
    [anon_sym_exit] = ACTIONS(499),
    [anon_sym_return] = ACTIONS(499),
    [anon_sym_switch] = ACTIONS(499),
    [anon_sym_LBRACE] = ACTIONS(499),
    [anon_sym_RBRACE] = ACTIONS(499),
    [anon_sym_getline] = ACTIONS(499),
    [anon_sym_LT] = ACTIONS(569),
    [sym_next_statement] = ACTIONS(499),
    [sym_nextfile_statement] = ACTIONS(499),
    [anon_sym_print] = ACTIONS(499),
    [anon_sym_printf] = ACTIONS(499),
    [anon_sym_GT] = ACTIONS(499),
    [anon_sym_GT_GT] = ACTIONS(499),
    [anon_sym_PIPE] = ACTIONS(499),
    [anon_sym_PIPE_AMP] = ACTIONS(499),
    [anon_sym_QMARK] = ACTIONS(499),
    [anon_sym_CARET] = ACTIONS(499),
    [anon_sym_STAR_STAR] = ACTIONS(499),
    [anon_sym_STAR] = ACTIONS(499),
    [anon_sym_SLASH] = ACTIONS(499),
    [anon_sym_PERCENT] = ACTIONS(499),
    [anon_sym_PLUS] = ACTIONS(499),
    [anon_sym_DASH] = ACTIONS(499),
    [anon_sym_LT_EQ] = ACTIONS(499),
    [anon_sym_GT_EQ] = ACTIONS(499),
    [anon_sym_EQ_EQ] = ACTIONS(499),
    [anon_sym_BANG_EQ] = ACTIONS(499),
    [anon_sym_TILDE] = ACTIONS(499),
    [anon_sym_BANG_TILDE] = ACTIONS(499),
    [anon_sym_AMP_AMP] = ACTIONS(499),
    [anon_sym_PIPE_PIPE] = ACTIONS(499),
    [anon_sym_BANG] = ACTIONS(499),
    [anon_sym_PLUS_PLUS] = ACTIONS(499),
    [anon_sym_DASH_DASH] = ACTIONS(499),
    [anon_sym_EQ] = ACTIONS(499),
    [anon_sym_PLUS_EQ] = ACTIONS(499),
    [anon_sym_DASH_EQ] = ACTIONS(499),
    [anon_sym_STAR_EQ] = ACTIONS(499),
    [anon_sym_SLASH_EQ] = ACTIONS(499),
    [anon_sym_PERCENT_EQ] = ACTIONS(499),
    [anon_sym_CARET_EQ] = ACTIONS(499),
    [anon_sym_DOLLAR] = ACTIONS(499),
    [anon_sym_AT] = ACTIONS(499),
    [sym_number] = ACTIONS(499),
    [anon_sym_DQUOTE] = ACTIONS(499),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(501),
    [sym__if_else_separator] = ACTIONS(501),
  },
  [144] = {
    [sym_comment] = STATE(144),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_LPAREN2] = ACTIONS(523),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(571),
    [anon_sym_DASH_DASH] = ACTIONS(571),
    [anon_sym_EQ] = ACTIONS(573),
    [anon_sym_PLUS_EQ] = ACTIONS(573),
    [anon_sym_DASH_EQ] = ACTIONS(573),
    [anon_sym_STAR_EQ] = ACTIONS(573),
    [anon_sym_SLASH_EQ] = ACTIONS(573),
    [anon_sym_PERCENT_EQ] = ACTIONS(573),
    [anon_sym_CARET_EQ] = ACTIONS(573),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_LBRACK] = ACTIONS(447),
    [anon_sym_AT] = ACTIONS(423),
    [anon_sym_COLON_COLON] = ACTIONS(431),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(433),
  },
  [145] = {
    [sym_comment] = STATE(145),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_LPAREN2] = ACTIONS(455),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(463),
    [anon_sym_DASH_DASH] = ACTIONS(463),
    [anon_sym_EQ] = ACTIONS(465),
    [anon_sym_PLUS_EQ] = ACTIONS(465),
    [anon_sym_DASH_EQ] = ACTIONS(465),
    [anon_sym_STAR_EQ] = ACTIONS(465),
    [anon_sym_SLASH_EQ] = ACTIONS(465),
    [anon_sym_PERCENT_EQ] = ACTIONS(465),
    [anon_sym_CARET_EQ] = ACTIONS(465),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(423),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(467),
    [sym__if_else_separator] = ACTIONS(433),
  },
  [146] = {
    [sym_comment] = STATE(146),
    [sym_identifier] = ACTIONS(575),
    [anon_sym_COMMA] = ACTIONS(575),
    [anon_sym_SEMI] = ACTIONS(575),
    [anon_sym_LF] = ACTIONS(575),
    [anon_sym_CR_LF] = ACTIONS(575),
    [anon_sym_if] = ACTIONS(575),
    [anon_sym_LPAREN] = ACTIONS(575),
    [anon_sym_while] = ACTIONS(575),
    [anon_sym_do] = ACTIONS(575),
    [anon_sym_for] = ACTIONS(575),
    [anon_sym_in] = ACTIONS(575),
    [sym_break_statement] = ACTIONS(575),
    [sym_continue_statement] = ACTIONS(575),
    [anon_sym_delete] = ACTIONS(575),
    [anon_sym_exit] = ACTIONS(575),
    [anon_sym_return] = ACTIONS(575),
    [anon_sym_switch] = ACTIONS(575),
    [anon_sym_LBRACE] = ACTIONS(575),
    [anon_sym_RBRACE] = ACTIONS(575),
    [anon_sym_case] = ACTIONS(575),
    [anon_sym_default] = ACTIONS(575),
    [anon_sym_getline] = ACTIONS(575),
    [anon_sym_LT] = ACTIONS(575),
    [sym_next_statement] = ACTIONS(575),
    [sym_nextfile_statement] = ACTIONS(575),
    [anon_sym_print] = ACTIONS(575),
    [anon_sym_printf] = ACTIONS(575),
    [anon_sym_GT] = ACTIONS(575),
    [anon_sym_GT_GT] = ACTIONS(575),
    [anon_sym_PIPE] = ACTIONS(575),
    [anon_sym_PIPE_AMP] = ACTIONS(575),
    [anon_sym_QMARK] = ACTIONS(575),
    [anon_sym_CARET] = ACTIONS(575),
    [anon_sym_STAR_STAR] = ACTIONS(575),
    [anon_sym_STAR] = ACTIONS(575),
    [anon_sym_SLASH] = ACTIONS(575),
    [anon_sym_PERCENT] = ACTIONS(575),
    [anon_sym_PLUS] = ACTIONS(575),
    [anon_sym_DASH] = ACTIONS(575),
    [anon_sym_LT_EQ] = ACTIONS(575),
    [anon_sym_GT_EQ] = ACTIONS(575),
    [anon_sym_EQ_EQ] = ACTIONS(575),
    [anon_sym_BANG_EQ] = ACTIONS(575),
    [anon_sym_TILDE] = ACTIONS(575),
    [anon_sym_BANG_TILDE] = ACTIONS(575),
    [anon_sym_AMP_AMP] = ACTIONS(575),
    [anon_sym_PIPE_PIPE] = ACTIONS(575),
    [anon_sym_BANG] = ACTIONS(575),
    [anon_sym_PLUS_PLUS] = ACTIONS(575),
    [anon_sym_DASH_DASH] = ACTIONS(575),
    [anon_sym_EQ] = ACTIONS(575),
    [anon_sym_PLUS_EQ] = ACTIONS(575),
    [anon_sym_DASH_EQ] = ACTIONS(575),
    [anon_sym_STAR_EQ] = ACTIONS(575),
    [anon_sym_SLASH_EQ] = ACTIONS(575),
    [anon_sym_PERCENT_EQ] = ACTIONS(575),
    [anon_sym_CARET_EQ] = ACTIONS(575),
    [anon_sym_DOLLAR] = ACTIONS(575),
    [anon_sym_AT] = ACTIONS(575),
    [sym_number] = ACTIONS(575),
    [anon_sym_DQUOTE] = ACTIONS(575),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(577),
    [sym__if_else_separator] = ACTIONS(577),
  },
  [147] = {
    [sym_comment] = STATE(147),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_COMMA] = ACTIONS(441),
    [anon_sym_SEMI] = ACTIONS(441),
    [anon_sym_LF] = ACTIONS(441),
    [anon_sym_CR_LF] = ACTIONS(441),
    [anon_sym_if] = ACTIONS(441),
    [anon_sym_LPAREN] = ACTIONS(441),
    [anon_sym_while] = ACTIONS(441),
    [anon_sym_do] = ACTIONS(441),
    [anon_sym_for] = ACTIONS(441),
    [anon_sym_in] = ACTIONS(441),
    [sym_break_statement] = ACTIONS(441),
    [sym_continue_statement] = ACTIONS(441),
    [anon_sym_delete] = ACTIONS(441),
    [anon_sym_exit] = ACTIONS(441),
    [anon_sym_return] = ACTIONS(441),
    [anon_sym_switch] = ACTIONS(441),
    [anon_sym_LBRACE] = ACTIONS(441),
    [anon_sym_RBRACE] = ACTIONS(441),
    [anon_sym_case] = ACTIONS(441),
    [anon_sym_default] = ACTIONS(441),
    [anon_sym_getline] = ACTIONS(441),
    [anon_sym_LT] = ACTIONS(441),
    [sym_next_statement] = ACTIONS(441),
    [sym_nextfile_statement] = ACTIONS(441),
    [anon_sym_print] = ACTIONS(441),
    [anon_sym_printf] = ACTIONS(441),
    [anon_sym_GT] = ACTIONS(441),
    [anon_sym_GT_GT] = ACTIONS(441),
    [anon_sym_PIPE] = ACTIONS(441),
    [anon_sym_PIPE_AMP] = ACTIONS(441),
    [anon_sym_QMARK] = ACTIONS(441),
    [anon_sym_CARET] = ACTIONS(441),
    [anon_sym_STAR_STAR] = ACTIONS(441),
    [anon_sym_STAR] = ACTIONS(441),
    [anon_sym_SLASH] = ACTIONS(441),
    [anon_sym_PERCENT] = ACTIONS(441),
    [anon_sym_PLUS] = ACTIONS(441),
    [anon_sym_DASH] = ACTIONS(441),
    [anon_sym_LT_EQ] = ACTIONS(441),
    [anon_sym_GT_EQ] = ACTIONS(441),
    [anon_sym_EQ_EQ] = ACTIONS(441),
    [anon_sym_BANG_EQ] = ACTIONS(441),
    [anon_sym_TILDE] = ACTIONS(441),
    [anon_sym_BANG_TILDE] = ACTIONS(441),
    [anon_sym_AMP_AMP] = ACTIONS(441),
    [anon_sym_PIPE_PIPE] = ACTIONS(441),
    [anon_sym_BANG] = ACTIONS(441),
    [anon_sym_PLUS_PLUS] = ACTIONS(441),
    [anon_sym_DASH_DASH] = ACTIONS(441),
    [anon_sym_EQ] = ACTIONS(441),
    [anon_sym_PLUS_EQ] = ACTIONS(441),
    [anon_sym_DASH_EQ] = ACTIONS(441),
    [anon_sym_STAR_EQ] = ACTIONS(441),
    [anon_sym_SLASH_EQ] = ACTIONS(441),
    [anon_sym_PERCENT_EQ] = ACTIONS(441),
    [anon_sym_CARET_EQ] = ACTIONS(441),
    [anon_sym_DOLLAR] = ACTIONS(441),
    [anon_sym_LBRACK] = ACTIONS(447),
    [anon_sym_AT] = ACTIONS(441),
    [sym_number] = ACTIONS(441),
    [anon_sym_DQUOTE] = ACTIONS(441),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(443),
  },
  [148] = {
    [sym_comment] = STATE(148),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_case] = ACTIONS(423),
    [anon_sym_default] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(449),
    [anon_sym_DASH_DASH] = ACTIONS(449),
    [anon_sym_EQ] = ACTIONS(423),
    [anon_sym_PLUS_EQ] = ACTIONS(423),
    [anon_sym_DASH_EQ] = ACTIONS(423),
    [anon_sym_STAR_EQ] = ACTIONS(423),
    [anon_sym_SLASH_EQ] = ACTIONS(423),
    [anon_sym_PERCENT_EQ] = ACTIONS(423),
    [anon_sym_CARET_EQ] = ACTIONS(423),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_LBRACK] = ACTIONS(447),
    [anon_sym_AT] = ACTIONS(423),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(433),
  },
  [149] = {
    [sym_comment] = STATE(149),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(423),
    [anon_sym_SEMI] = ACTIONS(423),
    [anon_sym_LF] = ACTIONS(423),
    [anon_sym_CR_LF] = ACTIONS(423),
    [anon_sym_if] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_while] = ACTIONS(423),
    [anon_sym_do] = ACTIONS(423),
    [anon_sym_for] = ACTIONS(423),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(423),
    [sym_continue_statement] = ACTIONS(423),
    [anon_sym_delete] = ACTIONS(423),
    [anon_sym_exit] = ACTIONS(423),
    [anon_sym_return] = ACTIONS(423),
    [anon_sym_switch] = ACTIONS(423),
    [anon_sym_LBRACE] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_case] = ACTIONS(423),
    [anon_sym_default] = ACTIONS(423),
    [anon_sym_getline] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(423),
    [sym_nextfile_statement] = ACTIONS(423),
    [anon_sym_print] = ACTIONS(423),
    [anon_sym_printf] = ACTIONS(423),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(423),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(423),
    [anon_sym_PLUS_PLUS] = ACTIONS(427),
    [anon_sym_DASH_DASH] = ACTIONS(427),
    [anon_sym_EQ] = ACTIONS(423),
    [anon_sym_PLUS_EQ] = ACTIONS(423),
    [anon_sym_DASH_EQ] = ACTIONS(423),
    [anon_sym_STAR_EQ] = ACTIONS(423),
    [anon_sym_SLASH_EQ] = ACTIONS(423),
    [anon_sym_PERCENT_EQ] = ACTIONS(423),
    [anon_sym_CARET_EQ] = ACTIONS(423),
    [anon_sym_DOLLAR] = ACTIONS(423),
    [anon_sym_AT] = ACTIONS(423),
    [sym_number] = ACTIONS(423),
    [anon_sym_DQUOTE] = ACTIONS(423),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(433),
    [sym__if_else_separator] = ACTIONS(433),
  },
  [150] = {
    [sym_comment] = STATE(150),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_LPAREN2] = ACTIONS(455),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(437),
    [anon_sym_DASH_DASH] = ACTIONS(437),
    [anon_sym_EQ] = ACTIONS(461),
    [anon_sym_PLUS_EQ] = ACTIONS(461),
    [anon_sym_DASH_EQ] = ACTIONS(461),
    [anon_sym_STAR_EQ] = ACTIONS(461),
    [anon_sym_SLASH_EQ] = ACTIONS(461),
    [anon_sym_PERCENT_EQ] = ACTIONS(461),
    [anon_sym_CARET_EQ] = ACTIONS(461),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_LBRACK] = ACTIONS(429),
    [anon_sym_AT] = ACTIONS(435),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
    [sym__if_else_separator] = ACTIONS(439),
  },
  [151] = {
    [sym_comment] = STATE(151),
    [sym_identifier] = ACTIONS(579),
    [anon_sym_COMMA] = ACTIONS(579),
    [anon_sym_SEMI] = ACTIONS(579),
    [anon_sym_LF] = ACTIONS(579),
    [anon_sym_CR_LF] = ACTIONS(579),
    [anon_sym_if] = ACTIONS(579),
    [anon_sym_LPAREN] = ACTIONS(579),
    [anon_sym_while] = ACTIONS(579),
    [anon_sym_do] = ACTIONS(579),
    [anon_sym_for] = ACTIONS(579),
    [anon_sym_in] = ACTIONS(579),
    [sym_break_statement] = ACTIONS(579),
    [sym_continue_statement] = ACTIONS(579),
    [anon_sym_delete] = ACTIONS(579),
    [anon_sym_exit] = ACTIONS(579),
    [anon_sym_return] = ACTIONS(579),
    [anon_sym_switch] = ACTIONS(579),
    [anon_sym_LBRACE] = ACTIONS(579),
    [anon_sym_RBRACE] = ACTIONS(579),
    [anon_sym_case] = ACTIONS(579),
    [anon_sym_default] = ACTIONS(579),
    [anon_sym_getline] = ACTIONS(579),
    [anon_sym_LT] = ACTIONS(579),
    [sym_next_statement] = ACTIONS(579),
    [sym_nextfile_statement] = ACTIONS(579),
    [anon_sym_print] = ACTIONS(579),
    [anon_sym_printf] = ACTIONS(579),
    [anon_sym_GT] = ACTIONS(579),
    [anon_sym_GT_GT] = ACTIONS(579),
    [anon_sym_PIPE] = ACTIONS(579),
    [anon_sym_PIPE_AMP] = ACTIONS(579),
    [anon_sym_QMARK] = ACTIONS(579),
    [anon_sym_CARET] = ACTIONS(579),
    [anon_sym_STAR_STAR] = ACTIONS(579),
    [anon_sym_STAR] = ACTIONS(579),
    [anon_sym_SLASH] = ACTIONS(579),
    [anon_sym_PERCENT] = ACTIONS(579),
    [anon_sym_PLUS] = ACTIONS(579),
    [anon_sym_DASH] = ACTIONS(579),
    [anon_sym_LT_EQ] = ACTIONS(579),
    [anon_sym_GT_EQ] = ACTIONS(579),
    [anon_sym_EQ_EQ] = ACTIONS(579),
    [anon_sym_BANG_EQ] = ACTIONS(579),
    [anon_sym_TILDE] = ACTIONS(579),
    [anon_sym_BANG_TILDE] = ACTIONS(579),
    [anon_sym_AMP_AMP] = ACTIONS(579),
    [anon_sym_PIPE_PIPE] = ACTIONS(579),
    [anon_sym_BANG] = ACTIONS(579),
    [anon_sym_PLUS_PLUS] = ACTIONS(579),
    [anon_sym_DASH_DASH] = ACTIONS(579),
    [anon_sym_EQ] = ACTIONS(579),
    [anon_sym_PLUS_EQ] = ACTIONS(579),
    [anon_sym_DASH_EQ] = ACTIONS(579),
    [anon_sym_STAR_EQ] = ACTIONS(579),
    [anon_sym_SLASH_EQ] = ACTIONS(579),
    [anon_sym_PERCENT_EQ] = ACTIONS(579),
    [anon_sym_CARET_EQ] = ACTIONS(579),
    [anon_sym_DOLLAR] = ACTIONS(579),
    [anon_sym_AT] = ACTIONS(579),
    [sym_number] = ACTIONS(579),
    [anon_sym_DQUOTE] = ACTIONS(579),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(581),
    [sym__if_else_separator] = ACTIONS(581),
  },
  [152] = {
    [sym_comment] = STATE(152),
    [sym_identifier] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_CR_LF] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_do] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_in] = ACTIONS(423),
    [sym_break_statement] = ACTIONS(435),
    [sym_continue_statement] = ACTIONS(435),
    [anon_sym_delete] = ACTIONS(435),
    [anon_sym_exit] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_case] = ACTIONS(435),
    [anon_sym_default] = ACTIONS(435),
    [anon_sym_getline] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(423),
    [sym_next_statement] = ACTIONS(435),
    [sym_nextfile_statement] = ACTIONS(435),
    [anon_sym_print] = ACTIONS(435),
    [anon_sym_printf] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_GT_GT] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(423),
    [anon_sym_PIPE_AMP] = ACTIONS(423),
    [anon_sym_QMARK] = ACTIONS(423),
    [anon_sym_CARET] = ACTIONS(423),
    [anon_sym_STAR_STAR] = ACTIONS(423),
    [anon_sym_STAR] = ACTIONS(423),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(423),
    [anon_sym_PLUS] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(423),
    [anon_sym_LT_EQ] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(423),
    [anon_sym_EQ_EQ] = ACTIONS(423),
    [anon_sym_BANG_EQ] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(423),
    [anon_sym_BANG_TILDE] = ACTIONS(423),
    [anon_sym_AMP_AMP] = ACTIONS(423),
    [anon_sym_PIPE_PIPE] = ACTIONS(423),
    [anon_sym_BANG] = ACTIONS(435),
    [anon_sym_PLUS_PLUS] = ACTIONS(437),
    [anon_sym_DASH_DASH] = ACTIONS(437),
    [anon_sym_EQ] = ACTIONS(461),
    [anon_sym_PLUS_EQ] = ACTIONS(461),
    [anon_sym_DASH_EQ] = ACTIONS(461),
    [anon_sym_STAR_EQ] = ACTIONS(461),
    [anon_sym_SLASH_EQ] = ACTIONS(461),
    [anon_sym_PERCENT_EQ] = ACTIONS(461),
    [anon_sym_CARET_EQ] = ACTIONS(461),
    [anon_sym_DOLLAR] = ACTIONS(435),
    [anon_sym_AT] = ACTIONS(435),
    [sym_number] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [anon_sym_POUND] = ACTIONS(83),
    [sym_concatenating_space] = ACTIONS(439),
    [sym__if_else_separator] = ACTIONS(439),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(565), 1,
      sym_concatenating_space,
    STATE(153), 1,
      sym_comment,
    ACTIONS(563), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [73] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    STATE(154), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(457), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(459), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [152] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    STATE(155), 1,
      sym_comment,
    ACTIONS(423), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [225] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(479), 1,
      sym_concatenating_space,
    STATE(156), 1,
      sym_comment,
    ACTIONS(477), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [298] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(439), 1,
      sym_concatenating_space,
    STATE(157), 1,
      sym_comment,
    ACTIONS(437), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(423), 21,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(435), 38,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [375] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(577), 1,
      sym_concatenating_space,
    STATE(158), 1,
      sym_comment,
    ACTIONS(575), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [448] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(443), 1,
      sym_concatenating_space,
    STATE(159), 1,
      sym_comment,
    ACTIONS(441), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [521] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(517), 1,
      sym_concatenating_space,
    STATE(160), 1,
      sym_comment,
    ACTIONS(515), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [594] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    STATE(161), 1,
      sym_comment,
    ACTIONS(449), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(423), 59,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [669] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    STATE(162), 1,
      sym_comment,
    ACTIONS(423), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [742] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(505), 1,
      sym_concatenating_space,
    STATE(163), 1,
      sym_comment,
    ACTIONS(503), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [815] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(523), 1,
      anon_sym_LPAREN2,
    STATE(164), 1,
      sym_comment,
    ACTIONS(571), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(573), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [896] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(483), 1,
      sym_concatenating_space,
    STATE(165), 1,
      sym_comment,
    ACTIONS(481), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [969] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym_concatenating_space,
    ACTIONS(583), 1,
      sym_identifier,
    ACTIONS(585), 1,
      anon_sym_LT,
    STATE(166), 1,
      sym_comment,
    STATE(207), 1,
      sym_ns_qualified_name,
    STATE(1808), 1,
      sym_namespace,
    ACTIONS(499), 57,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
  [1050] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym_concatenating_space,
    STATE(167), 1,
      sym_comment,
    ACTIONS(469), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [1123] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    ACTIONS(433), 1,
      sym__if_else_separator,
    ACTIONS(467), 1,
      sym_concatenating_space,
    STATE(168), 1,
      sym_comment,
    ACTIONS(463), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(465), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [1204] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(581), 1,
      sym_concatenating_space,
    STATE(169), 1,
      sym_comment,
    ACTIONS(579), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [1277] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(439), 1,
      sym_concatenating_space,
    STATE(170), 1,
      sym_comment,
    ACTIONS(423), 21,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(435), 40,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [1352] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(171), 1,
      sym_comment,
    ACTIONS(453), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(451), 60,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [1425] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(589), 1,
      sym_regex_flags,
    STATE(172), 1,
      sym_comment,
    ACTIONS(591), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(587), 59,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [1500] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(521), 1,
      sym_concatenating_space,
    STATE(173), 1,
      sym_comment,
    ACTIONS(519), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [1573] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(513), 1,
      sym_concatenating_space,
    STATE(174), 1,
      sym_comment,
    ACTIONS(511), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [1646] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(487), 1,
      sym_concatenating_space,
    STATE(175), 1,
      sym_comment,
    ACTIONS(485), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [1719] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(509), 1,
      sym_concatenating_space,
    STATE(176), 1,
      sym_comment,
    ACTIONS(507), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [1792] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym_concatenating_space,
    ACTIONS(593), 1,
      sym_identifier,
    STATE(167), 1,
      sym_ns_qualified_name,
    STATE(177), 1,
      sym_comment,
    STATE(1808), 1,
      sym_namespace,
    ACTIONS(499), 58,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
  [1871] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(178), 1,
      sym_comment,
    ACTIONS(539), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [1944] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(439), 1,
      sym_concatenating_space,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(523), 1,
      anon_sym_LPAREN2,
    STATE(179), 1,
      sym_comment,
    ACTIONS(437), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(461), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 21,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(435), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [2027] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(533), 1,
      sym_concatenating_space,
    STATE(180), 1,
      sym_comment,
    ACTIONS(531), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [2100] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(439), 1,
      sym_concatenating_space,
    STATE(181), 1,
      sym_comment,
    ACTIONS(437), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(461), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 21,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(435), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [2179] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(523), 1,
      anon_sym_LPAREN2,
    ACTIONS(529), 1,
      sym_concatenating_space,
    STATE(182), 1,
      sym_comment,
    ACTIONS(525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(527), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [2260] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(595), 1,
      anon_sym_LT,
    STATE(183), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 58,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [2337] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(495), 1,
      sym_concatenating_space,
    STATE(184), 1,
      sym_comment,
    ACTIONS(493), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [2410] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(537), 1,
      sym_concatenating_space,
    STATE(185), 1,
      sym_comment,
    ACTIONS(535), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [2483] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(491), 1,
      sym_concatenating_space,
    STATE(186), 1,
      sym_comment,
    ACTIONS(489), 61,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [2556] = 26,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(131), 1,
      sym_identifier,
    ACTIONS(149), 1,
      anon_sym_getline,
    ACTIONS(597), 1,
      anon_sym_LPAREN,
    ACTIONS(599), 1,
      anon_sym_LPAREN2,
    ACTIONS(601), 1,
      anon_sym_SLASH,
    ACTIONS(605), 1,
      anon_sym_DOLLAR,
    ACTIONS(607), 1,
      anon_sym_AT,
    ACTIONS(609), 1,
      sym_number,
    ACTIONS(611), 1,
      anon_sym_DQUOTE,
    STATE(182), 1,
      sym_ns_qualified_name,
    STATE(187), 1,
      sym_comment,
    STATE(203), 1,
      sym_array_ref,
    STATE(208), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(393), 1,
      sym__exp,
    STATE(610), 1,
      sym_exp_list,
    STATE(611), 1,
      sym__print_args,
    STATE(685), 1,
      aux_sym_exp_list_repeat1,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(603), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(392), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(157), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    STATE(381), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(391), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    ACTIONS(543), 23,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
  [2673] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(471), 1,
      sym_concatenating_space,
    ACTIONS(613), 1,
      anon_sym_LT,
    STATE(188), 1,
      sym_comment,
    ACTIONS(469), 58,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [2749] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(189), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(457), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(459), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [2825] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(190), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(615), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 57,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [2899] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(191), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(615), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(617), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 54,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [2975] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(192), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(615), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(621), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(617), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(619), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 44,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [3057] = 11,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(625), 1,
      anon_sym_in,
    STATE(193), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(615), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(621), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(627), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(617), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(619), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 41,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [3143] = 12,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(625), 1,
      anon_sym_in,
    ACTIONS(629), 1,
      anon_sym_AMP_AMP,
    STATE(194), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(615), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(621), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(627), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(617), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(619), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 40,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [3231] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    STATE(195), 1,
      sym_comment,
    ACTIONS(571), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(573), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [3309] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(625), 1,
      anon_sym_in,
    ACTIONS(629), 1,
      anon_sym_AMP_AMP,
    ACTIONS(633), 1,
      anon_sym_QMARK,
    ACTIONS(635), 1,
      anon_sym_PIPE_PIPE,
    STATE(196), 1,
      sym_comment,
    ACTIONS(615), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(621), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(627), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(637), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(617), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(619), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(631), 38,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [3401] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(197), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(615), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(621), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(617), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [3481] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(595), 1,
      anon_sym_LT,
    STATE(198), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 58,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [3555] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym__if_else_separator,
    ACTIONS(467), 1,
      sym_concatenating_space,
    STATE(199), 1,
      sym_comment,
    ACTIONS(463), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(465), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [3633] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(200), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(615), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(621), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(627), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(617), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(619), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 42,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [3717] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(625), 1,
      anon_sym_in,
    ACTIONS(629), 1,
      anon_sym_AMP_AMP,
    ACTIONS(633), 1,
      anon_sym_QMARK,
    ACTIONS(635), 1,
      anon_sym_PIPE_PIPE,
    STATE(201), 1,
      sym_comment,
    ACTIONS(615), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(621), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(627), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(641), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(617), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(619), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 38,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [3809] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(591), 1,
      sym_concatenating_space,
    ACTIONS(643), 1,
      sym_regex_flags,
    STATE(202), 1,
      sym_comment,
    ACTIONS(587), 59,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [3883] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(529), 1,
      sym_concatenating_space,
    STATE(203), 1,
      sym_comment,
    ACTIONS(525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(527), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [3961] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(204), 1,
      sym_comment,
    ACTIONS(615), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(647), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(617), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [4039] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(453), 1,
      sym_concatenating_space,
    STATE(205), 1,
      sym_comment,
    ACTIONS(451), 60,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [4111] = 11,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    ACTIONS(649), 1,
      anon_sym_in,
    STATE(206), 1,
      sym_comment,
    ACTIONS(653), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(655), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(659), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(657), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(651), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 41,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [4196] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym_concatenating_space,
    ACTIONS(613), 1,
      anon_sym_LT,
    STATE(207), 1,
      sym_comment,
    ACTIONS(469), 58,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [4269] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(529), 1,
      sym_concatenating_space,
    STATE(208), 1,
      sym_comment,
    ACTIONS(525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(527), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [4344] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(209), 1,
      sym_comment,
    ACTIONS(653), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(655), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(659), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(657), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(651), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 44,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [4425] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(647), 1,
      sym_concatenating_space,
    STATE(210), 1,
      sym_comment,
    ACTIONS(655), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(659), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(657), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [4502] = 12,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    ACTIONS(649), 1,
      anon_sym_in,
    ACTIONS(663), 1,
      anon_sym_AMP_AMP,
    STATE(211), 1,
      sym_comment,
    ACTIONS(653), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(655), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(659), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(657), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(651), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 40,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [4589] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(212), 1,
      sym_comment,
    ACTIONS(655), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(657), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 54,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [4664] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(213), 1,
      sym_comment,
    ACTIONS(655), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 57,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [4737] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(637), 1,
      sym_concatenating_space,
    ACTIONS(649), 1,
      anon_sym_in,
    ACTIONS(663), 1,
      anon_sym_AMP_AMP,
    ACTIONS(665), 1,
      anon_sym_QMARK,
    ACTIONS(667), 1,
      anon_sym_PIPE_PIPE,
    STATE(214), 1,
      sym_comment,
    ACTIONS(653), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(655), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(659), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(657), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(651), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(631), 38,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [4828] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    STATE(215), 1,
      sym_comment,
    ACTIONS(571), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(573), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [4903] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(216), 1,
      sym_comment,
    ACTIONS(653), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(655), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(659), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(657), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(651), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 42,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [4986] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(217), 1,
      sym_comment,
    ACTIONS(653), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(655), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(659), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(657), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [5065] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(641), 1,
      sym_concatenating_space,
    ACTIONS(649), 1,
      anon_sym_in,
    ACTIONS(663), 1,
      anon_sym_AMP_AMP,
    ACTIONS(665), 1,
      anon_sym_QMARK,
    ACTIONS(667), 1,
      anon_sym_PIPE_PIPE,
    STATE(218), 1,
      sym_comment,
    ACTIONS(653), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(655), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(659), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(657), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(651), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 38,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [5156] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(669), 1,
      anon_sym_LPAREN2,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    STATE(219), 1,
      sym_comment,
    ACTIONS(671), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(423), 23,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 30,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [5233] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(669), 1,
      anon_sym_LPAREN2,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    STATE(220), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(423), 10,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 11,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(435), 13,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_LPAREN,
      anon_sym_COLON,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(439), 19,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [5314] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(221), 1,
      sym_comment,
    ACTIONS(451), 22,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(453), 35,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_LPAREN2,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [5382] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    STATE(222), 1,
      sym_comment,
    ACTIONS(441), 22,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(443), 33,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [5454] = 9,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(669), 1,
      anon_sym_LPAREN2,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    STATE(223), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(423), 10,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 11,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(435), 12,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_LPAREN,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(439), 20,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [5532] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(669), 1,
      anon_sym_LPAREN2,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    STATE(224), 1,
      sym_comment,
    ACTIONS(671), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(423), 22,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 31,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [5606] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(453), 1,
      sym__if_else_separator,
    STATE(225), 1,
      sym_comment,
    ACTIONS(451), 55,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [5673] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    STATE(226), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(423), 10,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 11,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(435), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(439), 21,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [5748] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(227), 1,
      sym_comment,
    ACTIONS(473), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(475), 35,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [5815] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(475), 1,
      sym__if_else_separator,
    STATE(228), 1,
      sym_comment,
    ACTIONS(473), 55,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [5882] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    STATE(229), 1,
      sym_comment,
    ACTIONS(441), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(443), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [5951] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(677), 1,
      sym_identifier,
    STATE(230), 1,
      sym_comment,
    STATE(310), 1,
      sym_ns_qualified_name,
    STATE(1812), 1,
      sym_namespace,
    ACTIONS(501), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(499), 51,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
  [6024] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    STATE(231), 1,
      sym_comment,
    ACTIONS(671), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(423), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 32,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [6095] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(679), 1,
      anon_sym_LBRACK,
    STATE(232), 1,
      sym_comment,
    ACTIONS(443), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(441), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [6166] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(681), 1,
      sym_identifier,
    ACTIONS(683), 1,
      anon_sym_LT,
    STATE(233), 1,
      sym_comment,
    STATE(287), 1,
      sym_ns_qualified_name,
    STATE(1812), 1,
      sym_namespace,
    ACTIONS(501), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(499), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
  [6241] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    STATE(234), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 10,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(435), 10,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 11,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(439), 15,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [6320] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    STATE(235), 1,
      sym_comment,
    ACTIONS(469), 22,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(471), 33,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [6389] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(236), 1,
      sym_comment,
    ACTIONS(489), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(491), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [6455] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(237), 1,
      sym_comment,
    ACTIONS(473), 55,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [6519] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(238), 1,
      sym_comment,
    ACTIONS(453), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(451), 53,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [6585] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(687), 1,
      sym_regex_flags,
    STATE(239), 1,
      sym_comment,
    ACTIONS(591), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(587), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [6653] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(443), 1,
      sym_concatenating_space,
    ACTIONS(689), 1,
      anon_sym_LBRACK,
    STATE(240), 1,
      sym_comment,
    ACTIONS(441), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [6723] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(241), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(423), 10,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 11,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(435), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(439), 21,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [6795] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym_concatenating_space,
    ACTIONS(691), 1,
      sym_identifier,
    ACTIONS(693), 1,
      anon_sym_LT,
    STATE(242), 1,
      sym_comment,
    STATE(334), 1,
      sym_ns_qualified_name,
    STATE(1807), 1,
      sym_namespace,
    ACTIONS(499), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
  [6869] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(243), 1,
      sym_comment,
    ACTIONS(475), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(473), 53,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [6935] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(244), 1,
      sym_comment,
    ACTIONS(515), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(517), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [7001] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(245), 1,
      sym_comment,
    ACTIONS(671), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(423), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 32,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [7069] = 9,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(461), 1,
      anon_sym_EQ,
    STATE(246), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 10,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(435), 10,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 11,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(439), 15,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [7145] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(247), 1,
      sym_comment,
    ACTIONS(481), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(483), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [7211] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(248), 1,
      sym_comment,
    ACTIONS(423), 10,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 11,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(435), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(439), 23,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [7281] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(249), 1,
      sym_comment,
    ACTIONS(535), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(537), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [7347] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(250), 1,
      sym_comment,
    ACTIONS(539), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [7413] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(251), 1,
      sym_comment,
    ACTIONS(579), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(581), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [7479] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym_concatenating_space,
    ACTIONS(695), 1,
      sym_identifier,
    STATE(252), 1,
      sym_comment,
    STATE(344), 1,
      sym_ns_qualified_name,
    STATE(1807), 1,
      sym_namespace,
    ACTIONS(499), 51,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
  [7551] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(253), 1,
      sym_comment,
    ACTIONS(423), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [7617] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(254), 1,
      sym_comment,
    ACTIONS(563), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(565), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [7683] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(255), 1,
      sym_comment,
    ACTIONS(423), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [7749] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    STATE(256), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [7817] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(257), 1,
      sym_comment,
    ACTIONS(441), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(443), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [7883] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(258), 1,
      sym_comment,
    ACTIONS(485), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(487), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [7949] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(259), 1,
      sym_comment,
    ACTIONS(477), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(479), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [8015] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(260), 1,
      sym_comment,
    ACTIONS(503), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(505), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [8081] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(261), 1,
      sym_comment,
    ACTIONS(493), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(495), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [8147] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(679), 1,
      anon_sym_LBRACK,
    STATE(262), 1,
      sym_comment,
    ACTIONS(443), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(441), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [8215] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(263), 1,
      sym_comment,
    ACTIONS(531), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(533), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [8281] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(264), 1,
      sym_comment,
    ACTIONS(575), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(577), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [8347] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(265), 1,
      sym_comment,
    ACTIONS(507), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(509), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [8413] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(697), 1,
      anon_sym_LT,
    STATE(266), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 51,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [8483] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym__if_else_separator,
    ACTIONS(699), 1,
      sym_identifier,
    ACTIONS(701), 1,
      anon_sym_LT,
    STATE(267), 1,
      sym_comment,
    STATE(355), 1,
      sym_ns_qualified_name,
    STATE(1811), 1,
      sym_namespace,
    ACTIONS(499), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
  [8557] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(268), 1,
      sym_comment,
    ACTIONS(511), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(513), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [8623] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(269), 1,
      sym_comment,
    ACTIONS(519), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(521), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [8689] = 23,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(321), 1,
      sym_identifier,
    ACTIONS(337), 1,
      anon_sym_getline,
    ACTIONS(545), 1,
      anon_sym_LPAREN,
    ACTIONS(549), 1,
      anon_sym_SLASH,
    ACTIONS(553), 1,
      anon_sym_DOLLAR,
    ACTIONS(555), 1,
      anon_sym_AT,
    ACTIONS(557), 1,
      sym_number,
    ACTIONS(559), 1,
      anon_sym_DQUOTE,
    ACTIONS(705), 1,
      sym__if_else_separator,
    STATE(145), 1,
      sym_ns_qualified_name,
    STATE(168), 1,
      sym_array_ref,
    STATE(199), 1,
      sym_field_ref,
    STATE(270), 1,
      sym_comment,
    STATE(294), 1,
      sym_string,
    STATE(423), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(551), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(354), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(345), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    STATE(286), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(353), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    ACTIONS(703), 19,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
  [8793] = 23,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(321), 1,
      sym_identifier,
    ACTIONS(337), 1,
      anon_sym_getline,
    ACTIONS(545), 1,
      anon_sym_LPAREN,
    ACTIONS(549), 1,
      anon_sym_SLASH,
    ACTIONS(553), 1,
      anon_sym_DOLLAR,
    ACTIONS(555), 1,
      anon_sym_AT,
    ACTIONS(557), 1,
      sym_number,
    ACTIONS(559), 1,
      anon_sym_DQUOTE,
    ACTIONS(709), 1,
      sym__if_else_separator,
    STATE(145), 1,
      sym_ns_qualified_name,
    STATE(168), 1,
      sym_array_ref,
    STATE(199), 1,
      sym_field_ref,
    STATE(271), 1,
      sym_comment,
    STATE(294), 1,
      sym_string,
    STATE(424), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(551), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(354), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(345), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    STATE(286), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(353), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    ACTIONS(707), 19,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
  [8897] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(443), 1,
      sym__if_else_separator,
    ACTIONS(711), 1,
      anon_sym_LBRACK,
    STATE(272), 1,
      sym_comment,
    ACTIONS(441), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [8967] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(273), 1,
      sym_comment,
    ACTIONS(451), 55,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [9031] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(274), 1,
      sym_comment,
    ACTIONS(469), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(471), 34,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [9097] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym__if_else_separator,
    ACTIONS(713), 1,
      sym_identifier,
    STATE(275), 1,
      sym_comment,
    STATE(367), 1,
      sym_ns_qualified_name,
    STATE(1811), 1,
      sym_namespace,
    ACTIONS(499), 51,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
  [9169] = 22,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(131), 1,
      sym_identifier,
    ACTIONS(149), 1,
      anon_sym_getline,
    ACTIONS(597), 1,
      anon_sym_LPAREN,
    ACTIONS(601), 1,
      anon_sym_SLASH,
    ACTIONS(605), 1,
      anon_sym_DOLLAR,
    ACTIONS(607), 1,
      anon_sym_AT,
    ACTIONS(609), 1,
      sym_number,
    ACTIONS(611), 1,
      anon_sym_DQUOTE,
    STATE(182), 1,
      sym_ns_qualified_name,
    STATE(203), 1,
      sym_array_ref,
    STATE(208), 1,
      sym_field_ref,
    STATE(276), 1,
      sym_comment,
    STATE(330), 1,
      sym_string,
    STATE(432), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(603), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(392), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(157), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    STATE(381), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(391), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    ACTIONS(703), 19,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
  [9270] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(715), 1,
      sym_identifier,
    ACTIONS(717), 1,
      anon_sym_LT,
    STATE(277), 1,
      sym_comment,
    STATE(398), 1,
      sym_ns_qualified_name,
    STATE(1801), 1,
      sym_namespace,
    ACTIONS(499), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
  [9341] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(443), 1,
      sym__if_else_separator,
    ACTIONS(711), 1,
      anon_sym_LBRACK,
    STATE(278), 1,
      sym_comment,
    ACTIONS(441), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [9408] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(279), 1,
      sym_comment,
    ACTIONS(537), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(535), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [9473] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(280), 1,
      sym_comment,
    ACTIONS(581), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(579), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [9538] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(471), 1,
      sym__if_else_separator,
    STATE(281), 1,
      sym_comment,
    ACTIONS(469), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [9605] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(282), 1,
      sym_comment,
    ACTIONS(505), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(503), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [9670] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(283), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(423), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [9735] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(284), 1,
      sym_comment,
    ACTIONS(565), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(563), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [9800] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(285), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(423), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [9865] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym__if_else_separator,
    ACTIONS(467), 1,
      sym_concatenating_space,
    STATE(286), 1,
      sym_comment,
    ACTIONS(423), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [9932] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(697), 1,
      anon_sym_LT,
    STATE(287), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 51,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [9999] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(453), 1,
      sym_concatenating_space,
    STATE(288), 1,
      sym_comment,
    ACTIONS(451), 53,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [10064] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(289), 1,
      sym_comment,
    ACTIONS(443), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(441), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [10129] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(475), 1,
      sym_concatenating_space,
    STATE(290), 1,
      sym_comment,
    ACTIONS(473), 53,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [10194] = 31,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(719), 1,
      ts_builtin_sym_end,
    ACTIONS(721), 1,
      sym_identifier,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(733), 1,
      anon_sym_LBRACE,
    ACTIONS(736), 1,
      anon_sym_getline,
    ACTIONS(739), 1,
      anon_sym_SLASH,
    ACTIONS(745), 1,
      anon_sym_BANG,
    ACTIONS(751), 1,
      anon_sym_DOLLAR,
    ACTIONS(754), 1,
      anon_sym_AT,
    ACTIONS(757), 1,
      sym_number,
    ACTIONS(760), 1,
      anon_sym_DQUOTE,
    STATE(348), 1,
      sym_ns_qualified_name,
    STATE(409), 1,
      sym_array_ref,
    STATE(415), 1,
      sym_field_ref,
    STATE(479), 1,
      sym_string,
    STATE(514), 1,
      sym__exp,
    STATE(1408), 1,
      sym_pattern,
    STATE(1422), 1,
      sym_block,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(742), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(748), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(763), 2,
      anon_sym_function,
      anon_sym_func,
    STATE(291), 2,
      sym_comment,
      aux_sym_program_repeat1,
    STATE(513), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1415), 2,
      sym_range_pattern,
      sym__special_pattern,
    ACTIONS(727), 3,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
    STATE(1418), 3,
      sym_rule,
      sym_directive,
      sym_func_def,
    ACTIONS(724), 4,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
    STATE(471), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(503), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [10313] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(591), 1,
      sym_concatenating_space,
    ACTIONS(766), 1,
      sym_regex_flags,
    STATE(292), 1,
      sym_comment,
    ACTIONS(587), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [10380] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(293), 1,
      sym_comment,
    ACTIONS(487), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(485), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [10445] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(294), 1,
      sym_comment,
    ACTIONS(517), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(515), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [10510] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(295), 1,
      sym_comment,
    ACTIONS(479), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(477), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [10575] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(296), 1,
      sym_comment,
    ACTIONS(491), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(489), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [10640] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(297), 1,
      sym_comment,
    ACTIONS(495), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(493), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [10705] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(768), 1,
      anon_sym_in,
    ACTIONS(774), 1,
      anon_sym_QMARK,
    ACTIONS(784), 1,
      anon_sym_AMP_AMP,
    ACTIONS(786), 1,
      anon_sym_PIPE_PIPE,
    STATE(298), 1,
      sym_comment,
    ACTIONS(641), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(772), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(782), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [10790] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(299), 1,
      sym_comment,
    ACTIONS(509), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(507), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [10855] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(300), 1,
      sym_comment,
    ACTIONS(513), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(511), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [10920] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(301), 1,
      sym_comment,
    ACTIONS(521), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(519), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [10985] = 22,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(131), 1,
      sym_identifier,
    ACTIONS(149), 1,
      anon_sym_getline,
    ACTIONS(597), 1,
      anon_sym_LPAREN,
    ACTIONS(601), 1,
      anon_sym_SLASH,
    ACTIONS(605), 1,
      anon_sym_DOLLAR,
    ACTIONS(607), 1,
      anon_sym_AT,
    ACTIONS(609), 1,
      sym_number,
    ACTIONS(611), 1,
      anon_sym_DQUOTE,
    STATE(182), 1,
      sym_ns_qualified_name,
    STATE(203), 1,
      sym_array_ref,
    STATE(208), 1,
      sym_field_ref,
    STATE(302), 1,
      sym_comment,
    STATE(330), 1,
      sym_string,
    STATE(431), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(603), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(392), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(157), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    STATE(381), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(391), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    ACTIONS(707), 19,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
  [11086] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(471), 1,
      sym__if_else_separator,
    ACTIONS(788), 1,
      anon_sym_LT,
    STATE(303), 1,
      sym_comment,
    ACTIONS(469), 51,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [11155] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(304), 1,
      sym_comment,
    ACTIONS(647), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 45,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [11226] = 32,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(17), 1,
      anon_sym_getline,
    ACTIONS(19), 1,
      anon_sym_SLASH,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(29), 1,
      anon_sym_AT,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(790), 1,
      ts_builtin_sym_end,
    STATE(291), 1,
      aux_sym_program_repeat1,
    STATE(305), 1,
      sym_comment,
    STATE(348), 1,
      sym_ns_qualified_name,
    STATE(409), 1,
      sym_array_ref,
    STATE(415), 1,
      sym_field_ref,
    STATE(479), 1,
      sym_string,
    STATE(514), 1,
      sym__exp,
    STATE(1408), 1,
      sym_pattern,
    STATE(1422), 1,
      sym_block,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(25), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(35), 2,
      anon_sym_function,
      anon_sym_func,
    STATE(513), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1415), 2,
      sym_range_pattern,
      sym__special_pattern,
    ACTIONS(11), 3,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
    STATE(1418), 3,
      sym_rule,
      sym_directive,
      sym_func_def,
    ACTIONS(9), 4,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
    STATE(471), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(503), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [11347] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(471), 1,
      sym_concatenating_space,
    STATE(306), 1,
      sym_comment,
    ACTIONS(469), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [11414] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(307), 1,
      sym_comment,
    ACTIONS(483), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(481), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [11479] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(308), 1,
      sym_comment,
    ACTIONS(439), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(423), 21,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(435), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [11546] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(309), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(772), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(782), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 35,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [11623] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(310), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [11688] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(311), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(772), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 43,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [11761] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(312), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(539), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [11826] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(313), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [11893] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(314), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 47,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [11962] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(315), 1,
      sym_comment,
    ACTIONS(577), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(575), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [12027] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(316), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(772), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 37,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [12102] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LPAREN2,
    STATE(317), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 10,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(439), 10,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LBRACE,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
    ACTIONS(433), 11,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(435), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_LPAREN,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
  [12183] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(591), 1,
      sym__if_else_separator,
    ACTIONS(794), 1,
      sym_regex_flags,
    STATE(318), 1,
      sym_comment,
    ACTIONS(587), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [12250] = 11,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(768), 1,
      anon_sym_in,
    STATE(319), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(772), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(782), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 34,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [12329] = 12,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(768), 1,
      anon_sym_in,
    ACTIONS(784), 1,
      anon_sym_AMP_AMP,
    STATE(320), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(772), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(782), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 33,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [12410] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(321), 1,
      sym_comment,
    ACTIONS(533), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(531), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [12475] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LPAREN2,
    ACTIONS(798), 1,
      anon_sym_EQ,
    ACTIONS(802), 1,
      sym_concatenating_space,
    STATE(322), 1,
      sym_comment,
    ACTIONS(796), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(800), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(433), 20,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
    ACTIONS(423), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
  [12554] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(804), 1,
      sym_identifier,
    STATE(323), 1,
      sym_comment,
    STATE(411), 1,
      sym_ns_qualified_name,
    STATE(1801), 1,
      sym_namespace,
    ACTIONS(499), 51,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
  [12623] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(768), 1,
      anon_sym_in,
    ACTIONS(774), 1,
      anon_sym_QMARK,
    ACTIONS(784), 1,
      anon_sym_AMP_AMP,
    ACTIONS(786), 1,
      anon_sym_PIPE_PIPE,
    STATE(324), 1,
      sym_comment,
    ACTIONS(637), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(772), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(782), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(631), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [12708] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(471), 1,
      sym_concatenating_space,
    ACTIONS(806), 1,
      anon_sym_LT,
    STATE(325), 1,
      sym_comment,
    ACTIONS(469), 51,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [12777] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(443), 1,
      sym_concatenating_space,
    ACTIONS(689), 1,
      anon_sym_LBRACK,
    STATE(326), 1,
      sym_comment,
    ACTIONS(441), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [12844] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(808), 1,
      anon_sym_LBRACK,
    STATE(327), 1,
      sym_comment,
    ACTIONS(441), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [12911] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LPAREN2,
    ACTIONS(812), 1,
      anon_sym_EQ,
    STATE(328), 1,
      sym_comment,
    ACTIONS(810), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(814), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 21,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [12988] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(641), 1,
      sym__if_else_separator,
    ACTIONS(768), 1,
      anon_sym_in,
    ACTIONS(774), 1,
      anon_sym_QMARK,
    ACTIONS(784), 1,
      anon_sym_AMP_AMP,
    ACTIONS(786), 1,
      anon_sym_PIPE_PIPE,
    STATE(329), 1,
      sym_comment,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(782), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(816), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13072] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(517), 1,
      sym_concatenating_space,
    STATE(330), 1,
      sym_comment,
    ACTIONS(515), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13136] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(479), 1,
      sym_concatenating_space,
    STATE(331), 1,
      sym_comment,
    ACTIONS(477), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13200] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(487), 1,
      sym_concatenating_space,
    STATE(332), 1,
      sym_comment,
    ACTIONS(485), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13264] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(443), 1,
      sym_concatenating_space,
    STATE(333), 1,
      sym_comment,
    ACTIONS(441), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13328] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym_concatenating_space,
    ACTIONS(806), 1,
      anon_sym_LT,
    STATE(334), 1,
      sym_comment,
    ACTIONS(469), 51,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13394] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    STATE(335), 1,
      sym_comment,
    ACTIONS(423), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13458] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(565), 1,
      sym_concatenating_space,
    STATE(336), 1,
      sym_comment,
    ACTIONS(563), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13522] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    STATE(337), 1,
      sym_comment,
    ACTIONS(423), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13586] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(637), 1,
      sym_concatenating_space,
    ACTIONS(818), 1,
      anon_sym_in,
    ACTIONS(824), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AMP_AMP,
    ACTIONS(836), 1,
      anon_sym_PIPE_PIPE,
    STATE(338), 1,
      sym_comment,
    ACTIONS(822), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(832), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(631), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13670] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(495), 1,
      sym_concatenating_space,
    STATE(339), 1,
      sym_comment,
    ACTIONS(493), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13734] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(641), 1,
      sym_concatenating_space,
    ACTIONS(818), 1,
      anon_sym_in,
    ACTIONS(824), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AMP_AMP,
    ACTIONS(836), 1,
      anon_sym_PIPE_PIPE,
    STATE(340), 1,
      sym_comment,
    ACTIONS(822), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(832), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13818] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(509), 1,
      sym_concatenating_space,
    STATE(341), 1,
      sym_comment,
    ACTIONS(507), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13882] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(513), 1,
      sym_concatenating_space,
    STATE(342), 1,
      sym_comment,
    ACTIONS(511), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [13946] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(521), 1,
      sym_concatenating_space,
    STATE(343), 1,
      sym_comment,
    ACTIONS(519), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [14010] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym_concatenating_space,
    STATE(344), 1,
      sym_comment,
    ACTIONS(469), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [14074] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(345), 1,
      sym_comment,
    ACTIONS(822), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 43,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [14146] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(346), 1,
      sym_comment,
    ACTIONS(822), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(832), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 35,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [14222] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(581), 1,
      sym__if_else_separator,
    STATE(347), 1,
      sym_comment,
    ACTIONS(579), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [14286] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LPAREN2,
    ACTIONS(798), 1,
      anon_sym_EQ,
    ACTIONS(802), 1,
      sym_concatenating_space,
    STATE(348), 1,
      sym_comment,
    ACTIONS(796), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(800), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(433), 20,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
    ACTIONS(423), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
  [14362] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(577), 1,
      sym_concatenating_space,
    STATE(349), 1,
      sym_comment,
    ACTIONS(575), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [14426] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(505), 1,
      sym_concatenating_space,
    STATE(350), 1,
      sym_comment,
    ACTIONS(503), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [14490] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(581), 1,
      sym_concatenating_space,
    STATE(351), 1,
      sym_comment,
    ACTIONS(579), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [14554] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LPAREN2,
    STATE(352), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 10,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(439), 10,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LBRACE,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
    ACTIONS(433), 11,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(435), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_LPAREN,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
  [14632] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym__if_else_separator,
    STATE(353), 1,
      sym_comment,
    ACTIONS(423), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [14696] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(565), 1,
      sym__if_else_separator,
    STATE(354), 1,
      sym_comment,
    ACTIONS(563), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [14760] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym__if_else_separator,
    ACTIONS(788), 1,
      anon_sym_LT,
    STATE(355), 1,
      sym_comment,
    ACTIONS(469), 51,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [14826] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(443), 1,
      sym__if_else_separator,
    STATE(356), 1,
      sym_comment,
    ACTIONS(441), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [14890] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(487), 1,
      sym__if_else_separator,
    STATE(357), 1,
      sym_comment,
    ACTIONS(485), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [14954] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(479), 1,
      sym__if_else_separator,
    STATE(358), 1,
      sym_comment,
    ACTIONS(477), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15018] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(491), 1,
      sym__if_else_separator,
    STATE(359), 1,
      sym_comment,
    ACTIONS(489), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15082] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(537), 1,
      sym__if_else_separator,
    STATE(360), 1,
      sym_comment,
    ACTIONS(535), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15146] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(537), 1,
      sym_concatenating_space,
    STATE(361), 1,
      sym_comment,
    ACTIONS(535), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15210] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(495), 1,
      sym__if_else_separator,
    STATE(362), 1,
      sym_comment,
    ACTIONS(493), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15274] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(509), 1,
      sym__if_else_separator,
    STATE(363), 1,
      sym_comment,
    ACTIONS(507), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15338] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(513), 1,
      sym__if_else_separator,
    STATE(364), 1,
      sym_comment,
    ACTIONS(511), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15402] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(808), 1,
      anon_sym_LBRACK,
    STATE(365), 1,
      sym_comment,
    ACTIONS(441), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15466] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(521), 1,
      sym__if_else_separator,
    STATE(366), 1,
      sym_comment,
    ACTIONS(519), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15530] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym__if_else_separator,
    STATE(367), 1,
      sym_comment,
    ACTIONS(469), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15594] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(838), 1,
      sym_identifier,
    STATE(274), 1,
      sym_ns_qualified_name,
    STATE(368), 1,
      sym_comment,
    STATE(1804), 1,
      sym_namespace,
    ACTIONS(499), 20,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(501), 30,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [15664] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(768), 1,
      anon_sym_in,
    ACTIONS(774), 1,
      anon_sym_QMARK,
    ACTIONS(784), 1,
      anon_sym_AMP_AMP,
    ACTIONS(786), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(842), 1,
      anon_sym_COMMA,
    ACTIONS(844), 1,
      sym__if_else_separator,
    STATE(369), 1,
      sym_comment,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(782), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 5,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(840), 33,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15748] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(577), 1,
      sym__if_else_separator,
    STATE(370), 1,
      sym_comment,
    ACTIONS(575), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15812] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(647), 1,
      sym_concatenating_space,
    STATE(371), 1,
      sym_comment,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 45,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15882] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(491), 1,
      sym_concatenating_space,
    STATE(372), 1,
      sym_comment,
    ACTIONS(489), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [15946] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(846), 1,
      anon_sym_LT,
    STATE(373), 1,
      sym_comment,
    ACTIONS(469), 51,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [16012] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(533), 1,
      sym_concatenating_space,
    STATE(374), 1,
      sym_comment,
    ACTIONS(531), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [16076] = 9,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LPAREN2,
    ACTIONS(812), 1,
      anon_sym_EQ,
    STATE(375), 1,
      sym_comment,
    ACTIONS(810), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(814), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 21,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [16150] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(439), 1,
      sym_concatenating_space,
    STATE(376), 1,
      sym_comment,
    ACTIONS(423), 21,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(435), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [16216] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    STATE(377), 1,
      sym_comment,
    ACTIONS(469), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [16280] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(848), 1,
      sym_regex_flags,
    STATE(378), 1,
      sym_comment,
    ACTIONS(587), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [16344] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(850), 1,
      sym_identifier,
    ACTIONS(852), 1,
      anon_sym_LT,
    STATE(379), 1,
      sym_comment,
    STATE(417), 1,
      sym_ns_qualified_name,
    STATE(1804), 1,
      sym_namespace,
    ACTIONS(499), 19,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(501), 30,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [16416] = 12,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    ACTIONS(818), 1,
      anon_sym_in,
    ACTIONS(834), 1,
      anon_sym_AMP_AMP,
    STATE(380), 1,
      sym_comment,
    ACTIONS(822), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(832), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 33,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [16496] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(529), 1,
      sym_concatenating_space,
    STATE(381), 1,
      sym_comment,
    ACTIONS(423), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [16560] = 15,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(768), 1,
      anon_sym_in,
    ACTIONS(774), 1,
      anon_sym_QMARK,
    ACTIONS(784), 1,
      anon_sym_AMP_AMP,
    ACTIONS(786), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(842), 1,
      anon_sym_COMMA,
    ACTIONS(856), 1,
      sym__if_else_separator,
    STATE(382), 1,
      sym_comment,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(782), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(816), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(854), 30,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [16646] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(383), 1,
      sym_comment,
    ACTIONS(539), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [16710] = 11,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    ACTIONS(818), 1,
      anon_sym_in,
    STATE(384), 1,
      sym_comment,
    ACTIONS(822), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(832), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 34,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [16788] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(385), 1,
      sym_comment,
    ACTIONS(822), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 37,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [16862] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(386), 1,
      sym_comment,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 50,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [16928] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(387), 1,
      sym_comment,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 47,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [16996] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(483), 1,
      sym_concatenating_space,
    STATE(388), 1,
      sym_comment,
    ACTIONS(481), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [17060] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(858), 1,
      sym_regex_flags,
    STATE(389), 1,
      sym_comment,
    ACTIONS(587), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(591), 30,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [17125] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(390), 1,
      sym_comment,
    ACTIONS(579), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [17186] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(391), 1,
      sym_comment,
    ACTIONS(423), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [17247] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(392), 1,
      sym_comment,
    ACTIONS(563), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [17308] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(818), 1,
      anon_sym_in,
    ACTIONS(824), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AMP_AMP,
    ACTIONS(836), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(842), 1,
      anon_sym_COMMA,
    STATE(393), 1,
      sym_comment,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(832), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 5,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(840), 33,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [17389] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(812), 1,
      anon_sym_EQ,
    STATE(394), 1,
      sym_comment,
    ACTIONS(810), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(814), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 20,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 22,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [17460] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(860), 1,
      anon_sym_LT,
    STATE(395), 1,
      sym_comment,
    ACTIONS(469), 20,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(471), 30,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [17527] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(396), 1,
      sym_comment,
    ACTIONS(511), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [17588] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(397), 1,
      sym_comment,
    ACTIONS(575), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [17649] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      anon_sym_LT,
    STATE(398), 1,
      sym_comment,
    ACTIONS(469), 51,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [17712] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(399), 1,
      sym_comment,
    ACTIONS(507), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [17773] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(400), 1,
      sym_comment,
    ACTIONS(441), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [17834] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(401), 1,
      sym_comment,
    ACTIONS(493), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [17895] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(818), 1,
      anon_sym_in,
    ACTIONS(824), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AMP_AMP,
    ACTIONS(836), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(842), 1,
      anon_sym_COMMA,
    STATE(402), 1,
      sym_comment,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(832), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(862), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(854), 30,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [17978] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(818), 1,
      anon_sym_in,
    ACTIONS(824), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AMP_AMP,
    ACTIONS(836), 1,
      anon_sym_PIPE_PIPE,
    STATE(403), 1,
      sym_comment,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(832), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(862), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT_GT,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [18059] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(404), 1,
      sym_comment,
    ACTIONS(485), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [18120] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(405), 1,
      sym_comment,
    ACTIONS(477), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [18181] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(406), 1,
      sym_comment,
    ACTIONS(519), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [18242] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(407), 1,
      sym_comment,
    ACTIONS(489), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [18303] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(408), 1,
      sym_comment,
    ACTIONS(535), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [18364] = 9,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(798), 1,
      anon_sym_EQ,
    ACTIONS(802), 1,
      sym_concatenating_space,
    STATE(409), 1,
      sym_comment,
    ACTIONS(796), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(800), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 20,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 21,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [18437] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(410), 1,
      sym_comment,
    ACTIONS(451), 21,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(453), 31,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [18500] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(411), 1,
      sym_comment,
    ACTIONS(469), 52,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      anon_sym_in,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      anon_sym_LT,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [18561] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(864), 1,
      anon_sym_CARET,
    ACTIONS(866), 1,
      anon_sym_STAR_STAR,
    STATE(412), 1,
      sym_comment,
    ACTIONS(868), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 29,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [18629] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(864), 1,
      anon_sym_CARET,
    ACTIONS(866), 1,
      anon_sym_STAR_STAR,
    ACTIONS(872), 1,
      anon_sym_PIPE,
    ACTIONS(874), 1,
      anon_sym_PIPE_AMP,
    STATE(413), 1,
      sym_comment,
    ACTIONS(870), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(876), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(868), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(878), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 12,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 24,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [18707] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(864), 1,
      anon_sym_CARET,
    ACTIONS(866), 1,
      anon_sym_STAR_STAR,
    STATE(414), 1,
      sym_comment,
    ACTIONS(876), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(868), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 15,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(647), 29,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [18777] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(798), 1,
      anon_sym_EQ,
    ACTIONS(802), 1,
      sym_concatenating_space,
    STATE(415), 1,
      sym_comment,
    ACTIONS(796), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(800), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 20,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 21,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [18847] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(864), 1,
      anon_sym_CARET,
    ACTIONS(866), 1,
      anon_sym_STAR_STAR,
    ACTIONS(872), 1,
      anon_sym_PIPE,
    ACTIONS(874), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(880), 1,
      anon_sym_in,
    ACTIONS(882), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AMP_AMP,
    ACTIONS(888), 1,
      anon_sym_PIPE_PIPE,
    STATE(416), 1,
      sym_comment,
    ACTIONS(870), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(876), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(884), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(868), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(878), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(641), 19,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [18935] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(860), 1,
      anon_sym_LT,
    STATE(417), 1,
      sym_comment,
    ACTIONS(469), 20,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(471), 30,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [18999] = 13,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(864), 1,
      anon_sym_CARET,
    ACTIONS(866), 1,
      anon_sym_STAR_STAR,
    ACTIONS(872), 1,
      anon_sym_PIPE,
    ACTIONS(874), 1,
      anon_sym_PIPE_AMP,
    STATE(418), 1,
      sym_comment,
    ACTIONS(870), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(876), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(884), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(868), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(878), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 12,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 22,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [19079] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(85), 1,
      sym__if_else_separator,
    ACTIONS(768), 1,
      anon_sym_in,
    ACTIONS(774), 1,
      anon_sym_QMARK,
    ACTIONS(784), 1,
      anon_sym_AMP_AMP,
    ACTIONS(786), 1,
      anon_sym_PIPE_PIPE,
    STATE(419), 1,
      sym_comment,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(782), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(816), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(39), 29,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [19161] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(812), 1,
      anon_sym_EQ,
    STATE(420), 1,
      sym_comment,
    ACTIONS(810), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(814), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 20,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 22,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [19229] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(768), 1,
      anon_sym_in,
    ACTIONS(774), 1,
      anon_sym_QMARK,
    ACTIONS(784), 1,
      anon_sym_AMP_AMP,
    ACTIONS(786), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(892), 1,
      sym__if_else_separator,
    STATE(421), 1,
      sym_comment,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(782), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(816), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(890), 29,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [19311] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(864), 1,
      anon_sym_CARET,
    ACTIONS(866), 1,
      anon_sym_STAR_STAR,
    ACTIONS(872), 1,
      anon_sym_PIPE,
    ACTIONS(874), 1,
      anon_sym_PIPE_AMP,
    STATE(422), 1,
      sym_comment,
    ACTIONS(876), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(868), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 14,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 28,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [19385] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(768), 1,
      anon_sym_in,
    ACTIONS(774), 1,
      anon_sym_QMARK,
    ACTIONS(784), 1,
      anon_sym_AMP_AMP,
    ACTIONS(786), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(896), 1,
      sym__if_else_separator,
    STATE(423), 1,
      sym_comment,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(782), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(816), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(894), 29,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [19467] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(768), 1,
      anon_sym_in,
    ACTIONS(774), 1,
      anon_sym_QMARK,
    ACTIONS(784), 1,
      anon_sym_AMP_AMP,
    ACTIONS(786), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(900), 1,
      sym__if_else_separator,
    STATE(424), 1,
      sym_comment,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(782), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(816), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(898), 29,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [19549] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(768), 1,
      anon_sym_in,
    ACTIONS(774), 1,
      anon_sym_QMARK,
    ACTIONS(784), 1,
      anon_sym_AMP_AMP,
    ACTIONS(786), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(904), 1,
      sym__if_else_separator,
    STATE(425), 1,
      sym_comment,
    ACTIONS(776), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(782), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(816), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(778), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(770), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(902), 29,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [19631] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(864), 1,
      anon_sym_CARET,
    ACTIONS(866), 1,
      anon_sym_STAR_STAR,
    STATE(426), 1,
      sym_comment,
    ACTIONS(539), 20,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 29,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [19697] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(864), 1,
      anon_sym_CARET,
    ACTIONS(866), 1,
      anon_sym_STAR_STAR,
    ACTIONS(872), 1,
      anon_sym_PIPE,
    ACTIONS(874), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(880), 1,
      anon_sym_in,
    ACTIONS(882), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AMP_AMP,
    ACTIONS(888), 1,
      anon_sym_PIPE_PIPE,
    STATE(427), 1,
      sym_comment,
    ACTIONS(870), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(876), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(884), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(868), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(878), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(631), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(637), 19,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [19785] = 14,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(864), 1,
      anon_sym_CARET,
    ACTIONS(866), 1,
      anon_sym_STAR_STAR,
    ACTIONS(872), 1,
      anon_sym_PIPE,
    ACTIONS(874), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(880), 1,
      anon_sym_in,
    STATE(428), 1,
      sym_comment,
    ACTIONS(870), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(876), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(884), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(868), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(878), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 22,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [19867] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(864), 1,
      anon_sym_CARET,
    ACTIONS(866), 1,
      anon_sym_STAR_STAR,
    ACTIONS(872), 1,
      anon_sym_PIPE,
    ACTIONS(874), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(880), 1,
      anon_sym_in,
    ACTIONS(886), 1,
      anon_sym_AMP_AMP,
    STATE(429), 1,
      sym_comment,
    ACTIONS(870), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(876), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(884), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(868), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(878), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_EQ,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 21,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [19951] = 27,
    ACTIONS(37), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LPAREN,
    ACTIONS(61), 1,
      anon_sym_getline,
    ACTIONS(69), 1,
      anon_sym_SLASH,
    ACTIONS(75), 1,
      anon_sym_DOLLAR,
    ACTIONS(77), 1,
      anon_sym_AT,
    ACTIONS(79), 1,
      sym_number,
    ACTIONS(81), 1,
      anon_sym_DQUOTE,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(547), 1,
      anon_sym_LPAREN2,
    ACTIONS(561), 1,
      sym__if_else_separator,
    STATE(430), 1,
      sym_comment,
    STATE(522), 1,
      sym_ns_qualified_name,
    STATE(534), 1,
      sym_array_ref,
    STATE(550), 1,
      sym_field_ref,
    STATE(562), 1,
      sym_exp_list,
    STATE(585), 1,
      sym__print_args,
    STATE(700), 1,
      aux_sym_exp_list_repeat1,
    STATE(1178), 1,
      sym_string,
    STATE(1243), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(73), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(71), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1222), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    ACTIONS(543), 10,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
  [20058] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(818), 1,
      anon_sym_in,
    ACTIONS(824), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AMP_AMP,
    ACTIONS(836), 1,
      anon_sym_PIPE_PIPE,
    STATE(431), 1,
      sym_comment,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(832), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(862), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(898), 29,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [20137] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(818), 1,
      anon_sym_in,
    ACTIONS(824), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AMP_AMP,
    ACTIONS(836), 1,
      anon_sym_PIPE_PIPE,
    STATE(432), 1,
      sym_comment,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(832), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(862), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(894), 29,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [20216] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(818), 1,
      anon_sym_in,
    ACTIONS(824), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AMP_AMP,
    ACTIONS(836), 1,
      anon_sym_PIPE_PIPE,
    STATE(433), 1,
      sym_comment,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(832), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(862), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(902), 29,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [20295] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(818), 1,
      anon_sym_in,
    ACTIONS(824), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AMP_AMP,
    ACTIONS(836), 1,
      anon_sym_PIPE_PIPE,
    STATE(434), 1,
      sym_comment,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(832), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(862), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(890), 29,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [20374] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(818), 1,
      anon_sym_in,
    ACTIONS(824), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AMP_AMP,
    ACTIONS(836), 1,
      anon_sym_PIPE_PIPE,
    STATE(435), 1,
      sym_comment,
    ACTIONS(826), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(832), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(862), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(828), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(39), 29,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [20453] = 26,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(87), 1,
      sym_identifier,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      anon_sym_getline,
    ACTIONS(117), 1,
      anon_sym_SLASH,
    ACTIONS(123), 1,
      anon_sym_DOLLAR,
    ACTIONS(125), 1,
      anon_sym_AT,
    ACTIONS(127), 1,
      sym_number,
    ACTIONS(129), 1,
      anon_sym_DQUOTE,
    ACTIONS(599), 1,
      anon_sym_LPAREN2,
    STATE(436), 1,
      sym_comment,
    STATE(532), 1,
      sym_ns_qualified_name,
    STATE(552), 1,
      sym_array_ref,
    STATE(572), 1,
      sym_field_ref,
    STATE(610), 1,
      sym_exp_list,
    STATE(611), 1,
      sym__print_args,
    STATE(697), 1,
      aux_sym_exp_list_repeat1,
    STATE(1232), 1,
      sym_string,
    STATE(1302), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(121), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(119), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    STATE(1248), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    ACTIONS(543), 10,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
  [20557] = 27,
    ACTIONS(43), 1,
      anon_sym_LPAREN,
    ACTIONS(79), 1,
      sym_number,
    ACTIONS(81), 1,
      anon_sym_DQUOTE,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(269), 1,
      anon_sym_getline,
    ACTIONS(275), 1,
      anon_sym_SLASH,
    ACTIONS(281), 1,
      anon_sym_DOLLAR,
    ACTIONS(283), 1,
      anon_sym_AT,
    ACTIONS(547), 1,
      anon_sym_LPAREN2,
    ACTIONS(561), 1,
      sym__if_else_separator,
    STATE(437), 1,
      sym_comment,
    STATE(551), 1,
      sym_ns_qualified_name,
    STATE(562), 1,
      sym_exp_list,
    STATE(576), 1,
      sym_array_ref,
    STATE(585), 1,
      sym__print_args,
    STATE(595), 1,
      sym_field_ref,
    STATE(683), 1,
      aux_sym_exp_list_repeat1,
    STATE(1178), 1,
      sym_string,
    STATE(1326), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(277), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1279), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    ACTIONS(543), 8,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
  [20662] = 26,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(127), 1,
      sym_number,
    ACTIONS(129), 1,
      anon_sym_DQUOTE,
    ACTIONS(383), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_getline,
    ACTIONS(399), 1,
      anon_sym_SLASH,
    ACTIONS(405), 1,
      anon_sym_DOLLAR,
    ACTIONS(407), 1,
      anon_sym_AT,
    ACTIONS(599), 1,
      anon_sym_LPAREN2,
    STATE(438), 1,
      sym_comment,
    STATE(587), 1,
      sym_ns_qualified_name,
    STATE(610), 1,
      sym_exp_list,
    STATE(611), 1,
      sym__print_args,
    STATE(624), 1,
      sym_array_ref,
    STATE(669), 1,
      sym_field_ref,
    STATE(684), 1,
      aux_sym_exp_list_repeat1,
    STATE(1232), 1,
      sym_string,
    STATE(1359), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(401), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1320), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    ACTIONS(543), 8,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
  [20764] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(906), 1,
      anon_sym_LBRACK,
    STATE(439), 1,
      sym_comment,
    ACTIONS(441), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(443), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [20825] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(908), 1,
      sym_identifier,
    STATE(440), 1,
      sym_comment,
    STATE(460), 1,
      sym_ns_qualified_name,
    STATE(1803), 1,
      sym_namespace,
    ACTIONS(499), 16,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(501), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [20888] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LT,
    STATE(441), 1,
      sym_comment,
    STATE(477), 1,
      sym_ns_qualified_name,
    STATE(1803), 1,
      sym_namespace,
    ACTIONS(499), 15,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(501), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [20953] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(914), 1,
      sym_identifier,
    STATE(442), 1,
      sym_comment,
    STATE(495), 1,
      sym_ns_qualified_name,
    STATE(1725), 1,
      sym_namespace,
    ACTIONS(499), 16,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(501), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [21015] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(916), 1,
      anon_sym_LT,
    STATE(443), 1,
      sym_comment,
    ACTIONS(469), 16,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(471), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [21075] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    STATE(444), 1,
      sym_comment,
    ACTIONS(441), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(443), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [21135] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(445), 1,
      sym_comment,
    ACTIONS(473), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(475), 28,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [21191] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(446), 1,
      sym_comment,
    ACTIONS(451), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(453), 28,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [21247] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    STATE(447), 1,
      sym_comment,
    ACTIONS(469), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(471), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [21305] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(920), 1,
      sym_regex_flags,
    STATE(448), 1,
      sym_comment,
    ACTIONS(587), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(591), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [21363] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(449), 1,
      sym_comment,
    ACTIONS(473), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(475), 28,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [21419] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(906), 1,
      anon_sym_LBRACK,
    STATE(450), 1,
      sym_comment,
    ACTIONS(441), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(443), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [21477] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(922), 1,
      sym_identifier,
    ACTIONS(924), 1,
      anon_sym_LT,
    STATE(451), 1,
      sym_comment,
    STATE(502), 1,
      sym_ns_qualified_name,
    STATE(1725), 1,
      sym_namespace,
    ACTIONS(499), 15,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(501), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [21541] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(452), 1,
      sym_comment,
    ACTIONS(451), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(453), 28,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_LBRACK,
      sym_number,
      anon_sym_DQUOTE,
  [21597] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(928), 1,
      anon_sym_STAR,
    STATE(453), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(930), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(932), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(645), 14,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(647), 23,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [21660] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(454), 1,
      sym_comment,
    ACTIONS(507), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(509), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [21715] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    STATE(455), 1,
      sym_comment,
    ACTIONS(441), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(443), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [21772] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(934), 1,
      anon_sym_LT,
    STATE(456), 1,
      sym_comment,
    ACTIONS(469), 16,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(471), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [21831] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(936), 1,
      anon_sym_PIPE,
    ACTIONS(938), 1,
      anon_sym_PIPE_AMP,
    STATE(457), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(930), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(932), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(539), 13,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 22,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [21898] = 13,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(936), 1,
      anon_sym_PIPE,
    ACTIONS(938), 1,
      anon_sym_PIPE_AMP,
    STATE(458), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(930), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(932), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(940), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(944), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(942), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 16,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [21971] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(459), 1,
      sym_comment,
    ACTIONS(539), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22026] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(460), 1,
      sym_comment,
    ACTIONS(469), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(471), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22081] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(461), 1,
      sym_comment,
    ACTIONS(519), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(521), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22136] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(462), 1,
      sym_comment,
    ACTIONS(579), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(581), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22191] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(463), 1,
      sym_comment,
    ACTIONS(511), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(513), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22246] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(464), 1,
      sym_comment,
    ACTIONS(423), 7,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(435), 10,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(439), 13,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
    ACTIONS(433), 14,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [22305] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(936), 1,
      anon_sym_PIPE,
    ACTIONS(938), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(946), 1,
      anon_sym_in,
    ACTIONS(948), 1,
      anon_sym_AMP_AMP,
    STATE(465), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(930), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(932), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(940), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(944), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(942), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 10,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 15,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22382] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(466), 1,
      sym_comment,
    ACTIONS(575), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(577), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22437] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(467), 1,
      sym_comment,
    ACTIONS(423), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22492] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(468), 1,
      sym_comment,
    ACTIONS(563), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(565), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22547] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(469), 1,
      sym_comment,
    ACTIONS(423), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22602] = 14,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(936), 1,
      anon_sym_PIPE,
    ACTIONS(938), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(946), 1,
      anon_sym_in,
    STATE(470), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(930), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(932), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(940), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(944), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(942), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 10,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 16,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22677] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(802), 1,
      sym_concatenating_space,
    STATE(471), 1,
      sym_comment,
    ACTIONS(423), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22734] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(472), 1,
      sym_comment,
    ACTIONS(531), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(533), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22789] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(936), 1,
      anon_sym_PIPE,
    ACTIONS(938), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(946), 1,
      anon_sym_in,
    ACTIONS(948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(950), 1,
      anon_sym_QMARK,
    ACTIONS(952), 1,
      anon_sym_PIPE_PIPE,
    STATE(473), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(930), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(932), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(940), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(944), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(942), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(631), 10,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(637), 13,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22870] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(936), 1,
      anon_sym_PIPE,
    ACTIONS(938), 1,
      anon_sym_PIPE_AMP,
    STATE(474), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(930), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(932), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(940), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(942), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 18,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [22941] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(936), 1,
      anon_sym_PIPE,
    ACTIONS(938), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(946), 1,
      anon_sym_in,
    ACTIONS(948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(950), 1,
      anon_sym_QMARK,
    ACTIONS(952), 1,
      anon_sym_PIPE_PIPE,
    STATE(475), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(930), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(932), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(940), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(944), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(942), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 10,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(641), 13,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23022] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(928), 1,
      anon_sym_STAR,
    STATE(476), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(930), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 16,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 23,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23083] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(916), 1,
      anon_sym_LT,
    STATE(477), 1,
      sym_comment,
    ACTIONS(469), 16,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(471), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23140] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(478), 1,
      sym_comment,
    ACTIONS(503), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(505), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23195] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(479), 1,
      sym_comment,
    ACTIONS(515), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(517), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23250] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(480), 1,
      sym_comment,
    ACTIONS(441), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(443), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23305] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    STATE(481), 1,
      sym_comment,
    ACTIONS(469), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(471), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23362] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(482), 1,
      sym_comment,
    ACTIONS(485), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(487), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23417] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(483), 1,
      sym_comment,
    ACTIONS(477), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(479), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23472] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(484), 1,
      sym_comment,
    ACTIONS(489), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(491), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23527] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(485), 1,
      sym_comment,
    ACTIONS(535), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(537), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23582] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(497), 1,
      sym_identifier,
    STATE(115), 1,
      sym_ns_qualified_name,
    STATE(486), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(501), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(499), 39,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [23643] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(487), 1,
      sym_comment,
    ACTIONS(519), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(521), 27,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23698] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(488), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(541), 25,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23755] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(489), 1,
      sym_comment,
    ACTIONS(481), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(483), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23810] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(490), 1,
      sym_comment,
    ACTIONS(493), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(495), 27,
      sym_concatenating_space,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23865] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(954), 1,
      sym_regex_flags,
    STATE(491), 1,
      sym_comment,
    ACTIONS(587), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(591), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [23922] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(956), 1,
      anon_sym_LPAREN2,
    STATE(492), 1,
      sym_comment,
    ACTIONS(437), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(439), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(461), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(435), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
    ACTIONS(423), 21,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [23989] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(956), 1,
      anon_sym_LPAREN2,
    STATE(493), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(958), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(960), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24053] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(494), 1,
      sym_comment,
    ACTIONS(575), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(577), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [24107] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(495), 1,
      sym_comment,
    ACTIONS(469), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(471), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [24161] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(496), 1,
      sym_comment,
    ACTIONS(485), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(487), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [24215] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(497), 1,
      sym_comment,
    ACTIONS(507), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(509), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [24269] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(439), 1,
      sym_concatenating_space,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(962), 1,
      anon_sym_LPAREN2,
    STATE(498), 1,
      sym_comment,
    ACTIONS(437), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(461), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(435), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
    ACTIONS(423), 21,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24335] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(499), 1,
      sym_comment,
    ACTIONS(493), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(495), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [24389] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(500), 1,
      sym_comment,
    ACTIONS(441), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(443), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [24443] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(501), 1,
      sym_comment,
    ACTIONS(535), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(537), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [24497] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(934), 1,
      anon_sym_LT,
    STATE(502), 1,
      sym_comment,
    ACTIONS(469), 16,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(471), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [24553] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(503), 1,
      sym_comment,
    ACTIONS(423), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(433), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [24607] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    ACTIONS(956), 1,
      anon_sym_LPAREN2,
    STATE(504), 1,
      sym_comment,
    ACTIONS(437), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(439), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(461), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(435), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
    ACTIONS(423), 21,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24671] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(505), 1,
      sym_comment,
    ACTIONS(511), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(513), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [24725] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym_concatenating_space,
    ACTIONS(593), 1,
      sym_identifier,
    STATE(167), 1,
      sym_ns_qualified_name,
    STATE(506), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(499), 39,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [24785] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(507), 1,
      sym_comment,
    ACTIONS(579), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(581), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [24839] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(964), 1,
      sym_identifier,
    ACTIONS(966), 1,
      anon_sym_LT,
    STATE(508), 1,
      sym_comment,
    STATE(544), 1,
      sym_ns_qualified_name,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(501), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(499), 37,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [24901] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(509), 1,
      sym_comment,
    ACTIONS(489), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(491), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [24955] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(946), 1,
      anon_sym_in,
    ACTIONS(948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(950), 1,
      anon_sym_QMARK,
    ACTIONS(952), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(968), 1,
      anon_sym_PIPE,
    ACTIONS(970), 1,
      anon_sym_PIPE_AMP,
    STATE(510), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(930), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(932), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(940), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(944), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(942), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 10,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(641), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [25035] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(511), 1,
      sym_comment,
    ACTIONS(477), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(479), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [25089] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(433), 1,
      sym__if_else_separator,
    ACTIONS(956), 1,
      anon_sym_LPAREN2,
    ACTIONS(976), 1,
      sym_concatenating_space,
    STATE(512), 1,
      sym_comment,
    ACTIONS(972), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(974), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25155] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(513), 1,
      sym_comment,
    ACTIONS(563), 17,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_in,
      anon_sym_getline,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(565), 26,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [25209] = 18,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(946), 1,
      anon_sym_in,
    ACTIONS(948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(950), 1,
      anon_sym_QMARK,
    ACTIONS(952), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(968), 1,
      anon_sym_PIPE,
    ACTIONS(970), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(982), 1,
      anon_sym_COMMA,
    STATE(514), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(930), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(932), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(940), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(944), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(942), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(980), 10,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(978), 11,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [25291] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym_concatenating_space,
    ACTIONS(984), 1,
      sym_identifier,
    ACTIONS(986), 1,
      anon_sym_LT,
    STATE(515), 1,
      sym_comment,
    STATE(588), 1,
      sym_ns_qualified_name,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(499), 37,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [25352] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    ACTIONS(956), 1,
      anon_sym_LPAREN2,
    STATE(516), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(958), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(960), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25413] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(439), 1,
      sym_concatenating_space,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(962), 1,
      anon_sym_LPAREN2,
    STATE(517), 1,
      sym_comment,
    ACTIONS(437), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(461), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(435), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
    ACTIONS(423), 21,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25476] = 23,
    ACTIONS(37), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LPAREN,
    ACTIONS(61), 1,
      anon_sym_getline,
    ACTIONS(69), 1,
      anon_sym_SLASH,
    ACTIONS(75), 1,
      anon_sym_DOLLAR,
    ACTIONS(77), 1,
      anon_sym_AT,
    ACTIONS(79), 1,
      sym_number,
    ACTIONS(81), 1,
      anon_sym_DQUOTE,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(709), 1,
      sym__if_else_separator,
    STATE(518), 1,
      sym_comment,
    STATE(522), 1,
      sym_ns_qualified_name,
    STATE(534), 1,
      sym_array_ref,
    STATE(550), 1,
      sym_field_ref,
    STATE(1178), 1,
      sym_string,
    STATE(1317), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(73), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(71), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(707), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1222), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [25567] = 23,
    ACTIONS(37), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LPAREN,
    ACTIONS(61), 1,
      anon_sym_getline,
    ACTIONS(69), 1,
      anon_sym_SLASH,
    ACTIONS(75), 1,
      anon_sym_DOLLAR,
    ACTIONS(77), 1,
      anon_sym_AT,
    ACTIONS(79), 1,
      sym_number,
    ACTIONS(81), 1,
      anon_sym_DQUOTE,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(705), 1,
      sym__if_else_separator,
    STATE(519), 1,
      sym_comment,
    STATE(522), 1,
      sym_ns_qualified_name,
    STATE(534), 1,
      sym_array_ref,
    STATE(550), 1,
      sym_field_ref,
    STATE(1178), 1,
      sym_string,
    STATE(1318), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(73), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(71), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(703), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1222), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [25658] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(946), 1,
      anon_sym_in,
    ACTIONS(948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(950), 1,
      anon_sym_QMARK,
    ACTIONS(952), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(968), 1,
      anon_sym_PIPE,
    ACTIONS(970), 1,
      anon_sym_PIPE_AMP,
    STATE(520), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(930), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(932), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(940), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(944), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(942), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(990), 10,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_BANG,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(988), 11,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [25737] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(433), 1,
      sym_concatenating_space,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(962), 1,
      anon_sym_LPAREN2,
    STATE(521), 1,
      sym_comment,
    ACTIONS(992), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(994), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25800] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    ACTIONS(433), 1,
      sym__if_else_separator,
    ACTIONS(956), 1,
      anon_sym_LPAREN2,
    ACTIONS(976), 1,
      sym_concatenating_space,
    STATE(522), 1,
      sym_comment,
    ACTIONS(972), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(974), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25863] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(962), 1,
      anon_sym_LPAREN2,
    ACTIONS(1000), 1,
      sym_concatenating_space,
    STATE(523), 1,
      sym_comment,
    ACTIONS(996), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(998), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25926] = 22,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(87), 1,
      sym_identifier,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      anon_sym_getline,
    ACTIONS(117), 1,
      anon_sym_SLASH,
    ACTIONS(123), 1,
      anon_sym_DOLLAR,
    ACTIONS(125), 1,
      anon_sym_AT,
    ACTIONS(127), 1,
      sym_number,
    ACTIONS(129), 1,
      anon_sym_DQUOTE,
    STATE(524), 1,
      sym_comment,
    STATE(532), 1,
      sym_ns_qualified_name,
    STATE(552), 1,
      sym_array_ref,
    STATE(572), 1,
      sym_field_ref,
    STATE(1232), 1,
      sym_string,
    STATE(1360), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(121), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(119), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(703), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    STATE(1248), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [26014] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(589), 1,
      sym_regex_flags,
    STATE(525), 1,
      sym_comment,
    ACTIONS(591), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(587), 38,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [26068] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(962), 1,
      anon_sym_LPAREN2,
    STATE(526), 1,
      sym_comment,
    ACTIONS(992), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(994), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26128] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(956), 1,
      anon_sym_LPAREN2,
    STATE(527), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(958), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1002), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26190] = 22,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(87), 1,
      sym_identifier,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(109), 1,
      anon_sym_getline,
    ACTIONS(117), 1,
      anon_sym_SLASH,
    ACTIONS(123), 1,
      anon_sym_DOLLAR,
    ACTIONS(125), 1,
      anon_sym_AT,
    ACTIONS(127), 1,
      sym_number,
    ACTIONS(129), 1,
      anon_sym_DQUOTE,
    STATE(528), 1,
      sym_comment,
    STATE(532), 1,
      sym_ns_qualified_name,
    STATE(552), 1,
      sym_array_ref,
    STATE(572), 1,
      sym_field_ref,
    STATE(1232), 1,
      sym_string,
    STATE(1347), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(121), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(119), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(707), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    STATE(1248), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [26278] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    STATE(529), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(958), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(960), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26336] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1004), 1,
      anon_sym_LT,
    STATE(530), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 37,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [26392] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(433), 1,
      sym__if_else_separator,
    ACTIONS(956), 1,
      anon_sym_LPAREN2,
    ACTIONS(1008), 1,
      sym_concatenating_space,
    STATE(531), 1,
      sym_comment,
    ACTIONS(972), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1006), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26456] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(962), 1,
      anon_sym_LPAREN2,
    ACTIONS(1000), 1,
      sym_concatenating_space,
    STATE(532), 1,
      sym_comment,
    ACTIONS(996), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(998), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26516] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1010), 1,
      sym_identifier,
    ACTIONS(1012), 1,
      anon_sym_LT,
    STATE(533), 1,
      sym_comment,
    STATE(603), 1,
      sym_ns_qualified_name,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(501), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(499), 35,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [26576] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    ACTIONS(433), 1,
      sym__if_else_separator,
    ACTIONS(976), 1,
      sym_concatenating_space,
    STATE(534), 1,
      sym_comment,
    ACTIONS(972), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(974), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26636] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(471), 1,
      sym_concatenating_space,
    ACTIONS(1014), 1,
      anon_sym_LT,
    STATE(535), 1,
      sym_comment,
    ACTIONS(469), 37,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [26691] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    ACTIONS(956), 1,
      anon_sym_LPAREN2,
    STATE(536), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(958), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1002), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26750] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(537), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(958), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(960), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26805] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(538), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1020), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1024), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1022), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1016), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 23,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [26866] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1026), 1,
      anon_sym_in,
    ACTIONS(1028), 1,
      anon_sym_QMARK,
    ACTIONS(1032), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1034), 1,
      anon_sym_PIPE_PIPE,
    STATE(539), 1,
      sym_comment,
    ACTIONS(641), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1020), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1024), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1030), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1022), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1016), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [26937] = 23,
    ACTIONS(43), 1,
      anon_sym_LPAREN,
    ACTIONS(79), 1,
      sym_number,
    ACTIONS(81), 1,
      anon_sym_DQUOTE,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(269), 1,
      anon_sym_getline,
    ACTIONS(275), 1,
      anon_sym_SLASH,
    ACTIONS(281), 1,
      anon_sym_DOLLAR,
    ACTIONS(283), 1,
      anon_sym_AT,
    ACTIONS(709), 1,
      sym__if_else_separator,
    STATE(540), 1,
      sym_comment,
    STATE(551), 1,
      sym_ns_qualified_name,
    STATE(576), 1,
      sym_array_ref,
    STATE(595), 1,
      sym_field_ref,
    STATE(1178), 1,
      sym_string,
    STATE(1390), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(277), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(707), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1279), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [27026] = 23,
    ACTIONS(43), 1,
      anon_sym_LPAREN,
    ACTIONS(79), 1,
      sym_number,
    ACTIONS(81), 1,
      anon_sym_DQUOTE,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(269), 1,
      anon_sym_getline,
    ACTIONS(275), 1,
      anon_sym_SLASH,
    ACTIONS(281), 1,
      anon_sym_DOLLAR,
    ACTIONS(283), 1,
      anon_sym_AT,
    ACTIONS(705), 1,
      sym__if_else_separator,
    STATE(541), 1,
      sym_comment,
    STATE(551), 1,
      sym_ns_qualified_name,
    STATE(576), 1,
      sym_array_ref,
    STATE(595), 1,
      sym_field_ref,
    STATE(1178), 1,
      sym_string,
    STATE(1384), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(277), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(703), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1279), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [27115] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(542), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1020), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1022), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 33,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [27170] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(591), 1,
      sym_concatenating_space,
    ACTIONS(643), 1,
      sym_regex_flags,
    STATE(543), 1,
      sym_comment,
    ACTIONS(587), 38,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [27223] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1004), 1,
      anon_sym_LT,
    STATE(544), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 37,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [27276] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(545), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1020), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 36,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [27329] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym_concatenating_space,
    ACTIONS(1036), 1,
      sym_identifier,
    ACTIONS(1038), 1,
      anon_sym_LT,
    STATE(546), 1,
      sym_comment,
    STATE(667), 1,
      sym_ns_qualified_name,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(499), 35,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [27388] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(547), 1,
      sym_comment,
    ACTIONS(647), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1020), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1024), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1022), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [27445] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(548), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1020), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1024), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1022), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [27504] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(962), 1,
      anon_sym_LPAREN2,
    ACTIONS(1042), 1,
      sym_concatenating_space,
    STATE(549), 1,
      sym_comment,
    ACTIONS(996), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1040), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27565] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym__if_else_separator,
    ACTIONS(976), 1,
      sym_concatenating_space,
    STATE(550), 1,
      sym_comment,
    ACTIONS(972), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(974), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27622] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    ACTIONS(433), 1,
      sym__if_else_separator,
    ACTIONS(956), 1,
      anon_sym_LPAREN2,
    ACTIONS(1008), 1,
      sym_concatenating_space,
    STATE(551), 1,
      sym_comment,
    ACTIONS(972), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1006), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27683] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      sym_concatenating_space,
    STATE(552), 1,
      sym_comment,
    ACTIONS(996), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(998), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27740] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(433), 1,
      sym_concatenating_space,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(962), 1,
      anon_sym_LPAREN2,
    STATE(553), 1,
      sym_comment,
    ACTIONS(992), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1044), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27801] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    STATE(554), 1,
      sym_comment,
    ACTIONS(992), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(994), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27858] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1026), 1,
      anon_sym_in,
    ACTIONS(1028), 1,
      anon_sym_QMARK,
    ACTIONS(1032), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1034), 1,
      anon_sym_PIPE_PIPE,
    STATE(555), 1,
      sym_comment,
    ACTIONS(637), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1020), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1024), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1030), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1022), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1016), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(631), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [27929] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(556), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1020), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1024), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1030), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1022), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1016), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 21,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [27992] = 12,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1026), 1,
      anon_sym_in,
    ACTIONS(1032), 1,
      anon_sym_AMP_AMP,
    STATE(557), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1020), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1024), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1030), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1022), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1016), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 19,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [28059] = 11,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1026), 1,
      anon_sym_in,
    STATE(558), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1020), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1024), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1030), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1022), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1016), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 20,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [28124] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(589), 1,
      sym_regex_flags,
    STATE(559), 1,
      sym_comment,
    ACTIONS(591), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(587), 36,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [28176] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(560), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1050), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1054), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1056), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1052), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1046), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 21,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [28238] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(962), 1,
      anon_sym_LPAREN2,
    STATE(561), 1,
      sym_comment,
    ACTIONS(992), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1044), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28296] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      sym__if_else_separator,
    STATE(562), 1,
      sym_comment,
    ACTIONS(840), 38,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [28346] = 22,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(127), 1,
      sym_number,
    ACTIONS(129), 1,
      anon_sym_DQUOTE,
    ACTIONS(383), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_getline,
    ACTIONS(399), 1,
      anon_sym_SLASH,
    ACTIONS(405), 1,
      anon_sym_DOLLAR,
    ACTIONS(407), 1,
      anon_sym_AT,
    STATE(563), 1,
      sym_comment,
    STATE(587), 1,
      sym_ns_qualified_name,
    STATE(624), 1,
      sym_array_ref,
    STATE(669), 1,
      sym_field_ref,
    STATE(1232), 1,
      sym_string,
    STATE(1410), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(401), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(707), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1320), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [28432] = 12,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    ACTIONS(1058), 1,
      anon_sym_in,
    ACTIONS(1060), 1,
      anon_sym_AMP_AMP,
    STATE(564), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1050), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1054), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1056), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1052), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1046), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 19,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [28498] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1064), 1,
      sym__if_else_separator,
    STATE(565), 1,
      sym_comment,
    ACTIONS(1062), 38,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [28548] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    STATE(566), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(958), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1002), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28604] = 11,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    ACTIONS(1058), 1,
      anon_sym_in,
    STATE(567), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1050), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1054), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1056), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1052), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1046), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 20,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [28668] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(568), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1050), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1054), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1046), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 23,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [28728] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(838), 1,
      sym_identifier,
    STATE(274), 1,
      sym_ns_qualified_name,
    STATE(569), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(499), 11,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ,
    ACTIONS(501), 25,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [28784] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(641), 1,
      sym_concatenating_space,
    ACTIONS(1058), 1,
      anon_sym_in,
    ACTIONS(1060), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1066), 1,
      anon_sym_QMARK,
    ACTIONS(1068), 1,
      anon_sym_PIPE_PIPE,
    STATE(570), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1050), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1054), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1056), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1052), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1046), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [28854] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(571), 1,
      sym_comment,
    ACTIONS(1050), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1052), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 33,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [28908] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1000), 1,
      sym_concatenating_space,
    STATE(572), 1,
      sym_comment,
    ACTIONS(996), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(998), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28962] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1074), 1,
      anon_sym_EQ,
    STATE(573), 1,
      sym_comment,
    ACTIONS(1072), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1076), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 10,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 17,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [29024] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(637), 1,
      sym_concatenating_space,
    ACTIONS(1058), 1,
      anon_sym_in,
    ACTIONS(1060), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1066), 1,
      anon_sym_QMARK,
    ACTIONS(1068), 1,
      anon_sym_PIPE_PIPE,
    STATE(574), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1050), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1054), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1056), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1052), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1046), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(631), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [29094] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1080), 1,
      sym__if_else_separator,
    STATE(575), 1,
      sym_comment,
    ACTIONS(1078), 38,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [29144] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(429), 1,
      anon_sym_LBRACK,
    ACTIONS(433), 1,
      sym__if_else_separator,
    ACTIONS(1008), 1,
      sym_concatenating_space,
    STATE(576), 1,
      sym_comment,
    ACTIONS(972), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1006), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29202] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1084), 1,
      sym__if_else_separator,
    STATE(577), 1,
      sym_comment,
    ACTIONS(1082), 38,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [29252] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(578), 1,
      sym_comment,
    ACTIONS(1050), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 36,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [29304] = 22,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(127), 1,
      sym_number,
    ACTIONS(129), 1,
      anon_sym_DQUOTE,
    ACTIONS(383), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_getline,
    ACTIONS(399), 1,
      anon_sym_SLASH,
    ACTIONS(405), 1,
      anon_sym_DOLLAR,
    ACTIONS(407), 1,
      anon_sym_AT,
    STATE(579), 1,
      sym_comment,
    STATE(587), 1,
      sym_ns_qualified_name,
    STATE(624), 1,
      sym_array_ref,
    STATE(669), 1,
      sym_field_ref,
    STATE(1232), 1,
      sym_string,
    STATE(1409), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    ACTIONS(401), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(703), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1320), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [29390] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1086), 1,
      anon_sym_LT,
    STATE(580), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 35,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [29444] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    STATE(581), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 10,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [29508] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(647), 1,
      sym_concatenating_space,
    STATE(582), 1,
      sym_comment,
    ACTIONS(1050), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1054), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [29564] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(583), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1050), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1054), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [29622] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1090), 1,
      sym_identifier,
    ACTIONS(1092), 1,
      anon_sym_LT,
    STATE(584), 1,
      sym_comment,
    STATE(676), 1,
      sym_ns_qualified_name,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(499), 10,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ,
    ACTIONS(501), 25,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [29680] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1096), 1,
      sym__if_else_separator,
    STATE(585), 1,
      sym_comment,
    ACTIONS(1094), 38,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [29730] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(435), 1,
      anon_sym_COLON,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    STATE(586), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(439), 5,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_in,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29796] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(962), 1,
      anon_sym_LPAREN2,
    ACTIONS(1042), 1,
      sym_concatenating_space,
    STATE(587), 1,
      sym_comment,
    ACTIONS(996), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1040), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29854] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym_concatenating_space,
    ACTIONS(1014), 1,
      anon_sym_LT,
    STATE(588), 1,
      sym_comment,
    ACTIONS(469), 37,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [29906] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    STATE(589), 1,
      sym_comment,
    ACTIONS(992), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(994), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29960] = 25,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(383), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_getline,
    ACTIONS(413), 1,
      anon_sym_SLASH,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_AT,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    STATE(587), 1,
      sym_ns_qualified_name,
    STATE(590), 1,
      sym_comment,
    STATE(605), 1,
      sym__print_args,
    STATE(610), 1,
      sym_exp_list,
    STATE(624), 1,
      sym_array_ref,
    STATE(669), 1,
      sym_field_ref,
    STATE(684), 1,
      aux_sym_exp_list_repeat1,
    STATE(1232), 1,
      sym_string,
    STATE(1359), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(417), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1320), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [30051] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    STATE(591), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(439), 6,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_in,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30112] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1100), 1,
      anon_sym_in,
    ACTIONS(1104), 1,
      anon_sym_QMARK,
    ACTIONS(1114), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1116), 1,
      anon_sym_PIPE_PIPE,
    STATE(592), 1,
      sym_comment,
    ACTIONS(637), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1106), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1112), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1108), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1102), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(631), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [30181] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(593), 1,
      sym_comment,
    ACTIONS(1082), 38,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [30228] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    STATE(594), 1,
      sym_comment,
    ACTIONS(992), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1044), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30283] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym__if_else_separator,
    ACTIONS(1008), 1,
      sym_concatenating_space,
    STATE(595), 1,
      sym_comment,
    ACTIONS(972), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1006), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30338] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1100), 1,
      anon_sym_in,
    ACTIONS(1104), 1,
      anon_sym_QMARK,
    ACTIONS(1114), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1116), 1,
      anon_sym_PIPE_PIPE,
    STATE(596), 1,
      sym_comment,
    ACTIONS(641), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1106), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1112), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1108), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1102), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [30407] = 25,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(597), 1,
      sym_comment,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1425), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1885), 1,
      sym__print_args,
    STATE(1894), 1,
      sym_exp_list,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [30498] = 25,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(598), 1,
      sym_comment,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1436), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1884), 1,
      sym__print_args,
    STATE(1894), 1,
      sym_exp_list,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [30589] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(599), 1,
      sym_comment,
    ACTIONS(1078), 38,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [30636] = 25,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(87), 1,
      sym_identifier,
    ACTIONS(109), 1,
      anon_sym_getline,
    ACTIONS(365), 1,
      anon_sym_SLASH,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(373), 1,
      anon_sym_AT,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    STATE(532), 1,
      sym_ns_qualified_name,
    STATE(552), 1,
      sym_array_ref,
    STATE(572), 1,
      sym_field_ref,
    STATE(600), 1,
      sym_comment,
    STATE(605), 1,
      sym__print_args,
    STATE(610), 1,
      sym_exp_list,
    STATE(697), 1,
      aux_sym_exp_list_repeat1,
    STATE(1232), 1,
      sym_string,
    STATE(1302), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(369), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1248), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [30727] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    STATE(601), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [30788] = 25,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(37), 1,
      sym_identifier,
    ACTIONS(61), 1,
      anon_sym_getline,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(311), 1,
      anon_sym_SLASH,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(319), 1,
      anon_sym_AT,
    ACTIONS(1140), 1,
      anon_sym_LPAREN,
    STATE(522), 1,
      sym_ns_qualified_name,
    STATE(534), 1,
      sym_array_ref,
    STATE(550), 1,
      sym_field_ref,
    STATE(562), 1,
      sym_exp_list,
    STATE(565), 1,
      sym__print_args,
    STATE(602), 1,
      sym_comment,
    STATE(700), 1,
      aux_sym_exp_list_repeat1,
    STATE(1178), 1,
      sym_string,
    STATE(1243), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(315), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1222), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [30879] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1086), 1,
      anon_sym_LT,
    STATE(603), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 35,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [30930] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(604), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(958), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1002), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30983] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(605), 1,
      sym_comment,
    ACTIONS(1062), 38,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [31030] = 9,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1074), 1,
      anon_sym_EQ,
    STATE(606), 1,
      sym_comment,
    ACTIONS(1072), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1076), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 18,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [31089] = 25,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(607), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1425), 1,
      sym__exp,
    STATE(1722), 1,
      sym__print_args,
    STATE(1853), 1,
      sym_namespace,
    STATE(1894), 1,
      sym_exp_list,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [31180] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(471), 1,
      sym_concatenating_space,
    ACTIONS(1142), 1,
      anon_sym_LT,
    STATE(608), 1,
      sym_comment,
    ACTIONS(469), 35,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [31233] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(609), 1,
      sym_comment,
    ACTIONS(647), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1106), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1108), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [31288] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(610), 1,
      sym_comment,
    ACTIONS(840), 38,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [31335] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(611), 1,
      sym_comment,
    ACTIONS(1094), 38,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [31382] = 12,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1100), 1,
      anon_sym_in,
    ACTIONS(1114), 1,
      anon_sym_AMP_AMP,
    STATE(612), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1106), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1112), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1108), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1102), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [31447] = 25,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(131), 1,
      sym_identifier,
    ACTIONS(149), 1,
      anon_sym_getline,
    ACTIONS(155), 1,
      anon_sym_SLASH,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(165), 1,
      anon_sym_AT,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    STATE(182), 1,
      sym_ns_qualified_name,
    STATE(203), 1,
      sym_array_ref,
    STATE(208), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(393), 1,
      sym__exp,
    STATE(605), 1,
      sym__print_args,
    STATE(610), 1,
      sym_exp_list,
    STATE(613), 1,
      sym_comment,
    STATE(685), 1,
      aux_sym_exp_list_repeat1,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(161), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(392), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(381), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(391), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [31538] = 25,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(614), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1436), 1,
      sym__exp,
    STATE(1721), 1,
      sym__print_args,
    STATE(1853), 1,
      sym_namespace,
    STATE(1894), 1,
      sym_exp_list,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [31629] = 25,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(321), 1,
      sym_identifier,
    ACTIONS(337), 1,
      anon_sym_getline,
    ACTIONS(343), 1,
      anon_sym_SLASH,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(353), 1,
      anon_sym_AT,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1140), 1,
      anon_sym_LPAREN,
    STATE(145), 1,
      sym_ns_qualified_name,
    STATE(168), 1,
      sym_array_ref,
    STATE(199), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(369), 1,
      sym__exp,
    STATE(562), 1,
      sym_exp_list,
    STATE(565), 1,
      sym__print_args,
    STATE(615), 1,
      sym_comment,
    STATE(710), 1,
      aux_sym_exp_list_repeat1,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(349), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(354), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(286), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(353), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [31720] = 11,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1100), 1,
      anon_sym_in,
    STATE(616), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1106), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1112), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1108), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1102), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 18,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [31783] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(617), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1106), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1108), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1102), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 21,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [31842] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(618), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1106), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1108), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [31895] = 25,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(269), 1,
      anon_sym_getline,
    ACTIONS(293), 1,
      anon_sym_SLASH,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(301), 1,
      anon_sym_AT,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1140), 1,
      anon_sym_LPAREN,
    STATE(551), 1,
      sym_ns_qualified_name,
    STATE(562), 1,
      sym_exp_list,
    STATE(565), 1,
      sym__print_args,
    STATE(576), 1,
      sym_array_ref,
    STATE(595), 1,
      sym_field_ref,
    STATE(619), 1,
      sym_comment,
    STATE(683), 1,
      aux_sym_exp_list_repeat1,
    STATE(1178), 1,
      sym_string,
    STATE(1326), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(297), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1279), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [31986] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(591), 1,
      sym_concatenating_space,
    ACTIONS(643), 1,
      sym_regex_flags,
    STATE(620), 1,
      sym_comment,
    ACTIONS(587), 36,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [32037] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(621), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1106), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 34,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [32088] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(622), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1106), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1108), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [32145] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(623), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1018), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1106), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1112), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1108), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1102), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 19,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [32206] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(447), 1,
      anon_sym_LBRACK,
    ACTIONS(1042), 1,
      sym_concatenating_space,
    STATE(624), 1,
      sym_comment,
    ACTIONS(996), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1040), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32261] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1144), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(625), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1839), 1,
      sym_args,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [32349] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(626), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1428), 1,
      sym__exp,
    STATE(1834), 1,
      sym_exp_list,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [32437] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(627), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1435), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1857), 1,
      sym_exp_list,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [32525] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(628), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1434), 1,
      sym__exp,
    STATE(1844), 1,
      sym_exp_list,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [32613] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    STATE(629), 1,
      sym_comment,
    ACTIONS(992), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1044), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32665] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(630), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1432), 1,
      sym__exp,
    STATE(1838), 1,
      sym_exp_list,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [32753] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(631), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1437), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1861), 1,
      sym_exp_list,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [32841] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(632), 1,
      sym_comment,
    ACTIONS(1146), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 34,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [32891] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(633), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1431), 1,
      sym__exp,
    STATE(1715), 1,
      sym_exp_list,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [32979] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(634), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1427), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1866), 1,
      sym_exp_list,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [33067] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(635), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1429), 1,
      sym__exp,
    STATE(1830), 1,
      sym_exp_list,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [33155] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(636), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1441), 1,
      sym__exp,
    STATE(1826), 1,
      sym_exp_list,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [33243] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1148), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(637), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1716), 1,
      sym_args,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [33331] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1074), 1,
      anon_sym_EQ,
    STATE(638), 1,
      sym_comment,
    ACTIONS(1072), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1076), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 18,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [33387] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(641), 1,
      sym_concatenating_space,
    ACTIONS(1150), 1,
      anon_sym_in,
    ACTIONS(1154), 1,
      anon_sym_QMARK,
    ACTIONS(1162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1164), 1,
      anon_sym_PIPE_PIPE,
    STATE(639), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1146), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1160), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1156), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1152), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [33455] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(640), 1,
      sym_comment,
    STATE(641), 1,
      sym_array_ref,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1433), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1870), 1,
      sym_exp_list,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [33543] = 9,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    STATE(641), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [33601] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(642), 1,
      sym_comment,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1426), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1877), 1,
      sym_exp_list,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [33689] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(711), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      sym__if_else_separator,
    STATE(643), 1,
      sym_comment,
    ACTIONS(1166), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [33741] = 12,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    ACTIONS(1150), 1,
      anon_sym_in,
    ACTIONS(1162), 1,
      anon_sym_AMP_AMP,
    STATE(644), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1146), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1160), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1156), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1152), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [33805] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(645), 1,
      sym_comment,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1439), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1882), 1,
      sym_exp_list,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [33893] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1170), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(646), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1827), 1,
      sym_args,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [33981] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1172), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(647), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1831), 1,
      sym_args,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [34069] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1174), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(648), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1835), 1,
      sym_args,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [34157] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(649), 1,
      sym_comment,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1442), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1888), 1,
      sym_exp_list,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [34245] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1176), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(650), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1845), 1,
      sym_args,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [34333] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1178), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(651), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1711), 1,
      sym_args,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [34421] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(637), 1,
      sym_concatenating_space,
    ACTIONS(1150), 1,
      anon_sym_in,
    ACTIONS(1154), 1,
      anon_sym_QMARK,
    ACTIONS(1162), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1164), 1,
      anon_sym_PIPE_PIPE,
    STATE(652), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1146), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1160), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1156), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1152), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(631), 15,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [34489] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1180), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(653), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1854), 1,
      sym_args,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [34577] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1182), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(654), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1892), 1,
      sym_args,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [34665] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(655), 1,
      sym_comment,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1440), 1,
      sym__exp,
    STATE(1849), 1,
      sym_exp_list,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [34753] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1184), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(656), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1858), 1,
      sym_args,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [34841] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(657), 1,
      sym_comment,
    STATE(702), 1,
      aux_sym_exp_list_repeat1,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1430), 1,
      sym__exp,
    STATE(1852), 1,
      sym_exp_list,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [34929] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(658), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1146), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1156), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1152), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 21,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [34987] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1186), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(659), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1862), 1,
      sym_args,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [35075] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1188), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(660), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1867), 1,
      sym_args,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [35163] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(661), 1,
      sym_comment,
    ACTIONS(1146), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1156), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [35215] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1190), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(662), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1871), 1,
      sym_args,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [35303] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(858), 1,
      sym_regex_flags,
    STATE(663), 1,
      sym_comment,
    ACTIONS(587), 11,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ,
    ACTIONS(591), 25,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [35353] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1192), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(664), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1878), 1,
      sym_args,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [35441] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1200), 1,
      sym__if_else_separator,
    STATE(665), 1,
      sym_comment,
    ACTIONS(1196), 2,
      anon_sym_GT,
      anon_sym_GT_GT,
    ACTIONS(1198), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1194), 32,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [35493] = 11,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    ACTIONS(1150), 1,
      anon_sym_in,
    STATE(666), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1146), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1160), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1156), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1152), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 18,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [35555] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym_concatenating_space,
    ACTIONS(1142), 1,
      anon_sym_LT,
    STATE(667), 1,
      sym_comment,
    ACTIONS(469), 35,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [35605] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(668), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1146), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1160), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1156), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1152), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 19,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [35665] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1042), 1,
      sym_concatenating_space,
    STATE(669), 1,
      sym_comment,
    ACTIONS(996), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1040), 7,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35717] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(670), 1,
      sym_comment,
    ACTIONS(1048), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1146), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1156), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [35773] = 24,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1202), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(671), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1421), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    STATE(1881), 1,
      sym_args,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [35861] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(647), 1,
      sym_concatenating_space,
    STATE(672), 1,
      sym_comment,
    ACTIONS(1146), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1156), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
  [35915] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1204), 1,
      anon_sym_LT,
    STATE(673), 1,
      sym_comment,
    ACTIONS(469), 10,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ,
    ACTIONS(471), 25,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [35967] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1206), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(674), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1452), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [36052] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1208), 1,
      sym_identifier,
    ACTIONS(1210), 1,
      anon_sym_SEMI,
    STATE(641), 1,
      sym_array_ref,
    STATE(675), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1135), 1,
      sym_ns_qualified_name,
    STATE(1372), 1,
      sym_string,
    STATE(1477), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [36137] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1204), 1,
      anon_sym_LT,
    STATE(676), 1,
      sym_comment,
    ACTIONS(469), 9,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ,
    ACTIONS(471), 26,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [36186] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1212), 1,
      sym_identifier,
    ACTIONS(1214), 1,
      anon_sym_SEMI,
    STATE(641), 1,
      sym_array_ref,
    STATE(677), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1130), 1,
      sym_ns_qualified_name,
    STATE(1372), 1,
      sym_string,
    STATE(1495), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [36271] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1216), 1,
      sym_identifier,
    ACTIONS(1219), 1,
      anon_sym_LPAREN,
    ACTIONS(1222), 1,
      anon_sym_getline,
    ACTIONS(1225), 1,
      anon_sym_SLASH,
    ACTIONS(1231), 1,
      anon_sym_BANG,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1240), 1,
      anon_sym_AT,
    ACTIONS(1243), 1,
      sym_number,
    ACTIONS(1246), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1468), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1228), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(678), 2,
      sym_comment,
      aux_sym_exp_list_repeat1,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [36354] = 13,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(539), 1,
      anon_sym_EQ,
    ACTIONS(1251), 1,
      anon_sym_PIPE,
    ACTIONS(1253), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1255), 1,
      anon_sym_CARET,
    ACTIONS(1257), 1,
      anon_sym_STAR_STAR,
    STATE(679), 1,
      sym_comment,
    ACTIONS(1249), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1265), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1259), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1263), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(541), 18,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [36419] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1267), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(680), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1475), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [36504] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1269), 1,
      anon_sym_SEMI,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(681), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1507), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [36589] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1271), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(682), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1457), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [36674] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(269), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_SLASH,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(301), 1,
      anon_sym_AT,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    STATE(551), 1,
      sym_ns_qualified_name,
    STATE(576), 1,
      sym_array_ref,
    STATE(595), 1,
      sym_field_ref,
    STATE(678), 1,
      aux_sym_exp_list_repeat1,
    STATE(683), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1336), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(297), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1279), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [36759] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(383), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_getline,
    ACTIONS(413), 1,
      anon_sym_SLASH,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_AT,
    STATE(587), 1,
      sym_ns_qualified_name,
    STATE(624), 1,
      sym_array_ref,
    STATE(669), 1,
      sym_field_ref,
    STATE(678), 1,
      aux_sym_exp_list_repeat1,
    STATE(684), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1381), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(417), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1320), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [36844] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(131), 1,
      sym_identifier,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(149), 1,
      anon_sym_getline,
    ACTIONS(155), 1,
      anon_sym_SLASH,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(165), 1,
      anon_sym_AT,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    STATE(182), 1,
      sym_ns_qualified_name,
    STATE(203), 1,
      sym_array_ref,
    STATE(208), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(402), 1,
      sym__exp,
    STATE(678), 1,
      aux_sym_exp_list_repeat1,
    STATE(685), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(161), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(392), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(381), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(391), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [36929] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1273), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(686), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1515), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [37014] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1275), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(687), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1479), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [37099] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1277), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(688), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1474), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [37184] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1279), 1,
      anon_sym_SEMI,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(689), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1510), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [37269] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1281), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(690), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1493), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [37354] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(639), 1,
      anon_sym_EQ,
    ACTIONS(1251), 1,
      anon_sym_PIPE,
    ACTIONS(1253), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1255), 1,
      anon_sym_CARET,
    ACTIONS(1257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1283), 1,
      anon_sym_in,
    ACTIONS(1285), 1,
      anon_sym_QMARK,
    ACTIONS(1287), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1289), 1,
      anon_sym_PIPE_PIPE,
    STATE(691), 1,
      sym_comment,
    ACTIONS(1249), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1265), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1259), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1263), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(641), 14,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [37427] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1291), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(692), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1443), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [37512] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1293), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(693), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1473), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [37597] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1295), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(694), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1500), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [37682] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1297), 1,
      sym_identifier,
    ACTIONS(1299), 1,
      anon_sym_SEMI,
    STATE(641), 1,
      sym_array_ref,
    STATE(695), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1121), 1,
      sym_ns_qualified_name,
    STATE(1372), 1,
      sym_string,
    STATE(1504), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [37767] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1301), 1,
      anon_sym_SEMI,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(696), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1478), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [37852] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(87), 1,
      sym_identifier,
    ACTIONS(109), 1,
      anon_sym_getline,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_SLASH,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(373), 1,
      anon_sym_AT,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    STATE(532), 1,
      sym_ns_qualified_name,
    STATE(552), 1,
      sym_array_ref,
    STATE(572), 1,
      sym_field_ref,
    STATE(678), 1,
      aux_sym_exp_list_repeat1,
    STATE(697), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1305), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(369), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1248), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [37937] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1074), 1,
      anon_sym_EQ,
    STATE(698), 1,
      sym_comment,
    ACTIONS(1072), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1076), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 18,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [37990] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1303), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(699), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1472), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [38075] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(37), 1,
      sym_identifier,
    ACTIONS(61), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(311), 1,
      anon_sym_SLASH,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(319), 1,
      anon_sym_AT,
    STATE(522), 1,
      sym_ns_qualified_name,
    STATE(534), 1,
      sym_array_ref,
    STATE(550), 1,
      sym_field_ref,
    STATE(678), 1,
      aux_sym_exp_list_repeat1,
    STATE(700), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1267), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(315), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1222), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [38160] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1305), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(701), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1471), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [38245] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(678), 1,
      aux_sym_exp_list_repeat1,
    STATE(702), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1423), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [38330] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(703), 1,
      sym_comment,
    ACTIONS(1307), 2,
      anon_sym_GT,
      anon_sym_GT_GT,
    ACTIONS(1309), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1194), 32,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [38379] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1311), 1,
      anon_sym_SEMI,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(704), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1499), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [38464] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1255), 1,
      anon_sym_CARET,
    ACTIONS(1257), 1,
      anon_sym_STAR_STAR,
    STATE(705), 1,
      sym_comment,
    ACTIONS(539), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ,
    ACTIONS(541), 25,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [38515] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1313), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(706), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1498), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [38600] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1255), 1,
      anon_sym_CARET,
    ACTIONS(1257), 1,
      anon_sym_STAR_STAR,
    STATE(707), 1,
      sym_comment,
    ACTIONS(1261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1259), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_EQ,
    ACTIONS(647), 25,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [38655] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1251), 1,
      anon_sym_PIPE,
    ACTIONS(1253), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1255), 1,
      anon_sym_CARET,
    ACTIONS(1257), 1,
      anon_sym_STAR_STAR,
    STATE(708), 1,
      sym_comment,
    ACTIONS(1261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(539), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
    ACTIONS(1259), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(541), 24,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [38714] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1315), 1,
      anon_sym_SEMI,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(709), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1467), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [38799] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(321), 1,
      sym_identifier,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(337), 1,
      anon_sym_getline,
    ACTIONS(343), 1,
      anon_sym_SLASH,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(353), 1,
      anon_sym_AT,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    STATE(145), 1,
      sym_ns_qualified_name,
    STATE(168), 1,
      sym_array_ref,
    STATE(199), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(382), 1,
      sym__exp,
    STATE(678), 1,
      aux_sym_exp_list_repeat1,
    STATE(710), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(349), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(354), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(286), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(353), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [38884] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(808), 1,
      anon_sym_LBRACK,
    STATE(711), 1,
      sym_comment,
    ACTIONS(1166), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [38933] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1319), 1,
      anon_sym_SEMI,
    STATE(641), 1,
      sym_array_ref,
    STATE(712), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1110), 1,
      sym_ns_qualified_name,
    STATE(1372), 1,
      sym_string,
    STATE(1487), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [39018] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1321), 1,
      anon_sym_SEMI,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(713), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1514), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [39103] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1323), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(714), 1,
      sym_comment,
    STATE(715), 1,
      sym_field_ref,
    STATE(1372), 1,
      sym_string,
    STATE(1491), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [39188] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    STATE(715), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 17,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [39243] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(711), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      sym__if_else_separator,
    STATE(716), 1,
      sym_comment,
    ACTIONS(1166), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [39292] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1325), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(717), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1445), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [39377] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1327), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(718), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1485), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [39462] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(631), 1,
      anon_sym_EQ,
    ACTIONS(1251), 1,
      anon_sym_PIPE,
    ACTIONS(1253), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1255), 1,
      anon_sym_CARET,
    ACTIONS(1257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1283), 1,
      anon_sym_in,
    ACTIONS(1285), 1,
      anon_sym_QMARK,
    ACTIONS(1287), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1289), 1,
      anon_sym_PIPE_PIPE,
    STATE(719), 1,
      sym_comment,
    ACTIONS(1249), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1265), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1259), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1263), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(637), 14,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [39535] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1329), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(720), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1517), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [39620] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1331), 1,
      anon_sym_SEMI,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(721), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1451), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [39705] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1255), 1,
      anon_sym_CARET,
    ACTIONS(1257), 1,
      anon_sym_STAR_STAR,
    STATE(722), 1,
      sym_comment,
    ACTIONS(1259), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_EQ,
    ACTIONS(541), 25,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [39758] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1333), 1,
      anon_sym_SEMI,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(723), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1454), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [39843] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1335), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(724), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1492), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [39928] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(539), 1,
      anon_sym_EQ,
    ACTIONS(1251), 1,
      anon_sym_PIPE,
    ACTIONS(1253), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1255), 1,
      anon_sym_CARET,
    ACTIONS(1257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1283), 1,
      anon_sym_in,
    ACTIONS(1287), 1,
      anon_sym_AMP_AMP,
    STATE(725), 1,
      sym_comment,
    ACTIONS(1249), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1265), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1259), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1263), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(541), 16,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [39997] = 14,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(539), 1,
      anon_sym_EQ,
    ACTIONS(1251), 1,
      anon_sym_PIPE,
    ACTIONS(1253), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1255), 1,
      anon_sym_CARET,
    ACTIONS(1257), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1283), 1,
      anon_sym_in,
    STATE(726), 1,
      sym_comment,
    ACTIONS(1249), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1265), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1259), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1263), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(541), 17,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [40064] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1337), 1,
      sym_identifier,
    ACTIONS(1339), 1,
      anon_sym_SEMI,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(727), 1,
      sym_comment,
    STATE(1124), 1,
      sym_ns_qualified_name,
    STATE(1372), 1,
      sym_string,
    STATE(1512), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [40149] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1341), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(728), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1488), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [40234] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1343), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(729), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1508), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [40319] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1345), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(730), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1505), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [40404] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1347), 1,
      anon_sym_SEMI,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(731), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1453), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [40489] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1349), 1,
      anon_sym_SEMI,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(732), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1476), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [40574] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1351), 1,
      sym_identifier,
    ACTIONS(1353), 1,
      anon_sym_SEMI,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(733), 1,
      sym_comment,
    STATE(1133), 1,
      sym_ns_qualified_name,
    STATE(1372), 1,
      sym_string,
    STATE(1516), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [40659] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1355), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(734), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1489), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [40744] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(539), 1,
      anon_sym_EQ,
    ACTIONS(1251), 1,
      anon_sym_PIPE,
    ACTIONS(1253), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1255), 1,
      anon_sym_CARET,
    ACTIONS(1257), 1,
      anon_sym_STAR_STAR,
    STATE(735), 1,
      sym_comment,
    ACTIONS(1249), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1259), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1263), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(541), 20,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
      anon_sym_RBRACK,
  [40807] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1357), 1,
      anon_sym_SEMI,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(736), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1469), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [40892] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1359), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(737), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1449), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [40977] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1361), 1,
      anon_sym_RPAREN,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(738), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1519), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [41062] = 23,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1363), 1,
      anon_sym_SEMI,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(739), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1494), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [41147] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(479), 1,
      sym_string,
    STATE(490), 1,
      sym__exp,
    STATE(740), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [41229] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_getline,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(1385), 1,
      anon_sym_BANG,
    ACTIONS(1389), 1,
      anon_sym_AT,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(618), 1,
      sym__exp,
    STATE(741), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1383), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1387), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [41311] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(742), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1503), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [41393] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1395), 1,
      anon_sym_getline,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(1401), 1,
      anon_sym_BANG,
    ACTIONS(1405), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(200), 1,
      sym__exp,
    STATE(743), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [41475] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1395), 1,
      anon_sym_getline,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(1401), 1,
      anon_sym_BANG,
    ACTIONS(1405), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(197), 1,
      sym__exp,
    STATE(744), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [41557] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1395), 1,
      anon_sym_getline,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(1401), 1,
      anon_sym_BANG,
    ACTIONS(1405), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(137), 1,
      sym__exp,
    STATE(149), 1,
      sym_field_ref,
    STATE(745), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [41639] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1395), 1,
      anon_sym_getline,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(1401), 1,
      anon_sym_BANG,
    ACTIONS(1405), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(190), 1,
      sym__exp,
    STATE(746), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [41721] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1395), 1,
      anon_sym_getline,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(1401), 1,
      anon_sym_BANG,
    ACTIONS(1405), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(191), 1,
      sym__exp,
    STATE(747), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [41803] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1395), 1,
      anon_sym_getline,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(1401), 1,
      anon_sym_BANG,
    ACTIONS(1405), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(192), 1,
      sym__exp,
    STATE(748), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [41885] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1395), 1,
      anon_sym_getline,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(1401), 1,
      anon_sym_BANG,
    ACTIONS(1405), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(193), 1,
      sym__exp,
    STATE(749), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [41967] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1395), 1,
      anon_sym_getline,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(1401), 1,
      anon_sym_BANG,
    ACTIONS(1405), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(194), 1,
      sym__exp,
    STATE(750), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [42049] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(751), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1456), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [42131] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(339), 1,
      sym__exp,
    STATE(752), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [42213] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(342), 1,
      sym__exp,
    STATE(753), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [42295] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(453), 1,
      sym__exp,
    STATE(479), 1,
      sym_string,
    STATE(754), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [42377] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1421), 1,
      anon_sym_getline,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(1427), 1,
      anon_sym_BANG,
    ACTIONS(1431), 1,
      anon_sym_AT,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(264), 1,
      sym__exp,
    STATE(755), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1425), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1429), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [42459] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(324), 1,
      sym__exp,
    STATE(756), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [42541] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    ACTIONS(1447), 1,
      anon_sym_in,
    STATE(757), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [42603] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1449), 1,
      sym_identifier,
    STATE(103), 1,
      sym_array_ref,
    STATE(152), 1,
      sym_field_ref,
    STATE(504), 1,
      sym_ns_qualified_name,
    STATE(758), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1529), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1161), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [42685] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1451), 1,
      sym_identifier,
    STATE(134), 1,
      sym_array_ref,
    STATE(181), 1,
      sym_field_ref,
    STATE(517), 1,
      sym_ns_qualified_name,
    STATE(759), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1538), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1218), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [42767] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    ACTIONS(1453), 1,
      anon_sym_in,
    STATE(760), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [42829] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(761), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1458), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [42911] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    ACTIONS(1455), 1,
      anon_sym_in,
    STATE(762), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [42973] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(763), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1450), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [43055] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(764), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1446), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [43137] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(765), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1526), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [43219] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1457), 1,
      anon_sym_getline,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(1463), 1,
      anon_sym_BANG,
    ACTIONS(1467), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(146), 1,
      sym__exp,
    STATE(149), 1,
      sym_field_ref,
    STATE(766), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [43301] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1457), 1,
      anon_sym_getline,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(1463), 1,
      anon_sym_BANG,
    ACTIONS(1467), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(547), 1,
      sym__exp,
    STATE(767), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [43383] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(383), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_getline,
    ACTIONS(413), 1,
      anon_sym_SLASH,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_AT,
    STATE(587), 1,
      sym_ns_qualified_name,
    STATE(624), 1,
      sym_array_ref,
    STATE(669), 1,
      sym_field_ref,
    STATE(768), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1276), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(417), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1320), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [43465] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1473), 1,
      anon_sym_getline,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(1479), 1,
      anon_sym_BANG,
    ACTIONS(1483), 1,
      anon_sym_AT,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(582), 1,
      sym__exp,
    STATE(769), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1477), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1481), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [43547] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(320), 1,
      sym__exp,
    STATE(770), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [43629] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(319), 1,
      sym__exp,
    STATE(771), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [43711] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(316), 1,
      sym__exp,
    STATE(772), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [43793] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1473), 1,
      anon_sym_getline,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(1479), 1,
      anon_sym_BANG,
    ACTIONS(1483), 1,
      anon_sym_AT,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(158), 1,
      sym__exp,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(773), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1477), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1481), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [43875] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(314), 1,
      sym__exp,
    STATE(774), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [43957] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(313), 1,
      sym__exp,
    STATE(775), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [44039] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1395), 1,
      anon_sym_getline,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(1401), 1,
      anon_sym_BANG,
    ACTIONS(1405), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(196), 1,
      sym__exp,
    STATE(776), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [44121] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1457), 1,
      anon_sym_getline,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(1463), 1,
      anon_sym_BANG,
    ACTIONS(1467), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(125), 1,
      sym__exp,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(777), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [44203] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(312), 1,
      sym__exp,
    STATE(778), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [44285] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(311), 1,
      sym__exp,
    STATE(779), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [44367] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(309), 1,
      sym__exp,
    STATE(780), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [44449] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1457), 1,
      anon_sym_getline,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(1463), 1,
      anon_sym_BANG,
    ACTIONS(1467), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(120), 1,
      sym__exp,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(781), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [44531] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(383), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_getline,
    ACTIONS(413), 1,
      anon_sym_SLASH,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_AT,
    STATE(587), 1,
      sym_ns_qualified_name,
    STATE(624), 1,
      sym_array_ref,
    STATE(669), 1,
      sym_field_ref,
    STATE(782), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1354), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(417), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1320), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [44613] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1473), 1,
      anon_sym_getline,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(1479), 1,
      anon_sym_BANG,
    ACTIONS(1483), 1,
      anon_sym_AT,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(174), 1,
      sym__exp,
    STATE(783), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1477), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1481), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [44695] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1489), 1,
      sym_identifier,
    STATE(103), 1,
      sym_array_ref,
    STATE(150), 1,
      sym_ns_qualified_name,
    STATE(152), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(784), 1,
      sym_comment,
    STATE(1536), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(308), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [44777] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1473), 1,
      anon_sym_getline,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(1479), 1,
      anon_sym_BANG,
    ACTIONS(1483), 1,
      anon_sym_AT,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(184), 1,
      sym__exp,
    STATE(785), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1477), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1481), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [44859] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1457), 1,
      anon_sym_getline,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(1463), 1,
      anon_sym_BANG,
    ACTIONS(1467), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(555), 1,
      sym__exp,
    STATE(786), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [44941] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_getline,
    ACTIONS(19), 1,
      anon_sym_SLASH,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1491), 1,
      anon_sym_AT,
    STATE(348), 1,
      sym_ns_qualified_name,
    STATE(409), 1,
      sym_array_ref,
    STATE(415), 1,
      sym_field_ref,
    STATE(479), 1,
      sym_string,
    STATE(499), 1,
      sym__exp,
    STATE(787), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(25), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(513), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(471), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(503), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [45023] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1493), 1,
      anon_sym_getline,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(1499), 1,
      anon_sym_BANG,
    ACTIONS(1503), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(184), 1,
      sym__exp,
    STATE(788), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1497), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1501), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [45105] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1457), 1,
      anon_sym_getline,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(1463), 1,
      anon_sym_BANG,
    ACTIONS(1467), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(557), 1,
      sym__exp,
    STATE(789), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [45187] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1457), 1,
      anon_sym_getline,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(1463), 1,
      anon_sym_BANG,
    ACTIONS(1467), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(558), 1,
      sym__exp,
    STATE(790), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [45269] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1457), 1,
      anon_sym_getline,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(1463), 1,
      anon_sym_BANG,
    ACTIONS(1467), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(538), 1,
      sym__exp,
    STATE(791), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [45351] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1457), 1,
      anon_sym_getline,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(1463), 1,
      anon_sym_BANG,
    ACTIONS(1467), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(542), 1,
      sym__exp,
    STATE(792), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [45433] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1457), 1,
      anon_sym_getline,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(1463), 1,
      anon_sym_BANG,
    ACTIONS(1467), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(545), 1,
      sym__exp,
    STATE(793), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [45515] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1457), 1,
      anon_sym_getline,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(1463), 1,
      anon_sym_BANG,
    ACTIONS(1467), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(137), 1,
      sym__exp,
    STATE(149), 1,
      sym_field_ref,
    STATE(794), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [45597] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(383), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_getline,
    ACTIONS(413), 1,
      anon_sym_SLASH,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_AT,
    STATE(587), 1,
      sym_ns_qualified_name,
    STATE(624), 1,
      sym_array_ref,
    STATE(669), 1,
      sym_field_ref,
    STATE(795), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1269), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(417), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1320), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [45679] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1457), 1,
      anon_sym_getline,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(1463), 1,
      anon_sym_BANG,
    ACTIONS(1467), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(548), 1,
      sym__exp,
    STATE(796), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [45761] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1457), 1,
      anon_sym_getline,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(1463), 1,
      anon_sym_BANG,
    ACTIONS(1467), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(556), 1,
      sym__exp,
    STATE(797), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1465), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [45843] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1449), 1,
      sym_identifier,
    STATE(103), 1,
      sym_array_ref,
    STATE(152), 1,
      sym_field_ref,
    STATE(504), 1,
      sym_ns_qualified_name,
    STATE(798), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1539), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1161), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [45925] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1505), 1,
      sym_identifier,
    STATE(234), 1,
      sym_array_ref,
    STATE(246), 1,
      sym_field_ref,
    STATE(352), 1,
      sym_ns_qualified_name,
    STATE(479), 1,
      sym_string,
    STATE(799), 1,
      sym_comment,
    STATE(1542), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(464), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [46007] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1473), 1,
      anon_sym_getline,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(1479), 1,
      anon_sym_BANG,
    ACTIONS(1483), 1,
      anon_sym_AT,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(574), 1,
      sym__exp,
    STATE(800), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1477), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1481), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [46089] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(801), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1300), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [46171] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(802), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1299), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [46253] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(803), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1180), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [46335] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(804), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1297), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [46417] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(805), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1295), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [46499] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(806), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1294), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [46581] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(807), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1293), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [46663] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(808), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1285), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [46745] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_getline,
    ACTIONS(19), 1,
      anon_sym_SLASH,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1491), 1,
      anon_sym_AT,
    STATE(348), 1,
      sym_ns_qualified_name,
    STATE(409), 1,
      sym_array_ref,
    STATE(415), 1,
      sym_field_ref,
    STATE(479), 1,
      sym_string,
    STATE(510), 1,
      sym__exp,
    STATE(809), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(25), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(513), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(471), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(503), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [46827] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1493), 1,
      anon_sym_getline,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(1499), 1,
      anon_sym_BANG,
    ACTIONS(1503), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(214), 1,
      sym__exp,
    STATE(810), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1497), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1501), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [46909] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1493), 1,
      anon_sym_getline,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(1499), 1,
      anon_sym_BANG,
    ACTIONS(1503), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(174), 1,
      sym__exp,
    STATE(811), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1497), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1501), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [46991] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_getline,
    ACTIONS(19), 1,
      anon_sym_SLASH,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1491), 1,
      anon_sym_AT,
    STATE(348), 1,
      sym_ns_qualified_name,
    STATE(409), 1,
      sym_array_ref,
    STATE(415), 1,
      sym_field_ref,
    STATE(479), 1,
      sym_string,
    STATE(520), 1,
      sym__exp,
    STATE(812), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(25), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(513), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(471), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(503), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [47073] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1473), 1,
      anon_sym_getline,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(1479), 1,
      anon_sym_BANG,
    ACTIONS(1483), 1,
      anon_sym_AT,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(564), 1,
      sym__exp,
    STATE(813), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1477), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1481), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [47155] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1473), 1,
      anon_sym_getline,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(1479), 1,
      anon_sym_BANG,
    ACTIONS(1483), 1,
      anon_sym_AT,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(567), 1,
      sym__exp,
    STATE(814), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1477), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1481), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [47237] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1473), 1,
      anon_sym_getline,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(1479), 1,
      anon_sym_BANG,
    ACTIONS(1483), 1,
      anon_sym_AT,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(568), 1,
      sym__exp,
    STATE(815), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1477), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1481), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [47319] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1473), 1,
      anon_sym_getline,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(1479), 1,
      anon_sym_BANG,
    ACTIONS(1483), 1,
      anon_sym_AT,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(571), 1,
      sym__exp,
    STATE(816), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1477), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1481), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [47401] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1473), 1,
      anon_sym_getline,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(1479), 1,
      anon_sym_BANG,
    ACTIONS(1483), 1,
      anon_sym_AT,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(578), 1,
      sym__exp,
    STATE(817), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1477), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1481), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [47483] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1473), 1,
      anon_sym_getline,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(1479), 1,
      anon_sym_BANG,
    ACTIONS(1483), 1,
      anon_sym_AT,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(178), 1,
      sym__exp,
    STATE(818), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1477), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1481), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [47565] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1473), 1,
      anon_sym_getline,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(1479), 1,
      anon_sym_BANG,
    ACTIONS(1483), 1,
      anon_sym_AT,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(583), 1,
      sym__exp,
    STATE(819), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1477), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1481), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [47647] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1473), 1,
      anon_sym_getline,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(1479), 1,
      anon_sym_BANG,
    ACTIONS(1483), 1,
      anon_sym_AT,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(560), 1,
      sym__exp,
    STATE(820), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1477), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1481), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [47729] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(458), 1,
      sym__exp,
    STATE(479), 1,
      sym_string,
    STATE(821), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [47811] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    ACTIONS(1517), 1,
      anon_sym_in,
    STATE(822), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [47873] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(457), 1,
      sym__exp,
    STATE(479), 1,
      sym_string,
    STATE(823), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [47955] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(824), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1496), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [48037] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(825), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1501), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [48119] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(826), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1511), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [48201] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(827), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1444), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [48283] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(828), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1524), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [48365] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1493), 1,
      anon_sym_getline,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(1499), 1,
      anon_sym_BANG,
    ACTIONS(1503), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(206), 1,
      sym__exp,
    STATE(829), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1497), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1501), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [48447] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(830), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1523), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [48529] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(831), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1513), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [48611] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(832), 1,
      sym_comment,
    STATE(1177), 1,
      sym__exp,
    STATE(1178), 1,
      sym_string,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [48693] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(37), 1,
      sym_identifier,
    ACTIONS(61), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(311), 1,
      anon_sym_SLASH,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(319), 1,
      anon_sym_AT,
    STATE(522), 1,
      sym_ns_qualified_name,
    STATE(534), 1,
      sym_array_ref,
    STATE(550), 1,
      sym_field_ref,
    STATE(833), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1240), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(315), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1222), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [48775] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(834), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1292), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [48857] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_getline,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(1385), 1,
      anon_sym_BANG,
    ACTIONS(1389), 1,
      anon_sym_AT,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(146), 1,
      sym__exp,
    STATE(149), 1,
      sym_field_ref,
    STATE(835), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1383), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1387), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [48939] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(836), 1,
      sym_comment,
    STATE(1200), 1,
      sym__exp,
    STATE(1232), 1,
      sym_string,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [49021] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(837), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1206), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [49103] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_getline,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(1385), 1,
      anon_sym_BANG,
    ACTIONS(1389), 1,
      anon_sym_AT,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(609), 1,
      sym__exp,
    STATE(838), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1383), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1387), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [49185] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(87), 1,
      sym_identifier,
    ACTIONS(109), 1,
      anon_sym_getline,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_SLASH,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(373), 1,
      anon_sym_AT,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    STATE(532), 1,
      sym_ns_qualified_name,
    STATE(552), 1,
      sym_array_ref,
    STATE(572), 1,
      sym_field_ref,
    STATE(839), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1278), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(369), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1248), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [49267] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1539), 1,
      anon_sym_getline,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(1545), 1,
      anon_sym_BANG,
    ACTIONS(1549), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(672), 1,
      sym__exp,
    STATE(840), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1543), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1547), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [49349] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(841), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1257), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [49431] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(842), 1,
      sym_comment,
    STATE(1191), 1,
      sym__exp,
    STATE(1232), 1,
      sym_string,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [49513] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(37), 1,
      sym_identifier,
    ACTIONS(61), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(311), 1,
      anon_sym_SLASH,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(319), 1,
      anon_sym_AT,
    STATE(522), 1,
      sym_ns_qualified_name,
    STATE(534), 1,
      sym_array_ref,
    STATE(550), 1,
      sym_field_ref,
    STATE(843), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1312), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(315), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1222), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [49595] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(37), 1,
      sym_identifier,
    ACTIONS(61), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(311), 1,
      anon_sym_SLASH,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(319), 1,
      anon_sym_AT,
    STATE(522), 1,
      sym_ns_qualified_name,
    STATE(534), 1,
      sym_array_ref,
    STATE(550), 1,
      sym_field_ref,
    STATE(844), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1315), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(315), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1222), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [49677] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(845), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1459), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [49759] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(459), 1,
      sym__exp,
    STATE(479), 1,
      sym_string,
    STATE(846), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [49841] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    ACTIONS(1561), 1,
      anon_sym_getline,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(1567), 1,
      anon_sym_BANG,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(707), 1,
      sym__exp,
    STATE(847), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1565), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1569), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [49923] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(479), 1,
      sym_string,
    STATE(488), 1,
      sym__exp,
    STATE(848), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [50005] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(476), 1,
      sym__exp,
    STATE(479), 1,
      sym_string,
    STATE(849), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [50087] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(474), 1,
      sym__exp,
    STATE(479), 1,
      sym_string,
    STATE(850), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [50169] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(470), 1,
      sym__exp,
    STATE(479), 1,
      sym_string,
    STATE(851), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [50251] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(852), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1322), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [50333] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(465), 1,
      sym__exp,
    STATE(479), 1,
      sym_string,
    STATE(853), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [50415] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(854), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1448), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [50497] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(855), 1,
      sym_comment,
    STATE(1199), 1,
      sym__exp,
    STATE(1232), 1,
      sym_string,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [50579] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(856), 1,
      sym_comment,
    STATE(1349), 1,
      sym__exp,
    STATE(1372), 1,
      sym_string,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [50661] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(857), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1447), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [50743] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(808), 1,
      anon_sym_LBRACK,
    STATE(858), 1,
      sym_comment,
    ACTIONS(1166), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [50789] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(859), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1482), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [50871] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(131), 1,
      sym_identifier,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(149), 1,
      anon_sym_getline,
    ACTIONS(155), 1,
      anon_sym_SLASH,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(165), 1,
      anon_sym_AT,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    STATE(182), 1,
      sym_ns_qualified_name,
    STATE(203), 1,
      sym_array_ref,
    STATE(208), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(433), 1,
      sym__exp,
    STATE(860), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(161), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(392), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(381), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(391), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [50953] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(131), 1,
      sym_identifier,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(149), 1,
      anon_sym_getline,
    ACTIONS(155), 1,
      anon_sym_SLASH,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(165), 1,
      anon_sym_AT,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    STATE(182), 1,
      sym_ns_qualified_name,
    STATE(203), 1,
      sym_array_ref,
    STATE(208), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(434), 1,
      sym__exp,
    STATE(861), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(161), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(392), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(381), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(391), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [51035] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_getline,
    ACTIONS(19), 1,
      anon_sym_SLASH,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1491), 1,
      anon_sym_AT,
    STATE(348), 1,
      sym_ns_qualified_name,
    STATE(409), 1,
      sym_array_ref,
    STATE(415), 1,
      sym_field_ref,
    STATE(479), 1,
      sym_string,
    STATE(505), 1,
      sym__exp,
    STATE(862), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(25), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(513), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(471), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(503), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [51117] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(87), 1,
      sym_identifier,
    ACTIONS(109), 1,
      anon_sym_getline,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_SLASH,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(373), 1,
      anon_sym_AT,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    STATE(532), 1,
      sym_ns_qualified_name,
    STATE(552), 1,
      sym_array_ref,
    STATE(572), 1,
      sym_field_ref,
    STATE(863), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1361), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(369), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1248), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [51199] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(87), 1,
      sym_identifier,
    ACTIONS(109), 1,
      anon_sym_getline,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_SLASH,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(373), 1,
      anon_sym_AT,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    STATE(532), 1,
      sym_ns_qualified_name,
    STATE(552), 1,
      sym_array_ref,
    STATE(572), 1,
      sym_field_ref,
    STATE(864), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1356), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(369), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1248), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [51281] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1539), 1,
      anon_sym_getline,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(1545), 1,
      anon_sym_BANG,
    ACTIONS(1549), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(158), 1,
      sym__exp,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(865), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1543), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1547), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [51363] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(866), 1,
      sym_comment,
    STATE(1164), 1,
      sym__exp,
    STATE(1178), 1,
      sym_string,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [51445] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(867), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1207), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [51527] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(868), 1,
      sym_comment,
    STATE(1155), 1,
      sym__exp,
    STATE(1178), 1,
      sym_string,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [51609] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1493), 1,
      anon_sym_getline,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(1499), 1,
      anon_sym_BANG,
    ACTIONS(1503), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(211), 1,
      sym__exp,
    STATE(869), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1497), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1501), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [51691] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(37), 1,
      sym_identifier,
    ACTIONS(61), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(311), 1,
      anon_sym_SLASH,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(319), 1,
      anon_sym_AT,
    STATE(522), 1,
      sym_ns_qualified_name,
    STATE(534), 1,
      sym_array_ref,
    STATE(550), 1,
      sym_field_ref,
    STATE(870), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1227), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(315), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1222), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [51773] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1493), 1,
      anon_sym_getline,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(1499), 1,
      anon_sym_BANG,
    ACTIONS(1503), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(209), 1,
      sym__exp,
    STATE(871), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1497), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1501), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [51855] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1493), 1,
      anon_sym_getline,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(1499), 1,
      anon_sym_BANG,
    ACTIONS(1503), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(212), 1,
      sym__exp,
    STATE(872), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1497), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1501), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [51937] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(321), 1,
      sym_identifier,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(337), 1,
      anon_sym_getline,
    ACTIONS(343), 1,
      anon_sym_SLASH,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(353), 1,
      anon_sym_AT,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    STATE(145), 1,
      sym_ns_qualified_name,
    STATE(168), 1,
      sym_array_ref,
    STATE(199), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(362), 1,
      sym__exp,
    STATE(873), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(349), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(354), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(286), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(353), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [52019] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1493), 1,
      anon_sym_getline,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(1499), 1,
      anon_sym_BANG,
    ACTIONS(1503), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(213), 1,
      sym__exp,
    STATE(874), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1497), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1501), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [52101] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1493), 1,
      anon_sym_getline,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(1499), 1,
      anon_sym_BANG,
    ACTIONS(1503), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(178), 1,
      sym__exp,
    STATE(875), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1497), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1501), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [52183] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1493), 1,
      anon_sym_getline,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(1499), 1,
      anon_sym_BANG,
    ACTIONS(1503), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(217), 1,
      sym__exp,
    STATE(876), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1497), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1501), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [52265] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1493), 1,
      anon_sym_getline,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(1499), 1,
      anon_sym_BANG,
    ACTIONS(1503), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(216), 1,
      sym__exp,
    STATE(877), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1497), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1501), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [52347] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(37), 1,
      sym_identifier,
    ACTIONS(61), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(311), 1,
      anon_sym_SLASH,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(319), 1,
      anon_sym_AT,
    STATE(522), 1,
      sym_ns_qualified_name,
    STATE(534), 1,
      sym_array_ref,
    STATE(550), 1,
      sym_field_ref,
    STATE(878), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1249), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(315), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1222), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [52429] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(879), 1,
      sym_comment,
    STATE(1343), 1,
      sym__exp,
    STATE(1372), 1,
      sym_string,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [52511] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(37), 1,
      sym_identifier,
    ACTIONS(61), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(311), 1,
      anon_sym_SLASH,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(319), 1,
      anon_sym_AT,
    STATE(522), 1,
      sym_ns_qualified_name,
    STATE(534), 1,
      sym_array_ref,
    STATE(550), 1,
      sym_field_ref,
    STATE(880), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1229), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(315), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1222), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [52593] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_getline,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(1385), 1,
      anon_sym_BANG,
    ACTIONS(1389), 1,
      anon_sym_AT,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(125), 1,
      sym__exp,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(881), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1383), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1387), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [52675] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_getline,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(1385), 1,
      anon_sym_BANG,
    ACTIONS(1389), 1,
      anon_sym_AT,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(120), 1,
      sym__exp,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(882), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1383), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1387), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [52757] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(321), 1,
      sym_identifier,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(337), 1,
      anon_sym_getline,
    ACTIONS(343), 1,
      anon_sym_SLASH,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(353), 1,
      anon_sym_AT,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    STATE(145), 1,
      sym_ns_qualified_name,
    STATE(168), 1,
      sym_array_ref,
    STATE(199), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(329), 1,
      sym__exp,
    STATE(883), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(349), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(354), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(286), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(353), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [52839] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(884), 1,
      sym_comment,
    STATE(1199), 1,
      sym__exp,
    STATE(1232), 1,
      sym_string,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [52921] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(321), 1,
      sym_identifier,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(337), 1,
      anon_sym_getline,
    ACTIONS(343), 1,
      anon_sym_SLASH,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(353), 1,
      anon_sym_AT,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    STATE(145), 1,
      sym_ns_qualified_name,
    STATE(168), 1,
      sym_array_ref,
    STATE(199), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(364), 1,
      sym__exp,
    STATE(885), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(349), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(354), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(286), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(353), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [53003] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(886), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1244), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [53085] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(887), 1,
      sym_comment,
    STATE(1191), 1,
      sym__exp,
    STATE(1232), 1,
      sym_string,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [53167] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(888), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1231), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [53249] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1539), 1,
      anon_sym_getline,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(1545), 1,
      anon_sym_BANG,
    ACTIONS(1549), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(174), 1,
      sym__exp,
    STATE(889), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1543), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1547), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [53331] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(890), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1233), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [53413] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(891), 1,
      sym_comment,
    STATE(1353), 1,
      sym__exp,
    STATE(1372), 1,
      sym_string,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [53495] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(892), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1234), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [53577] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(893), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1237), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [53659] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(894), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1238), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [53741] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(895), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1186), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [53823] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(896), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1180), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [53905] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(897), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1333), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [53987] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(898), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1193), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [54069] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(313), 1,
      anon_sym_BANG,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(1519), 1,
      sym_identifier,
    ACTIONS(1521), 1,
      anon_sym_getline,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(1527), 1,
      anon_sym_AT,
    STATE(516), 1,
      sym_ns_qualified_name,
    STATE(529), 1,
      sym_array_ref,
    STATE(537), 1,
      sym_field_ref,
    STATE(899), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1192), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(71), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1525), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [54151] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1539), 1,
      anon_sym_getline,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(1545), 1,
      anon_sym_BANG,
    ACTIONS(1549), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(184), 1,
      sym__exp,
    STATE(900), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1543), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1547), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [54233] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_getline,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(1385), 1,
      anon_sym_BANG,
    ACTIONS(1389), 1,
      anon_sym_AT,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(592), 1,
      sym__exp,
    STATE(901), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1383), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1387), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [54315] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(297), 1,
      sym__exp,
    STATE(902), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [54397] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    ACTIONS(1583), 1,
      anon_sym_in,
    STATE(903), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [54459] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_getline,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(1385), 1,
      anon_sym_BANG,
    ACTIONS(1389), 1,
      anon_sym_AT,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(612), 1,
      sym__exp,
    STATE(904), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1383), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1387), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [54541] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_getline,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(1385), 1,
      anon_sym_BANG,
    ACTIONS(1389), 1,
      anon_sym_AT,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(616), 1,
      sym__exp,
    STATE(905), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1383), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1387), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [54623] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_getline,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(1385), 1,
      anon_sym_BANG,
    ACTIONS(1389), 1,
      anon_sym_AT,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(617), 1,
      sym__exp,
    STATE(906), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1383), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1387), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [54705] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(340), 1,
      sym__exp,
    STATE(907), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [54787] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_getline,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(1385), 1,
      anon_sym_BANG,
    ACTIONS(1389), 1,
      anon_sym_AT,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(621), 1,
      sym__exp,
    STATE(908), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1383), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1387), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [54869] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_getline,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(1385), 1,
      anon_sym_BANG,
    ACTIONS(1389), 1,
      anon_sym_AT,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(137), 1,
      sym__exp,
    STATE(149), 1,
      sym_field_ref,
    STATE(909), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1383), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1387), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [54951] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1421), 1,
      anon_sym_getline,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(1427), 1,
      anon_sym_BANG,
    ACTIONS(1431), 1,
      anon_sym_AT,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(268), 1,
      sym__exp,
    STATE(910), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1425), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1429), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [55033] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_getline,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(1385), 1,
      anon_sym_BANG,
    ACTIONS(1389), 1,
      anon_sym_AT,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(622), 1,
      sym__exp,
    STATE(911), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1383), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1387), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [55115] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(298), 1,
      sym__exp,
    STATE(912), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [55197] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_getline,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(1385), 1,
      anon_sym_BANG,
    ACTIONS(1389), 1,
      anon_sym_AT,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(623), 1,
      sym__exp,
    STATE(913), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1383), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1387), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [55279] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(300), 1,
      sym__exp,
    STATE(914), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [55361] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(915), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1310), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [55443] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(916), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1311), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [55525] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(917), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1319), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [55607] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(918), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1329), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [55689] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(919), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1334), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [55771] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(920), 1,
      sym_comment,
    STATE(1205), 1,
      sym__exp,
    STATE(1232), 1,
      sym_string,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [55853] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(921), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1330), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [55935] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(922), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1328), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [56017] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1451), 1,
      sym_identifier,
    STATE(134), 1,
      sym_array_ref,
    STATE(181), 1,
      sym_field_ref,
    STATE(517), 1,
      sym_ns_qualified_name,
    STATE(923), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1540), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1218), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [56099] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(87), 1,
      sym_identifier,
    ACTIONS(109), 1,
      anon_sym_getline,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_SLASH,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(373), 1,
      anon_sym_AT,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    STATE(532), 1,
      sym_ns_qualified_name,
    STATE(552), 1,
      sym_array_ref,
    STATE(572), 1,
      sym_field_ref,
    STATE(924), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1276), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(369), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1248), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [56181] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1421), 1,
      anon_sym_getline,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(1427), 1,
      anon_sym_BANG,
    ACTIONS(1431), 1,
      anon_sym_AT,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(261), 1,
      sym__exp,
    STATE(925), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1425), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1429), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [56263] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(87), 1,
      sym_identifier,
    ACTIONS(109), 1,
      anon_sym_getline,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_SLASH,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(373), 1,
      anon_sym_AT,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    STATE(532), 1,
      sym_ns_qualified_name,
    STATE(552), 1,
      sym_array_ref,
    STATE(572), 1,
      sym_field_ref,
    STATE(926), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1288), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(369), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1248), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [56345] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(87), 1,
      sym_identifier,
    ACTIONS(109), 1,
      anon_sym_getline,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(365), 1,
      anon_sym_SLASH,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(373), 1,
      anon_sym_AT,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    STATE(532), 1,
      sym_ns_qualified_name,
    STATE(552), 1,
      sym_array_ref,
    STATE(572), 1,
      sym_field_ref,
    STATE(927), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1269), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(369), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1248), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [56427] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1539), 1,
      anon_sym_getline,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(1545), 1,
      anon_sym_BANG,
    ACTIONS(1549), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(652), 1,
      sym__exp,
    STATE(928), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1543), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1547), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [56509] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1421), 1,
      anon_sym_getline,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(1427), 1,
      anon_sym_BANG,
    ACTIONS(1431), 1,
      anon_sym_AT,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(427), 1,
      sym__exp,
    STATE(929), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1425), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1429), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [56591] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(930), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1438), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [56673] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1395), 1,
      anon_sym_getline,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(1401), 1,
      anon_sym_BANG,
    ACTIONS(1405), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(120), 1,
      sym__exp,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(931), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [56755] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1539), 1,
      anon_sym_getline,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(1545), 1,
      anon_sym_BANG,
    ACTIONS(1549), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(644), 1,
      sym__exp,
    STATE(932), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1543), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1547), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [56837] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1587), 1,
      sym__if_else_separator,
    STATE(933), 1,
      sym_comment,
    ACTIONS(1585), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [56883] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1539), 1,
      anon_sym_getline,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(1545), 1,
      anon_sym_BANG,
    ACTIONS(1549), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(666), 1,
      sym__exp,
    STATE(934), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1543), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1547), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [56965] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(463), 1,
      sym__exp,
    STATE(479), 1,
      sym_string,
    STATE(935), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [57047] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1539), 1,
      anon_sym_getline,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(1545), 1,
      anon_sym_BANG,
    ACTIONS(1549), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(658), 1,
      sym__exp,
    STATE(936), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1543), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1547), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [57129] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1539), 1,
      anon_sym_getline,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(1545), 1,
      anon_sym_BANG,
    ACTIONS(1549), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(661), 1,
      sym__exp,
    STATE(937), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1543), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1547), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [57211] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1539), 1,
      anon_sym_getline,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(1545), 1,
      anon_sym_BANG,
    ACTIONS(1549), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(632), 1,
      sym__exp,
    STATE(938), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1543), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1547), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [57293] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1421), 1,
      anon_sym_getline,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(1427), 1,
      anon_sym_BANG,
    ACTIONS(1431), 1,
      anon_sym_AT,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(429), 1,
      sym__exp,
    STATE(939), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1425), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1429), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [57375] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1421), 1,
      anon_sym_getline,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(1427), 1,
      anon_sym_BANG,
    ACTIONS(1431), 1,
      anon_sym_AT,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(428), 1,
      sym__exp,
    STATE(940), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1425), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1429), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [57457] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1421), 1,
      anon_sym_getline,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(1427), 1,
      anon_sym_BANG,
    ACTIONS(1431), 1,
      anon_sym_AT,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(413), 1,
      sym__exp,
    STATE(941), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1425), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1429), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [57539] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1395), 1,
      anon_sym_getline,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(1401), 1,
      anon_sym_BANG,
    ACTIONS(1405), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(125), 1,
      sym__exp,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(942), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [57621] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1421), 1,
      anon_sym_getline,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(1427), 1,
      anon_sym_BANG,
    ACTIONS(1431), 1,
      anon_sym_AT,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(412), 1,
      sym__exp,
    STATE(943), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1425), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1429), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [57703] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1421), 1,
      anon_sym_getline,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(1427), 1,
      anon_sym_BANG,
    ACTIONS(1431), 1,
      anon_sym_AT,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(426), 1,
      sym__exp,
    STATE(944), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1425), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1429), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [57785] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1421), 1,
      anon_sym_getline,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(1427), 1,
      anon_sym_BANG,
    ACTIONS(1431), 1,
      anon_sym_AT,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(250), 1,
      sym__exp,
    STATE(945), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1425), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1429), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [57867] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1421), 1,
      anon_sym_getline,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(1427), 1,
      anon_sym_BANG,
    ACTIONS(1431), 1,
      anon_sym_AT,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(422), 1,
      sym__exp,
    STATE(946), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1425), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1429), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [57949] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1421), 1,
      anon_sym_getline,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(1427), 1,
      anon_sym_BANG,
    ACTIONS(1431), 1,
      anon_sym_AT,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(418), 1,
      sym__exp,
    STATE(947), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1425), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1429), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [58031] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(475), 1,
      sym__exp,
    STATE(479), 1,
      sym_string,
    STATE(948), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [58113] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1539), 1,
      anon_sym_getline,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(1545), 1,
      anon_sym_BANG,
    ACTIONS(1549), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(178), 1,
      sym__exp,
    STATE(949), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1543), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1547), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [58195] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1539), 1,
      anon_sym_getline,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(1545), 1,
      anon_sym_BANG,
    ACTIONS(1549), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(670), 1,
      sym__exp,
    STATE(950), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1543), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1547), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [58277] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1539), 1,
      anon_sym_getline,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(1545), 1,
      anon_sym_BANG,
    ACTIONS(1549), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(668), 1,
      sym__exp,
    STATE(951), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1543), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1547), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [58359] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(338), 1,
      sym__exp,
    STATE(952), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [58441] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(953), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1265), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [58523] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(473), 1,
      sym__exp,
    STATE(479), 1,
      sym_string,
    STATE(954), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [58605] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    ACTIONS(1561), 1,
      anon_sym_getline,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(1567), 1,
      anon_sym_BANG,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(268), 1,
      sym__exp,
    STATE(955), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1565), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1569), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [58687] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(956), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1246), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [58769] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(957), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1253), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [58851] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(958), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1262), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [58933] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(269), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_SLASH,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(301), 1,
      anon_sym_AT,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    STATE(551), 1,
      sym_ns_qualified_name,
    STATE(576), 1,
      sym_array_ref,
    STATE(595), 1,
      sym_field_ref,
    STATE(959), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1229), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(297), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1279), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [59015] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(960), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1264), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [59097] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(961), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1263), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [59179] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(962), 1,
      sym_comment,
    STATE(1205), 1,
      sym__exp,
    STATE(1232), 1,
      sym_string,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [59261] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(963), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1251), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [59343] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_BANG,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(1529), 1,
      sym_identifier,
    ACTIONS(1531), 1,
      anon_sym_getline,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(1537), 1,
      anon_sym_AT,
    STATE(526), 1,
      sym_ns_qualified_name,
    STATE(554), 1,
      sym_array_ref,
    STATE(589), 1,
      sym_field_ref,
    STATE(964), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1273), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(119), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1535), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [59425] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    ACTIONS(1561), 1,
      anon_sym_getline,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(1567), 1,
      anon_sym_BANG,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(261), 1,
      sym__exp,
    STATE(965), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1565), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1569), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [59507] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(966), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1497), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [59589] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    ACTIONS(1561), 1,
      anon_sym_getline,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(1567), 1,
      anon_sym_BANG,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(719), 1,
      sym__exp,
    STATE(967), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1565), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1569), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [59671] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    ACTIONS(1561), 1,
      anon_sym_getline,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(1567), 1,
      anon_sym_BANG,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(725), 1,
      sym__exp,
    STATE(968), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1565), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1569), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [59753] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(269), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_SLASH,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(301), 1,
      anon_sym_AT,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    STATE(551), 1,
      sym_ns_qualified_name,
    STATE(576), 1,
      sym_array_ref,
    STATE(595), 1,
      sym_field_ref,
    STATE(969), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1314), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(297), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1279), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [59835] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    ACTIONS(1561), 1,
      anon_sym_getline,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(1567), 1,
      anon_sym_BANG,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(726), 1,
      sym__exp,
    STATE(970), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1565), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1569), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [59917] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(269), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_SLASH,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(301), 1,
      anon_sym_AT,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    STATE(551), 1,
      sym_ns_qualified_name,
    STATE(576), 1,
      sym_array_ref,
    STATE(595), 1,
      sym_field_ref,
    STATE(971), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1227), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(297), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1279), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [59999] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    ACTIONS(1561), 1,
      anon_sym_getline,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(1567), 1,
      anon_sym_BANG,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(735), 1,
      sym__exp,
    STATE(972), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1565), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1569), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [60081] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    ACTIONS(1561), 1,
      anon_sym_getline,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(1567), 1,
      anon_sym_BANG,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(722), 1,
      sym__exp,
    STATE(973), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1565), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1569), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [60163] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    ACTIONS(1561), 1,
      anon_sym_getline,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(1567), 1,
      anon_sym_BANG,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(705), 1,
      sym__exp,
    STATE(974), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1565), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1569), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [60245] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    ACTIONS(1561), 1,
      anon_sym_getline,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(1567), 1,
      anon_sym_BANG,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(250), 1,
      sym__exp,
    STATE(975), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1565), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1569), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [60327] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    ACTIONS(1561), 1,
      anon_sym_getline,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(1567), 1,
      anon_sym_BANG,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(708), 1,
      sym__exp,
    STATE(976), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1565), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1569), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [60409] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    ACTIONS(1561), 1,
      anon_sym_getline,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(1567), 1,
      anon_sym_BANG,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(679), 1,
      sym__exp,
    STATE(977), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1565), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1569), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [60491] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    ACTIONS(1589), 1,
      anon_sym_in,
    STATE(978), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [60553] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(979), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1518), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [60635] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(980), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1490), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [60717] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(981), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1484), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [60799] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    ACTIONS(1561), 1,
      anon_sym_getline,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(1567), 1,
      anon_sym_BANG,
    ACTIONS(1571), 1,
      anon_sym_AT,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(264), 1,
      sym__exp,
    STATE(982), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1565), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1569), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [60881] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(131), 1,
      sym_identifier,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(149), 1,
      anon_sym_getline,
    ACTIONS(155), 1,
      anon_sym_SLASH,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(165), 1,
      anon_sym_AT,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    STATE(182), 1,
      sym_ns_qualified_name,
    STATE(203), 1,
      sym_array_ref,
    STATE(208), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(396), 1,
      sym__exp,
    STATE(983), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(161), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(392), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(381), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(391), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [60963] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(984), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1455), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [61045] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(985), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1460), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [61127] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(986), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1461), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [61209] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(987), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1462), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [61291] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(988), 1,
      sym_comment,
    STATE(1155), 1,
      sym__exp,
    STATE(1178), 1,
      sym_string,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [61373] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(989), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1463), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [61455] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(990), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1464), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [61537] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(991), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1465), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [61619] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(992), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1466), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [61701] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(993), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1525), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [61783] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(994), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1470), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [61865] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(995), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1480), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [61947] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(996), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1481), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [62029] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(997), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1486), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [62111] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(998), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1282), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [62193] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(999), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1520), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [62275] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(1000), 1,
      sym_comment,
    STATE(1164), 1,
      sym__exp,
    STATE(1178), 1,
      sym_string,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [62357] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1595), 1,
      sym__if_else_separator,
    STATE(1001), 1,
      sym_comment,
    ACTIONS(1593), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1591), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [62405] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(1002), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1521), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [62487] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(1003), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1522), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [62569] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1597), 1,
      sym_identifier,
    STATE(1004), 1,
      sym_comment,
    STATE(1165), 1,
      sym_ns_qualified_name,
    STATE(1815), 1,
      sym_namespace,
    ACTIONS(501), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(499), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [62621] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(1005), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1509), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [62703] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(1006), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1506), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [62785] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(1007), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1502), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [62867] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(1008), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1483), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [62949] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(1009), 1,
      sym_comment,
    STATE(1177), 1,
      sym__exp,
    STATE(1178), 1,
      sym_string,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [63031] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(269), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_SLASH,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(301), 1,
      anon_sym_AT,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    STATE(551), 1,
      sym_ns_qualified_name,
    STATE(576), 1,
      sym_array_ref,
    STATE(595), 1,
      sym_field_ref,
    STATE(1010), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1240), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(297), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1279), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [63113] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(315), 1,
      sym__exp,
    STATE(1011), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [63195] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(321), 1,
      sym_identifier,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(337), 1,
      anon_sym_getline,
    ACTIONS(343), 1,
      anon_sym_SLASH,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(353), 1,
      anon_sym_AT,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    STATE(145), 1,
      sym_ns_qualified_name,
    STATE(168), 1,
      sym_array_ref,
    STATE(199), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(370), 1,
      sym__exp,
    STATE(1012), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(349), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(354), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(286), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(353), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [63277] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1395), 1,
      anon_sym_getline,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(1401), 1,
      anon_sym_BANG,
    ACTIONS(1405), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(146), 1,
      sym__exp,
    STATE(149), 1,
      sym_field_ref,
    STATE(1013), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [63359] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(380), 1,
      sym__exp,
    STATE(1014), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [63441] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(1015), 1,
      sym_comment,
    STATE(1200), 1,
      sym__exp,
    STATE(1232), 1,
      sym_string,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [63523] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_getline,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(1515), 1,
      anon_sym_AT,
    STATE(536), 1,
      sym_ns_qualified_name,
    STATE(566), 1,
      sym_array_ref,
    STATE(604), 1,
      sym_field_ref,
    STATE(1016), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1280), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1513), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1167), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1152), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1157), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [63605] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(384), 1,
      sym__exp,
    STATE(1017), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [63687] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(349), 1,
      sym__exp,
    STATE(1018), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [63769] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(1375), 1,
      sym_identifier,
    ACTIONS(1377), 1,
      anon_sym_LPAREN,
    ACTIONS(1391), 1,
      sym_number,
    ACTIONS(1393), 1,
      anon_sym_DQUOTE,
    ACTIONS(1395), 1,
      anon_sym_getline,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(1401), 1,
      anon_sym_BANG,
    ACTIONS(1405), 1,
      anon_sym_AT,
    STATE(98), 1,
      sym_ns_qualified_name,
    STATE(109), 1,
      sym_array_ref,
    STATE(126), 1,
      sym_string,
    STATE(149), 1,
      sym_field_ref,
    STATE(204), 1,
      sym__exp,
    STATE(1019), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(1399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1403), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(141), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(136), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(142), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [63851] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(383), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_getline,
    ACTIONS(413), 1,
      anon_sym_SLASH,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_AT,
    STATE(587), 1,
      sym_ns_qualified_name,
    STATE(624), 1,
      sym_array_ref,
    STATE(669), 1,
      sym_field_ref,
    STATE(1020), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1278), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(417), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1320), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [63933] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_getline,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(1445), 1,
      anon_sym_AT,
    STATE(121), 1,
      sym_ns_qualified_name,
    STATE(154), 1,
      sym_array_ref,
    STATE(189), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(304), 1,
      sym__exp,
    STATE(1021), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1443), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(284), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(283), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(285), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [64015] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(385), 1,
      sym__exp,
    STATE(1022), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [64097] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(1023), 1,
      sym_comment,
    STATE(1352), 1,
      sym__exp,
    STATE(1372), 1,
      sym_string,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [64179] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1493), 1,
      anon_sym_getline,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(1499), 1,
      anon_sym_BANG,
    ACTIONS(1503), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(210), 1,
      sym__exp,
    STATE(1024), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1497), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1501), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [64261] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(387), 1,
      sym__exp,
    STATE(1025), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [64343] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(386), 1,
      sym__exp,
    STATE(1026), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [64425] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(1027), 1,
      sym_comment,
    STATE(1355), 1,
      sym__exp,
    STATE(1372), 1,
      sym_string,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [64507] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1365), 1,
      sym_identifier,
    ACTIONS(1367), 1,
      anon_sym_getline,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(1373), 1,
      anon_sym_AT,
    STATE(375), 1,
      sym_ns_qualified_name,
    STATE(394), 1,
      sym_array_ref,
    STATE(420), 1,
      sym_field_ref,
    STATE(466), 1,
      sym__exp,
    STATE(479), 1,
      sym_string,
    STATE(1028), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1371), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(468), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(467), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(469), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [64589] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(1469), 1,
      sym_identifier,
    ACTIONS(1471), 1,
      anon_sym_LPAREN,
    ACTIONS(1485), 1,
      sym_number,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1493), 1,
      anon_sym_getline,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(1499), 1,
      anon_sym_BANG,
    ACTIONS(1503), 1,
      anon_sym_AT,
    STATE(112), 1,
      sym_ns_qualified_name,
    STATE(148), 1,
      sym_array_ref,
    STATE(158), 1,
      sym__exp,
    STATE(160), 1,
      sym_string,
    STATE(161), 1,
      sym_field_ref,
    STATE(1029), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(1497), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1501), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(153), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(155), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(162), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [64671] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(1551), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_getline,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(1559), 1,
      anon_sym_AT,
    STATE(561), 1,
      sym_ns_qualified_name,
    STATE(594), 1,
      sym_array_ref,
    STATE(629), 1,
      sym_field_ref,
    STATE(1030), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1313), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1557), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1214), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1208), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1217), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [64753] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(383), 1,
      sym__exp,
    STATE(1031), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [64835] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_getline,
    ACTIONS(19), 1,
      anon_sym_SLASH,
    ACTIONS(23), 1,
      anon_sym_BANG,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(31), 1,
      sym_number,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(1491), 1,
      anon_sym_AT,
    STATE(348), 1,
      sym_ns_qualified_name,
    STATE(409), 1,
      sym_array_ref,
    STATE(415), 1,
      sym_field_ref,
    STATE(479), 1,
      sym_string,
    STATE(494), 1,
      sym__exp,
    STATE(1032), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(21), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(25), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(513), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(471), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(503), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [64917] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(345), 1,
      sym__exp,
    STATE(1033), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [64999] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(346), 1,
      sym__exp,
    STATE(1034), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [65081] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(269), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_SLASH,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(301), 1,
      anon_sym_AT,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    STATE(551), 1,
      sym_ns_qualified_name,
    STATE(576), 1,
      sym_array_ref,
    STATE(595), 1,
      sym_field_ref,
    STATE(1035), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1392), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(297), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1279), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [65163] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(269), 1,
      anon_sym_getline,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    ACTIONS(293), 1,
      anon_sym_SLASH,
    ACTIONS(295), 1,
      anon_sym_BANG,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(301), 1,
      anon_sym_AT,
    ACTIONS(303), 1,
      sym_number,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    STATE(551), 1,
      sym_ns_qualified_name,
    STATE(576), 1,
      sym_array_ref,
    STATE(595), 1,
      sym_field_ref,
    STATE(1036), 1,
      sym_comment,
    STATE(1178), 1,
      sym_string,
    STATE(1389), 1,
      sym__exp,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(277), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(297), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1196), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1194), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1279), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [65245] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1601), 1,
      sym__if_else_separator,
    STATE(1037), 1,
      sym_comment,
    ACTIONS(1599), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [65291] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(131), 1,
      sym_identifier,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(149), 1,
      anon_sym_getline,
    ACTIONS(155), 1,
      anon_sym_SLASH,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(165), 1,
      anon_sym_AT,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    STATE(182), 1,
      sym_ns_qualified_name,
    STATE(203), 1,
      sym_array_ref,
    STATE(208), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(403), 1,
      sym__exp,
    STATE(1038), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(161), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(392), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(381), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(391), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [65373] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1603), 1,
      sym_identifier,
    STATE(134), 1,
      sym_array_ref,
    STATE(179), 1,
      sym_ns_qualified_name,
    STATE(181), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(1039), 1,
      sym_comment,
    STATE(1537), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(376), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [65455] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(131), 1,
      sym_identifier,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(149), 1,
      anon_sym_getline,
    ACTIONS(155), 1,
      anon_sym_SLASH,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(165), 1,
      anon_sym_AT,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    STATE(182), 1,
      sym_ns_qualified_name,
    STATE(203), 1,
      sym_array_ref,
    STATE(208), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(401), 1,
      sym__exp,
    STATE(1040), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(161), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(392), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(381), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(391), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [65537] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1607), 1,
      sym__if_else_separator,
    STATE(1041), 1,
      sym_comment,
    ACTIONS(1605), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [65583] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1595), 1,
      sym__if_else_separator,
    STATE(1042), 1,
      sym_comment,
    ACTIONS(1591), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [65629] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(131), 1,
      sym_identifier,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(149), 1,
      anon_sym_getline,
    ACTIONS(155), 1,
      anon_sym_SLASH,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(165), 1,
      anon_sym_AT,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    STATE(182), 1,
      sym_ns_qualified_name,
    STATE(203), 1,
      sym_array_ref,
    STATE(208), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(397), 1,
      sym__exp,
    STATE(1043), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(161), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(392), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(381), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(391), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [65711] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1611), 1,
      sym__if_else_separator,
    STATE(1044), 1,
      sym_comment,
    ACTIONS(1609), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [65757] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(1417), 1,
      sym_identifier,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1421), 1,
      anon_sym_getline,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(1427), 1,
      anon_sym_BANG,
    ACTIONS(1431), 1,
      anon_sym_AT,
    ACTIONS(1433), 1,
      sym_number,
    ACTIONS(1435), 1,
      anon_sym_DQUOTE,
    STATE(224), 1,
      sym_ns_qualified_name,
    STATE(231), 1,
      sym_array_ref,
    STATE(244), 1,
      sym_string,
    STATE(245), 1,
      sym_field_ref,
    STATE(414), 1,
      sym__exp,
    STATE(1045), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1425), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1429), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(254), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(253), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(255), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [65839] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1200), 1,
      sym__if_else_separator,
    STATE(1046), 1,
      sym_comment,
    ACTIONS(1194), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [65885] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1615), 1,
      sym__if_else_separator,
    STATE(1047), 1,
      sym_comment,
    ACTIONS(1613), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [65931] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(383), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_getline,
    ACTIONS(413), 1,
      anon_sym_SLASH,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_AT,
    STATE(587), 1,
      sym_ns_qualified_name,
    STATE(624), 1,
      sym_array_ref,
    STATE(669), 1,
      sym_field_ref,
    STATE(1048), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1414), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(417), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1320), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [66013] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(359), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 1,
      sym_number,
    ACTIONS(377), 1,
      anon_sym_DQUOTE,
    ACTIONS(383), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_getline,
    ACTIONS(413), 1,
      anon_sym_SLASH,
    ACTIONS(415), 1,
      anon_sym_BANG,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(421), 1,
      anon_sym_AT,
    STATE(587), 1,
      sym_ns_qualified_name,
    STATE(624), 1,
      sym_array_ref,
    STATE(669), 1,
      sym_field_ref,
    STATE(1049), 1,
      sym_comment,
    STATE(1232), 1,
      sym_string,
    STATE(1406), 1,
      sym__exp,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(401), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(417), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1247), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1256), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1320), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [66095] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1615), 1,
      sym__if_else_separator,
    STATE(1050), 1,
      sym_comment,
    ACTIONS(1593), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1613), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [66143] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1619), 1,
      sym__if_else_separator,
    STATE(1051), 1,
      sym_comment,
    ACTIONS(1617), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [66189] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(85), 1,
      sym__if_else_separator,
    STATE(1052), 1,
      sym_comment,
    ACTIONS(39), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [66235] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(1053), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1398), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [66317] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1621), 1,
      sym_identifier,
    STATE(234), 1,
      sym_array_ref,
    STATE(246), 1,
      sym_field_ref,
    STATE(591), 1,
      sym_ns_qualified_name,
    STATE(1054), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1541), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1368), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [66399] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(1055), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1396), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [66481] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(1056), 1,
      sym_comment,
    STATE(1370), 1,
      sym__exp,
    STATE(1372), 1,
      sym_string,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [66563] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(1057), 1,
      sym_comment,
    STATE(1371), 1,
      sym__exp,
    STATE(1372), 1,
      sym_string,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [66645] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(1058), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1374), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [66727] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(1059), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1375), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [66809] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1619), 1,
      sym__if_else_separator,
    STATE(1060), 1,
      sym_comment,
    ACTIONS(1593), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1617), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [66857] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1625), 1,
      sym__if_else_separator,
    STATE(1061), 1,
      sym_comment,
    ACTIONS(1623), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [66903] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1625), 1,
      sym__if_else_separator,
    STATE(1062), 1,
      sym_comment,
    ACTIONS(1593), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1623), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [66951] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(1063), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1376), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [67033] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(1064), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1377), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [67115] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1629), 1,
      sym__if_else_separator,
    STATE(1065), 1,
      sym_comment,
    ACTIONS(1627), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [67161] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(1066), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1378), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [67243] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1629), 1,
      sym__if_else_separator,
    STATE(1067), 1,
      sym_comment,
    ACTIONS(1627), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [67289] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(1068), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1379), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [67371] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(321), 1,
      sym_identifier,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(337), 1,
      anon_sym_getline,
    ACTIONS(343), 1,
      anon_sym_SLASH,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(353), 1,
      anon_sym_AT,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    STATE(145), 1,
      sym_ns_qualified_name,
    STATE(168), 1,
      sym_array_ref,
    STATE(199), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(421), 1,
      sym__exp,
    STATE(1069), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(349), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(354), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(286), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(353), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [67453] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1633), 1,
      sym__if_else_separator,
    STATE(1070), 1,
      sym_comment,
    ACTIONS(1631), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [67499] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(321), 1,
      sym_identifier,
    ACTIONS(327), 1,
      anon_sym_LPAREN,
    ACTIONS(337), 1,
      anon_sym_getline,
    ACTIONS(343), 1,
      anon_sym_SLASH,
    ACTIONS(347), 1,
      anon_sym_BANG,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(353), 1,
      anon_sym_AT,
    ACTIONS(355), 1,
      sym_number,
    ACTIONS(357), 1,
      anon_sym_DQUOTE,
    STATE(145), 1,
      sym_ns_qualified_name,
    STATE(168), 1,
      sym_array_ref,
    STATE(199), 1,
      sym_field_ref,
    STATE(294), 1,
      sym_string,
    STATE(425), 1,
      sym__exp,
    STATE(1071), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    ACTIONS(345), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(349), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(354), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(286), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(353), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [67581] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1637), 1,
      sym__if_else_separator,
    STATE(1072), 1,
      sym_comment,
    ACTIONS(1635), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [67627] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1641), 1,
      sym__if_else_separator,
    STATE(1073), 1,
      sym_comment,
    ACTIONS(1639), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [67673] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1641), 1,
      sym__if_else_separator,
    STATE(1074), 1,
      sym_comment,
    ACTIONS(1593), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1639), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [67721] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(1075), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1399), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [67803] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1645), 1,
      sym__if_else_separator,
    STATE(1076), 1,
      sym_comment,
    ACTIONS(1643), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [67849] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1645), 1,
      sym__if_else_separator,
    STATE(1077), 1,
      sym_comment,
    ACTIONS(1593), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1643), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [67897] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(135), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(167), 1,
      sym_number,
    ACTIONS(169), 1,
      anon_sym_DQUOTE,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_getline,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(1415), 1,
      anon_sym_AT,
    STATE(164), 1,
      sym_ns_qualified_name,
    STATE(195), 1,
      sym_array_ref,
    STATE(215), 1,
      sym_field_ref,
    STATE(330), 1,
      sym_string,
    STATE(371), 1,
      sym__exp,
    STATE(1078), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    ACTIONS(157), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1413), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(336), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(335), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(337), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [67979] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1649), 1,
      sym__if_else_separator,
    STATE(1079), 1,
      sym_comment,
    ACTIONS(1647), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68025] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1118), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_getline,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1134), 1,
      anon_sym_AT,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    STATE(601), 1,
      sym_ns_qualified_name,
    STATE(641), 1,
      sym_array_ref,
    STATE(715), 1,
      sym_field_ref,
    STATE(1080), 1,
      sym_comment,
    STATE(1372), 1,
      sym_string,
    STATE(1388), 1,
      sym__exp,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1130), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1395), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1363), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
    STATE(1393), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
  [68107] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1649), 1,
      sym__if_else_separator,
    STATE(1081), 1,
      sym_comment,
    ACTIONS(1593), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1647), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68155] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1653), 1,
      sym__if_else_separator,
    STATE(1082), 1,
      sym_comment,
    ACTIONS(1651), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68201] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1653), 1,
      sym__if_else_separator,
    STATE(1083), 1,
      sym_comment,
    ACTIONS(1593), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1651), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68249] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1657), 1,
      sym__if_else_separator,
    STATE(1084), 1,
      sym_comment,
    ACTIONS(1655), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68295] = 22,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_LPAREN,
    ACTIONS(1128), 1,
      anon_sym_BANG,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(1136), 1,
      sym_number,
    ACTIONS(1138), 1,
      anon_sym_DQUOTE,
    ACTIONS(1573), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_getline,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(1581), 1,
      anon_sym_AT,
    STATE(606), 1,
      sym_ns_qualified_name,
    STATE(638), 1,
      sym_array_ref,
    STATE(698), 1,
      sym_field_ref,
    STATE(1085), 1,
      sym_comment,
    STATE(1362), 1,
      sym__exp,
    STATE(1372), 1,
      sym_string,
    STATE(1853), 1,
      sym_namespace,
    ACTIONS(1126), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1579), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1367), 2,
      sym_getline_input,
      sym_getline_file,
    STATE(1364), 7,
      sym__getline_exp,
      sym_update_exp,
      sym_assignment_exp,
      sym_piped_io_exp,
      sym_regex,
      sym_regex_constant,
      sym_indirect_func_call,
    STATE(1373), 7,
      sym_ternary_exp,
      sym_binary_exp,
      sym_unary_exp,
      sym_string_concat,
      sym_grouping,
      sym__primitive,
      sym_func_call,
  [68377] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1661), 1,
      sym__if_else_separator,
    STATE(1086), 1,
      sym_comment,
    ACTIONS(1659), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68423] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1665), 1,
      sym__if_else_separator,
    STATE(1087), 1,
      sym_comment,
    ACTIONS(1663), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68469] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1665), 1,
      sym__if_else_separator,
    STATE(1088), 1,
      sym_comment,
    ACTIONS(1593), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1663), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68517] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1669), 1,
      sym__if_else_separator,
    STATE(1089), 1,
      sym_comment,
    ACTIONS(1667), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68563] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1673), 1,
      sym__if_else_separator,
    STATE(1090), 1,
      sym_comment,
    ACTIONS(1671), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68609] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1677), 1,
      sym__if_else_separator,
    STATE(1091), 1,
      sym_comment,
    ACTIONS(1675), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68655] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1677), 1,
      sym__if_else_separator,
    STATE(1092), 1,
      sym_comment,
    ACTIONS(1593), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1675), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68703] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1093), 1,
      sym_comment,
    ACTIONS(1591), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68746] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym_concatenating_space,
    ACTIONS(1679), 1,
      sym_identifier,
    STATE(1094), 1,
      sym_comment,
    STATE(1210), 1,
      sym_ns_qualified_name,
    STATE(1809), 1,
      sym_namespace,
    ACTIONS(499), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [68797] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1095), 1,
      sym_comment,
    ACTIONS(39), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68840] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1096), 1,
      sym_comment,
    ACTIONS(1605), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68883] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1097), 1,
      sym_comment,
    ACTIONS(1655), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68926] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1098), 1,
      sym_comment,
    ACTIONS(1609), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [68969] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1099), 1,
      sym_comment,
    ACTIONS(1667), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69012] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1100), 1,
      sym_comment,
    ACTIONS(1643), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69055] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1101), 1,
      sym_comment,
    ACTIONS(1635), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69098] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1102), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1651), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69143] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1103), 1,
      sym_comment,
    ACTIONS(1651), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69186] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1104), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1647), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69231] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1105), 1,
      sym_comment,
    ACTIONS(1647), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69274] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1683), 1,
      anon_sym_LBRACK,
    STATE(1106), 1,
      sym_comment,
    ACTIONS(443), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(441), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [69323] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1107), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1643), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69368] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1108), 1,
      sym_comment,
    ACTIONS(1599), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69411] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1109), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1623), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69456] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    ACTIONS(1447), 1,
      anon_sym_in,
    STATE(1110), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [69515] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1111), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1663), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69560] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1112), 1,
      sym_comment,
    ACTIONS(1627), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69603] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1113), 1,
      sym_comment,
    ACTIONS(1617), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69646] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1114), 1,
      sym_comment,
    ACTIONS(1585), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69689] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1115), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1639), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69734] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1116), 1,
      sym_comment,
    ACTIONS(1639), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69777] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1117), 1,
      sym_comment,
    ACTIONS(1623), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69820] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1118), 1,
      sym_comment,
    ACTIONS(1631), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69863] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym__if_else_separator,
    ACTIONS(1685), 1,
      sym_identifier,
    STATE(1119), 1,
      sym_comment,
    STATE(1209), 1,
      sym_ns_qualified_name,
    STATE(1814), 1,
      sym_namespace,
    ACTIONS(499), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [69914] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1120), 1,
      sym_comment,
    ACTIONS(1663), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [69957] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    ACTIONS(1583), 1,
      anon_sym_in,
    STATE(1121), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [70016] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1122), 1,
      sym_comment,
    ACTIONS(1675), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [70059] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1123), 1,
      sym_comment,
    ACTIONS(1627), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [70102] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    ACTIONS(1589), 1,
      anon_sym_in,
    STATE(1124), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [70161] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1125), 1,
      sym_comment,
    ACTIONS(1659), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [70204] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1126), 1,
      sym_comment,
    ACTIONS(1671), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [70247] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1127), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1675), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [70292] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1128), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1617), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [70337] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1129), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1591), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [70382] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    ACTIONS(1453), 1,
      anon_sym_in,
    STATE(1130), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [70441] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1131), 1,
      sym_comment,
    ACTIONS(1194), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [70484] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1132), 1,
      sym_comment,
    ACTIONS(1613), 34,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [70527] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    ACTIONS(1517), 1,
      anon_sym_in,
    STATE(1133), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [70586] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1687), 1,
      sym_identifier,
    ACTIONS(1689), 1,
      anon_sym_LT,
    STATE(1134), 1,
      sym_comment,
    STATE(1211), 1,
      sym_ns_qualified_name,
    STATE(1815), 1,
      sym_namespace,
    ACTIONS(501), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(499), 28,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [70639] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(461), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_LBRACK,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    ACTIONS(1455), 1,
      anon_sym_in,
    STATE(1135), 1,
      sym_comment,
    ACTIONS(675), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(685), 6,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_CARET_EQ,
    ACTIONS(423), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(433), 12,
      anon_sym_SEMI,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_STAR,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [70698] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1136), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1613), 31,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [70743] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1691), 1,
      sym_identifier,
    STATE(1137), 1,
      sym_comment,
    STATE(1271), 1,
      sym_ns_qualified_name,
    STATE(1806), 1,
      sym_namespace,
    ACTIONS(499), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [70791] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(443), 1,
      sym_concatenating_space,
    ACTIONS(1693), 1,
      anon_sym_LBRACK,
    STATE(1138), 1,
      sym_comment,
    ACTIONS(441), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [70839] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1683), 1,
      anon_sym_LBRACK,
    STATE(1139), 1,
      sym_comment,
    ACTIONS(443), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(441), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [70885] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym_concatenating_space,
    ACTIONS(1695), 1,
      sym_identifier,
    ACTIONS(1697), 1,
      anon_sym_LT,
    STATE(1140), 1,
      sym_comment,
    STATE(1254), 1,
      sym_ns_qualified_name,
    STATE(1809), 1,
      sym_namespace,
    ACTIONS(499), 28,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [70937] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1141), 1,
      sym_comment,
    ACTIONS(453), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(451), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
  [70981] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(443), 1,
      sym__if_else_separator,
    ACTIONS(1699), 1,
      anon_sym_LBRACK,
    STATE(1142), 1,
      sym_comment,
    ACTIONS(441), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71029] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    STATE(1143), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71075] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1703), 1,
      sym__if_else_separator,
    STATE(1144), 1,
      sym_comment,
    ACTIONS(1701), 32,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [71119] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1705), 1,
      sym__if_else_separator,
    STATE(1145), 1,
      sym_comment,
    ACTIONS(1701), 32,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [71163] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1705), 1,
      sym__if_else_separator,
    STATE(1146), 1,
      sym_comment,
    ACTIONS(1701), 32,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [71207] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1147), 1,
      sym_comment,
    ACTIONS(475), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(473), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
  [71251] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym__if_else_separator,
    ACTIONS(1707), 1,
      sym_identifier,
    ACTIONS(1709), 1,
      anon_sym_LT,
    STATE(1148), 1,
      sym_comment,
    STATE(1255), 1,
      sym_ns_qualified_name,
    STATE(1814), 1,
      sym_namespace,
    ACTIONS(499), 28,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71303] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1703), 1,
      sym__if_else_separator,
    STATE(1149), 1,
      sym_comment,
    ACTIONS(1701), 32,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [71347] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1150), 1,
      sym_comment,
    ACTIONS(521), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(519), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71390] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1151), 1,
      sym_comment,
    ACTIONS(509), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(507), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71433] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1152), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(423), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71476] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1711), 1,
      sym_regex_flags,
    STATE(1153), 1,
      sym_comment,
    ACTIONS(591), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(587), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71521] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1154), 1,
      sym_comment,
    ACTIONS(581), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(579), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71564] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1155), 1,
      sym_comment,
    ACTIONS(495), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(493), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71607] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1713), 1,
      anon_sym_LBRACK,
    STATE(1156), 1,
      sym_comment,
    ACTIONS(441), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71652] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1157), 1,
      sym_comment,
    ACTIONS(433), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(423), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71695] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(453), 1,
      sym__if_else_separator,
    STATE(1158), 1,
      sym_comment,
    ACTIONS(451), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
  [71738] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(443), 1,
      sym_concatenating_space,
    ACTIONS(1693), 1,
      anon_sym_LBRACK,
    STATE(1159), 1,
      sym_comment,
    ACTIONS(441), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71783] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(471), 1,
      sym_concatenating_space,
    STATE(1160), 1,
      sym_comment,
    ACTIONS(469), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71828] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1161), 1,
      sym_comment,
    ACTIONS(439), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(435), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
    ACTIONS(423), 21,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71873] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1162), 1,
      sym_comment,
    ACTIONS(487), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(485), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71916] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1715), 1,
      sym_identifier,
    ACTIONS(1717), 1,
      anon_sym_LT,
    STATE(1163), 1,
      sym_comment,
    STATE(1289), 1,
      sym_ns_qualified_name,
    STATE(1815), 1,
      sym_namespace,
    ACTIONS(501), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(499), 26,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [71967] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1164), 1,
      sym_comment,
    ACTIONS(513), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(511), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72010] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1165), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72053] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1719), 1,
      sym_identifier,
    ACTIONS(1721), 1,
      anon_sym_LT,
    STATE(1166), 1,
      sym_comment,
    STATE(1284), 1,
      sym_ns_qualified_name,
    STATE(1806), 1,
      sym_namespace,
    ACTIONS(499), 28,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72102] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1167), 1,
      sym_comment,
    ACTIONS(565), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(563), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72145] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1168), 1,
      sym_comment,
    ACTIONS(537), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(535), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72188] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1169), 1,
      sym_comment,
    ACTIONS(479), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(477), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72231] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(475), 1,
      sym__if_else_separator,
    STATE(1170), 1,
      sym_comment,
    ACTIONS(473), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
  [72274] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1171), 1,
      sym_comment,
    ACTIONS(483), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(481), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72317] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1172), 1,
      sym_comment,
    ACTIONS(491), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(489), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72360] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(475), 1,
      sym_concatenating_space,
    STATE(1173), 1,
      sym_comment,
    ACTIONS(473), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
  [72403] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1723), 1,
      anon_sym_LT,
    STATE(1174), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 28,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72450] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1175), 1,
      sym_comment,
    ACTIONS(443), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(441), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72493] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1176), 1,
      sym_comment,
    ACTIONS(505), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(503), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72536] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1177), 1,
      sym_comment,
    ACTIONS(577), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(575), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72579] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1178), 1,
      sym_comment,
    ACTIONS(517), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(515), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72622] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1179), 1,
      sym_comment,
    ACTIONS(533), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(531), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72665] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1180), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(539), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72708] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(453), 1,
      sym_concatenating_space,
    STATE(1181), 1,
      sym_comment,
    ACTIONS(451), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
  [72751] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(471), 1,
      sym__if_else_separator,
    STATE(1182), 1,
      sym_comment,
    ACTIONS(469), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72796] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1183), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(1725), 29,
      anon_sym_if,
      anon_sym_LPAREN,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_identifier,
      sym_number,
      anon_sym_DQUOTE,
  [72839] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(443), 1,
      sym__if_else_separator,
    ACTIONS(1699), 1,
      anon_sym_LBRACK,
    STATE(1184), 1,
      sym_comment,
    ACTIONS(441), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72884] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(533), 1,
      sym_concatenating_space,
    STATE(1185), 1,
      sym_comment,
    ACTIONS(531), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72926] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1186), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [72970] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(479), 1,
      sym_concatenating_space,
    STATE(1187), 1,
      sym_comment,
    ACTIONS(477), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73012] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(491), 1,
      sym_concatenating_space,
    STATE(1188), 1,
      sym_comment,
    ACTIONS(489), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73054] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym__if_else_separator,
    ACTIONS(1729), 1,
      sym_identifier,
    ACTIONS(1731), 1,
      anon_sym_LT,
    STATE(1189), 1,
      sym_comment,
    STATE(1323), 1,
      sym_ns_qualified_name,
    STATE(1814), 1,
      sym_namespace,
    ACTIONS(499), 26,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73104] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(487), 1,
      sym_concatenating_space,
    STATE(1190), 1,
      sym_comment,
    ACTIONS(485), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73146] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(495), 1,
      sym_concatenating_space,
    STATE(1191), 1,
      sym_comment,
    ACTIONS(493), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73188] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1192), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1741), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1733), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73242] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1193), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 20,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73292] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym__if_else_separator,
    STATE(1194), 1,
      sym_comment,
    ACTIONS(423), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73334] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(443), 1,
      sym__if_else_separator,
    STATE(1195), 1,
      sym_comment,
    ACTIONS(441), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73376] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(565), 1,
      sym__if_else_separator,
    STATE(1196), 1,
      sym_comment,
    ACTIONS(563), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73418] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(509), 1,
      sym_concatenating_space,
    STATE(1197), 1,
      sym_comment,
    ACTIONS(507), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73460] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1198), 1,
      sym_comment,
    ACTIONS(473), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
  [73500] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(513), 1,
      sym_concatenating_space,
    STATE(1199), 1,
      sym_comment,
    ACTIONS(511), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73542] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(577), 1,
      sym_concatenating_space,
    STATE(1200), 1,
      sym_comment,
    ACTIONS(575), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73584] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(443), 1,
      sym_concatenating_space,
    STATE(1201), 1,
      sym_comment,
    ACTIONS(441), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73626] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(581), 1,
      sym_concatenating_space,
    STATE(1202), 1,
      sym_comment,
    ACTIONS(579), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73668] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(537), 1,
      sym__if_else_separator,
    STATE(1203), 1,
      sym_comment,
    ACTIONS(535), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73710] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(521), 1,
      sym_concatenating_space,
    STATE(1204), 1,
      sym_comment,
    ACTIONS(519), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73752] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(1205), 1,
      sym_comment,
    ACTIONS(539), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73794] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1206), 1,
      sym_comment,
    ACTIONS(647), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73842] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1743), 1,
      anon_sym_in,
    ACTIONS(1745), 1,
      anon_sym_QMARK,
    ACTIONS(1747), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1749), 1,
      anon_sym_PIPE_PIPE,
    STATE(1207), 1,
      sym_comment,
    ACTIONS(641), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1741), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1733), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
  [73904] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    STATE(1208), 1,
      sym_comment,
    ACTIONS(423), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73946] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym__if_else_separator,
    STATE(1209), 1,
      sym_comment,
    ACTIONS(469), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [73988] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym_concatenating_space,
    STATE(1210), 1,
      sym_comment,
    ACTIONS(469), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74030] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1723), 1,
      anon_sym_LT,
    STATE(1211), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 28,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74074] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1713), 1,
      anon_sym_LBRACK,
    STATE(1212), 1,
      sym_comment,
    ACTIONS(441), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74116] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(537), 1,
      sym_concatenating_space,
    STATE(1213), 1,
      sym_comment,
    ACTIONS(535), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74158] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(565), 1,
      sym_concatenating_space,
    STATE(1214), 1,
      sym_comment,
    ACTIONS(563), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74200] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(581), 1,
      sym__if_else_separator,
    STATE(1215), 1,
      sym_comment,
    ACTIONS(579), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74242] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(591), 1,
      sym__if_else_separator,
    ACTIONS(1751), 1,
      sym_regex_flags,
    STATE(1216), 1,
      sym_comment,
    ACTIONS(587), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74286] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym_concatenating_space,
    STATE(1217), 1,
      sym_comment,
    ACTIONS(423), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74328] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(439), 1,
      sym_concatenating_space,
    STATE(1218), 1,
      sym_comment,
    ACTIONS(435), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
    ACTIONS(423), 21,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74372] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(505), 1,
      sym_concatenating_space,
    STATE(1219), 1,
      sym_comment,
    ACTIONS(503), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74414] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(501), 1,
      sym_concatenating_space,
    ACTIONS(1753), 1,
      sym_identifier,
    ACTIONS(1755), 1,
      anon_sym_LT,
    STATE(1220), 1,
      sym_comment,
    STATE(1335), 1,
      sym_ns_qualified_name,
    STATE(1809), 1,
      sym_namespace,
    ACTIONS(499), 26,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74464] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(471), 1,
      sym__if_else_separator,
    ACTIONS(1757), 1,
      anon_sym_LT,
    STATE(1221), 1,
      sym_comment,
    ACTIONS(469), 28,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74510] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym__if_else_separator,
    ACTIONS(976), 1,
      sym_concatenating_space,
    STATE(1222), 1,
      sym_comment,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74554] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(483), 1,
      sym_concatenating_space,
    STATE(1223), 1,
      sym_comment,
    ACTIONS(481), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74596] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(521), 1,
      sym__if_else_separator,
    STATE(1224), 1,
      sym_comment,
    ACTIONS(519), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74638] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(591), 1,
      sym_concatenating_space,
    ACTIONS(1759), 1,
      sym_regex_flags,
    STATE(1225), 1,
      sym_comment,
    ACTIONS(587), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74682] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1226), 1,
      sym_comment,
    ACTIONS(451), 31,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
  [74722] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(513), 1,
      sym__if_else_separator,
    STATE(1227), 1,
      sym_comment,
    ACTIONS(511), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74764] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(509), 1,
      sym__if_else_separator,
    STATE(1228), 1,
      sym_comment,
    ACTIONS(507), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74806] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(495), 1,
      sym__if_else_separator,
    STATE(1229), 1,
      sym_comment,
    ACTIONS(493), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74848] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(491), 1,
      sym__if_else_separator,
    STATE(1230), 1,
      sym_comment,
    ACTIONS(489), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74890] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1743), 1,
      anon_sym_in,
    ACTIONS(1745), 1,
      anon_sym_QMARK,
    ACTIONS(1747), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1749), 1,
      anon_sym_PIPE_PIPE,
    STATE(1231), 1,
      sym_comment,
    ACTIONS(637), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1741), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1733), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(631), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
  [74952] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(517), 1,
      sym_concatenating_space,
    STATE(1232), 1,
      sym_comment,
    ACTIONS(515), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [74994] = 12,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1743), 1,
      anon_sym_in,
    ACTIONS(1747), 1,
      anon_sym_AMP_AMP,
    STATE(1233), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1741), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1733), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
  [75052] = 11,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1743), 1,
      anon_sym_in,
    STATE(1234), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1741), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1733), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75108] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(471), 1,
      sym_concatenating_space,
    ACTIONS(1761), 1,
      anon_sym_LT,
    STATE(1235), 1,
      sym_comment,
    ACTIONS(469), 28,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75154] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(479), 1,
      sym__if_else_separator,
    STATE(1236), 1,
      sym_comment,
    ACTIONS(477), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75196] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1237), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1733), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75248] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1238), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 24,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75294] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(487), 1,
      sym__if_else_separator,
    STATE(1239), 1,
      sym_comment,
    ACTIONS(485), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75336] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(577), 1,
      sym__if_else_separator,
    STATE(1240), 1,
      sym_comment,
    ACTIONS(575), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75378] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    STATE(1241), 1,
      sym_comment,
    ACTIONS(469), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75420] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1242), 1,
      sym_comment,
    ACTIONS(535), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75459] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(842), 1,
      anon_sym_COMMA,
    ACTIONS(844), 1,
      sym__if_else_separator,
    ACTIONS(1743), 1,
      anon_sym_in,
    ACTIONS(1745), 1,
      anon_sym_QMARK,
    ACTIONS(1747), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1749), 1,
      anon_sym_PIPE_PIPE,
    STATE(1243), 1,
      sym_comment,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1741), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1733), 5,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(840), 10,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
  [75520] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(641), 1,
      sym_concatenating_space,
    ACTIONS(1763), 1,
      anon_sym_in,
    ACTIONS(1769), 1,
      anon_sym_QMARK,
    ACTIONS(1779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1781), 1,
      anon_sym_PIPE_PIPE,
    STATE(1244), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1777), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1765), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
  [75581] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1783), 1,
      sym_identifier,
    ACTIONS(1785), 1,
      anon_sym_LT,
    STATE(1245), 1,
      sym_comment,
    STATE(1382), 1,
      sym_ns_qualified_name,
    STATE(1805), 1,
      sym_namespace,
    ACTIONS(499), 4,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(501), 22,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [75630] = 12,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    ACTIONS(1763), 1,
      anon_sym_in,
    ACTIONS(1779), 1,
      anon_sym_AMP_AMP,
    STATE(1246), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1777), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1765), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
  [75687] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1247), 1,
      sym_comment,
    ACTIONS(563), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75726] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1000), 1,
      sym_concatenating_space,
    STATE(1248), 1,
      sym_comment,
    ACTIONS(423), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75767] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(641), 1,
      sym__if_else_separator,
    ACTIONS(1743), 1,
      anon_sym_in,
    ACTIONS(1745), 1,
      anon_sym_QMARK,
    ACTIONS(1747), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1749), 1,
      anon_sym_PIPE_PIPE,
    STATE(1249), 1,
      sym_comment,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1741), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1733), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
  [75828] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1789), 1,
      anon_sym_LT,
    STATE(1250), 1,
      sym_comment,
    ACTIONS(469), 28,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75871] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(1251), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 20,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75920] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1252), 1,
      sym_comment,
    ACTIONS(489), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [75959] = 11,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    ACTIONS(1763), 1,
      anon_sym_in,
    STATE(1253), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1777), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1765), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76014] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym_concatenating_space,
    ACTIONS(1761), 1,
      anon_sym_LT,
    STATE(1254), 1,
      sym_comment,
    ACTIONS(469), 28,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76057] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym__if_else_separator,
    ACTIONS(1757), 1,
      anon_sym_LT,
    STATE(1255), 1,
      sym_comment,
    ACTIONS(469), 28,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76100] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1256), 1,
      sym_comment,
    ACTIONS(423), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76139] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(647), 1,
      sym_concatenating_space,
    STATE(1257), 1,
      sym_comment,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76186] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1258), 1,
      sym_comment,
    ACTIONS(579), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76225] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1259), 1,
      sym_comment,
    ACTIONS(441), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76264] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1791), 1,
      anon_sym_LT,
    STATE(1260), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 26,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76309] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1793), 1,
      sym_identifier,
    STATE(1261), 1,
      sym_comment,
    STATE(1339), 1,
      sym_ns_qualified_name,
    STATE(1805), 1,
      sym_namespace,
    ACTIONS(499), 5,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(501), 22,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [76356] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(1262), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1765), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 14,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76407] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(1263), 1,
      sym_comment,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76450] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(1264), 1,
      sym_comment,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 24,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76495] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(637), 1,
      sym_concatenating_space,
    ACTIONS(1763), 1,
      anon_sym_in,
    ACTIONS(1769), 1,
      anon_sym_QMARK,
    ACTIONS(1779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1781), 1,
      anon_sym_PIPE_PIPE,
    STATE(1265), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1777), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1765), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(631), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
  [76556] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1266), 1,
      sym_comment,
    ACTIONS(485), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76595] = 15,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(842), 1,
      anon_sym_COMMA,
    ACTIONS(856), 1,
      sym__if_else_separator,
    ACTIONS(1743), 1,
      anon_sym_in,
    ACTIONS(1745), 1,
      anon_sym_QMARK,
    ACTIONS(1747), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1749), 1,
      anon_sym_PIPE_PIPE,
    STATE(1267), 1,
      sym_comment,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1741), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1733), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(854), 7,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
  [76658] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1795), 1,
      sym_regex_flags,
    STATE(1268), 1,
      sym_comment,
    ACTIONS(587), 29,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76699] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1269), 1,
      sym_comment,
    ACTIONS(493), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76738] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1711), 1,
      sym_regex_flags,
    STATE(1270), 1,
      sym_comment,
    ACTIONS(591), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(587), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76781] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1271), 1,
      sym_comment,
    ACTIONS(469), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76820] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1272), 1,
      sym_comment,
    ACTIONS(477), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76859] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(1273), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1777), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1765), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76912] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1797), 1,
      sym_identifier,
    ACTIONS(1799), 1,
      anon_sym_LT,
    STATE(1274), 1,
      sym_comment,
    STATE(1380), 1,
      sym_ns_qualified_name,
    STATE(1806), 1,
      sym_namespace,
    ACTIONS(499), 26,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76959] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1275), 1,
      sym_comment,
    ACTIONS(519), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [76998] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1276), 1,
      sym_comment,
    ACTIONS(511), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [77037] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1277), 1,
      sym_comment,
    ACTIONS(507), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [77076] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1278), 1,
      sym_comment,
    ACTIONS(575), 30,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [77115] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(433), 1,
      sym__if_else_separator,
    ACTIONS(1008), 1,
      sym_concatenating_space,
    STATE(1279), 1,
      sym_comment,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [77157] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1280), 1,
      sym_comment,
    ACTIONS(647), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 20,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [77203] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1807), 1,
      anon_sym_LBRACK,
    STATE(1281), 1,
      sym_comment,
    ACTIONS(441), 5,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(443), 22,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [77247] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1809), 1,
      anon_sym_in,
    ACTIONS(1813), 1,
      anon_sym_QMARK,
    ACTIONS(1817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1819), 1,
      anon_sym_PIPE_PIPE,
    STATE(1282), 1,
      sym_comment,
    ACTIONS(641), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1815), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(639), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
    ACTIONS(1811), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [77307] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1283), 1,
      sym_comment,
    ACTIONS(1821), 11,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
    ACTIONS(1725), 18,
      anon_sym_if,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_identifier,
  [77347] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1789), 1,
      anon_sym_LT,
    STATE(1284), 1,
      sym_comment,
    ACTIONS(469), 28,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [77387] = 12,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1809), 1,
      anon_sym_in,
    ACTIONS(1817), 1,
      anon_sym_AMP_AMP,
    STATE(1285), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1815), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1811), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
  [77443] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(591), 1,
      sym__if_else_separator,
    ACTIONS(1751), 1,
      sym_regex_flags,
    STATE(1286), 1,
      sym_comment,
    ACTIONS(587), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [77485] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1823), 1,
      sym_identifier,
    STATE(1287), 1,
      sym_comment,
    STATE(1386), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
    ACTIONS(499), 5,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(501), 21,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [77531] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1763), 1,
      anon_sym_in,
    ACTIONS(1769), 1,
      anon_sym_QMARK,
    ACTIONS(1779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1781), 1,
      anon_sym_PIPE_PIPE,
    STATE(1288), 1,
      sym_comment,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1777), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1765), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(639), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
  [77589] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1791), 1,
      anon_sym_LT,
    STATE(1289), 1,
      sym_comment,
    ACTIONS(471), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(469), 26,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [77631] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1290), 1,
      sym_comment,
    ACTIONS(1829), 11,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
    ACTIONS(1827), 18,
      anon_sym_if,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_identifier,
  [77671] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1291), 1,
      sym_comment,
    ACTIONS(1587), 11,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
    ACTIONS(1585), 18,
      anon_sym_if,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_identifier,
  [77711] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1809), 1,
      anon_sym_in,
    ACTIONS(1813), 1,
      anon_sym_QMARK,
    ACTIONS(1817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1819), 1,
      anon_sym_PIPE_PIPE,
    STATE(1292), 1,
      sym_comment,
    ACTIONS(637), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1815), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(631), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
    ACTIONS(1811), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [77771] = 11,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1809), 1,
      anon_sym_in,
    STATE(1293), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1815), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1811), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [77825] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1294), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1811), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [77875] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1295), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [77919] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(591), 1,
      sym_concatenating_space,
    ACTIONS(1759), 1,
      sym_regex_flags,
    STATE(1296), 1,
      sym_comment,
    ACTIONS(587), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [77961] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1297), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 25,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [78003] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(471), 1,
      sym_concatenating_space,
    ACTIONS(1831), 1,
      anon_sym_LT,
    STATE(1298), 1,
      sym_comment,
    ACTIONS(469), 26,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [78047] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1299), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 18,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [78095] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1300), 1,
      sym_comment,
    ACTIONS(541), 2,
      sym_concatenating_space,
      sym__if_else_separator,
    ACTIONS(1735), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1815), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1811), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [78147] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(471), 1,
      sym__if_else_separator,
    ACTIONS(1833), 1,
      anon_sym_LT,
    STATE(1301), 1,
      sym_comment,
    ACTIONS(469), 26,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [78191] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(842), 1,
      anon_sym_COMMA,
    ACTIONS(1763), 1,
      anon_sym_in,
    ACTIONS(1769), 1,
      anon_sym_QMARK,
    ACTIONS(1779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1781), 1,
      anon_sym_PIPE_PIPE,
    STATE(1302), 1,
      sym_comment,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1777), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1765), 5,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(840), 10,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
  [78249] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1303), 1,
      sym_comment,
    ACTIONS(1607), 11,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
    ACTIONS(1605), 18,
      anon_sym_if,
      anon_sym_while,
      anon_sym_do,
      anon_sym_for,
      sym_break_statement,
      sym_continue_statement,
      anon_sym_delete,
      anon_sym_exit,
      anon_sym_return,
      anon_sym_switch,
      anon_sym_getline,
      sym_next_statement,
      sym_nextfile_statement,
      anon_sym_print,
      anon_sym_printf,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_identifier,
  [78289] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1835), 1,
      sym_identifier,
    ACTIONS(1837), 1,
      anon_sym_LT,
    STATE(1304), 1,
      sym_comment,
    STATE(1400), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
    ACTIONS(499), 4,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(501), 21,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [78337] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(842), 1,
      anon_sym_COMMA,
    ACTIONS(1763), 1,
      anon_sym_in,
    ACTIONS(1769), 1,
      anon_sym_QMARK,
    ACTIONS(1779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1781), 1,
      anon_sym_PIPE_PIPE,
    STATE(1305), 1,
      sym_comment,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1777), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1765), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(854), 7,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_GT_GT,
  [78397] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1306), 1,
      sym_comment,
    ACTIONS(473), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(475), 24,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [78436] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    STATE(1307), 1,
      sym_comment,
    ACTIONS(469), 5,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(471), 22,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [78477] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1308), 1,
      sym_comment,
    ACTIONS(451), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(453), 24,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_LPAREN2,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [78516] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1839), 1,
      anon_sym_LT,
    STATE(1309), 1,
      sym_comment,
    ACTIONS(469), 4,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(471), 22,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [78559] = 12,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    ACTIONS(1841), 1,
      anon_sym_in,
    ACTIONS(1853), 1,
      anon_sym_AMP_AMP,
    STATE(1310), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1851), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1843), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 8,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
  [78614] = 11,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    ACTIONS(1841), 1,
      anon_sym_in,
    STATE(1311), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1851), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1843), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 9,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [78667] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(892), 1,
      sym__if_else_separator,
    ACTIONS(1743), 1,
      anon_sym_in,
    ACTIONS(1745), 1,
      anon_sym_QMARK,
    ACTIONS(1747), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1749), 1,
      anon_sym_PIPE_PIPE,
    STATE(1312), 1,
      sym_comment,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1741), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(890), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(1733), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [78726] = 7,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(647), 1,
      sym_concatenating_space,
    STATE(1313), 1,
      sym_comment,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(645), 20,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [78771] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(641), 1,
      sym__if_else_separator,
    ACTIONS(1809), 1,
      anon_sym_in,
    ACTIONS(1813), 1,
      anon_sym_QMARK,
    ACTIONS(1817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1819), 1,
      anon_sym_PIPE_PIPE,
    STATE(1314), 1,
      sym_comment,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1815), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(639), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
    ACTIONS(1811), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [78830] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(904), 1,
      sym__if_else_separator,
    ACTIONS(1743), 1,
      anon_sym_in,
    ACTIONS(1745), 1,
      anon_sym_QMARK,
    ACTIONS(1747), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1749), 1,
      anon_sym_PIPE_PIPE,
    STATE(1315), 1,
      sym_comment,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1741), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(902), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(1733), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [78889] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1855), 1,
      anon_sym_LT,
    STATE(1316), 1,
      sym_comment,
    ACTIONS(469), 26,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [78930] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(900), 1,
      sym__if_else_separator,
    ACTIONS(1743), 1,
      anon_sym_in,
    ACTIONS(1745), 1,
      anon_sym_QMARK,
    ACTIONS(1747), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1749), 1,
      anon_sym_PIPE_PIPE,
    STATE(1317), 1,
      sym_comment,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1741), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(898), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(1733), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [78989] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(896), 1,
      sym__if_else_separator,
    ACTIONS(1743), 1,
      anon_sym_in,
    ACTIONS(1745), 1,
      anon_sym_QMARK,
    ACTIONS(1747), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1749), 1,
      anon_sym_PIPE_PIPE,
    STATE(1318), 1,
      sym_comment,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1741), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(894), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(1733), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [79048] = 9,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(1319), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1843), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 12,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [79097] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1042), 1,
      sym_concatenating_space,
    STATE(1320), 1,
      sym_comment,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [79136] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1857), 1,
      sym_regex_flags,
    STATE(1321), 1,
      sym_comment,
    ACTIONS(587), 5,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(591), 22,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [79177] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(641), 1,
      sym_concatenating_space,
    ACTIONS(1841), 1,
      anon_sym_in,
    ACTIONS(1853), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1859), 1,
      anon_sym_QMARK,
    ACTIONS(1861), 1,
      anon_sym_PIPE_PIPE,
    STATE(1322), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1851), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(639), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
    ACTIONS(1843), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [79236] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym__if_else_separator,
    ACTIONS(1833), 1,
      anon_sym_LT,
    STATE(1323), 1,
      sym_comment,
    ACTIONS(469), 26,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [79277] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1324), 1,
      sym_comment,
    ACTIONS(451), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(453), 24,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [79316] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(85), 1,
      sym__if_else_separator,
    ACTIONS(1743), 1,
      anon_sym_in,
    ACTIONS(1745), 1,
      anon_sym_QMARK,
    ACTIONS(1747), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1749), 1,
      anon_sym_PIPE_PIPE,
    STATE(1325), 1,
      sym_comment,
    ACTIONS(1727), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1739), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1741), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1737), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(39), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(1733), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [79375] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(842), 1,
      anon_sym_COMMA,
    ACTIONS(844), 1,
      sym__if_else_separator,
    ACTIONS(1809), 1,
      anon_sym_in,
    ACTIONS(1813), 1,
      anon_sym_QMARK,
    ACTIONS(1817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1819), 1,
      anon_sym_PIPE_PIPE,
    STATE(1326), 1,
      sym_comment,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1815), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1811), 5,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(840), 8,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
  [79434] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1807), 1,
      anon_sym_LBRACK,
    STATE(1327), 1,
      sym_comment,
    ACTIONS(441), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(443), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [79475] = 10,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(1328), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1851), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1843), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(539), 10,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [79526] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(1329), 1,
      sym_comment,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [79569] = 8,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(1330), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 18,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [79616] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1795), 1,
      sym_regex_flags,
    STATE(1331), 1,
      sym_comment,
    ACTIONS(587), 27,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [79655] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1863), 1,
      anon_sym_LBRACK,
    STATE(1332), 1,
      sym_comment,
    ACTIONS(441), 5,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(443), 21,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [79698] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(637), 1,
      sym_concatenating_space,
    ACTIONS(1841), 1,
      anon_sym_in,
    ACTIONS(1853), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1859), 1,
      anon_sym_QMARK,
    ACTIONS(1861), 1,
      anon_sym_PIPE_PIPE,
    STATE(1333), 1,
      sym_comment,
    ACTIONS(1767), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1851), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(631), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
    ACTIONS(1843), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [79757] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(541), 1,
      sym_concatenating_space,
    STATE(1334), 1,
      sym_comment,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 25,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [79798] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(471), 1,
      sym_concatenating_space,
    ACTIONS(1831), 1,
      anon_sym_LT,
    STATE(1335), 1,
      sym_comment,
    ACTIONS(469), 26,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [79839] = 15,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(842), 1,
      anon_sym_COMMA,
    ACTIONS(856), 1,
      sym__if_else_separator,
    ACTIONS(1809), 1,
      anon_sym_in,
    ACTIONS(1813), 1,
      anon_sym_QMARK,
    ACTIONS(1817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1819), 1,
      anon_sym_PIPE_PIPE,
    STATE(1336), 1,
      sym_comment,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1815), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(854), 5,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
    ACTIONS(1811), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [79900] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1337), 1,
      sym_comment,
    ACTIONS(477), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(479), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [79938] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1338), 1,
      sym_comment,
    ACTIONS(531), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(533), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [79976] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1339), 1,
      sym_comment,
    ACTIONS(469), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(471), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80014] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1340), 1,
      sym_comment,
    ACTIONS(473), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(475), 23,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [80052] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1763), 1,
      anon_sym_in,
    ACTIONS(1769), 1,
      anon_sym_QMARK,
    ACTIONS(1779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1781), 1,
      anon_sym_PIPE_PIPE,
    STATE(1341), 1,
      sym_comment,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1777), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(39), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(1765), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [80108] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1342), 1,
      sym_comment,
    ACTIONS(519), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(521), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80146] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1869), 1,
      anon_sym_PIPE,
    ACTIONS(1871), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    STATE(1343), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(641), 6,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
  [80208] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1344), 1,
      sym_comment,
    ACTIONS(489), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(491), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80246] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    STATE(1345), 1,
      sym_comment,
    ACTIONS(469), 5,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(471), 21,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80286] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1346), 1,
      sym_comment,
    ACTIONS(485), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(487), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80324] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1763), 1,
      anon_sym_in,
    ACTIONS(1769), 1,
      anon_sym_QMARK,
    ACTIONS(1779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1781), 1,
      anon_sym_PIPE_PIPE,
    STATE(1347), 1,
      sym_comment,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1777), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(898), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(1765), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [80380] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1863), 1,
      anon_sym_LBRACK,
    STATE(1348), 1,
      sym_comment,
    ACTIONS(441), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(443), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80420] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1349), 1,
      sym_comment,
    ACTIONS(511), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(513), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80458] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1350), 1,
      sym_comment,
    ACTIONS(507), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(509), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80496] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1351), 1,
      sym_comment,
    ACTIONS(481), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(483), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80534] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1352), 1,
      sym_comment,
    ACTIONS(575), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(577), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80572] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1353), 1,
      sym_comment,
    ACTIONS(493), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(495), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80610] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1841), 1,
      anon_sym_in,
    ACTIONS(1853), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1859), 1,
      anon_sym_QMARK,
    ACTIONS(1861), 1,
      anon_sym_PIPE_PIPE,
    STATE(1354), 1,
      sym_comment,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1851), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(639), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
    ACTIONS(1843), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [80666] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    STATE(1355), 1,
      sym_comment,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(645), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
    ACTIONS(647), 17,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80712] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1763), 1,
      anon_sym_in,
    ACTIONS(1769), 1,
      anon_sym_QMARK,
    ACTIONS(1779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1781), 1,
      anon_sym_PIPE_PIPE,
    STATE(1356), 1,
      sym_comment,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1777), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(902), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(1765), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [80768] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1891), 1,
      anon_sym_LT,
    STATE(1357), 1,
      sym_comment,
    ACTIONS(469), 4,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(471), 21,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80810] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1358), 1,
      sym_comment,
    ACTIONS(441), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(443), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [80848] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(842), 1,
      anon_sym_COMMA,
    ACTIONS(1841), 1,
      anon_sym_in,
    ACTIONS(1853), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1859), 1,
      anon_sym_QMARK,
    ACTIONS(1861), 1,
      anon_sym_PIPE_PIPE,
    STATE(1359), 1,
      sym_comment,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1851), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1843), 5,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(840), 8,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
  [80904] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1763), 1,
      anon_sym_in,
    ACTIONS(1769), 1,
      anon_sym_QMARK,
    ACTIONS(1779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1781), 1,
      anon_sym_PIPE_PIPE,
    STATE(1360), 1,
      sym_comment,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1777), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(894), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(1765), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [80960] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1763), 1,
      anon_sym_in,
    ACTIONS(1769), 1,
      anon_sym_QMARK,
    ACTIONS(1779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1781), 1,
      anon_sym_PIPE_PIPE,
    STATE(1361), 1,
      sym_comment,
    ACTIONS(1771), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1775), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1777), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1773), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(890), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(1765), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [81016] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1869), 1,
      anon_sym_PIPE,
    ACTIONS(1871), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    STATE(1362), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(637), 6,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
  [81078] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1088), 1,
      sym_concatenating_space,
    STATE(1363), 1,
      sym_comment,
    ACTIONS(423), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(433), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81118] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1364), 1,
      sym_comment,
    ACTIONS(423), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(433), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81156] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1893), 1,
      sym_regex_flags,
    STATE(1365), 1,
      sym_comment,
    ACTIONS(587), 5,
      anon_sym_in,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(591), 21,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81196] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1366), 1,
      sym_comment,
    ACTIONS(503), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(505), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81234] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1367), 1,
      sym_comment,
    ACTIONS(563), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(565), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81272] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1368), 1,
      sym_comment,
    ACTIONS(423), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(439), 6,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(433), 17,
      anon_sym_in,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [81312] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1369), 1,
      sym_comment,
    ACTIONS(535), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(537), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81350] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1869), 1,
      anon_sym_PIPE,
    ACTIONS(1871), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    STATE(1370), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(541), 10,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81404] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1869), 1,
      anon_sym_PIPE,
    ACTIONS(1871), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    STATE(1371), 1,
      sym_comment,
    ACTIONS(539), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(541), 16,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81454] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1372), 1,
      sym_comment,
    ACTIONS(515), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(517), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81492] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1373), 1,
      sym_comment,
    ACTIONS(423), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(433), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81530] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1374), 1,
      sym_comment,
    ACTIONS(539), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(541), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81568] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1375), 1,
      sym_comment,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(539), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(541), 21,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81608] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    STATE(1376), 1,
      sym_comment,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(539), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
    ACTIONS(541), 19,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81652] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1869), 1,
      anon_sym_PIPE,
    ACTIONS(1871), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    STATE(1377), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(541), 12,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81704] = 13,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1869), 1,
      anon_sym_PIPE,
    ACTIONS(1871), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    STATE(1378), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(541), 9,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81760] = 14,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1869), 1,
      anon_sym_PIPE,
    ACTIONS(1871), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    STATE(1379), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(541), 8,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81818] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1855), 1,
      anon_sym_LT,
    STATE(1380), 1,
      sym_comment,
    ACTIONS(469), 26,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_in,
      anon_sym_GT,
      anon_sym_GT_GT,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [81856] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(842), 1,
      anon_sym_COMMA,
    ACTIONS(1841), 1,
      anon_sym_in,
    ACTIONS(1853), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1859), 1,
      anon_sym_QMARK,
    ACTIONS(1861), 1,
      anon_sym_PIPE_PIPE,
    STATE(1381), 1,
      sym_comment,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1851), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(854), 5,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
      anon_sym_GT_GT,
    ACTIONS(1843), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [81914] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1839), 1,
      anon_sym_LT,
    STATE(1382), 1,
      sym_comment,
    ACTIONS(469), 3,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(471), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81954] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1383), 1,
      sym_comment,
    ACTIONS(579), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(581), 23,
      sym_concatenating_space,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [81992] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(896), 1,
      sym__if_else_separator,
    ACTIONS(1809), 1,
      anon_sym_in,
    ACTIONS(1813), 1,
      anon_sym_QMARK,
    ACTIONS(1817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1819), 1,
      anon_sym_PIPE_PIPE,
    STATE(1384), 1,
      sym_comment,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1815), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(894), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    ACTIONS(1811), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [82049] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1385), 1,
      sym_comment,
    ACTIONS(489), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(491), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82086] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1386), 1,
      sym_comment,
    ACTIONS(469), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(471), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82123] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1387), 1,
      sym_comment,
    ACTIONS(519), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(521), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82160] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1388), 1,
      sym_comment,
    ACTIONS(511), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(513), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82197] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(904), 1,
      sym__if_else_separator,
    ACTIONS(1809), 1,
      anon_sym_in,
    ACTIONS(1813), 1,
      anon_sym_QMARK,
    ACTIONS(1817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1819), 1,
      anon_sym_PIPE_PIPE,
    STATE(1389), 1,
      sym_comment,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1815), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(902), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    ACTIONS(1811), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [82254] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(900), 1,
      sym__if_else_separator,
    ACTIONS(1809), 1,
      anon_sym_in,
    ACTIONS(1813), 1,
      anon_sym_QMARK,
    ACTIONS(1817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1819), 1,
      anon_sym_PIPE_PIPE,
    STATE(1390), 1,
      sym_comment,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1815), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(898), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    ACTIONS(1811), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [82311] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(85), 1,
      sym__if_else_separator,
    ACTIONS(1809), 1,
      anon_sym_in,
    ACTIONS(1813), 1,
      anon_sym_QMARK,
    ACTIONS(1817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1819), 1,
      anon_sym_PIPE_PIPE,
    STATE(1391), 1,
      sym_comment,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1815), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(39), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    ACTIONS(1811), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [82368] = 14,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(892), 1,
      sym__if_else_separator,
    ACTIONS(1809), 1,
      anon_sym_in,
    ACTIONS(1813), 1,
      anon_sym_QMARK,
    ACTIONS(1817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1819), 1,
      anon_sym_PIPE_PIPE,
    STATE(1392), 1,
      sym_comment,
    ACTIONS(1787), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1801), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1815), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1803), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(890), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    ACTIONS(1811), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [82425] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1393), 1,
      sym_comment,
    ACTIONS(423), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(433), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82462] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1394), 1,
      sym_comment,
    ACTIONS(507), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(509), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82499] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1395), 1,
      sym_comment,
    ACTIONS(563), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(565), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82536] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    STATE(1396), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(641), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
  [82597] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1397), 1,
      sym_comment,
    ACTIONS(535), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(537), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82634] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1398), 1,
      sym_comment,
    ACTIONS(493), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(495), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82671] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1399), 1,
      sym_comment,
    ACTIONS(575), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(577), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82708] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1891), 1,
      anon_sym_LT,
    STATE(1400), 1,
      sym_comment,
    ACTIONS(469), 3,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(471), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82747] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1401), 1,
      sym_comment,
    ACTIONS(441), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(443), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82784] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1402), 1,
      sym_comment,
    ACTIONS(485), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(487), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82821] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1403), 1,
      sym_comment,
    ACTIONS(579), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(581), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82858] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1404), 1,
      sym_comment,
    ACTIONS(477), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_STAR,
    ACTIONS(479), 22,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_in,
      anon_sym_COLON,
      anon_sym_PIPE_AMP,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [82895] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1405), 1,
      sym_comment,
    ACTIONS(1605), 12,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_while,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(1607), 13,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [82931] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1841), 1,
      anon_sym_in,
    ACTIONS(1853), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1859), 1,
      anon_sym_QMARK,
    ACTIONS(1861), 1,
      anon_sym_PIPE_PIPE,
    STATE(1406), 1,
      sym_comment,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1851), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(890), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    ACTIONS(1843), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [82985] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1407), 1,
      sym_comment,
    ACTIONS(503), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(505), 14,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [83021] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    STATE(1408), 1,
      sym_comment,
    STATE(1416), 1,
      sym_block,
    ACTIONS(1901), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(1899), 12,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [83061] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1841), 1,
      anon_sym_in,
    ACTIONS(1853), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1859), 1,
      anon_sym_QMARK,
    ACTIONS(1861), 1,
      anon_sym_PIPE_PIPE,
    STATE(1409), 1,
      sym_comment,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1851), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(894), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    ACTIONS(1843), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [83115] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1841), 1,
      anon_sym_in,
    ACTIONS(1853), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1859), 1,
      anon_sym_QMARK,
    ACTIONS(1861), 1,
      anon_sym_PIPE_PIPE,
    STATE(1410), 1,
      sym_comment,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1851), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(898), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    ACTIONS(1843), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [83169] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1841), 1,
      anon_sym_in,
    ACTIONS(1853), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1859), 1,
      anon_sym_QMARK,
    ACTIONS(1861), 1,
      anon_sym_PIPE_PIPE,
    STATE(1411), 1,
      sym_comment,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1851), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(39), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    ACTIONS(1843), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [83223] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1412), 1,
      sym_comment,
    ACTIONS(531), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(533), 14,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [83259] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1413), 1,
      sym_comment,
    ACTIONS(1585), 12,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_while,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(1587), 13,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [83295] = 13,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1841), 1,
      anon_sym_in,
    ACTIONS(1853), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1859), 1,
      anon_sym_QMARK,
    ACTIONS(1861), 1,
      anon_sym_PIPE_PIPE,
    STATE(1414), 1,
      sym_comment,
    ACTIONS(1825), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1845), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1849), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1851), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(902), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
    ACTIONS(1843), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [83349] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1415), 1,
      sym_comment,
    ACTIONS(980), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(978), 13,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [83384] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1416), 1,
      sym_comment,
    ACTIONS(1905), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(1903), 13,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [83419] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1417), 1,
      sym_comment,
    ACTIONS(1909), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(1907), 13,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [83454] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1418), 1,
      sym_comment,
    ACTIONS(1913), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(1911), 13,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [83489] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1419), 1,
      sym_comment,
    ACTIONS(1917), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(1915), 13,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [83524] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1420), 1,
      sym_comment,
    ACTIONS(1921), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(1919), 13,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [83559] = 18,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1923), 1,
      anon_sym_COMMA,
    ACTIONS(1925), 1,
      anon_sym_RPAREN,
    STATE(1421), 1,
      sym_comment,
    STATE(1644), 1,
      aux_sym_args_repeat1,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [83622] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1422), 1,
      sym_comment,
    ACTIONS(1901), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(1899), 13,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [83657] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    STATE(1423), 1,
      sym_comment,
    ACTIONS(856), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [83718] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1424), 1,
      sym_comment,
    ACTIONS(1931), 11,
      anon_sym_BEGIN,
      anon_sym_END,
      anon_sym_BEGINFILE,
      anon_sym_ENDFILE,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AT,
      sym_identifier,
      anon_sym_function,
      anon_sym_func,
    ACTIONS(1929), 13,
      ts_builtin_sym_end,
      anon_sym_ATinclude,
      anon_sym_ATload,
      anon_sym_ATnamespace,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      sym_number,
      anon_sym_DQUOTE,
  [83753] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      anon_sym_RPAREN,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    STATE(1425), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [83813] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1933), 1,
      anon_sym_RBRACK,
    STATE(1426), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [83873] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1935), 1,
      anon_sym_RBRACK,
    STATE(1427), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [83933] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1937), 1,
      anon_sym_RBRACK,
    STATE(1428), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [83993] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1939), 1,
      anon_sym_RBRACK,
    STATE(1429), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84053] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1941), 1,
      anon_sym_RBRACK,
    STATE(1430), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84113] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1943), 1,
      anon_sym_RBRACK,
    STATE(1431), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84173] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1945), 1,
      anon_sym_RBRACK,
    STATE(1432), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84233] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1947), 1,
      anon_sym_RBRACK,
    STATE(1433), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84293] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1949), 1,
      anon_sym_RBRACK,
    STATE(1434), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84353] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1951), 1,
      anon_sym_RBRACK,
    STATE(1435), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84413] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      anon_sym_RPAREN,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    STATE(1436), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84473] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1953), 1,
      anon_sym_RBRACK,
    STATE(1437), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84533] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    STATE(1438), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1955), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84591] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1957), 1,
      anon_sym_RBRACK,
    STATE(1439), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84651] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1959), 1,
      anon_sym_RBRACK,
    STATE(1440), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84711] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1961), 1,
      anon_sym_RBRACK,
    STATE(1441), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84771] = 17,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    ACTIONS(1963), 1,
      anon_sym_RBRACK,
    STATE(1442), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84831] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1965), 1,
      anon_sym_RPAREN,
    STATE(1443), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84888] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1967), 1,
      anon_sym_COLON,
    STATE(1444), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [84945] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1969), 1,
      anon_sym_RPAREN,
    STATE(1445), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85002] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1971), 1,
      anon_sym_COLON,
    STATE(1446), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85059] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1973), 1,
      anon_sym_RPAREN,
    STATE(1447), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85116] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1975), 1,
      anon_sym_RPAREN,
    STATE(1448), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85173] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1977), 1,
      anon_sym_RPAREN,
    STATE(1449), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85230] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1979), 1,
      anon_sym_RPAREN,
    STATE(1450), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85287] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1981), 1,
      anon_sym_SEMI,
    STATE(1451), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85344] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1983), 1,
      anon_sym_RPAREN,
    STATE(1452), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85401] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1985), 1,
      anon_sym_SEMI,
    STATE(1453), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85458] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1987), 1,
      anon_sym_SEMI,
    STATE(1454), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85515] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1989), 1,
      anon_sym_COLON,
    STATE(1455), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85572] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1991), 1,
      anon_sym_RPAREN,
    STATE(1456), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85629] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1993), 1,
      anon_sym_RPAREN,
    STATE(1457), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85686] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1995), 1,
      anon_sym_RPAREN,
    STATE(1458), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85743] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1997), 1,
      anon_sym_COLON,
    STATE(1459), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85800] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1999), 1,
      anon_sym_RPAREN,
    STATE(1460), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85857] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2001), 1,
      anon_sym_COLON,
    STATE(1461), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85914] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2003), 1,
      anon_sym_RPAREN,
    STATE(1462), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [85971] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2005), 1,
      anon_sym_COLON,
    STATE(1463), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86028] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2007), 1,
      anon_sym_RPAREN,
    STATE(1464), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86085] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2009), 1,
      anon_sym_COLON,
    STATE(1465), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86142] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2011), 1,
      anon_sym_RPAREN,
    STATE(1466), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86199] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2013), 1,
      anon_sym_SEMI,
    STATE(1467), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86256] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(1927), 1,
      anon_sym_COMMA,
    STATE(1468), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86313] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2015), 1,
      anon_sym_SEMI,
    STATE(1469), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86370] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2017), 1,
      anon_sym_RPAREN,
    STATE(1470), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86427] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2019), 1,
      anon_sym_RPAREN,
    STATE(1471), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86484] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2021), 1,
      anon_sym_RPAREN,
    STATE(1472), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86541] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2023), 1,
      anon_sym_RPAREN,
    STATE(1473), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86598] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2025), 1,
      anon_sym_RPAREN,
    STATE(1474), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86655] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2027), 1,
      anon_sym_RPAREN,
    STATE(1475), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86712] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2029), 1,
      anon_sym_SEMI,
    STATE(1476), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86769] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2031), 1,
      anon_sym_SEMI,
    STATE(1477), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86826] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2033), 1,
      anon_sym_SEMI,
    STATE(1478), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86883] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2035), 1,
      anon_sym_RPAREN,
    STATE(1479), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86940] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2037), 1,
      anon_sym_RPAREN,
    STATE(1480), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [86997] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2039), 1,
      anon_sym_COLON,
    STATE(1481), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87054] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2041), 1,
      anon_sym_RPAREN,
    STATE(1482), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87111] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2043), 1,
      anon_sym_RPAREN,
    STATE(1483), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87168] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2045), 1,
      anon_sym_RPAREN,
    STATE(1484), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87225] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2047), 1,
      anon_sym_RPAREN,
    STATE(1485), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87282] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2049), 1,
      anon_sym_RPAREN,
    STATE(1486), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87339] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2051), 1,
      anon_sym_SEMI,
    STATE(1487), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87396] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2053), 1,
      anon_sym_RPAREN,
    STATE(1488), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87453] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2055), 1,
      anon_sym_RPAREN,
    STATE(1489), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87510] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2057), 1,
      anon_sym_RPAREN,
    STATE(1490), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87567] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2059), 1,
      anon_sym_RPAREN,
    STATE(1491), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87624] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2061), 1,
      anon_sym_RPAREN,
    STATE(1492), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87681] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2063), 1,
      anon_sym_RPAREN,
    STATE(1493), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87738] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2065), 1,
      anon_sym_SEMI,
    STATE(1494), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87795] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2067), 1,
      anon_sym_SEMI,
    STATE(1495), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87852] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2069), 1,
      anon_sym_RPAREN,
    STATE(1496), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87909] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2071), 1,
      anon_sym_RPAREN,
    STATE(1497), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [87966] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2073), 1,
      anon_sym_RPAREN,
    STATE(1498), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88023] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2075), 1,
      anon_sym_SEMI,
    STATE(1499), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88080] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2077), 1,
      anon_sym_RPAREN,
    STATE(1500), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88137] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2079), 1,
      anon_sym_RPAREN,
    STATE(1501), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88194] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2081), 1,
      anon_sym_COLON,
    STATE(1502), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88251] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2083), 1,
      anon_sym_RPAREN,
    STATE(1503), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88308] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2085), 1,
      anon_sym_SEMI,
    STATE(1504), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88365] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2087), 1,
      anon_sym_RPAREN,
    STATE(1505), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88422] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2089), 1,
      anon_sym_RPAREN,
    STATE(1506), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88479] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2091), 1,
      anon_sym_SEMI,
    STATE(1507), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88536] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2093), 1,
      anon_sym_RPAREN,
    STATE(1508), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88593] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2095), 1,
      anon_sym_RPAREN,
    STATE(1509), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88650] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2097), 1,
      anon_sym_SEMI,
    STATE(1510), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88707] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2099), 1,
      anon_sym_COLON,
    STATE(1511), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88764] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2101), 1,
      anon_sym_SEMI,
    STATE(1512), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88821] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2103), 1,
      anon_sym_COLON,
    STATE(1513), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88878] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2105), 1,
      anon_sym_SEMI,
    STATE(1514), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88935] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2107), 1,
      anon_sym_RPAREN,
    STATE(1515), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88992] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2109), 1,
      anon_sym_SEMI,
    STATE(1516), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89049] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2111), 1,
      anon_sym_RPAREN,
    STATE(1517), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89106] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2113), 1,
      anon_sym_RPAREN,
    STATE(1518), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89163] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2115), 1,
      anon_sym_RPAREN,
    STATE(1519), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89220] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2117), 1,
      anon_sym_RPAREN,
    STATE(1520), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89277] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2119), 1,
      anon_sym_COLON,
    STATE(1521), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89334] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2121), 1,
      anon_sym_RPAREN,
    STATE(1522), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89391] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2123), 1,
      anon_sym_COLON,
    STATE(1523), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89448] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2125), 1,
      anon_sym_COLON,
    STATE(1524), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89505] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2127), 1,
      anon_sym_COLON,
    STATE(1525), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89562] = 16,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2129), 1,
      anon_sym_COLON,
    STATE(1526), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89619] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(868), 1,
      anon_sym_STAR,
    ACTIONS(882), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AMP_AMP,
    ACTIONS(888), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2131), 1,
      anon_sym_in,
    STATE(1527), 1,
      sym_comment,
    ACTIONS(866), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(870), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(884), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2133), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2135), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(878), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89673] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1022), 1,
      anon_sym_STAR,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2137), 1,
      anon_sym_in,
    ACTIONS(2139), 1,
      anon_sym_QMARK,
    ACTIONS(2151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2153), 1,
      anon_sym_PIPE_PIPE,
    STATE(1528), 1,
      sym_comment,
    ACTIONS(1016), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2141), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(2143), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2149), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2147), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89727] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1737), 1,
      anon_sym_STAR,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2155), 1,
      anon_sym_in,
    ACTIONS(2157), 1,
      anon_sym_QMARK,
    ACTIONS(2169), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2171), 1,
      anon_sym_PIPE_PIPE,
    STATE(1529), 1,
      sym_comment,
    ACTIONS(1733), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2159), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(2161), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2163), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2167), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2165), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89781] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(617), 1,
      anon_sym_STAR,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2173), 1,
      anon_sym_in,
    ACTIONS(2175), 1,
      anon_sym_QMARK,
    ACTIONS(2187), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2189), 1,
      anon_sym_PIPE_PIPE,
    STATE(1530), 1,
      sym_comment,
    ACTIONS(619), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2177), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(2179), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2181), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2185), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2183), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89835] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1259), 1,
      anon_sym_STAR,
    ACTIONS(1283), 1,
      anon_sym_in,
    ACTIONS(1285), 1,
      anon_sym_QMARK,
    ACTIONS(1287), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1289), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    STATE(1531), 1,
      sym_comment,
    ACTIONS(1249), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1257), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1265), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2191), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2193), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1263), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89889] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1052), 1,
      anon_sym_STAR,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2195), 1,
      anon_sym_in,
    ACTIONS(2197), 1,
      anon_sym_QMARK,
    ACTIONS(2209), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2211), 1,
      anon_sym_PIPE_PIPE,
    STATE(1532), 1,
      sym_comment,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2199), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(2201), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2203), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2205), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89943] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1108), 1,
      anon_sym_STAR,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2213), 1,
      anon_sym_in,
    ACTIONS(2215), 1,
      anon_sym_QMARK,
    ACTIONS(2227), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE_PIPE,
    STATE(1533), 1,
      sym_comment,
    ACTIONS(1102), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2217), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(2219), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2221), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2225), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2223), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89997] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1156), 1,
      anon_sym_STAR,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2231), 1,
      anon_sym_in,
    ACTIONS(2233), 1,
      anon_sym_QMARK,
    ACTIONS(2245), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2247), 1,
      anon_sym_PIPE_PIPE,
    STATE(1534), 1,
      sym_comment,
    ACTIONS(1152), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2235), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(2237), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2243), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2241), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90051] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(657), 1,
      anon_sym_STAR,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2249), 1,
      anon_sym_in,
    ACTIONS(2251), 1,
      anon_sym_QMARK,
    ACTIONS(2263), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2265), 1,
      anon_sym_PIPE_PIPE,
    STATE(1535), 1,
      sym_comment,
    ACTIONS(651), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2253), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(2255), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2257), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2261), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2259), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90105] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(778), 1,
      anon_sym_STAR,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2267), 1,
      anon_sym_in,
    ACTIONS(2269), 1,
      anon_sym_QMARK,
    ACTIONS(2281), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2283), 1,
      anon_sym_PIPE_PIPE,
    STATE(1536), 1,
      sym_comment,
    ACTIONS(770), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2271), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(2273), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2275), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2279), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2277), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90159] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(828), 1,
      anon_sym_STAR,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2285), 1,
      anon_sym_in,
    ACTIONS(2287), 1,
      anon_sym_QMARK,
    ACTIONS(2299), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2301), 1,
      anon_sym_PIPE_PIPE,
    STATE(1537), 1,
      sym_comment,
    ACTIONS(820), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2289), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(2291), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2293), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2297), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2295), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90213] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1773), 1,
      anon_sym_STAR,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2303), 1,
      anon_sym_in,
    ACTIONS(2305), 1,
      anon_sym_QMARK,
    ACTIONS(2317), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2319), 1,
      anon_sym_PIPE_PIPE,
    STATE(1538), 1,
      sym_comment,
    ACTIONS(1765), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2307), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(2309), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2311), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2315), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2313), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90267] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1803), 1,
      anon_sym_STAR,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2321), 1,
      anon_sym_in,
    ACTIONS(2323), 1,
      anon_sym_QMARK,
    ACTIONS(2335), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2337), 1,
      anon_sym_PIPE_PIPE,
    STATE(1539), 1,
      sym_comment,
    ACTIONS(1811), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2325), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(2327), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2329), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2333), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2331), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90321] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1847), 1,
      anon_sym_STAR,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2339), 1,
      anon_sym_in,
    ACTIONS(2341), 1,
      anon_sym_QMARK,
    ACTIONS(2353), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2355), 1,
      anon_sym_PIPE_PIPE,
    STATE(1540), 1,
      sym_comment,
    ACTIONS(1843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2343), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(2345), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2347), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2351), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2349), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90375] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_in,
    ACTIONS(1873), 1,
      anon_sym_QMARK,
    ACTIONS(1877), 1,
      anon_sym_STAR,
    ACTIONS(1887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1889), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    STATE(1541), 1,
      sym_comment,
    ACTIONS(1867), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1875), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(1879), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1885), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1883), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90429] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(950), 1,
      anon_sym_QMARK,
    ACTIONS(952), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_PIPE,
    ACTIONS(1897), 1,
      anon_sym_PIPE_AMP,
    ACTIONS(2357), 1,
      anon_sym_in,
    STATE(1542), 1,
      sym_comment,
    ACTIONS(926), 2,
      anon_sym_CARET,
      anon_sym_STAR_STAR,
    ACTIONS(930), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(940), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(944), 2,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(2359), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(942), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90483] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1543), 1,
      sym_comment,
    ACTIONS(2361), 4,
      anon_sym_getline,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_identifier,
    ACTIONS(2363), 9,
      anon_sym_LPAREN,
      anon_sym_SLASH,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_number,
      anon_sym_DQUOTE,
  [90507] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1200), 1,
      sym__if_else_separator,
    STATE(1544), 1,
      sym_comment,
    ACTIONS(2365), 2,
      anon_sym_GT,
      anon_sym_GT_GT,
    ACTIONS(2367), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1194), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [90533] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1545), 1,
      sym_comment,
    ACTIONS(2369), 2,
      anon_sym_GT,
      anon_sym_GT_GT,
    ACTIONS(2371), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1194), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [90556] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(1200), 1,
      sym__if_else_separator,
    STATE(1546), 1,
      sym_comment,
    ACTIONS(2373), 2,
      anon_sym_GT,
      anon_sym_GT_GT,
    ACTIONS(2375), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1194), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
  [90580] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1547), 1,
      sym_comment,
    ACTIONS(2377), 2,
      anon_sym_GT,
      anon_sym_GT_GT,
    ACTIONS(2379), 2,
      anon_sym_PIPE,
      anon_sym_PIPE_AMP,
    ACTIONS(1194), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
  [90601] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2381), 1,
      sym__if_else_separator,
    STATE(1548), 1,
      sym_comment,
    ACTIONS(1701), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [90619] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2381), 1,
      sym__if_else_separator,
    STATE(1549), 1,
      sym_comment,
    ACTIONS(1701), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [90637] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2383), 1,
      sym__if_else_separator,
    STATE(1550), 1,
      sym_comment,
    ACTIONS(1701), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [90655] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2383), 1,
      sym__if_else_separator,
    STATE(1551), 1,
      sym_comment,
    ACTIONS(1701), 6,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [90673] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1552), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(2385), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [90690] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DOLLAR,
    ACTIONS(2387), 1,
      sym_identifier,
    STATE(257), 1,
      sym_field_ref,
    STATE(1553), 1,
      sym_comment,
    STATE(1804), 1,
      sym_namespace,
    STATE(229), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [90713] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2389), 1,
      sym_identifier,
    ACTIONS(2391), 1,
      anon_sym_DOLLAR,
    STATE(1175), 1,
      sym_field_ref,
    STATE(1554), 1,
      sym_comment,
    STATE(1815), 1,
      sym_namespace,
    STATE(1139), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [90736] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(311), 1,
      anon_sym_SLASH,
    ACTIONS(2393), 1,
      sym_identifier,
    STATE(1236), 1,
      sym_func_call,
    STATE(1239), 1,
      sym_regex,
    STATE(1555), 1,
      sym_comment,
    STATE(1747), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [90761] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2395), 1,
      anon_sym_RBRACE,
    ACTIONS(2397), 1,
      anon_sym_case,
    ACTIONS(2399), 1,
      anon_sym_default,
    STATE(1556), 1,
      sym_comment,
    STATE(1605), 1,
      aux_sym_switch_body_repeat1,
    STATE(1656), 2,
      sym_switch_case,
      sym_switch_default,
  [90784] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2401), 1,
      sym_identifier,
    ACTIONS(2403), 1,
      anon_sym_DOLLAR,
    STATE(333), 1,
      sym_field_ref,
    STATE(1557), 1,
      sym_comment,
    STATE(1807), 1,
      sym_namespace,
    STATE(326), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [90807] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2405), 1,
      sym_identifier,
    ACTIONS(2407), 1,
      anon_sym_DOLLAR,
    STATE(400), 1,
      sym_field_ref,
    STATE(1558), 1,
      sym_comment,
    STATE(1801), 1,
      sym_namespace,
    STATE(365), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [90830] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    ACTIONS(2409), 1,
      sym_identifier,
    STATE(331), 1,
      sym_func_call,
    STATE(332), 1,
      sym_regex,
    STATE(1559), 1,
      sym_comment,
    STATE(1766), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [90855] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(163), 1,
      anon_sym_DOLLAR,
    ACTIONS(2411), 1,
      sym_identifier,
    STATE(159), 1,
      sym_field_ref,
    STATE(1560), 1,
      sym_comment,
    STATE(1808), 1,
      sym_namespace,
    STATE(147), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [90878] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2413), 1,
      sym_identifier,
    ACTIONS(2415), 1,
      anon_sym_DOLLAR,
    STATE(1195), 1,
      sym_field_ref,
    STATE(1561), 1,
      sym_comment,
    STATE(1814), 1,
      sym_namespace,
    STATE(1184), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [90901] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1381), 1,
      anon_sym_SLASH,
    ACTIONS(2417), 1,
      sym_identifier,
    STATE(114), 1,
      sym_func_call,
    STATE(118), 1,
      sym_regex,
    STATE(1562), 1,
      sym_comment,
    STATE(1750), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [90926] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1495), 1,
      anon_sym_SLASH,
    ACTIONS(2419), 1,
      sym_identifier,
    STATE(156), 1,
      sym_func_call,
    STATE(175), 1,
      sym_regex,
    STATE(1563), 1,
      sym_comment,
    STATE(1763), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [90951] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(155), 1,
      anon_sym_SLASH,
    ACTIONS(2421), 1,
      sym_identifier,
    STATE(404), 1,
      sym_regex,
    STATE(405), 1,
      sym_func_call,
    STATE(1564), 1,
      sym_comment,
    STATE(1784), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [90976] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(2423), 1,
      sym_identifier,
    STATE(117), 1,
      sym_field_ref,
    STATE(1565), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    STATE(111), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [90999] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    ACTIONS(2425), 1,
      sym_identifier,
    STATE(1187), 1,
      sym_func_call,
    STATE(1190), 1,
      sym_regex,
    STATE(1566), 1,
      sym_comment,
    STATE(1760), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91024] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2427), 1,
      sym_identifier,
    ACTIONS(2429), 1,
      anon_sym_DOLLAR,
    STATE(1201), 1,
      sym_field_ref,
    STATE(1567), 1,
      sym_comment,
    STATE(1809), 1,
      sym_namespace,
    STATE(1159), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91047] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2427), 1,
      sym_identifier,
    ACTIONS(2431), 1,
      anon_sym_DOLLAR,
    STATE(1201), 1,
      sym_field_ref,
    STATE(1568), 1,
      sym_comment,
    STATE(1809), 1,
      sym_namespace,
    STATE(1159), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91070] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1555), 1,
      anon_sym_SLASH,
    ACTIONS(2425), 1,
      sym_identifier,
    STATE(1187), 1,
      sym_func_call,
    STATE(1190), 1,
      sym_regex,
    STATE(1569), 1,
      sym_comment,
    STATE(1760), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91095] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1570), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
    ACTIONS(2433), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [91112] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2435), 1,
      sym_identifier,
    ACTIONS(2437), 1,
      anon_sym_DOLLAR,
    STATE(1259), 1,
      sym_field_ref,
    STATE(1571), 1,
      sym_comment,
    STATE(1806), 1,
      sym_namespace,
    STATE(1212), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91135] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    ACTIONS(2419), 1,
      sym_identifier,
    STATE(156), 1,
      sym_func_call,
    STATE(175), 1,
      sym_regex,
    STATE(1572), 1,
      sym_comment,
    STATE(1763), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91160] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(2411), 1,
      sym_identifier,
    STATE(159), 1,
      sym_field_ref,
    STATE(1573), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    STATE(147), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91183] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2439), 1,
      sym_identifier,
    ACTIONS(2441), 1,
      anon_sym_DOLLAR,
    STATE(356), 1,
      sym_field_ref,
    STATE(1574), 1,
      sym_comment,
    STATE(1811), 1,
      sym_namespace,
    STATE(278), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91206] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(365), 1,
      anon_sym_SLASH,
    ACTIONS(2443), 1,
      sym_identifier,
    STATE(1266), 1,
      sym_regex,
    STATE(1272), 1,
      sym_func_call,
    STATE(1575), 1,
      sym_comment,
    STATE(1771), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91231] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2397), 1,
      anon_sym_case,
    ACTIONS(2399), 1,
      anon_sym_default,
    ACTIONS(2445), 1,
      anon_sym_RBRACE,
    STATE(1556), 1,
      aux_sym_switch_body_repeat1,
    STATE(1576), 1,
      sym_comment,
    STATE(1656), 2,
      sym_switch_case,
      sym_switch_default,
  [91254] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2397), 1,
      anon_sym_case,
    ACTIONS(2399), 1,
      anon_sym_default,
    ACTIONS(2447), 1,
      anon_sym_RBRACE,
    STATE(1577), 1,
      sym_comment,
    STATE(1600), 1,
      aux_sym_switch_body_repeat1,
    STATE(1656), 2,
      sym_switch_case,
      sym_switch_default,
  [91277] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1563), 1,
      anon_sym_SLASH,
    ACTIONS(2449), 1,
      sym_identifier,
    STATE(258), 1,
      sym_regex,
    STATE(259), 1,
      sym_func_call,
    STATE(1578), 1,
      sym_comment,
    STATE(1777), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91302] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_DOLLAR,
    ACTIONS(2387), 1,
      sym_identifier,
    STATE(257), 1,
      sym_field_ref,
    STATE(1579), 1,
      sym_comment,
    STATE(1853), 1,
      sym_namespace,
    STATE(229), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91325] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2451), 1,
      sym_identifier,
    ACTIONS(2453), 1,
      anon_sym_DOLLAR,
    STATE(500), 1,
      sym_field_ref,
    STATE(1580), 1,
      sym_comment,
    STATE(1725), 1,
      sym_namespace,
    STATE(455), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91348] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(343), 1,
      anon_sym_SLASH,
    ACTIONS(2455), 1,
      sym_identifier,
    STATE(357), 1,
      sym_regex,
    STATE(358), 1,
      sym_func_call,
    STATE(1581), 1,
      sym_comment,
    STATE(1757), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91373] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(19), 1,
      anon_sym_SLASH,
    ACTIONS(2457), 1,
      sym_identifier,
    STATE(496), 1,
      sym_regex,
    STATE(511), 1,
      sym_func_call,
    STATE(1582), 1,
      sym_comment,
    STATE(1714), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91398] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2459), 1,
      sym_identifier,
    ACTIONS(2461), 1,
      anon_sym_DOLLAR,
    STATE(289), 1,
      sym_field_ref,
    STATE(1583), 1,
      sym_comment,
    STATE(1812), 1,
      sym_namespace,
    STATE(262), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91421] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1441), 1,
      anon_sym_SLASH,
    ACTIONS(2463), 1,
      sym_identifier,
    STATE(293), 1,
      sym_regex,
    STATE(295), 1,
      sym_func_call,
    STATE(1584), 1,
      sym_comment,
    STATE(1754), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91446] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(351), 1,
      anon_sym_DOLLAR,
    ACTIONS(2423), 1,
      sym_identifier,
    STATE(117), 1,
      sym_field_ref,
    STATE(1585), 1,
      sym_comment,
    STATE(1813), 1,
      sym_namespace,
    STATE(111), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91469] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2465), 1,
      sym_identifier,
    ACTIONS(2467), 1,
      anon_sym_DOLLAR,
    STATE(480), 1,
      sym_field_ref,
    STATE(1586), 1,
      sym_comment,
    STATE(1803), 1,
      sym_namespace,
    STATE(450), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91492] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1369), 1,
      anon_sym_SLASH,
    ACTIONS(2469), 1,
      sym_identifier,
    STATE(482), 1,
      sym_regex,
    STATE(483), 1,
      sym_func_call,
    STATE(1587), 1,
      sym_comment,
    STATE(1780), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91517] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1397), 1,
      anon_sym_SLASH,
    ACTIONS(2417), 1,
      sym_identifier,
    STATE(114), 1,
      sym_func_call,
    STATE(118), 1,
      sym_regex,
    STATE(1588), 1,
      sym_comment,
    STATE(1750), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91542] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    ACTIONS(2471), 1,
      sym_identifier,
    STATE(1337), 1,
      sym_func_call,
    STATE(1346), 1,
      sym_regex,
    STATE(1589), 1,
      sym_comment,
    STATE(1774), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91567] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2413), 1,
      sym_identifier,
    ACTIONS(2473), 1,
      anon_sym_DOLLAR,
    STATE(1195), 1,
      sym_field_ref,
    STATE(1590), 1,
      sym_comment,
    STATE(1814), 1,
      sym_namespace,
    STATE(1184), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91590] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(293), 1,
      anon_sym_SLASH,
    ACTIONS(2393), 1,
      sym_identifier,
    STATE(1236), 1,
      sym_func_call,
    STATE(1239), 1,
      sym_regex,
    STATE(1591), 1,
      sym_comment,
    STATE(1747), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91615] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2475), 1,
      sym_identifier,
    ACTIONS(2477), 1,
      anon_sym_DOLLAR,
    STATE(1358), 1,
      sym_field_ref,
    STATE(1592), 1,
      sym_comment,
    STATE(1805), 1,
      sym_namespace,
    STATE(1327), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91638] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1124), 1,
      anon_sym_SLASH,
    ACTIONS(2479), 1,
      sym_identifier,
    STATE(1402), 1,
      sym_regex,
    STATE(1404), 1,
      sym_func_call,
    STATE(1593), 1,
      sym_comment,
    STATE(1788), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91663] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2389), 1,
      sym_identifier,
    ACTIONS(2481), 1,
      anon_sym_DOLLAR,
    STATE(1175), 1,
      sym_field_ref,
    STATE(1594), 1,
      sym_comment,
    STATE(1815), 1,
      sym_namespace,
    STATE(1139), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91686] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    ACTIONS(2483), 1,
      sym_identifier,
    STATE(1162), 1,
      sym_regex,
    STATE(1169), 1,
      sym_func_call,
    STATE(1595), 1,
      sym_comment,
    STATE(1744), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91711] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1459), 1,
      anon_sym_SLASH,
    ACTIONS(2417), 1,
      sym_identifier,
    STATE(114), 1,
      sym_func_call,
    STATE(118), 1,
      sym_regex,
    STATE(1596), 1,
      sym_comment,
    STATE(1750), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91736] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2485), 1,
      anon_sym_SLASH,
    ACTIONS(2487), 1,
      sym_number,
    ACTIONS(2489), 1,
      anon_sym_DQUOTE,
    STATE(1597), 1,
      sym_comment,
    STATE(1712), 1,
      sym_string,
    STATE(1786), 2,
      sym_regex,
      sym__primitive,
  [91759] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(413), 1,
      anon_sym_SLASH,
    ACTIONS(2443), 1,
      sym_identifier,
    STATE(1266), 1,
      sym_regex,
    STATE(1272), 1,
      sym_func_call,
    STATE(1598), 1,
      sym_comment,
    STATE(1771), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91784] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2491), 1,
      sym_identifier,
    ACTIONS(2493), 1,
      anon_sym_DOLLAR,
    STATE(1401), 1,
      sym_field_ref,
    STATE(1599), 1,
      sym_comment,
    STATE(1794), 1,
      sym_namespace,
    STATE(1348), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91807] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2397), 1,
      anon_sym_case,
    ACTIONS(2399), 1,
      anon_sym_default,
    ACTIONS(2495), 1,
      anon_sym_RBRACE,
    STATE(1600), 1,
      sym_comment,
    STATE(1605), 1,
      aux_sym_switch_body_repeat1,
    STATE(1656), 2,
      sym_switch_case,
      sym_switch_default,
  [91830] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1423), 1,
      anon_sym_SLASH,
    ACTIONS(2449), 1,
      sym_identifier,
    STATE(258), 1,
      sym_regex,
    STATE(259), 1,
      sym_func_call,
    STATE(1601), 1,
      sym_comment,
    STATE(1777), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91855] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(317), 1,
      anon_sym_DOLLAR,
    ACTIONS(2423), 1,
      sym_identifier,
    STATE(117), 1,
      sym_field_ref,
    STATE(1602), 1,
      sym_comment,
    STATE(1810), 1,
      sym_namespace,
    STATE(111), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91878] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1475), 1,
      anon_sym_SLASH,
    ACTIONS(2419), 1,
      sym_identifier,
    STATE(156), 1,
      sym_func_call,
    STATE(175), 1,
      sym_regex,
    STATE(1603), 1,
      sym_comment,
    STATE(1763), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91903] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1523), 1,
      anon_sym_SLASH,
    ACTIONS(2483), 1,
      sym_identifier,
    STATE(1162), 1,
      sym_regex,
    STATE(1169), 1,
      sym_func_call,
    STATE(1604), 1,
      sym_comment,
    STATE(1744), 1,
      sym_ns_qualified_name,
    STATE(1794), 1,
      sym_namespace,
  [91928] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2497), 1,
      anon_sym_RBRACE,
    ACTIONS(2499), 1,
      anon_sym_case,
    ACTIONS(2502), 1,
      anon_sym_default,
    STATE(1605), 2,
      sym_comment,
      aux_sym_switch_body_repeat1,
    STATE(1656), 2,
      sym_switch_case,
      sym_switch_default,
  [91949] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(371), 1,
      anon_sym_DOLLAR,
    ACTIONS(2411), 1,
      sym_identifier,
    STATE(159), 1,
      sym_field_ref,
    STATE(1606), 1,
      sym_comment,
    STATE(1729), 1,
      sym_namespace,
    STATE(147), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91972] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2435), 1,
      sym_identifier,
    ACTIONS(2505), 1,
      anon_sym_DOLLAR,
    STATE(1259), 1,
      sym_field_ref,
    STATE(1607), 1,
      sym_comment,
    STATE(1806), 1,
      sym_namespace,
    STATE(1212), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [91995] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2507), 1,
      anon_sym_DQUOTE,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    STATE(1608), 1,
      sym_comment,
    STATE(1618), 1,
      aux_sym_string_repeat1,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92015] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2513), 1,
      anon_sym_DQUOTE,
    STATE(1609), 1,
      sym_comment,
    STATE(1613), 1,
      aux_sym_string_repeat1,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92035] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2515), 1,
      anon_sym_DQUOTE,
    STATE(1610), 1,
      sym_comment,
    STATE(1611), 1,
      aux_sym_string_repeat1,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92055] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2517), 1,
      anon_sym_DQUOTE,
    STATE(1611), 1,
      sym_comment,
    STATE(1626), 1,
      aux_sym_string_repeat1,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92075] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2519), 1,
      anon_sym_DQUOTE,
    STATE(1612), 1,
      sym_comment,
    STATE(1632), 1,
      aux_sym_string_repeat1,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92095] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2521), 1,
      anon_sym_DQUOTE,
    STATE(1613), 1,
      sym_comment,
    STATE(1626), 1,
      aux_sym_string_repeat1,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92115] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2523), 1,
      sym__if_else_separator,
    STATE(1614), 1,
      sym_comment,
    ACTIONS(1701), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
  [92131] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2523), 1,
      sym__if_else_separator,
    STATE(1615), 1,
      sym_comment,
    ACTIONS(1701), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
  [92147] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2525), 1,
      anon_sym_DQUOTE,
    STATE(1616), 1,
      sym_comment,
    STATE(1623), 1,
      aux_sym_string_repeat1,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92167] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2527), 1,
      anon_sym_DQUOTE,
    STATE(1617), 1,
      sym_comment,
    STATE(1625), 1,
      aux_sym_string_repeat1,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92187] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2529), 1,
      anon_sym_DQUOTE,
    STATE(1618), 1,
      sym_comment,
    STATE(1626), 1,
      aux_sym_string_repeat1,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92207] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2531), 1,
      anon_sym_DQUOTE,
    STATE(1619), 1,
      sym_comment,
    STATE(1626), 1,
      aux_sym_string_repeat1,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92227] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2533), 1,
      sym__if_else_separator,
    STATE(1620), 1,
      sym_comment,
    ACTIONS(1701), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
  [92243] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2533), 1,
      sym__if_else_separator,
    STATE(1621), 1,
      sym_comment,
    ACTIONS(1701), 4,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
      anon_sym_while,
  [92259] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2535), 1,
      anon_sym_DQUOTE,
    STATE(1619), 1,
      aux_sym_string_repeat1,
    STATE(1622), 1,
      sym_comment,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92279] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2537), 1,
      anon_sym_DQUOTE,
    STATE(1623), 1,
      sym_comment,
    STATE(1626), 1,
      aux_sym_string_repeat1,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92299] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2539), 1,
      anon_sym_DQUOTE,
    STATE(1624), 1,
      sym_comment,
    STATE(1630), 1,
      aux_sym_string_repeat1,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92319] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2541), 1,
      anon_sym_DQUOTE,
    STATE(1625), 1,
      sym_comment,
    STATE(1626), 1,
      aux_sym_string_repeat1,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92339] = 5,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2543), 1,
      anon_sym_DQUOTE,
    ACTIONS(2545), 1,
      aux_sym_string_token1,
    ACTIONS(2548), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
    STATE(1626), 2,
      sym_comment,
      aux_sym_string_repeat1,
  [92357] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2551), 1,
      anon_sym_DQUOTE,
    STATE(1626), 1,
      aux_sym_string_repeat1,
    STATE(1627), 1,
      sym_comment,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92377] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2553), 1,
      anon_sym_DQUOTE,
    STATE(1626), 1,
      aux_sym_string_repeat1,
    STATE(1628), 1,
      sym_comment,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92397] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2555), 1,
      anon_sym_DQUOTE,
    STATE(1628), 1,
      aux_sym_string_repeat1,
    STATE(1629), 1,
      sym_comment,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92417] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2557), 1,
      anon_sym_DQUOTE,
    STATE(1626), 1,
      aux_sym_string_repeat1,
    STATE(1630), 1,
      sym_comment,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92437] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2559), 1,
      anon_sym_DQUOTE,
    STATE(1627), 1,
      aux_sym_string_repeat1,
    STATE(1631), 1,
      sym_comment,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92457] = 6,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2509), 1,
      aux_sym_string_token1,
    ACTIONS(2561), 1,
      anon_sym_DQUOTE,
    STATE(1626), 1,
      aux_sym_string_repeat1,
    STATE(1632), 1,
      sym_comment,
    ACTIONS(2511), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92477] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2563), 1,
      sym_identifier,
    STATE(1633), 1,
      sym_comment,
    STATE(1725), 1,
      sym_namespace,
    STATE(1692), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [92494] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    STATE(1634), 1,
      sym_comment,
    ACTIONS(2565), 2,
      anon_sym_DQUOTE,
      aux_sym_string_token1,
    ACTIONS(2567), 2,
      sym__ambiguous_comment,
      sym_escape_sequence,
  [92509] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2569), 1,
      sym_identifier,
    STATE(1635), 1,
      sym_comment,
    STATE(1725), 1,
      sym_namespace,
    STATE(1675), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [92526] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2571), 1,
      sym_identifier,
    STATE(1636), 1,
      sym_comment,
    STATE(1725), 1,
      sym_namespace,
    STATE(1659), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [92543] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2573), 1,
      sym_identifier,
    STATE(1637), 1,
      sym_comment,
    STATE(1725), 1,
      sym_namespace,
    STATE(1669), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [92560] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2575), 1,
      sym_identifier,
    STATE(1638), 1,
      sym_comment,
    STATE(1811), 1,
      sym_namespace,
    STATE(716), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [92577] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2577), 1,
      anon_sym_while,
    STATE(1639), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
  [92592] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2579), 1,
      sym_identifier,
    STATE(1640), 1,
      sym_comment,
    STATE(1725), 1,
      sym_namespace,
    STATE(1665), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [92609] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2581), 1,
      sym_identifier,
    STATE(1641), 1,
      sym_comment,
    STATE(1801), 1,
      sym_namespace,
    STATE(858), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [92626] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2583), 1,
      sym_identifier,
    STATE(1642), 1,
      sym_comment,
    STATE(1725), 1,
      sym_namespace,
    STATE(1697), 2,
      sym_array_ref,
      sym_ns_qualified_name,
  [92643] = 4,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2585), 1,
      anon_sym_while,
    STATE(1643), 1,
      sym_comment,
    ACTIONS(1681), 3,
      anon_sym_SEMI,
      anon_sym_LF,
      anon_sym_CR_LF,
  [92658] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1923), 1,
      anon_sym_COMMA,
    ACTIONS(2587), 1,
      anon_sym_RPAREN,
    STATE(1644), 1,
      sym_comment,
    STATE(1648), 1,
      aux_sym_args_repeat1,
  [92674] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2589), 1,
      anon_sym_COMMA,
    ACTIONS(2591), 1,
      anon_sym_RPAREN,
    STATE(1645), 1,
      sym_comment,
    STATE(1646), 1,
      aux_sym_param_list_repeat1,
  [92690] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2589), 1,
      anon_sym_COMMA,
    ACTIONS(2593), 1,
      anon_sym_RPAREN,
    STATE(1646), 1,
      sym_comment,
    STATE(1652), 1,
      aux_sym_param_list_repeat1,
  [92706] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2595), 1,
      sym_identifier,
    ACTIONS(2597), 1,
      anon_sym_RPAREN,
    STATE(1647), 1,
      sym_comment,
    STATE(1723), 1,
      sym_param_list,
  [92722] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1955), 1,
      anon_sym_RPAREN,
    ACTIONS(2599), 1,
      anon_sym_COMMA,
    STATE(1648), 2,
      sym_comment,
      aux_sym_args_repeat1,
  [92736] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    ACTIONS(2602), 1,
      anon_sym_RPAREN,
    STATE(1649), 1,
      sym_comment,
  [92752] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    ACTIONS(2604), 1,
      anon_sym_RPAREN,
    STATE(1650), 1,
      sym_comment,
  [92768] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    ACTIONS(2606), 1,
      anon_sym_RPAREN,
    STATE(1651), 1,
      sym_comment,
  [92784] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2608), 1,
      anon_sym_COMMA,
    ACTIONS(2611), 1,
      anon_sym_RPAREN,
    STATE(1652), 2,
      sym_comment,
      aux_sym_param_list_repeat1,
  [92798] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    ACTIONS(2613), 1,
      anon_sym_RPAREN,
    STATE(1653), 1,
      sym_comment,
  [92814] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    ACTIONS(2615), 1,
      anon_sym_RPAREN,
    STATE(1654), 1,
      sym_comment,
  [92830] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    ACTIONS(2617), 1,
      anon_sym_RPAREN,
    STATE(1655), 1,
      sym_comment,
  [92846] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1656), 1,
      sym_comment,
    ACTIONS(2619), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [92858] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2621), 1,
      sym_identifier,
    STATE(1657), 1,
      sym_comment,
    STATE(1725), 1,
      sym_namespace,
    STATE(1751), 1,
      sym_ns_qualified_name,
  [92874] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(792), 1,
      anon_sym_LPAREN2,
    STATE(1658), 1,
      sym_comment,
  [92887] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    ACTIONS(2606), 1,
      anon_sym_RPAREN,
    STATE(1659), 1,
      sym_comment,
  [92900] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2623), 1,
      anon_sym_getline,
    STATE(124), 1,
      sym_getline_input,
    STATE(1660), 1,
      sym_comment,
  [92913] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2625), 1,
      anon_sym_getline,
    STATE(265), 1,
      sym_getline_input,
    STATE(1661), 1,
      sym_comment,
  [92926] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2627), 1,
      anon_sym_getline,
    STATE(1228), 1,
      sym_getline_input,
    STATE(1662), 1,
      sym_comment,
  [92939] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2629), 1,
      anon_sym_getline,
    STATE(1151), 1,
      sym_getline_input,
    STATE(1663), 1,
      sym_comment,
  [92952] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_LPAREN2,
    STATE(1664), 1,
      sym_comment,
  [92965] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    ACTIONS(2613), 1,
      anon_sym_RPAREN,
    STATE(1665), 1,
      sym_comment,
  [92978] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2633), 1,
      anon_sym_else,
    STATE(1097), 1,
      sym_else_clause,
    STATE(1666), 1,
      sym_comment,
  [92991] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2635), 1,
      anon_sym_LPAREN2,
    STATE(1667), 1,
      sym_comment,
  [93004] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2637), 1,
      anon_sym_else,
    STATE(1084), 1,
      sym_else_clause,
    STATE(1668), 1,
      sym_comment,
  [93017] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    ACTIONS(2617), 1,
      anon_sym_RPAREN,
    STATE(1669), 1,
      sym_comment,
  [93030] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    STATE(1417), 1,
      sym_block,
    STATE(1670), 1,
      sym_comment,
  [93043] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2639), 1,
      anon_sym_getline,
    STATE(176), 1,
      sym_getline_input,
    STATE(1671), 1,
      sym_comment,
  [93056] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2641), 1,
      anon_sym_getline,
    STATE(124), 1,
      sym_getline_input,
    STATE(1672), 1,
      sym_comment,
  [93069] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2643), 1,
      anon_sym_getline,
    STATE(454), 1,
      sym_getline_input,
    STATE(1673), 1,
      sym_comment,
  [93082] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    STATE(1420), 1,
      sym_block,
    STATE(1674), 1,
      sym_comment,
  [93095] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    ACTIONS(2615), 1,
      anon_sym_RPAREN,
    STATE(1675), 1,
      sym_comment,
  [93108] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2645), 1,
      anon_sym_else,
    STATE(1097), 1,
      sym_else_clause,
    STATE(1676), 1,
      sym_comment,
  [93121] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2647), 1,
      anon_sym_getline,
    STATE(176), 1,
      sym_getline_input,
    STATE(1677), 1,
      sym_comment,
  [93134] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2649), 1,
      anon_sym_else,
    STATE(1097), 1,
      sym_else_clause,
    STATE(1678), 1,
      sym_comment,
  [93147] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2651), 1,
      anon_sym_getline,
    STATE(1394), 1,
      sym_getline_input,
    STATE(1679), 1,
      sym_comment,
  [93160] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(669), 1,
      anon_sym_LPAREN2,
    STATE(1680), 1,
      sym_comment,
  [93173] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2653), 1,
      anon_sym_getline,
    STATE(341), 1,
      sym_getline_input,
    STATE(1681), 1,
      sym_comment,
  [93186] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    STATE(1682), 1,
      sym_comment,
  [93199] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2655), 1,
      anon_sym_LBRACE,
    STATE(1090), 1,
      sym_switch_body,
    STATE(1683), 1,
      sym_comment,
  [93212] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2657), 1,
      anon_sym_else,
    STATE(1084), 1,
      sym_else_clause,
    STATE(1684), 1,
      sym_comment,
  [93225] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2659), 1,
      anon_sym_getline,
    STATE(299), 1,
      sym_getline_input,
    STATE(1685), 1,
      sym_comment,
  [93238] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2661), 1,
      anon_sym_getline,
    STATE(363), 1,
      sym_getline_input,
    STATE(1686), 1,
      sym_comment,
  [93251] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2663), 1,
      anon_sym_LPAREN2,
    STATE(1687), 1,
      sym_comment,
  [93264] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2665), 1,
      anon_sym_LPAREN2,
    STATE(1688), 1,
      sym_comment,
  [93277] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2667), 1,
      anon_sym_getline,
    STATE(265), 1,
      sym_getline_input,
    STATE(1689), 1,
      sym_comment,
  [93290] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2669), 1,
      anon_sym_getline,
    STATE(1197), 1,
      sym_getline_input,
    STATE(1690), 1,
      sym_comment,
  [93303] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2489), 1,
      anon_sym_DQUOTE,
    STATE(1424), 1,
      sym_string,
    STATE(1691), 1,
      sym_comment,
  [93316] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    ACTIONS(2604), 1,
      anon_sym_RPAREN,
    STATE(1692), 1,
      sym_comment,
  [93329] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(523), 1,
      anon_sym_LPAREN2,
    STATE(1693), 1,
      sym_comment,
  [93342] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(445), 1,
      anon_sym_LPAREN2,
    STATE(1694), 1,
      sym_comment,
  [93355] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2671), 1,
      anon_sym_getline,
    STATE(399), 1,
      sym_getline_input,
    STATE(1695), 1,
      sym_comment,
  [93368] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(962), 1,
      anon_sym_LPAREN2,
    STATE(1696), 1,
      sym_comment,
  [93381] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(918), 1,
      anon_sym_LBRACK,
    ACTIONS(2602), 1,
      anon_sym_RPAREN,
    STATE(1697), 1,
      sym_comment,
  [93394] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2673), 1,
      anon_sym_else,
    STATE(1084), 1,
      sym_else_clause,
    STATE(1698), 1,
      sym_comment,
  [93407] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2675), 1,
      anon_sym_LPAREN2,
    STATE(1699), 1,
      sym_comment,
  [93420] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2677), 1,
      anon_sym_getline,
    STATE(1350), 1,
      sym_getline_input,
    STATE(1700), 1,
      sym_comment,
  [93433] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(455), 1,
      anon_sym_LPAREN2,
    STATE(1701), 1,
      sym_comment,
  [93446] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2679), 1,
      anon_sym_LPAREN,
    STATE(1702), 1,
      sym_comment,
  [93459] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(425), 1,
      anon_sym_LPAREN2,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    STATE(1703), 1,
      sym_comment,
  [93472] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2681), 1,
      anon_sym_LPAREN2,
    STATE(1704), 1,
      sym_comment,
  [93485] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(1705), 1,
      sym_comment,
    ACTIONS(2611), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [93496] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(431), 1,
      anon_sym_COLON_COLON,
    ACTIONS(956), 1,
      anon_sym_LPAREN2,
    STATE(1706), 1,
      sym_comment,
  [93509] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2683), 1,
      anon_sym_getline,
    STATE(497), 1,
      sym_getline_input,
    STATE(1707), 1,
      sym_comment,
  [93522] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2685), 1,
      anon_sym_getline,
    STATE(1277), 1,
      sym_getline_input,
    STATE(1708), 1,
      sym_comment,
  [93535] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(591), 1,
      anon_sym_COLON,
    ACTIONS(2687), 1,
      sym_regex_flags,
    STATE(1709), 1,
      sym_comment,
  [93548] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2689), 1,
      anon_sym_LBRACE,
    STATE(1126), 1,
      sym_switch_body,
    STATE(1710), 1,
      sym_comment,
  [93561] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2691), 1,
      anon_sym_RPAREN,
    STATE(1711), 1,
      sym_comment,
  [93571] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(517), 1,
      anon_sym_COLON,
    STATE(1712), 1,
      sym_comment,
  [93581] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2693), 1,
      anon_sym_while,
    STATE(1713), 1,
      sym_comment,
  [93591] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2665), 1,
      anon_sym_LPAREN2,
    STATE(1714), 1,
      sym_comment,
  [93601] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1943), 1,
      anon_sym_RBRACK,
    STATE(1715), 1,
      sym_comment,
  [93611] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2695), 1,
      anon_sym_RPAREN,
    STATE(1716), 1,
      sym_comment,
  [93621] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2697), 1,
      sym__no_space,
    STATE(1717), 1,
      sym_comment,
  [93631] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2699), 1,
      sym__no_space,
    STATE(1718), 1,
      sym_comment,
  [93641] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2701), 1,
      sym_identifier,
    STATE(1719), 1,
      sym_comment,
  [93651] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2703), 1,
      anon_sym_LPAREN,
    STATE(1720), 1,
      sym_comment,
  [93661] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2705), 1,
      anon_sym_RPAREN,
    STATE(1721), 1,
      sym_comment,
  [93671] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2707), 1,
      anon_sym_RPAREN,
    STATE(1722), 1,
      sym_comment,
  [93681] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2709), 1,
      anon_sym_RPAREN,
    STATE(1723), 1,
      sym_comment,
  [93691] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2711), 1,
      sym_identifier,
    STATE(1724), 1,
      sym_comment,
  [93701] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2713), 1,
      anon_sym_COLON_COLON,
    STATE(1725), 1,
      sym_comment,
  [93711] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2715), 1,
      anon_sym_LPAREN,
    STATE(1726), 1,
      sym_comment,
  [93721] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    STATE(1727), 1,
      sym_comment,
  [93731] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2719), 1,
      anon_sym_LPAREN,
    STATE(1728), 1,
      sym_comment,
  [93741] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2721), 1,
      anon_sym_COLON_COLON,
    STATE(1729), 1,
      sym_comment,
  [93751] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2723), 1,
      sym_regex_pattern,
    STATE(1730), 1,
      sym_comment,
  [93761] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2725), 1,
      sym_regex_pattern,
    STATE(1731), 1,
      sym_comment,
  [93771] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2727), 1,
      sym_regex_pattern,
    STATE(1732), 1,
      sym_comment,
  [93781] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2729), 1,
      sym_regex_pattern,
    STATE(1733), 1,
      sym_comment,
  [93791] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2731), 1,
      sym_regex_pattern,
    STATE(1734), 1,
      sym_comment,
  [93801] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2733), 1,
      sym_regex_pattern,
    STATE(1735), 1,
      sym_comment,
  [93811] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2735), 1,
      sym_regex_pattern,
    STATE(1736), 1,
      sym_comment,
  [93821] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2737), 1,
      sym_regex_pattern,
    STATE(1737), 1,
      sym_comment,
  [93831] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2739), 1,
      sym_regex_pattern,
    STATE(1738), 1,
      sym_comment,
  [93841] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2741), 1,
      sym__no_space,
    STATE(1739), 1,
      sym_comment,
  [93851] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2743), 1,
      sym_regex_pattern,
    STATE(1740), 1,
      sym_comment,
  [93861] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2745), 1,
      sym__no_space,
    STATE(1741), 1,
      sym_comment,
  [93871] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2747), 1,
      sym_regex_pattern,
    STATE(1742), 1,
      sym_comment,
  [93881] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2749), 1,
      sym__no_space,
    STATE(1743), 1,
      sym_comment,
  [93891] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(956), 1,
      anon_sym_LPAREN2,
    STATE(1744), 1,
      sym_comment,
  [93901] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2751), 1,
      sym_regex_pattern,
    STATE(1745), 1,
      sym_comment,
  [93911] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2753), 1,
      sym__no_space,
    STATE(1746), 1,
      sym_comment,
  [93921] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2681), 1,
      anon_sym_LPAREN2,
    STATE(1747), 1,
      sym_comment,
  [93931] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2755), 1,
      sym_regex_pattern,
    STATE(1748), 1,
      sym_comment,
  [93941] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2757), 1,
      sym__no_space,
    STATE(1749), 1,
      sym_comment,
  [93951] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(425), 1,
      anon_sym_LPAREN2,
    STATE(1750), 1,
      sym_comment,
  [93961] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2679), 1,
      anon_sym_LPAREN,
    STATE(1751), 1,
      sym_comment,
  [93971] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2759), 1,
      sym_regex_pattern,
    STATE(1752), 1,
      sym_comment,
  [93981] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2761), 1,
      sym__no_space,
    STATE(1753), 1,
      sym_comment,
  [93991] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(455), 1,
      anon_sym_LPAREN2,
    STATE(1754), 1,
      sym_comment,
  [94001] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2763), 1,
      sym_regex_pattern,
    STATE(1755), 1,
      sym_comment,
  [94011] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2765), 1,
      sym__no_space,
    STATE(1756), 1,
      sym_comment,
  [94021] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2675), 1,
      anon_sym_LPAREN2,
    STATE(1757), 1,
      sym_comment,
  [94031] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2767), 1,
      sym_regex_pattern,
    STATE(1758), 1,
      sym_comment,
  [94041] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2769), 1,
      sym__no_space,
    STATE(1759), 1,
      sym_comment,
  [94051] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(962), 1,
      anon_sym_LPAREN2,
    STATE(1760), 1,
      sym_comment,
  [94061] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2771), 1,
      sym_regex_pattern,
    STATE(1761), 1,
      sym_comment,
  [94071] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2773), 1,
      sym__no_space,
    STATE(1762), 1,
      sym_comment,
  [94081] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(445), 1,
      anon_sym_LPAREN2,
    STATE(1763), 1,
      sym_comment,
  [94091] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2775), 1,
      sym_regex_pattern,
    STATE(1764), 1,
      sym_comment,
  [94101] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2777), 1,
      sym__no_space,
    STATE(1765), 1,
      sym_comment,
  [94111] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(523), 1,
      anon_sym_LPAREN2,
    STATE(1766), 1,
      sym_comment,
  [94121] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2779), 1,
      aux_sym_comment_token1,
    STATE(1767), 1,
      sym_comment,
  [94131] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2781), 1,
      sym_regex_pattern,
    STATE(1768), 1,
      sym_comment,
  [94141] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2783), 1,
      anon_sym_SLASH2,
    STATE(1769), 1,
      sym_comment,
  [94151] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2785), 1,
      sym__no_space,
    STATE(1770), 1,
      sym_comment,
  [94161] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2663), 1,
      anon_sym_LPAREN2,
    STATE(1771), 1,
      sym_comment,
  [94171] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2787), 1,
      sym_regex_pattern,
    STATE(1772), 1,
      sym_comment,
  [94181] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2789), 1,
      sym__no_space,
    STATE(1773), 1,
      sym_comment,
  [94191] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1070), 1,
      anon_sym_LPAREN2,
    STATE(1774), 1,
      sym_comment,
  [94201] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2791), 1,
      sym_regex_pattern,
    STATE(1775), 1,
      sym_comment,
  [94211] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2793), 1,
      sym__no_space,
    STATE(1776), 1,
      sym_comment,
  [94221] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(669), 1,
      anon_sym_LPAREN2,
    STATE(1777), 1,
      sym_comment,
  [94231] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2795), 1,
      sym_regex_pattern,
    STATE(1778), 1,
      sym_comment,
  [94241] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2797), 1,
      sym__no_space,
    STATE(1779), 1,
      sym_comment,
  [94251] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(792), 1,
      anon_sym_LPAREN2,
    STATE(1780), 1,
      sym_comment,
  [94261] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2799), 1,
      sym_regex_pattern,
    STATE(1781), 1,
      sym_comment,
  [94271] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2801), 1,
      sym__no_space,
    STATE(1782), 1,
      sym_comment,
  [94281] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2803), 1,
      anon_sym_COLON,
    STATE(1783), 1,
      sym_comment,
  [94291] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2635), 1,
      anon_sym_LPAREN2,
    STATE(1784), 1,
      sym_comment,
  [94301] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2805), 1,
      anon_sym_SLASH2,
    STATE(1785), 1,
      sym_comment,
  [94311] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2807), 1,
      anon_sym_COLON,
    STATE(1786), 1,
      sym_comment,
  [94321] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2809), 1,
      sym__no_space,
    STATE(1787), 1,
      sym_comment,
  [94331] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2631), 1,
      anon_sym_LPAREN2,
    STATE(1788), 1,
      sym_comment,
  [94341] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2811), 1,
      sym_regex_pattern,
    STATE(1789), 1,
      sym_comment,
  [94351] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2813), 1,
      anon_sym_SLASH2,
    STATE(1790), 1,
      sym_comment,
  [94361] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2815), 1,
      anon_sym_SLASH2,
    STATE(1791), 1,
      sym_comment,
  [94371] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2817), 1,
      anon_sym_SLASH2,
    STATE(1792), 1,
      sym_comment,
  [94381] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2819), 1,
      anon_sym_SLASH2,
    STATE(1793), 1,
      sym_comment,
  [94391] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2821), 1,
      anon_sym_COLON_COLON,
    STATE(1794), 1,
      sym_comment,
  [94401] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2823), 1,
      anon_sym_LPAREN,
    STATE(1795), 1,
      sym_comment,
  [94411] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2825), 1,
      anon_sym_SLASH2,
    STATE(1796), 1,
      sym_comment,
  [94421] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2827), 1,
      anon_sym_LPAREN,
    STATE(1797), 1,
      sym_comment,
  [94431] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2829), 1,
      anon_sym_SLASH2,
    STATE(1798), 1,
      sym_comment,
  [94441] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2831), 1,
      anon_sym_SLASH2,
    STATE(1799), 1,
      sym_comment,
  [94451] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2833), 1,
      sym_identifier,
    STATE(1800), 1,
      sym_comment,
  [94461] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2835), 1,
      anon_sym_COLON_COLON,
    STATE(1801), 1,
      sym_comment,
  [94471] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2837), 1,
      anon_sym_SLASH2,
    STATE(1802), 1,
      sym_comment,
  [94481] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2839), 1,
      anon_sym_COLON_COLON,
    STATE(1803), 1,
      sym_comment,
  [94491] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2841), 1,
      anon_sym_COLON_COLON,
    STATE(1804), 1,
      sym_comment,
  [94501] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2843), 1,
      anon_sym_COLON_COLON,
    STATE(1805), 1,
      sym_comment,
  [94511] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2845), 1,
      anon_sym_COLON_COLON,
    STATE(1806), 1,
      sym_comment,
  [94521] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2847), 1,
      anon_sym_COLON_COLON,
    STATE(1807), 1,
      sym_comment,
  [94531] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2849), 1,
      anon_sym_COLON_COLON,
    STATE(1808), 1,
      sym_comment,
  [94541] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2851), 1,
      anon_sym_COLON_COLON,
    STATE(1809), 1,
      sym_comment,
  [94551] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2853), 1,
      anon_sym_COLON_COLON,
    STATE(1810), 1,
      sym_comment,
  [94561] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2855), 1,
      anon_sym_COLON_COLON,
    STATE(1811), 1,
      sym_comment,
  [94571] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2857), 1,
      anon_sym_COLON_COLON,
    STATE(1812), 1,
      sym_comment,
  [94581] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2859), 1,
      anon_sym_COLON_COLON,
    STATE(1813), 1,
      sym_comment,
  [94591] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2861), 1,
      anon_sym_COLON_COLON,
    STATE(1814), 1,
      sym_comment,
  [94601] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2863), 1,
      anon_sym_COLON_COLON,
    STATE(1815), 1,
      sym_comment,
  [94611] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2865), 1,
      anon_sym_LPAREN,
    STATE(1816), 1,
      sym_comment,
  [94621] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2867), 1,
      anon_sym_LPAREN,
    STATE(1817), 1,
      sym_comment,
  [94631] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2869), 1,
      anon_sym_LPAREN,
    STATE(1818), 1,
      sym_comment,
  [94641] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2871), 1,
      anon_sym_LPAREN,
    STATE(1819), 1,
      sym_comment,
  [94651] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2873), 1,
      sym_identifier,
    STATE(1820), 1,
      sym_comment,
  [94661] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2875), 1,
      anon_sym_while,
    STATE(1821), 1,
      sym_comment,
  [94671] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2877), 1,
      anon_sym_SLASH2,
    STATE(1822), 1,
      sym_comment,
  [94681] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2879), 1,
      sym_identifier,
    STATE(1823), 1,
      sym_comment,
  [94691] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2881), 1,
      anon_sym_SLASH2,
    STATE(1824), 1,
      sym_comment,
  [94701] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2883), 1,
      sym_identifier,
    STATE(1825), 1,
      sym_comment,
  [94711] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1961), 1,
      anon_sym_RBRACK,
    STATE(1826), 1,
      sym_comment,
  [94721] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2885), 1,
      anon_sym_RPAREN,
    STATE(1827), 1,
      sym_comment,
  [94731] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2887), 1,
      anon_sym_SLASH2,
    STATE(1828), 1,
      sym_comment,
  [94741] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2889), 1,
      sym_identifier,
    STATE(1829), 1,
      sym_comment,
  [94751] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1939), 1,
      anon_sym_RBRACK,
    STATE(1830), 1,
      sym_comment,
  [94761] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2891), 1,
      anon_sym_RPAREN,
    STATE(1831), 1,
      sym_comment,
  [94771] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2893), 1,
      anon_sym_SLASH2,
    STATE(1832), 1,
      sym_comment,
  [94781] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2895), 1,
      sym_identifier,
    STATE(1833), 1,
      sym_comment,
  [94791] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1937), 1,
      anon_sym_RBRACK,
    STATE(1834), 1,
      sym_comment,
  [94801] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2897), 1,
      anon_sym_RPAREN,
    STATE(1835), 1,
      sym_comment,
  [94811] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2899), 1,
      anon_sym_SLASH2,
    STATE(1836), 1,
      sym_comment,
  [94821] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2901), 1,
      sym_identifier,
    STATE(1837), 1,
      sym_comment,
  [94831] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1945), 1,
      anon_sym_RBRACK,
    STATE(1838), 1,
      sym_comment,
  [94841] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2903), 1,
      anon_sym_RPAREN,
    STATE(1839), 1,
      sym_comment,
  [94851] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2905), 1,
      anon_sym_LPAREN,
    STATE(1840), 1,
      sym_comment,
  [94861] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2907), 1,
      anon_sym_LPAREN,
    STATE(1841), 1,
      sym_comment,
  [94871] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2909), 1,
      anon_sym_SLASH2,
    STATE(1842), 1,
      sym_comment,
  [94881] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2911), 1,
      sym_identifier,
    STATE(1843), 1,
      sym_comment,
  [94891] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1949), 1,
      anon_sym_RBRACK,
    STATE(1844), 1,
      sym_comment,
  [94901] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2913), 1,
      anon_sym_RPAREN,
    STATE(1845), 1,
      sym_comment,
  [94911] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2915), 1,
      anon_sym_LPAREN,
    STATE(1846), 1,
      sym_comment,
  [94921] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2917), 1,
      anon_sym_SLASH2,
    STATE(1847), 1,
      sym_comment,
  [94931] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2919), 1,
      sym_identifier,
    STATE(1848), 1,
      sym_comment,
  [94941] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1959), 1,
      anon_sym_RBRACK,
    STATE(1849), 1,
      sym_comment,
  [94951] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2921), 1,
      anon_sym_SLASH2,
    STATE(1850), 1,
      sym_comment,
  [94961] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2923), 1,
      sym_identifier,
    STATE(1851), 1,
      sym_comment,
  [94971] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1941), 1,
      anon_sym_RBRACK,
    STATE(1852), 1,
      sym_comment,
  [94981] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2925), 1,
      anon_sym_COLON_COLON,
    STATE(1853), 1,
      sym_comment,
  [94991] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2927), 1,
      anon_sym_RPAREN,
    STATE(1854), 1,
      sym_comment,
  [95001] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2929), 1,
      anon_sym_SLASH2,
    STATE(1855), 1,
      sym_comment,
  [95011] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2931), 1,
      sym_identifier,
    STATE(1856), 1,
      sym_comment,
  [95021] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1951), 1,
      anon_sym_RBRACK,
    STATE(1857), 1,
      sym_comment,
  [95031] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2933), 1,
      anon_sym_RPAREN,
    STATE(1858), 1,
      sym_comment,
  [95041] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2935), 1,
      anon_sym_SLASH2,
    STATE(1859), 1,
      sym_comment,
  [95051] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2937), 1,
      sym_identifier,
    STATE(1860), 1,
      sym_comment,
  [95061] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1953), 1,
      anon_sym_RBRACK,
    STATE(1861), 1,
      sym_comment,
  [95071] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2939), 1,
      anon_sym_RPAREN,
    STATE(1862), 1,
      sym_comment,
  [95081] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2941), 1,
      ts_builtin_sym_end,
    STATE(1863), 1,
      sym_comment,
  [95091] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2943), 1,
      anon_sym_SLASH2,
    STATE(1864), 1,
      sym_comment,
  [95101] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2945), 1,
      sym_identifier,
    STATE(1865), 1,
      sym_comment,
  [95111] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1935), 1,
      anon_sym_RBRACK,
    STATE(1866), 1,
      sym_comment,
  [95121] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2947), 1,
      anon_sym_RPAREN,
    STATE(1867), 1,
      sym_comment,
  [95131] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2949), 1,
      anon_sym_SLASH2,
    STATE(1868), 1,
      sym_comment,
  [95141] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2951), 1,
      sym_identifier,
    STATE(1869), 1,
      sym_comment,
  [95151] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1947), 1,
      anon_sym_RBRACK,
    STATE(1870), 1,
      sym_comment,
  [95161] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2953), 1,
      anon_sym_RPAREN,
    STATE(1871), 1,
      sym_comment,
  [95171] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2955), 1,
      anon_sym_SLASH2,
    STATE(1872), 1,
      sym_comment,
  [95181] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2957), 1,
      sym_identifier,
    STATE(1873), 1,
      sym_comment,
  [95191] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2959), 1,
      anon_sym_LPAREN,
    STATE(1874), 1,
      sym_comment,
  [95201] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2961), 1,
      anon_sym_LPAREN,
    STATE(1875), 1,
      sym_comment,
  [95211] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2963), 1,
      anon_sym_LPAREN,
    STATE(1876), 1,
      sym_comment,
  [95221] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1933), 1,
      anon_sym_RBRACK,
    STATE(1877), 1,
      sym_comment,
  [95231] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2965), 1,
      anon_sym_RPAREN,
    STATE(1878), 1,
      sym_comment,
  [95241] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2967), 1,
      anon_sym_SLASH2,
    STATE(1879), 1,
      sym_comment,
  [95251] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2969), 1,
      anon_sym_SLASH2,
    STATE(1880), 1,
      sym_comment,
  [95261] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2971), 1,
      anon_sym_RPAREN,
    STATE(1881), 1,
      sym_comment,
  [95271] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1957), 1,
      anon_sym_RBRACK,
    STATE(1882), 1,
      sym_comment,
  [95281] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2973), 1,
      sym_identifier,
    STATE(1883), 1,
      sym_comment,
  [95291] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2975), 1,
      anon_sym_RPAREN,
    STATE(1884), 1,
      sym_comment,
  [95301] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2977), 1,
      anon_sym_RPAREN,
    STATE(1885), 1,
      sym_comment,
  [95311] = 3,
    ACTIONS(83), 1,
      anon_sym_POUND,
    ACTIONS(2979), 1,
      sym_regex_pattern,
    STATE(1886), 1,
      sym_comment,
  [95321] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2981), 1,
      sym_identifier,
    STATE(1887), 1,
      sym_comment,
  [95331] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1963), 1,
      anon_sym_RBRACK,
    STATE(1888), 1,
      sym_comment,
  [95341] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2983), 1,
      anon_sym_LPAREN,
    STATE(1889), 1,
      sym_comment,
  [95351] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2985), 1,
      anon_sym_LPAREN,
    STATE(1890), 1,
      sym_comment,
  [95361] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2987), 1,
      anon_sym_LPAREN,
    STATE(1891), 1,
      sym_comment,
  [95371] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2989), 1,
      anon_sym_RPAREN,
    STATE(1892), 1,
      sym_comment,
  [95381] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2991), 1,
      anon_sym_LPAREN,
    STATE(1893), 1,
      sym_comment,
  [95391] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      anon_sym_RPAREN,
    STATE(1894), 1,
      sym_comment,
  [95401] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2993), 1,
      anon_sym_LPAREN,
    STATE(1895), 1,
      sym_comment,
  [95411] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(2995), 1,
      anon_sym_LPAREN,
    STATE(1896), 1,
      sym_comment,
  [95421] = 1,
    ACTIONS(2997), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(153)] = 0,
  [SMALL_STATE(154)] = 73,
  [SMALL_STATE(155)] = 152,
  [SMALL_STATE(156)] = 225,
  [SMALL_STATE(157)] = 298,
  [SMALL_STATE(158)] = 375,
  [SMALL_STATE(159)] = 448,
  [SMALL_STATE(160)] = 521,
  [SMALL_STATE(161)] = 594,
  [SMALL_STATE(162)] = 669,
  [SMALL_STATE(163)] = 742,
  [SMALL_STATE(164)] = 815,
  [SMALL_STATE(165)] = 896,
  [SMALL_STATE(166)] = 969,
  [SMALL_STATE(167)] = 1050,
  [SMALL_STATE(168)] = 1123,
  [SMALL_STATE(169)] = 1204,
  [SMALL_STATE(170)] = 1277,
  [SMALL_STATE(171)] = 1352,
  [SMALL_STATE(172)] = 1425,
  [SMALL_STATE(173)] = 1500,
  [SMALL_STATE(174)] = 1573,
  [SMALL_STATE(175)] = 1646,
  [SMALL_STATE(176)] = 1719,
  [SMALL_STATE(177)] = 1792,
  [SMALL_STATE(178)] = 1871,
  [SMALL_STATE(179)] = 1944,
  [SMALL_STATE(180)] = 2027,
  [SMALL_STATE(181)] = 2100,
  [SMALL_STATE(182)] = 2179,
  [SMALL_STATE(183)] = 2260,
  [SMALL_STATE(184)] = 2337,
  [SMALL_STATE(185)] = 2410,
  [SMALL_STATE(186)] = 2483,
  [SMALL_STATE(187)] = 2556,
  [SMALL_STATE(188)] = 2673,
  [SMALL_STATE(189)] = 2749,
  [SMALL_STATE(190)] = 2825,
  [SMALL_STATE(191)] = 2899,
  [SMALL_STATE(192)] = 2975,
  [SMALL_STATE(193)] = 3057,
  [SMALL_STATE(194)] = 3143,
  [SMALL_STATE(195)] = 3231,
  [SMALL_STATE(196)] = 3309,
  [SMALL_STATE(197)] = 3401,
  [SMALL_STATE(198)] = 3481,
  [SMALL_STATE(199)] = 3555,
  [SMALL_STATE(200)] = 3633,
  [SMALL_STATE(201)] = 3717,
  [SMALL_STATE(202)] = 3809,
  [SMALL_STATE(203)] = 3883,
  [SMALL_STATE(204)] = 3961,
  [SMALL_STATE(205)] = 4039,
  [SMALL_STATE(206)] = 4111,
  [SMALL_STATE(207)] = 4196,
  [SMALL_STATE(208)] = 4269,
  [SMALL_STATE(209)] = 4344,
  [SMALL_STATE(210)] = 4425,
  [SMALL_STATE(211)] = 4502,
  [SMALL_STATE(212)] = 4589,
  [SMALL_STATE(213)] = 4664,
  [SMALL_STATE(214)] = 4737,
  [SMALL_STATE(215)] = 4828,
  [SMALL_STATE(216)] = 4903,
  [SMALL_STATE(217)] = 4986,
  [SMALL_STATE(218)] = 5065,
  [SMALL_STATE(219)] = 5156,
  [SMALL_STATE(220)] = 5233,
  [SMALL_STATE(221)] = 5314,
  [SMALL_STATE(222)] = 5382,
  [SMALL_STATE(223)] = 5454,
  [SMALL_STATE(224)] = 5532,
  [SMALL_STATE(225)] = 5606,
  [SMALL_STATE(226)] = 5673,
  [SMALL_STATE(227)] = 5748,
  [SMALL_STATE(228)] = 5815,
  [SMALL_STATE(229)] = 5882,
  [SMALL_STATE(230)] = 5951,
  [SMALL_STATE(231)] = 6024,
  [SMALL_STATE(232)] = 6095,
  [SMALL_STATE(233)] = 6166,
  [SMALL_STATE(234)] = 6241,
  [SMALL_STATE(235)] = 6320,
  [SMALL_STATE(236)] = 6389,
  [SMALL_STATE(237)] = 6455,
  [SMALL_STATE(238)] = 6519,
  [SMALL_STATE(239)] = 6585,
  [SMALL_STATE(240)] = 6653,
  [SMALL_STATE(241)] = 6723,
  [SMALL_STATE(242)] = 6795,
  [SMALL_STATE(243)] = 6869,
  [SMALL_STATE(244)] = 6935,
  [SMALL_STATE(245)] = 7001,
  [SMALL_STATE(246)] = 7069,
  [SMALL_STATE(247)] = 7145,
  [SMALL_STATE(248)] = 7211,
  [SMALL_STATE(249)] = 7281,
  [SMALL_STATE(250)] = 7347,
  [SMALL_STATE(251)] = 7413,
  [SMALL_STATE(252)] = 7479,
  [SMALL_STATE(253)] = 7551,
  [SMALL_STATE(254)] = 7617,
  [SMALL_STATE(255)] = 7683,
  [SMALL_STATE(256)] = 7749,
  [SMALL_STATE(257)] = 7817,
  [SMALL_STATE(258)] = 7883,
  [SMALL_STATE(259)] = 7949,
  [SMALL_STATE(260)] = 8015,
  [SMALL_STATE(261)] = 8081,
  [SMALL_STATE(262)] = 8147,
  [SMALL_STATE(263)] = 8215,
  [SMALL_STATE(264)] = 8281,
  [SMALL_STATE(265)] = 8347,
  [SMALL_STATE(266)] = 8413,
  [SMALL_STATE(267)] = 8483,
  [SMALL_STATE(268)] = 8557,
  [SMALL_STATE(269)] = 8623,
  [SMALL_STATE(270)] = 8689,
  [SMALL_STATE(271)] = 8793,
  [SMALL_STATE(272)] = 8897,
  [SMALL_STATE(273)] = 8967,
  [SMALL_STATE(274)] = 9031,
  [SMALL_STATE(275)] = 9097,
  [SMALL_STATE(276)] = 9169,
  [SMALL_STATE(277)] = 9270,
  [SMALL_STATE(278)] = 9341,
  [SMALL_STATE(279)] = 9408,
  [SMALL_STATE(280)] = 9473,
  [SMALL_STATE(281)] = 9538,
  [SMALL_STATE(282)] = 9605,
  [SMALL_STATE(283)] = 9670,
  [SMALL_STATE(284)] = 9735,
  [SMALL_STATE(285)] = 9800,
  [SMALL_STATE(286)] = 9865,
  [SMALL_STATE(287)] = 9932,
  [SMALL_STATE(288)] = 9999,
  [SMALL_STATE(289)] = 10064,
  [SMALL_STATE(290)] = 10129,
  [SMALL_STATE(291)] = 10194,
  [SMALL_STATE(292)] = 10313,
  [SMALL_STATE(293)] = 10380,
  [SMALL_STATE(294)] = 10445,
  [SMALL_STATE(295)] = 10510,
  [SMALL_STATE(296)] = 10575,
  [SMALL_STATE(297)] = 10640,
  [SMALL_STATE(298)] = 10705,
  [SMALL_STATE(299)] = 10790,
  [SMALL_STATE(300)] = 10855,
  [SMALL_STATE(301)] = 10920,
  [SMALL_STATE(302)] = 10985,
  [SMALL_STATE(303)] = 11086,
  [SMALL_STATE(304)] = 11155,
  [SMALL_STATE(305)] = 11226,
  [SMALL_STATE(306)] = 11347,
  [SMALL_STATE(307)] = 11414,
  [SMALL_STATE(308)] = 11479,
  [SMALL_STATE(309)] = 11546,
  [SMALL_STATE(310)] = 11623,
  [SMALL_STATE(311)] = 11688,
  [SMALL_STATE(312)] = 11761,
  [SMALL_STATE(313)] = 11826,
  [SMALL_STATE(314)] = 11893,
  [SMALL_STATE(315)] = 11962,
  [SMALL_STATE(316)] = 12027,
  [SMALL_STATE(317)] = 12102,
  [SMALL_STATE(318)] = 12183,
  [SMALL_STATE(319)] = 12250,
  [SMALL_STATE(320)] = 12329,
  [SMALL_STATE(321)] = 12410,
  [SMALL_STATE(322)] = 12475,
  [SMALL_STATE(323)] = 12554,
  [SMALL_STATE(324)] = 12623,
  [SMALL_STATE(325)] = 12708,
  [SMALL_STATE(326)] = 12777,
  [SMALL_STATE(327)] = 12844,
  [SMALL_STATE(328)] = 12911,
  [SMALL_STATE(329)] = 12988,
  [SMALL_STATE(330)] = 13072,
  [SMALL_STATE(331)] = 13136,
  [SMALL_STATE(332)] = 13200,
  [SMALL_STATE(333)] = 13264,
  [SMALL_STATE(334)] = 13328,
  [SMALL_STATE(335)] = 13394,
  [SMALL_STATE(336)] = 13458,
  [SMALL_STATE(337)] = 13522,
  [SMALL_STATE(338)] = 13586,
  [SMALL_STATE(339)] = 13670,
  [SMALL_STATE(340)] = 13734,
  [SMALL_STATE(341)] = 13818,
  [SMALL_STATE(342)] = 13882,
  [SMALL_STATE(343)] = 13946,
  [SMALL_STATE(344)] = 14010,
  [SMALL_STATE(345)] = 14074,
  [SMALL_STATE(346)] = 14146,
  [SMALL_STATE(347)] = 14222,
  [SMALL_STATE(348)] = 14286,
  [SMALL_STATE(349)] = 14362,
  [SMALL_STATE(350)] = 14426,
  [SMALL_STATE(351)] = 14490,
  [SMALL_STATE(352)] = 14554,
  [SMALL_STATE(353)] = 14632,
  [SMALL_STATE(354)] = 14696,
  [SMALL_STATE(355)] = 14760,
  [SMALL_STATE(356)] = 14826,
  [SMALL_STATE(357)] = 14890,
  [SMALL_STATE(358)] = 14954,
  [SMALL_STATE(359)] = 15018,
  [SMALL_STATE(360)] = 15082,
  [SMALL_STATE(361)] = 15146,
  [SMALL_STATE(362)] = 15210,
  [SMALL_STATE(363)] = 15274,
  [SMALL_STATE(364)] = 15338,
  [SMALL_STATE(365)] = 15402,
  [SMALL_STATE(366)] = 15466,
  [SMALL_STATE(367)] = 15530,
  [SMALL_STATE(368)] = 15594,
  [SMALL_STATE(369)] = 15664,
  [SMALL_STATE(370)] = 15748,
  [SMALL_STATE(371)] = 15812,
  [SMALL_STATE(372)] = 15882,
  [SMALL_STATE(373)] = 15946,
  [SMALL_STATE(374)] = 16012,
  [SMALL_STATE(375)] = 16076,
  [SMALL_STATE(376)] = 16150,
  [SMALL_STATE(377)] = 16216,
  [SMALL_STATE(378)] = 16280,
  [SMALL_STATE(379)] = 16344,
  [SMALL_STATE(380)] = 16416,
  [SMALL_STATE(381)] = 16496,
  [SMALL_STATE(382)] = 16560,
  [SMALL_STATE(383)] = 16646,
  [SMALL_STATE(384)] = 16710,
  [SMALL_STATE(385)] = 16788,
  [SMALL_STATE(386)] = 16862,
  [SMALL_STATE(387)] = 16928,
  [SMALL_STATE(388)] = 16996,
  [SMALL_STATE(389)] = 17060,
  [SMALL_STATE(390)] = 17125,
  [SMALL_STATE(391)] = 17186,
  [SMALL_STATE(392)] = 17247,
  [SMALL_STATE(393)] = 17308,
  [SMALL_STATE(394)] = 17389,
  [SMALL_STATE(395)] = 17460,
  [SMALL_STATE(396)] = 17527,
  [SMALL_STATE(397)] = 17588,
  [SMALL_STATE(398)] = 17649,
  [SMALL_STATE(399)] = 17712,
  [SMALL_STATE(400)] = 17773,
  [SMALL_STATE(401)] = 17834,
  [SMALL_STATE(402)] = 17895,
  [SMALL_STATE(403)] = 17978,
  [SMALL_STATE(404)] = 18059,
  [SMALL_STATE(405)] = 18120,
  [SMALL_STATE(406)] = 18181,
  [SMALL_STATE(407)] = 18242,
  [SMALL_STATE(408)] = 18303,
  [SMALL_STATE(409)] = 18364,
  [SMALL_STATE(410)] = 18437,
  [SMALL_STATE(411)] = 18500,
  [SMALL_STATE(412)] = 18561,
  [SMALL_STATE(413)] = 18629,
  [SMALL_STATE(414)] = 18707,
  [SMALL_STATE(415)] = 18777,
  [SMALL_STATE(416)] = 18847,
  [SMALL_STATE(417)] = 18935,
  [SMALL_STATE(418)] = 18999,
  [SMALL_STATE(419)] = 19079,
  [SMALL_STATE(420)] = 19161,
  [SMALL_STATE(421)] = 19229,
  [SMALL_STATE(422)] = 19311,
  [SMALL_STATE(423)] = 19385,
  [SMALL_STATE(424)] = 19467,
  [SMALL_STATE(425)] = 19549,
  [SMALL_STATE(426)] = 19631,
  [SMALL_STATE(427)] = 19697,
  [SMALL_STATE(428)] = 19785,
  [SMALL_STATE(429)] = 19867,
  [SMALL_STATE(430)] = 19951,
  [SMALL_STATE(431)] = 20058,
  [SMALL_STATE(432)] = 20137,
  [SMALL_STATE(433)] = 20216,
  [SMALL_STATE(434)] = 20295,
  [SMALL_STATE(435)] = 20374,
  [SMALL_STATE(436)] = 20453,
  [SMALL_STATE(437)] = 20557,
  [SMALL_STATE(438)] = 20662,
  [SMALL_STATE(439)] = 20764,
  [SMALL_STATE(440)] = 20825,
  [SMALL_STATE(441)] = 20888,
  [SMALL_STATE(442)] = 20953,
  [SMALL_STATE(443)] = 21015,
  [SMALL_STATE(444)] = 21075,
  [SMALL_STATE(445)] = 21135,
  [SMALL_STATE(446)] = 21191,
  [SMALL_STATE(447)] = 21247,
  [SMALL_STATE(448)] = 21305,
  [SMALL_STATE(449)] = 21363,
  [SMALL_STATE(450)] = 21419,
  [SMALL_STATE(451)] = 21477,
  [SMALL_STATE(452)] = 21541,
  [SMALL_STATE(453)] = 21597,
  [SMALL_STATE(454)] = 21660,
  [SMALL_STATE(455)] = 21715,
  [SMALL_STATE(456)] = 21772,
  [SMALL_STATE(457)] = 21831,
  [SMALL_STATE(458)] = 21898,
  [SMALL_STATE(459)] = 21971,
  [SMALL_STATE(460)] = 22026,
  [SMALL_STATE(461)] = 22081,
  [SMALL_STATE(462)] = 22136,
  [SMALL_STATE(463)] = 22191,
  [SMALL_STATE(464)] = 22246,
  [SMALL_STATE(465)] = 22305,
  [SMALL_STATE(466)] = 22382,
  [SMALL_STATE(467)] = 22437,
  [SMALL_STATE(468)] = 22492,
  [SMALL_STATE(469)] = 22547,
  [SMALL_STATE(470)] = 22602,
  [SMALL_STATE(471)] = 22677,
  [SMALL_STATE(472)] = 22734,
  [SMALL_STATE(473)] = 22789,
  [SMALL_STATE(474)] = 22870,
  [SMALL_STATE(475)] = 22941,
  [SMALL_STATE(476)] = 23022,
  [SMALL_STATE(477)] = 23083,
  [SMALL_STATE(478)] = 23140,
  [SMALL_STATE(479)] = 23195,
  [SMALL_STATE(480)] = 23250,
  [SMALL_STATE(481)] = 23305,
  [SMALL_STATE(482)] = 23362,
  [SMALL_STATE(483)] = 23417,
  [SMALL_STATE(484)] = 23472,
  [SMALL_STATE(485)] = 23527,
  [SMALL_STATE(486)] = 23582,
  [SMALL_STATE(487)] = 23643,
  [SMALL_STATE(488)] = 23698,
  [SMALL_STATE(489)] = 23755,
  [SMALL_STATE(490)] = 23810,
  [SMALL_STATE(491)] = 23865,
  [SMALL_STATE(492)] = 23922,
  [SMALL_STATE(493)] = 23989,
  [SMALL_STATE(494)] = 24053,
  [SMALL_STATE(495)] = 24107,
  [SMALL_STATE(496)] = 24161,
  [SMALL_STATE(497)] = 24215,
  [SMALL_STATE(498)] = 24269,
  [SMALL_STATE(499)] = 24335,
  [SMALL_STATE(500)] = 24389,
  [SMALL_STATE(501)] = 24443,
  [SMALL_STATE(502)] = 24497,
  [SMALL_STATE(503)] = 24553,
  [SMALL_STATE(504)] = 24607,
  [SMALL_STATE(505)] = 24671,
  [SMALL_STATE(506)] = 24725,
  [SMALL_STATE(507)] = 24785,
  [SMALL_STATE(508)] = 24839,
  [SMALL_STATE(509)] = 24901,
  [SMALL_STATE(510)] = 24955,
  [SMALL_STATE(511)] = 25035,
  [SMALL_STATE(512)] = 25089,
  [SMALL_STATE(513)] = 25155,
  [SMALL_STATE(514)] = 25209,
  [SMALL_STATE(515)] = 25291,
  [SMALL_STATE(516)] = 25352,
  [SMALL_STATE(517)] = 25413,
  [SMALL_STATE(518)] = 25476,
  [SMALL_STATE(519)] = 25567,
  [SMALL_STATE(520)] = 25658,
  [SMALL_STATE(521)] = 25737,
  [SMALL_STATE(522)] = 25800,
  [SMALL_STATE(523)] = 25863,
  [SMALL_STATE(524)] = 25926,
  [SMALL_STATE(525)] = 26014,
  [SMALL_STATE(526)] = 26068,
  [SMALL_STATE(527)] = 26128,
  [SMALL_STATE(528)] = 26190,
  [SMALL_STATE(529)] = 26278,
  [SMALL_STATE(530)] = 26336,
  [SMALL_STATE(531)] = 26392,
  [SMALL_STATE(532)] = 26456,
  [SMALL_STATE(533)] = 26516,
  [SMALL_STATE(534)] = 26576,
  [SMALL_STATE(535)] = 26636,
  [SMALL_STATE(536)] = 26691,
  [SMALL_STATE(537)] = 26750,
  [SMALL_STATE(538)] = 26805,
  [SMALL_STATE(539)] = 26866,
  [SMALL_STATE(540)] = 26937,
  [SMALL_STATE(541)] = 27026,
  [SMALL_STATE(542)] = 27115,
  [SMALL_STATE(543)] = 27170,
  [SMALL_STATE(544)] = 27223,
  [SMALL_STATE(545)] = 27276,
  [SMALL_STATE(546)] = 27329,
  [SMALL_STATE(547)] = 27388,
  [SMALL_STATE(548)] = 27445,
  [SMALL_STATE(549)] = 27504,
  [SMALL_STATE(550)] = 27565,
  [SMALL_STATE(551)] = 27622,
  [SMALL_STATE(552)] = 27683,
  [SMALL_STATE(553)] = 27740,
  [SMALL_STATE(554)] = 27801,
  [SMALL_STATE(555)] = 27858,
  [SMALL_STATE(556)] = 27929,
  [SMALL_STATE(557)] = 27992,
  [SMALL_STATE(558)] = 28059,
  [SMALL_STATE(559)] = 28124,
  [SMALL_STATE(560)] = 28176,
  [SMALL_STATE(561)] = 28238,
  [SMALL_STATE(562)] = 28296,
  [SMALL_STATE(563)] = 28346,
  [SMALL_STATE(564)] = 28432,
  [SMALL_STATE(565)] = 28498,
  [SMALL_STATE(566)] = 28548,
  [SMALL_STATE(567)] = 28604,
  [SMALL_STATE(568)] = 28668,
  [SMALL_STATE(569)] = 28728,
  [SMALL_STATE(570)] = 28784,
  [SMALL_STATE(571)] = 28854,
  [SMALL_STATE(572)] = 28908,
  [SMALL_STATE(573)] = 28962,
  [SMALL_STATE(574)] = 29024,
  [SMALL_STATE(575)] = 29094,
  [SMALL_STATE(576)] = 29144,
  [SMALL_STATE(577)] = 29202,
  [SMALL_STATE(578)] = 29252,
  [SMALL_STATE(579)] = 29304,
  [SMALL_STATE(580)] = 29390,
  [SMALL_STATE(581)] = 29444,
  [SMALL_STATE(582)] = 29508,
  [SMALL_STATE(583)] = 29564,
  [SMALL_STATE(584)] = 29622,
  [SMALL_STATE(585)] = 29680,
  [SMALL_STATE(586)] = 29730,
  [SMALL_STATE(587)] = 29796,
  [SMALL_STATE(588)] = 29854,
  [SMALL_STATE(589)] = 29906,
  [SMALL_STATE(590)] = 29960,
  [SMALL_STATE(591)] = 30051,
  [SMALL_STATE(592)] = 30112,
  [SMALL_STATE(593)] = 30181,
  [SMALL_STATE(594)] = 30228,
  [SMALL_STATE(595)] = 30283,
  [SMALL_STATE(596)] = 30338,
  [SMALL_STATE(597)] = 30407,
  [SMALL_STATE(598)] = 30498,
  [SMALL_STATE(599)] = 30589,
  [SMALL_STATE(600)] = 30636,
  [SMALL_STATE(601)] = 30727,
  [SMALL_STATE(602)] = 30788,
  [SMALL_STATE(603)] = 30879,
  [SMALL_STATE(604)] = 30930,
  [SMALL_STATE(605)] = 30983,
  [SMALL_STATE(606)] = 31030,
  [SMALL_STATE(607)] = 31089,
  [SMALL_STATE(608)] = 31180,
  [SMALL_STATE(609)] = 31233,
  [SMALL_STATE(610)] = 31288,
  [SMALL_STATE(611)] = 31335,
  [SMALL_STATE(612)] = 31382,
  [SMALL_STATE(613)] = 31447,
  [SMALL_STATE(614)] = 31538,
  [SMALL_STATE(615)] = 31629,
  [SMALL_STATE(616)] = 31720,
  [SMALL_STATE(617)] = 31783,
  [SMALL_STATE(618)] = 31842,
  [SMALL_STATE(619)] = 31895,
  [SMALL_STATE(620)] = 31986,
  [SMALL_STATE(621)] = 32037,
  [SMALL_STATE(622)] = 32088,
  [SMALL_STATE(623)] = 32145,
  [SMALL_STATE(624)] = 32206,
  [SMALL_STATE(625)] = 32261,
  [SMALL_STATE(626)] = 32349,
  [SMALL_STATE(627)] = 32437,
  [SMALL_STATE(628)] = 32525,
  [SMALL_STATE(629)] = 32613,
  [SMALL_STATE(630)] = 32665,
  [SMALL_STATE(631)] = 32753,
  [SMALL_STATE(632)] = 32841,
  [SMALL_STATE(633)] = 32891,
  [SMALL_STATE(634)] = 32979,
  [SMALL_STATE(635)] = 33067,
  [SMALL_STATE(636)] = 33155,
  [SMALL_STATE(637)] = 33243,
  [SMALL_STATE(638)] = 33331,
  [SMALL_STATE(639)] = 33387,
  [SMALL_STATE(640)] = 33455,
  [SMALL_STATE(641)] = 33543,
  [SMALL_STATE(642)] = 33601,
  [SMALL_STATE(643)] = 33689,
  [SMALL_STATE(644)] = 33741,
  [SMALL_STATE(645)] = 33805,
  [SMALL_STATE(646)] = 33893,
  [SMALL_STATE(647)] = 33981,
  [SMALL_STATE(648)] = 34069,
  [SMALL_STATE(649)] = 34157,
  [SMALL_STATE(650)] = 34245,
  [SMALL_STATE(651)] = 34333,
  [SMALL_STATE(652)] = 34421,
  [SMALL_STATE(653)] = 34489,
  [SMALL_STATE(654)] = 34577,
  [SMALL_STATE(655)] = 34665,
  [SMALL_STATE(656)] = 34753,
  [SMALL_STATE(657)] = 34841,
  [SMALL_STATE(658)] = 34929,
  [SMALL_STATE(659)] = 34987,
  [SMALL_STATE(660)] = 35075,
  [SMALL_STATE(661)] = 35163,
  [SMALL_STATE(662)] = 35215,
  [SMALL_STATE(663)] = 35303,
  [SMALL_STATE(664)] = 35353,
  [SMALL_STATE(665)] = 35441,
  [SMALL_STATE(666)] = 35493,
  [SMALL_STATE(667)] = 35555,
  [SMALL_STATE(668)] = 35605,
  [SMALL_STATE(669)] = 35665,
  [SMALL_STATE(670)] = 35717,
  [SMALL_STATE(671)] = 35773,
  [SMALL_STATE(672)] = 35861,
  [SMALL_STATE(673)] = 35915,
  [SMALL_STATE(674)] = 35967,
  [SMALL_STATE(675)] = 36052,
  [SMALL_STATE(676)] = 36137,
  [SMALL_STATE(677)] = 36186,
  [SMALL_STATE(678)] = 36271,
  [SMALL_STATE(679)] = 36354,
  [SMALL_STATE(680)] = 36419,
  [SMALL_STATE(681)] = 36504,
  [SMALL_STATE(682)] = 36589,
  [SMALL_STATE(683)] = 36674,
  [SMALL_STATE(684)] = 36759,
  [SMALL_STATE(685)] = 36844,
  [SMALL_STATE(686)] = 36929,
  [SMALL_STATE(687)] = 37014,
  [SMALL_STATE(688)] = 37099,
  [SMALL_STATE(689)] = 37184,
  [SMALL_STATE(690)] = 37269,
  [SMALL_STATE(691)] = 37354,
  [SMALL_STATE(692)] = 37427,
  [SMALL_STATE(693)] = 37512,
  [SMALL_STATE(694)] = 37597,
  [SMALL_STATE(695)] = 37682,
  [SMALL_STATE(696)] = 37767,
  [SMALL_STATE(697)] = 37852,
  [SMALL_STATE(698)] = 37937,
  [SMALL_STATE(699)] = 37990,
  [SMALL_STATE(700)] = 38075,
  [SMALL_STATE(701)] = 38160,
  [SMALL_STATE(702)] = 38245,
  [SMALL_STATE(703)] = 38330,
  [SMALL_STATE(704)] = 38379,
  [SMALL_STATE(705)] = 38464,
  [SMALL_STATE(706)] = 38515,
  [SMALL_STATE(707)] = 38600,
  [SMALL_STATE(708)] = 38655,
  [SMALL_STATE(709)] = 38714,
  [SMALL_STATE(710)] = 38799,
  [SMALL_STATE(711)] = 38884,
  [SMALL_STATE(712)] = 38933,
  [SMALL_STATE(713)] = 39018,
  [SMALL_STATE(714)] = 39103,
  [SMALL_STATE(715)] = 39188,
  [SMALL_STATE(716)] = 39243,
  [SMALL_STATE(717)] = 39292,
  [SMALL_STATE(718)] = 39377,
  [SMALL_STATE(719)] = 39462,
  [SMALL_STATE(720)] = 39535,
  [SMALL_STATE(721)] = 39620,
  [SMALL_STATE(722)] = 39705,
  [SMALL_STATE(723)] = 39758,
  [SMALL_STATE(724)] = 39843,
  [SMALL_STATE(725)] = 39928,
  [SMALL_STATE(726)] = 39997,
  [SMALL_STATE(727)] = 40064,
  [SMALL_STATE(728)] = 40149,
  [SMALL_STATE(729)] = 40234,
  [SMALL_STATE(730)] = 40319,
  [SMALL_STATE(731)] = 40404,
  [SMALL_STATE(732)] = 40489,
  [SMALL_STATE(733)] = 40574,
  [SMALL_STATE(734)] = 40659,
  [SMALL_STATE(735)] = 40744,
  [SMALL_STATE(736)] = 40807,
  [SMALL_STATE(737)] = 40892,
  [SMALL_STATE(738)] = 40977,
  [SMALL_STATE(739)] = 41062,
  [SMALL_STATE(740)] = 41147,
  [SMALL_STATE(741)] = 41229,
  [SMALL_STATE(742)] = 41311,
  [SMALL_STATE(743)] = 41393,
  [SMALL_STATE(744)] = 41475,
  [SMALL_STATE(745)] = 41557,
  [SMALL_STATE(746)] = 41639,
  [SMALL_STATE(747)] = 41721,
  [SMALL_STATE(748)] = 41803,
  [SMALL_STATE(749)] = 41885,
  [SMALL_STATE(750)] = 41967,
  [SMALL_STATE(751)] = 42049,
  [SMALL_STATE(752)] = 42131,
  [SMALL_STATE(753)] = 42213,
  [SMALL_STATE(754)] = 42295,
  [SMALL_STATE(755)] = 42377,
  [SMALL_STATE(756)] = 42459,
  [SMALL_STATE(757)] = 42541,
  [SMALL_STATE(758)] = 42603,
  [SMALL_STATE(759)] = 42685,
  [SMALL_STATE(760)] = 42767,
  [SMALL_STATE(761)] = 42829,
  [SMALL_STATE(762)] = 42911,
  [SMALL_STATE(763)] = 42973,
  [SMALL_STATE(764)] = 43055,
  [SMALL_STATE(765)] = 43137,
  [SMALL_STATE(766)] = 43219,
  [SMALL_STATE(767)] = 43301,
  [SMALL_STATE(768)] = 43383,
  [SMALL_STATE(769)] = 43465,
  [SMALL_STATE(770)] = 43547,
  [SMALL_STATE(771)] = 43629,
  [SMALL_STATE(772)] = 43711,
  [SMALL_STATE(773)] = 43793,
  [SMALL_STATE(774)] = 43875,
  [SMALL_STATE(775)] = 43957,
  [SMALL_STATE(776)] = 44039,
  [SMALL_STATE(777)] = 44121,
  [SMALL_STATE(778)] = 44203,
  [SMALL_STATE(779)] = 44285,
  [SMALL_STATE(780)] = 44367,
  [SMALL_STATE(781)] = 44449,
  [SMALL_STATE(782)] = 44531,
  [SMALL_STATE(783)] = 44613,
  [SMALL_STATE(784)] = 44695,
  [SMALL_STATE(785)] = 44777,
  [SMALL_STATE(786)] = 44859,
  [SMALL_STATE(787)] = 44941,
  [SMALL_STATE(788)] = 45023,
  [SMALL_STATE(789)] = 45105,
  [SMALL_STATE(790)] = 45187,
  [SMALL_STATE(791)] = 45269,
  [SMALL_STATE(792)] = 45351,
  [SMALL_STATE(793)] = 45433,
  [SMALL_STATE(794)] = 45515,
  [SMALL_STATE(795)] = 45597,
  [SMALL_STATE(796)] = 45679,
  [SMALL_STATE(797)] = 45761,
  [SMALL_STATE(798)] = 45843,
  [SMALL_STATE(799)] = 45925,
  [SMALL_STATE(800)] = 46007,
  [SMALL_STATE(801)] = 46089,
  [SMALL_STATE(802)] = 46171,
  [SMALL_STATE(803)] = 46253,
  [SMALL_STATE(804)] = 46335,
  [SMALL_STATE(805)] = 46417,
  [SMALL_STATE(806)] = 46499,
  [SMALL_STATE(807)] = 46581,
  [SMALL_STATE(808)] = 46663,
  [SMALL_STATE(809)] = 46745,
  [SMALL_STATE(810)] = 46827,
  [SMALL_STATE(811)] = 46909,
  [SMALL_STATE(812)] = 46991,
  [SMALL_STATE(813)] = 47073,
  [SMALL_STATE(814)] = 47155,
  [SMALL_STATE(815)] = 47237,
  [SMALL_STATE(816)] = 47319,
  [SMALL_STATE(817)] = 47401,
  [SMALL_STATE(818)] = 47483,
  [SMALL_STATE(819)] = 47565,
  [SMALL_STATE(820)] = 47647,
  [SMALL_STATE(821)] = 47729,
  [SMALL_STATE(822)] = 47811,
  [SMALL_STATE(823)] = 47873,
  [SMALL_STATE(824)] = 47955,
  [SMALL_STATE(825)] = 48037,
  [SMALL_STATE(826)] = 48119,
  [SMALL_STATE(827)] = 48201,
  [SMALL_STATE(828)] = 48283,
  [SMALL_STATE(829)] = 48365,
  [SMALL_STATE(830)] = 48447,
  [SMALL_STATE(831)] = 48529,
  [SMALL_STATE(832)] = 48611,
  [SMALL_STATE(833)] = 48693,
  [SMALL_STATE(834)] = 48775,
  [SMALL_STATE(835)] = 48857,
  [SMALL_STATE(836)] = 48939,
  [SMALL_STATE(837)] = 49021,
  [SMALL_STATE(838)] = 49103,
  [SMALL_STATE(839)] = 49185,
  [SMALL_STATE(840)] = 49267,
  [SMALL_STATE(841)] = 49349,
  [SMALL_STATE(842)] = 49431,
  [SMALL_STATE(843)] = 49513,
  [SMALL_STATE(844)] = 49595,
  [SMALL_STATE(845)] = 49677,
  [SMALL_STATE(846)] = 49759,
  [SMALL_STATE(847)] = 49841,
  [SMALL_STATE(848)] = 49923,
  [SMALL_STATE(849)] = 50005,
  [SMALL_STATE(850)] = 50087,
  [SMALL_STATE(851)] = 50169,
  [SMALL_STATE(852)] = 50251,
  [SMALL_STATE(853)] = 50333,
  [SMALL_STATE(854)] = 50415,
  [SMALL_STATE(855)] = 50497,
  [SMALL_STATE(856)] = 50579,
  [SMALL_STATE(857)] = 50661,
  [SMALL_STATE(858)] = 50743,
  [SMALL_STATE(859)] = 50789,
  [SMALL_STATE(860)] = 50871,
  [SMALL_STATE(861)] = 50953,
  [SMALL_STATE(862)] = 51035,
  [SMALL_STATE(863)] = 51117,
  [SMALL_STATE(864)] = 51199,
  [SMALL_STATE(865)] = 51281,
  [SMALL_STATE(866)] = 51363,
  [SMALL_STATE(867)] = 51445,
  [SMALL_STATE(868)] = 51527,
  [SMALL_STATE(869)] = 51609,
  [SMALL_STATE(870)] = 51691,
  [SMALL_STATE(871)] = 51773,
  [SMALL_STATE(872)] = 51855,
  [SMALL_STATE(873)] = 51937,
  [SMALL_STATE(874)] = 52019,
  [SMALL_STATE(875)] = 52101,
  [SMALL_STATE(876)] = 52183,
  [SMALL_STATE(877)] = 52265,
  [SMALL_STATE(878)] = 52347,
  [SMALL_STATE(879)] = 52429,
  [SMALL_STATE(880)] = 52511,
  [SMALL_STATE(881)] = 52593,
  [SMALL_STATE(882)] = 52675,
  [SMALL_STATE(883)] = 52757,
  [SMALL_STATE(884)] = 52839,
  [SMALL_STATE(885)] = 52921,
  [SMALL_STATE(886)] = 53003,
  [SMALL_STATE(887)] = 53085,
  [SMALL_STATE(888)] = 53167,
  [SMALL_STATE(889)] = 53249,
  [SMALL_STATE(890)] = 53331,
  [SMALL_STATE(891)] = 53413,
  [SMALL_STATE(892)] = 53495,
  [SMALL_STATE(893)] = 53577,
  [SMALL_STATE(894)] = 53659,
  [SMALL_STATE(895)] = 53741,
  [SMALL_STATE(896)] = 53823,
  [SMALL_STATE(897)] = 53905,
  [SMALL_STATE(898)] = 53987,
  [SMALL_STATE(899)] = 54069,
  [SMALL_STATE(900)] = 54151,
  [SMALL_STATE(901)] = 54233,
  [SMALL_STATE(902)] = 54315,
  [SMALL_STATE(903)] = 54397,
  [SMALL_STATE(904)] = 54459,
  [SMALL_STATE(905)] = 54541,
  [SMALL_STATE(906)] = 54623,
  [SMALL_STATE(907)] = 54705,
  [SMALL_STATE(908)] = 54787,
  [SMALL_STATE(909)] = 54869,
  [SMALL_STATE(910)] = 54951,
  [SMALL_STATE(911)] = 55033,
  [SMALL_STATE(912)] = 55115,
  [SMALL_STATE(913)] = 55197,
  [SMALL_STATE(914)] = 55279,
  [SMALL_STATE(915)] = 55361,
  [SMALL_STATE(916)] = 55443,
  [SMALL_STATE(917)] = 55525,
  [SMALL_STATE(918)] = 55607,
  [SMALL_STATE(919)] = 55689,
  [SMALL_STATE(920)] = 55771,
  [SMALL_STATE(921)] = 55853,
  [SMALL_STATE(922)] = 55935,
  [SMALL_STATE(923)] = 56017,
  [SMALL_STATE(924)] = 56099,
  [SMALL_STATE(925)] = 56181,
  [SMALL_STATE(926)] = 56263,
  [SMALL_STATE(927)] = 56345,
  [SMALL_STATE(928)] = 56427,
  [SMALL_STATE(929)] = 56509,
  [SMALL_STATE(930)] = 56591,
  [SMALL_STATE(931)] = 56673,
  [SMALL_STATE(932)] = 56755,
  [SMALL_STATE(933)] = 56837,
  [SMALL_STATE(934)] = 56883,
  [SMALL_STATE(935)] = 56965,
  [SMALL_STATE(936)] = 57047,
  [SMALL_STATE(937)] = 57129,
  [SMALL_STATE(938)] = 57211,
  [SMALL_STATE(939)] = 57293,
  [SMALL_STATE(940)] = 57375,
  [SMALL_STATE(941)] = 57457,
  [SMALL_STATE(942)] = 57539,
  [SMALL_STATE(943)] = 57621,
  [SMALL_STATE(944)] = 57703,
  [SMALL_STATE(945)] = 57785,
  [SMALL_STATE(946)] = 57867,
  [SMALL_STATE(947)] = 57949,
  [SMALL_STATE(948)] = 58031,
  [SMALL_STATE(949)] = 58113,
  [SMALL_STATE(950)] = 58195,
  [SMALL_STATE(951)] = 58277,
  [SMALL_STATE(952)] = 58359,
  [SMALL_STATE(953)] = 58441,
  [SMALL_STATE(954)] = 58523,
  [SMALL_STATE(955)] = 58605,
  [SMALL_STATE(956)] = 58687,
  [SMALL_STATE(957)] = 58769,
  [SMALL_STATE(958)] = 58851,
  [SMALL_STATE(959)] = 58933,
  [SMALL_STATE(960)] = 59015,
  [SMALL_STATE(961)] = 59097,
  [SMALL_STATE(962)] = 59179,
  [SMALL_STATE(963)] = 59261,
  [SMALL_STATE(964)] = 59343,
  [SMALL_STATE(965)] = 59425,
  [SMALL_STATE(966)] = 59507,
  [SMALL_STATE(967)] = 59589,
  [SMALL_STATE(968)] = 59671,
  [SMALL_STATE(969)] = 59753,
  [SMALL_STATE(970)] = 59835,
  [SMALL_STATE(971)] = 59917,
  [SMALL_STATE(972)] = 59999,
  [SMALL_STATE(973)] = 60081,
  [SMALL_STATE(974)] = 60163,
  [SMALL_STATE(975)] = 60245,
  [SMALL_STATE(976)] = 60327,
  [SMALL_STATE(977)] = 60409,
  [SMALL_STATE(978)] = 60491,
  [SMALL_STATE(979)] = 60553,
  [SMALL_STATE(980)] = 60635,
  [SMALL_STATE(981)] = 60717,
  [SMALL_STATE(982)] = 60799,
  [SMALL_STATE(983)] = 60881,
  [SMALL_STATE(984)] = 60963,
  [SMALL_STATE(985)] = 61045,
  [SMALL_STATE(986)] = 61127,
  [SMALL_STATE(987)] = 61209,
  [SMALL_STATE(988)] = 61291,
  [SMALL_STATE(989)] = 61373,
  [SMALL_STATE(990)] = 61455,
  [SMALL_STATE(991)] = 61537,
  [SMALL_STATE(992)] = 61619,
  [SMALL_STATE(993)] = 61701,
  [SMALL_STATE(994)] = 61783,
  [SMALL_STATE(995)] = 61865,
  [SMALL_STATE(996)] = 61947,
  [SMALL_STATE(997)] = 62029,
  [SMALL_STATE(998)] = 62111,
  [SMALL_STATE(999)] = 62193,
  [SMALL_STATE(1000)] = 62275,
  [SMALL_STATE(1001)] = 62357,
  [SMALL_STATE(1002)] = 62405,
  [SMALL_STATE(1003)] = 62487,
  [SMALL_STATE(1004)] = 62569,
  [SMALL_STATE(1005)] = 62621,
  [SMALL_STATE(1006)] = 62703,
  [SMALL_STATE(1007)] = 62785,
  [SMALL_STATE(1008)] = 62867,
  [SMALL_STATE(1009)] = 62949,
  [SMALL_STATE(1010)] = 63031,
  [SMALL_STATE(1011)] = 63113,
  [SMALL_STATE(1012)] = 63195,
  [SMALL_STATE(1013)] = 63277,
  [SMALL_STATE(1014)] = 63359,
  [SMALL_STATE(1015)] = 63441,
  [SMALL_STATE(1016)] = 63523,
  [SMALL_STATE(1017)] = 63605,
  [SMALL_STATE(1018)] = 63687,
  [SMALL_STATE(1019)] = 63769,
  [SMALL_STATE(1020)] = 63851,
  [SMALL_STATE(1021)] = 63933,
  [SMALL_STATE(1022)] = 64015,
  [SMALL_STATE(1023)] = 64097,
  [SMALL_STATE(1024)] = 64179,
  [SMALL_STATE(1025)] = 64261,
  [SMALL_STATE(1026)] = 64343,
  [SMALL_STATE(1027)] = 64425,
  [SMALL_STATE(1028)] = 64507,
  [SMALL_STATE(1029)] = 64589,
  [SMALL_STATE(1030)] = 64671,
  [SMALL_STATE(1031)] = 64753,
  [SMALL_STATE(1032)] = 64835,
  [SMALL_STATE(1033)] = 64917,
  [SMALL_STATE(1034)] = 64999,
  [SMALL_STATE(1035)] = 65081,
  [SMALL_STATE(1036)] = 65163,
  [SMALL_STATE(1037)] = 65245,
  [SMALL_STATE(1038)] = 65291,
  [SMALL_STATE(1039)] = 65373,
  [SMALL_STATE(1040)] = 65455,
  [SMALL_STATE(1041)] = 65537,
  [SMALL_STATE(1042)] = 65583,
  [SMALL_STATE(1043)] = 65629,
  [SMALL_STATE(1044)] = 65711,
  [SMALL_STATE(1045)] = 65757,
  [SMALL_STATE(1046)] = 65839,
  [SMALL_STATE(1047)] = 65885,
  [SMALL_STATE(1048)] = 65931,
  [SMALL_STATE(1049)] = 66013,
  [SMALL_STATE(1050)] = 66095,
  [SMALL_STATE(1051)] = 66143,
  [SMALL_STATE(1052)] = 66189,
  [SMALL_STATE(1053)] = 66235,
  [SMALL_STATE(1054)] = 66317,
  [SMALL_STATE(1055)] = 66399,
  [SMALL_STATE(1056)] = 66481,
  [SMALL_STATE(1057)] = 66563,
  [SMALL_STATE(1058)] = 66645,
  [SMALL_STATE(1059)] = 66727,
  [SMALL_STATE(1060)] = 66809,
  [SMALL_STATE(1061)] = 66857,
  [SMALL_STATE(1062)] = 66903,
  [SMALL_STATE(1063)] = 66951,
  [SMALL_STATE(1064)] = 67033,
  [SMALL_STATE(1065)] = 67115,
  [SMALL_STATE(1066)] = 67161,
  [SMALL_STATE(1067)] = 67243,
  [SMALL_STATE(1068)] = 67289,
  [SMALL_STATE(1069)] = 67371,
  [SMALL_STATE(1070)] = 67453,
  [SMALL_STATE(1071)] = 67499,
  [SMALL_STATE(1072)] = 67581,
  [SMALL_STATE(1073)] = 67627,
  [SMALL_STATE(1074)] = 67673,
  [SMALL_STATE(1075)] = 67721,
  [SMALL_STATE(1076)] = 67803,
  [SMALL_STATE(1077)] = 67849,
  [SMALL_STATE(1078)] = 67897,
  [SMALL_STATE(1079)] = 67979,
  [SMALL_STATE(1080)] = 68025,
  [SMALL_STATE(1081)] = 68107,
  [SMALL_STATE(1082)] = 68155,
  [SMALL_STATE(1083)] = 68201,
  [SMALL_STATE(1084)] = 68249,
  [SMALL_STATE(1085)] = 68295,
  [SMALL_STATE(1086)] = 68377,
  [SMALL_STATE(1087)] = 68423,
  [SMALL_STATE(1088)] = 68469,
  [SMALL_STATE(1089)] = 68517,
  [SMALL_STATE(1090)] = 68563,
  [SMALL_STATE(1091)] = 68609,
  [SMALL_STATE(1092)] = 68655,
  [SMALL_STATE(1093)] = 68703,
  [SMALL_STATE(1094)] = 68746,
  [SMALL_STATE(1095)] = 68797,
  [SMALL_STATE(1096)] = 68840,
  [SMALL_STATE(1097)] = 68883,
  [SMALL_STATE(1098)] = 68926,
  [SMALL_STATE(1099)] = 68969,
  [SMALL_STATE(1100)] = 69012,
  [SMALL_STATE(1101)] = 69055,
  [SMALL_STATE(1102)] = 69098,
  [SMALL_STATE(1103)] = 69143,
  [SMALL_STATE(1104)] = 69186,
  [SMALL_STATE(1105)] = 69231,
  [SMALL_STATE(1106)] = 69274,
  [SMALL_STATE(1107)] = 69323,
  [SMALL_STATE(1108)] = 69368,
  [SMALL_STATE(1109)] = 69411,
  [SMALL_STATE(1110)] = 69456,
  [SMALL_STATE(1111)] = 69515,
  [SMALL_STATE(1112)] = 69560,
  [SMALL_STATE(1113)] = 69603,
  [SMALL_STATE(1114)] = 69646,
  [SMALL_STATE(1115)] = 69689,
  [SMALL_STATE(1116)] = 69734,
  [SMALL_STATE(1117)] = 69777,
  [SMALL_STATE(1118)] = 69820,
  [SMALL_STATE(1119)] = 69863,
  [SMALL_STATE(1120)] = 69914,
  [SMALL_STATE(1121)] = 69957,
  [SMALL_STATE(1122)] = 70016,
  [SMALL_STATE(1123)] = 70059,
  [SMALL_STATE(1124)] = 70102,
  [SMALL_STATE(1125)] = 70161,
  [SMALL_STATE(1126)] = 70204,
  [SMALL_STATE(1127)] = 70247,
  [SMALL_STATE(1128)] = 70292,
  [SMALL_STATE(1129)] = 70337,
  [SMALL_STATE(1130)] = 70382,
  [SMALL_STATE(1131)] = 70441,
  [SMALL_STATE(1132)] = 70484,
  [SMALL_STATE(1133)] = 70527,
  [SMALL_STATE(1134)] = 70586,
  [SMALL_STATE(1135)] = 70639,
  [SMALL_STATE(1136)] = 70698,
  [SMALL_STATE(1137)] = 70743,
  [SMALL_STATE(1138)] = 70791,
  [SMALL_STATE(1139)] = 70839,
  [SMALL_STATE(1140)] = 70885,
  [SMALL_STATE(1141)] = 70937,
  [SMALL_STATE(1142)] = 70981,
  [SMALL_STATE(1143)] = 71029,
  [SMALL_STATE(1144)] = 71075,
  [SMALL_STATE(1145)] = 71119,
  [SMALL_STATE(1146)] = 71163,
  [SMALL_STATE(1147)] = 71207,
  [SMALL_STATE(1148)] = 71251,
  [SMALL_STATE(1149)] = 71303,
  [SMALL_STATE(1150)] = 71347,
  [SMALL_STATE(1151)] = 71390,
  [SMALL_STATE(1152)] = 71433,
  [SMALL_STATE(1153)] = 71476,
  [SMALL_STATE(1154)] = 71521,
  [SMALL_STATE(1155)] = 71564,
  [SMALL_STATE(1156)] = 71607,
  [SMALL_STATE(1157)] = 71652,
  [SMALL_STATE(1158)] = 71695,
  [SMALL_STATE(1159)] = 71738,
  [SMALL_STATE(1160)] = 71783,
  [SMALL_STATE(1161)] = 71828,
  [SMALL_STATE(1162)] = 71873,
  [SMALL_STATE(1163)] = 71916,
  [SMALL_STATE(1164)] = 71967,
  [SMALL_STATE(1165)] = 72010,
  [SMALL_STATE(1166)] = 72053,
  [SMALL_STATE(1167)] = 72102,
  [SMALL_STATE(1168)] = 72145,
  [SMALL_STATE(1169)] = 72188,
  [SMALL_STATE(1170)] = 72231,
  [SMALL_STATE(1171)] = 72274,
  [SMALL_STATE(1172)] = 72317,
  [SMALL_STATE(1173)] = 72360,
  [SMALL_STATE(1174)] = 72403,
  [SMALL_STATE(1175)] = 72450,
  [SMALL_STATE(1176)] = 72493,
  [SMALL_STATE(1177)] = 72536,
  [SMALL_STATE(1178)] = 72579,
  [SMALL_STATE(1179)] = 72622,
  [SMALL_STATE(1180)] = 72665,
  [SMALL_STATE(1181)] = 72708,
  [SMALL_STATE(1182)] = 72751,
  [SMALL_STATE(1183)] = 72796,
  [SMALL_STATE(1184)] = 72839,
  [SMALL_STATE(1185)] = 72884,
  [SMALL_STATE(1186)] = 72926,
  [SMALL_STATE(1187)] = 72970,
  [SMALL_STATE(1188)] = 73012,
  [SMALL_STATE(1189)] = 73054,
  [SMALL_STATE(1190)] = 73104,
  [SMALL_STATE(1191)] = 73146,
  [SMALL_STATE(1192)] = 73188,
  [SMALL_STATE(1193)] = 73242,
  [SMALL_STATE(1194)] = 73292,
  [SMALL_STATE(1195)] = 73334,
  [SMALL_STATE(1196)] = 73376,
  [SMALL_STATE(1197)] = 73418,
  [SMALL_STATE(1198)] = 73460,
  [SMALL_STATE(1199)] = 73500,
  [SMALL_STATE(1200)] = 73542,
  [SMALL_STATE(1201)] = 73584,
  [SMALL_STATE(1202)] = 73626,
  [SMALL_STATE(1203)] = 73668,
  [SMALL_STATE(1204)] = 73710,
  [SMALL_STATE(1205)] = 73752,
  [SMALL_STATE(1206)] = 73794,
  [SMALL_STATE(1207)] = 73842,
  [SMALL_STATE(1208)] = 73904,
  [SMALL_STATE(1209)] = 73946,
  [SMALL_STATE(1210)] = 73988,
  [SMALL_STATE(1211)] = 74030,
  [SMALL_STATE(1212)] = 74074,
  [SMALL_STATE(1213)] = 74116,
  [SMALL_STATE(1214)] = 74158,
  [SMALL_STATE(1215)] = 74200,
  [SMALL_STATE(1216)] = 74242,
  [SMALL_STATE(1217)] = 74286,
  [SMALL_STATE(1218)] = 74328,
  [SMALL_STATE(1219)] = 74372,
  [SMALL_STATE(1220)] = 74414,
  [SMALL_STATE(1221)] = 74464,
  [SMALL_STATE(1222)] = 74510,
  [SMALL_STATE(1223)] = 74554,
  [SMALL_STATE(1224)] = 74596,
  [SMALL_STATE(1225)] = 74638,
  [SMALL_STATE(1226)] = 74682,
  [SMALL_STATE(1227)] = 74722,
  [SMALL_STATE(1228)] = 74764,
  [SMALL_STATE(1229)] = 74806,
  [SMALL_STATE(1230)] = 74848,
  [SMALL_STATE(1231)] = 74890,
  [SMALL_STATE(1232)] = 74952,
  [SMALL_STATE(1233)] = 74994,
  [SMALL_STATE(1234)] = 75052,
  [SMALL_STATE(1235)] = 75108,
  [SMALL_STATE(1236)] = 75154,
  [SMALL_STATE(1237)] = 75196,
  [SMALL_STATE(1238)] = 75248,
  [SMALL_STATE(1239)] = 75294,
  [SMALL_STATE(1240)] = 75336,
  [SMALL_STATE(1241)] = 75378,
  [SMALL_STATE(1242)] = 75420,
  [SMALL_STATE(1243)] = 75459,
  [SMALL_STATE(1244)] = 75520,
  [SMALL_STATE(1245)] = 75581,
  [SMALL_STATE(1246)] = 75630,
  [SMALL_STATE(1247)] = 75687,
  [SMALL_STATE(1248)] = 75726,
  [SMALL_STATE(1249)] = 75767,
  [SMALL_STATE(1250)] = 75828,
  [SMALL_STATE(1251)] = 75871,
  [SMALL_STATE(1252)] = 75920,
  [SMALL_STATE(1253)] = 75959,
  [SMALL_STATE(1254)] = 76014,
  [SMALL_STATE(1255)] = 76057,
  [SMALL_STATE(1256)] = 76100,
  [SMALL_STATE(1257)] = 76139,
  [SMALL_STATE(1258)] = 76186,
  [SMALL_STATE(1259)] = 76225,
  [SMALL_STATE(1260)] = 76264,
  [SMALL_STATE(1261)] = 76309,
  [SMALL_STATE(1262)] = 76356,
  [SMALL_STATE(1263)] = 76407,
  [SMALL_STATE(1264)] = 76450,
  [SMALL_STATE(1265)] = 76495,
  [SMALL_STATE(1266)] = 76556,
  [SMALL_STATE(1267)] = 76595,
  [SMALL_STATE(1268)] = 76658,
  [SMALL_STATE(1269)] = 76699,
  [SMALL_STATE(1270)] = 76738,
  [SMALL_STATE(1271)] = 76781,
  [SMALL_STATE(1272)] = 76820,
  [SMALL_STATE(1273)] = 76859,
  [SMALL_STATE(1274)] = 76912,
  [SMALL_STATE(1275)] = 76959,
  [SMALL_STATE(1276)] = 76998,
  [SMALL_STATE(1277)] = 77037,
  [SMALL_STATE(1278)] = 77076,
  [SMALL_STATE(1279)] = 77115,
  [SMALL_STATE(1280)] = 77157,
  [SMALL_STATE(1281)] = 77203,
  [SMALL_STATE(1282)] = 77247,
  [SMALL_STATE(1283)] = 77307,
  [SMALL_STATE(1284)] = 77347,
  [SMALL_STATE(1285)] = 77387,
  [SMALL_STATE(1286)] = 77443,
  [SMALL_STATE(1287)] = 77485,
  [SMALL_STATE(1288)] = 77531,
  [SMALL_STATE(1289)] = 77589,
  [SMALL_STATE(1290)] = 77631,
  [SMALL_STATE(1291)] = 77671,
  [SMALL_STATE(1292)] = 77711,
  [SMALL_STATE(1293)] = 77771,
  [SMALL_STATE(1294)] = 77825,
  [SMALL_STATE(1295)] = 77875,
  [SMALL_STATE(1296)] = 77919,
  [SMALL_STATE(1297)] = 77961,
  [SMALL_STATE(1298)] = 78003,
  [SMALL_STATE(1299)] = 78047,
  [SMALL_STATE(1300)] = 78095,
  [SMALL_STATE(1301)] = 78147,
  [SMALL_STATE(1302)] = 78191,
  [SMALL_STATE(1303)] = 78249,
  [SMALL_STATE(1304)] = 78289,
  [SMALL_STATE(1305)] = 78337,
  [SMALL_STATE(1306)] = 78397,
  [SMALL_STATE(1307)] = 78436,
  [SMALL_STATE(1308)] = 78477,
  [SMALL_STATE(1309)] = 78516,
  [SMALL_STATE(1310)] = 78559,
  [SMALL_STATE(1311)] = 78614,
  [SMALL_STATE(1312)] = 78667,
  [SMALL_STATE(1313)] = 78726,
  [SMALL_STATE(1314)] = 78771,
  [SMALL_STATE(1315)] = 78830,
  [SMALL_STATE(1316)] = 78889,
  [SMALL_STATE(1317)] = 78930,
  [SMALL_STATE(1318)] = 78989,
  [SMALL_STATE(1319)] = 79048,
  [SMALL_STATE(1320)] = 79097,
  [SMALL_STATE(1321)] = 79136,
  [SMALL_STATE(1322)] = 79177,
  [SMALL_STATE(1323)] = 79236,
  [SMALL_STATE(1324)] = 79277,
  [SMALL_STATE(1325)] = 79316,
  [SMALL_STATE(1326)] = 79375,
  [SMALL_STATE(1327)] = 79434,
  [SMALL_STATE(1328)] = 79475,
  [SMALL_STATE(1329)] = 79526,
  [SMALL_STATE(1330)] = 79569,
  [SMALL_STATE(1331)] = 79616,
  [SMALL_STATE(1332)] = 79655,
  [SMALL_STATE(1333)] = 79698,
  [SMALL_STATE(1334)] = 79757,
  [SMALL_STATE(1335)] = 79798,
  [SMALL_STATE(1336)] = 79839,
  [SMALL_STATE(1337)] = 79900,
  [SMALL_STATE(1338)] = 79938,
  [SMALL_STATE(1339)] = 79976,
  [SMALL_STATE(1340)] = 80014,
  [SMALL_STATE(1341)] = 80052,
  [SMALL_STATE(1342)] = 80108,
  [SMALL_STATE(1343)] = 80146,
  [SMALL_STATE(1344)] = 80208,
  [SMALL_STATE(1345)] = 80246,
  [SMALL_STATE(1346)] = 80286,
  [SMALL_STATE(1347)] = 80324,
  [SMALL_STATE(1348)] = 80380,
  [SMALL_STATE(1349)] = 80420,
  [SMALL_STATE(1350)] = 80458,
  [SMALL_STATE(1351)] = 80496,
  [SMALL_STATE(1352)] = 80534,
  [SMALL_STATE(1353)] = 80572,
  [SMALL_STATE(1354)] = 80610,
  [SMALL_STATE(1355)] = 80666,
  [SMALL_STATE(1356)] = 80712,
  [SMALL_STATE(1357)] = 80768,
  [SMALL_STATE(1358)] = 80810,
  [SMALL_STATE(1359)] = 80848,
  [SMALL_STATE(1360)] = 80904,
  [SMALL_STATE(1361)] = 80960,
  [SMALL_STATE(1362)] = 81016,
  [SMALL_STATE(1363)] = 81078,
  [SMALL_STATE(1364)] = 81118,
  [SMALL_STATE(1365)] = 81156,
  [SMALL_STATE(1366)] = 81196,
  [SMALL_STATE(1367)] = 81234,
  [SMALL_STATE(1368)] = 81272,
  [SMALL_STATE(1369)] = 81312,
  [SMALL_STATE(1370)] = 81350,
  [SMALL_STATE(1371)] = 81404,
  [SMALL_STATE(1372)] = 81454,
  [SMALL_STATE(1373)] = 81492,
  [SMALL_STATE(1374)] = 81530,
  [SMALL_STATE(1375)] = 81568,
  [SMALL_STATE(1376)] = 81608,
  [SMALL_STATE(1377)] = 81652,
  [SMALL_STATE(1378)] = 81704,
  [SMALL_STATE(1379)] = 81760,
  [SMALL_STATE(1380)] = 81818,
  [SMALL_STATE(1381)] = 81856,
  [SMALL_STATE(1382)] = 81914,
  [SMALL_STATE(1383)] = 81954,
  [SMALL_STATE(1384)] = 81992,
  [SMALL_STATE(1385)] = 82049,
  [SMALL_STATE(1386)] = 82086,
  [SMALL_STATE(1387)] = 82123,
  [SMALL_STATE(1388)] = 82160,
  [SMALL_STATE(1389)] = 82197,
  [SMALL_STATE(1390)] = 82254,
  [SMALL_STATE(1391)] = 82311,
  [SMALL_STATE(1392)] = 82368,
  [SMALL_STATE(1393)] = 82425,
  [SMALL_STATE(1394)] = 82462,
  [SMALL_STATE(1395)] = 82499,
  [SMALL_STATE(1396)] = 82536,
  [SMALL_STATE(1397)] = 82597,
  [SMALL_STATE(1398)] = 82634,
  [SMALL_STATE(1399)] = 82671,
  [SMALL_STATE(1400)] = 82708,
  [SMALL_STATE(1401)] = 82747,
  [SMALL_STATE(1402)] = 82784,
  [SMALL_STATE(1403)] = 82821,
  [SMALL_STATE(1404)] = 82858,
  [SMALL_STATE(1405)] = 82895,
  [SMALL_STATE(1406)] = 82931,
  [SMALL_STATE(1407)] = 82985,
  [SMALL_STATE(1408)] = 83021,
  [SMALL_STATE(1409)] = 83061,
  [SMALL_STATE(1410)] = 83115,
  [SMALL_STATE(1411)] = 83169,
  [SMALL_STATE(1412)] = 83223,
  [SMALL_STATE(1413)] = 83259,
  [SMALL_STATE(1414)] = 83295,
  [SMALL_STATE(1415)] = 83349,
  [SMALL_STATE(1416)] = 83384,
  [SMALL_STATE(1417)] = 83419,
  [SMALL_STATE(1418)] = 83454,
  [SMALL_STATE(1419)] = 83489,
  [SMALL_STATE(1420)] = 83524,
  [SMALL_STATE(1421)] = 83559,
  [SMALL_STATE(1422)] = 83622,
  [SMALL_STATE(1423)] = 83657,
  [SMALL_STATE(1424)] = 83718,
  [SMALL_STATE(1425)] = 83753,
  [SMALL_STATE(1426)] = 83813,
  [SMALL_STATE(1427)] = 83873,
  [SMALL_STATE(1428)] = 83933,
  [SMALL_STATE(1429)] = 83993,
  [SMALL_STATE(1430)] = 84053,
  [SMALL_STATE(1431)] = 84113,
  [SMALL_STATE(1432)] = 84173,
  [SMALL_STATE(1433)] = 84233,
  [SMALL_STATE(1434)] = 84293,
  [SMALL_STATE(1435)] = 84353,
  [SMALL_STATE(1436)] = 84413,
  [SMALL_STATE(1437)] = 84473,
  [SMALL_STATE(1438)] = 84533,
  [SMALL_STATE(1439)] = 84591,
  [SMALL_STATE(1440)] = 84651,
  [SMALL_STATE(1441)] = 84711,
  [SMALL_STATE(1442)] = 84771,
  [SMALL_STATE(1443)] = 84831,
  [SMALL_STATE(1444)] = 84888,
  [SMALL_STATE(1445)] = 84945,
  [SMALL_STATE(1446)] = 85002,
  [SMALL_STATE(1447)] = 85059,
  [SMALL_STATE(1448)] = 85116,
  [SMALL_STATE(1449)] = 85173,
  [SMALL_STATE(1450)] = 85230,
  [SMALL_STATE(1451)] = 85287,
  [SMALL_STATE(1452)] = 85344,
  [SMALL_STATE(1453)] = 85401,
  [SMALL_STATE(1454)] = 85458,
  [SMALL_STATE(1455)] = 85515,
  [SMALL_STATE(1456)] = 85572,
  [SMALL_STATE(1457)] = 85629,
  [SMALL_STATE(1458)] = 85686,
  [SMALL_STATE(1459)] = 85743,
  [SMALL_STATE(1460)] = 85800,
  [SMALL_STATE(1461)] = 85857,
  [SMALL_STATE(1462)] = 85914,
  [SMALL_STATE(1463)] = 85971,
  [SMALL_STATE(1464)] = 86028,
  [SMALL_STATE(1465)] = 86085,
  [SMALL_STATE(1466)] = 86142,
  [SMALL_STATE(1467)] = 86199,
  [SMALL_STATE(1468)] = 86256,
  [SMALL_STATE(1469)] = 86313,
  [SMALL_STATE(1470)] = 86370,
  [SMALL_STATE(1471)] = 86427,
  [SMALL_STATE(1472)] = 86484,
  [SMALL_STATE(1473)] = 86541,
  [SMALL_STATE(1474)] = 86598,
  [SMALL_STATE(1475)] = 86655,
  [SMALL_STATE(1476)] = 86712,
  [SMALL_STATE(1477)] = 86769,
  [SMALL_STATE(1478)] = 86826,
  [SMALL_STATE(1479)] = 86883,
  [SMALL_STATE(1480)] = 86940,
  [SMALL_STATE(1481)] = 86997,
  [SMALL_STATE(1482)] = 87054,
  [SMALL_STATE(1483)] = 87111,
  [SMALL_STATE(1484)] = 87168,
  [SMALL_STATE(1485)] = 87225,
  [SMALL_STATE(1486)] = 87282,
  [SMALL_STATE(1487)] = 87339,
  [SMALL_STATE(1488)] = 87396,
  [SMALL_STATE(1489)] = 87453,
  [SMALL_STATE(1490)] = 87510,
  [SMALL_STATE(1491)] = 87567,
  [SMALL_STATE(1492)] = 87624,
  [SMALL_STATE(1493)] = 87681,
  [SMALL_STATE(1494)] = 87738,
  [SMALL_STATE(1495)] = 87795,
  [SMALL_STATE(1496)] = 87852,
  [SMALL_STATE(1497)] = 87909,
  [SMALL_STATE(1498)] = 87966,
  [SMALL_STATE(1499)] = 88023,
  [SMALL_STATE(1500)] = 88080,
  [SMALL_STATE(1501)] = 88137,
  [SMALL_STATE(1502)] = 88194,
  [SMALL_STATE(1503)] = 88251,
  [SMALL_STATE(1504)] = 88308,
  [SMALL_STATE(1505)] = 88365,
  [SMALL_STATE(1506)] = 88422,
  [SMALL_STATE(1507)] = 88479,
  [SMALL_STATE(1508)] = 88536,
  [SMALL_STATE(1509)] = 88593,
  [SMALL_STATE(1510)] = 88650,
  [SMALL_STATE(1511)] = 88707,
  [SMALL_STATE(1512)] = 88764,
  [SMALL_STATE(1513)] = 88821,
  [SMALL_STATE(1514)] = 88878,
  [SMALL_STATE(1515)] = 88935,
  [SMALL_STATE(1516)] = 88992,
  [SMALL_STATE(1517)] = 89049,
  [SMALL_STATE(1518)] = 89106,
  [SMALL_STATE(1519)] = 89163,
  [SMALL_STATE(1520)] = 89220,
  [SMALL_STATE(1521)] = 89277,
  [SMALL_STATE(1522)] = 89334,
  [SMALL_STATE(1523)] = 89391,
  [SMALL_STATE(1524)] = 89448,
  [SMALL_STATE(1525)] = 89505,
  [SMALL_STATE(1526)] = 89562,
  [SMALL_STATE(1527)] = 89619,
  [SMALL_STATE(1528)] = 89673,
  [SMALL_STATE(1529)] = 89727,
  [SMALL_STATE(1530)] = 89781,
  [SMALL_STATE(1531)] = 89835,
  [SMALL_STATE(1532)] = 89889,
  [SMALL_STATE(1533)] = 89943,
  [SMALL_STATE(1534)] = 89997,
  [SMALL_STATE(1535)] = 90051,
  [SMALL_STATE(1536)] = 90105,
  [SMALL_STATE(1537)] = 90159,
  [SMALL_STATE(1538)] = 90213,
  [SMALL_STATE(1539)] = 90267,
  [SMALL_STATE(1540)] = 90321,
  [SMALL_STATE(1541)] = 90375,
  [SMALL_STATE(1542)] = 90429,
  [SMALL_STATE(1543)] = 90483,
  [SMALL_STATE(1544)] = 90507,
  [SMALL_STATE(1545)] = 90533,
  [SMALL_STATE(1546)] = 90556,
  [SMALL_STATE(1547)] = 90580,
  [SMALL_STATE(1548)] = 90601,
  [SMALL_STATE(1549)] = 90619,
  [SMALL_STATE(1550)] = 90637,
  [SMALL_STATE(1551)] = 90655,
  [SMALL_STATE(1552)] = 90673,
  [SMALL_STATE(1553)] = 90690,
  [SMALL_STATE(1554)] = 90713,
  [SMALL_STATE(1555)] = 90736,
  [SMALL_STATE(1556)] = 90761,
  [SMALL_STATE(1557)] = 90784,
  [SMALL_STATE(1558)] = 90807,
  [SMALL_STATE(1559)] = 90830,
  [SMALL_STATE(1560)] = 90855,
  [SMALL_STATE(1561)] = 90878,
  [SMALL_STATE(1562)] = 90901,
  [SMALL_STATE(1563)] = 90926,
  [SMALL_STATE(1564)] = 90951,
  [SMALL_STATE(1565)] = 90976,
  [SMALL_STATE(1566)] = 90999,
  [SMALL_STATE(1567)] = 91024,
  [SMALL_STATE(1568)] = 91047,
  [SMALL_STATE(1569)] = 91070,
  [SMALL_STATE(1570)] = 91095,
  [SMALL_STATE(1571)] = 91112,
  [SMALL_STATE(1572)] = 91135,
  [SMALL_STATE(1573)] = 91160,
  [SMALL_STATE(1574)] = 91183,
  [SMALL_STATE(1575)] = 91206,
  [SMALL_STATE(1576)] = 91231,
  [SMALL_STATE(1577)] = 91254,
  [SMALL_STATE(1578)] = 91277,
  [SMALL_STATE(1579)] = 91302,
  [SMALL_STATE(1580)] = 91325,
  [SMALL_STATE(1581)] = 91348,
  [SMALL_STATE(1582)] = 91373,
  [SMALL_STATE(1583)] = 91398,
  [SMALL_STATE(1584)] = 91421,
  [SMALL_STATE(1585)] = 91446,
  [SMALL_STATE(1586)] = 91469,
  [SMALL_STATE(1587)] = 91492,
  [SMALL_STATE(1588)] = 91517,
  [SMALL_STATE(1589)] = 91542,
  [SMALL_STATE(1590)] = 91567,
  [SMALL_STATE(1591)] = 91590,
  [SMALL_STATE(1592)] = 91615,
  [SMALL_STATE(1593)] = 91638,
  [SMALL_STATE(1594)] = 91663,
  [SMALL_STATE(1595)] = 91686,
  [SMALL_STATE(1596)] = 91711,
  [SMALL_STATE(1597)] = 91736,
  [SMALL_STATE(1598)] = 91759,
  [SMALL_STATE(1599)] = 91784,
  [SMALL_STATE(1600)] = 91807,
  [SMALL_STATE(1601)] = 91830,
  [SMALL_STATE(1602)] = 91855,
  [SMALL_STATE(1603)] = 91878,
  [SMALL_STATE(1604)] = 91903,
  [SMALL_STATE(1605)] = 91928,
  [SMALL_STATE(1606)] = 91949,
  [SMALL_STATE(1607)] = 91972,
  [SMALL_STATE(1608)] = 91995,
  [SMALL_STATE(1609)] = 92015,
  [SMALL_STATE(1610)] = 92035,
  [SMALL_STATE(1611)] = 92055,
  [SMALL_STATE(1612)] = 92075,
  [SMALL_STATE(1613)] = 92095,
  [SMALL_STATE(1614)] = 92115,
  [SMALL_STATE(1615)] = 92131,
  [SMALL_STATE(1616)] = 92147,
  [SMALL_STATE(1617)] = 92167,
  [SMALL_STATE(1618)] = 92187,
  [SMALL_STATE(1619)] = 92207,
  [SMALL_STATE(1620)] = 92227,
  [SMALL_STATE(1621)] = 92243,
  [SMALL_STATE(1622)] = 92259,
  [SMALL_STATE(1623)] = 92279,
  [SMALL_STATE(1624)] = 92299,
  [SMALL_STATE(1625)] = 92319,
  [SMALL_STATE(1626)] = 92339,
  [SMALL_STATE(1627)] = 92357,
  [SMALL_STATE(1628)] = 92377,
  [SMALL_STATE(1629)] = 92397,
  [SMALL_STATE(1630)] = 92417,
  [SMALL_STATE(1631)] = 92437,
  [SMALL_STATE(1632)] = 92457,
  [SMALL_STATE(1633)] = 92477,
  [SMALL_STATE(1634)] = 92494,
  [SMALL_STATE(1635)] = 92509,
  [SMALL_STATE(1636)] = 92526,
  [SMALL_STATE(1637)] = 92543,
  [SMALL_STATE(1638)] = 92560,
  [SMALL_STATE(1639)] = 92577,
  [SMALL_STATE(1640)] = 92592,
  [SMALL_STATE(1641)] = 92609,
  [SMALL_STATE(1642)] = 92626,
  [SMALL_STATE(1643)] = 92643,
  [SMALL_STATE(1644)] = 92658,
  [SMALL_STATE(1645)] = 92674,
  [SMALL_STATE(1646)] = 92690,
  [SMALL_STATE(1647)] = 92706,
  [SMALL_STATE(1648)] = 92722,
  [SMALL_STATE(1649)] = 92736,
  [SMALL_STATE(1650)] = 92752,
  [SMALL_STATE(1651)] = 92768,
  [SMALL_STATE(1652)] = 92784,
  [SMALL_STATE(1653)] = 92798,
  [SMALL_STATE(1654)] = 92814,
  [SMALL_STATE(1655)] = 92830,
  [SMALL_STATE(1656)] = 92846,
  [SMALL_STATE(1657)] = 92858,
  [SMALL_STATE(1658)] = 92874,
  [SMALL_STATE(1659)] = 92887,
  [SMALL_STATE(1660)] = 92900,
  [SMALL_STATE(1661)] = 92913,
  [SMALL_STATE(1662)] = 92926,
  [SMALL_STATE(1663)] = 92939,
  [SMALL_STATE(1664)] = 92952,
  [SMALL_STATE(1665)] = 92965,
  [SMALL_STATE(1666)] = 92978,
  [SMALL_STATE(1667)] = 92991,
  [SMALL_STATE(1668)] = 93004,
  [SMALL_STATE(1669)] = 93017,
  [SMALL_STATE(1670)] = 93030,
  [SMALL_STATE(1671)] = 93043,
  [SMALL_STATE(1672)] = 93056,
  [SMALL_STATE(1673)] = 93069,
  [SMALL_STATE(1674)] = 93082,
  [SMALL_STATE(1675)] = 93095,
  [SMALL_STATE(1676)] = 93108,
  [SMALL_STATE(1677)] = 93121,
  [SMALL_STATE(1678)] = 93134,
  [SMALL_STATE(1679)] = 93147,
  [SMALL_STATE(1680)] = 93160,
  [SMALL_STATE(1681)] = 93173,
  [SMALL_STATE(1682)] = 93186,
  [SMALL_STATE(1683)] = 93199,
  [SMALL_STATE(1684)] = 93212,
  [SMALL_STATE(1685)] = 93225,
  [SMALL_STATE(1686)] = 93238,
  [SMALL_STATE(1687)] = 93251,
  [SMALL_STATE(1688)] = 93264,
  [SMALL_STATE(1689)] = 93277,
  [SMALL_STATE(1690)] = 93290,
  [SMALL_STATE(1691)] = 93303,
  [SMALL_STATE(1692)] = 93316,
  [SMALL_STATE(1693)] = 93329,
  [SMALL_STATE(1694)] = 93342,
  [SMALL_STATE(1695)] = 93355,
  [SMALL_STATE(1696)] = 93368,
  [SMALL_STATE(1697)] = 93381,
  [SMALL_STATE(1698)] = 93394,
  [SMALL_STATE(1699)] = 93407,
  [SMALL_STATE(1700)] = 93420,
  [SMALL_STATE(1701)] = 93433,
  [SMALL_STATE(1702)] = 93446,
  [SMALL_STATE(1703)] = 93459,
  [SMALL_STATE(1704)] = 93472,
  [SMALL_STATE(1705)] = 93485,
  [SMALL_STATE(1706)] = 93496,
  [SMALL_STATE(1707)] = 93509,
  [SMALL_STATE(1708)] = 93522,
  [SMALL_STATE(1709)] = 93535,
  [SMALL_STATE(1710)] = 93548,
  [SMALL_STATE(1711)] = 93561,
  [SMALL_STATE(1712)] = 93571,
  [SMALL_STATE(1713)] = 93581,
  [SMALL_STATE(1714)] = 93591,
  [SMALL_STATE(1715)] = 93601,
  [SMALL_STATE(1716)] = 93611,
  [SMALL_STATE(1717)] = 93621,
  [SMALL_STATE(1718)] = 93631,
  [SMALL_STATE(1719)] = 93641,
  [SMALL_STATE(1720)] = 93651,
  [SMALL_STATE(1721)] = 93661,
  [SMALL_STATE(1722)] = 93671,
  [SMALL_STATE(1723)] = 93681,
  [SMALL_STATE(1724)] = 93691,
  [SMALL_STATE(1725)] = 93701,
  [SMALL_STATE(1726)] = 93711,
  [SMALL_STATE(1727)] = 93721,
  [SMALL_STATE(1728)] = 93731,
  [SMALL_STATE(1729)] = 93741,
  [SMALL_STATE(1730)] = 93751,
  [SMALL_STATE(1731)] = 93761,
  [SMALL_STATE(1732)] = 93771,
  [SMALL_STATE(1733)] = 93781,
  [SMALL_STATE(1734)] = 93791,
  [SMALL_STATE(1735)] = 93801,
  [SMALL_STATE(1736)] = 93811,
  [SMALL_STATE(1737)] = 93821,
  [SMALL_STATE(1738)] = 93831,
  [SMALL_STATE(1739)] = 93841,
  [SMALL_STATE(1740)] = 93851,
  [SMALL_STATE(1741)] = 93861,
  [SMALL_STATE(1742)] = 93871,
  [SMALL_STATE(1743)] = 93881,
  [SMALL_STATE(1744)] = 93891,
  [SMALL_STATE(1745)] = 93901,
  [SMALL_STATE(1746)] = 93911,
  [SMALL_STATE(1747)] = 93921,
  [SMALL_STATE(1748)] = 93931,
  [SMALL_STATE(1749)] = 93941,
  [SMALL_STATE(1750)] = 93951,
  [SMALL_STATE(1751)] = 93961,
  [SMALL_STATE(1752)] = 93971,
  [SMALL_STATE(1753)] = 93981,
  [SMALL_STATE(1754)] = 93991,
  [SMALL_STATE(1755)] = 94001,
  [SMALL_STATE(1756)] = 94011,
  [SMALL_STATE(1757)] = 94021,
  [SMALL_STATE(1758)] = 94031,
  [SMALL_STATE(1759)] = 94041,
  [SMALL_STATE(1760)] = 94051,
  [SMALL_STATE(1761)] = 94061,
  [SMALL_STATE(1762)] = 94071,
  [SMALL_STATE(1763)] = 94081,
  [SMALL_STATE(1764)] = 94091,
  [SMALL_STATE(1765)] = 94101,
  [SMALL_STATE(1766)] = 94111,
  [SMALL_STATE(1767)] = 94121,
  [SMALL_STATE(1768)] = 94131,
  [SMALL_STATE(1769)] = 94141,
  [SMALL_STATE(1770)] = 94151,
  [SMALL_STATE(1771)] = 94161,
  [SMALL_STATE(1772)] = 94171,
  [SMALL_STATE(1773)] = 94181,
  [SMALL_STATE(1774)] = 94191,
  [SMALL_STATE(1775)] = 94201,
  [SMALL_STATE(1776)] = 94211,
  [SMALL_STATE(1777)] = 94221,
  [SMALL_STATE(1778)] = 94231,
  [SMALL_STATE(1779)] = 94241,
  [SMALL_STATE(1780)] = 94251,
  [SMALL_STATE(1781)] = 94261,
  [SMALL_STATE(1782)] = 94271,
  [SMALL_STATE(1783)] = 94281,
  [SMALL_STATE(1784)] = 94291,
  [SMALL_STATE(1785)] = 94301,
  [SMALL_STATE(1786)] = 94311,
  [SMALL_STATE(1787)] = 94321,
  [SMALL_STATE(1788)] = 94331,
  [SMALL_STATE(1789)] = 94341,
  [SMALL_STATE(1790)] = 94351,
  [SMALL_STATE(1791)] = 94361,
  [SMALL_STATE(1792)] = 94371,
  [SMALL_STATE(1793)] = 94381,
  [SMALL_STATE(1794)] = 94391,
  [SMALL_STATE(1795)] = 94401,
  [SMALL_STATE(1796)] = 94411,
  [SMALL_STATE(1797)] = 94421,
  [SMALL_STATE(1798)] = 94431,
  [SMALL_STATE(1799)] = 94441,
  [SMALL_STATE(1800)] = 94451,
  [SMALL_STATE(1801)] = 94461,
  [SMALL_STATE(1802)] = 94471,
  [SMALL_STATE(1803)] = 94481,
  [SMALL_STATE(1804)] = 94491,
  [SMALL_STATE(1805)] = 94501,
  [SMALL_STATE(1806)] = 94511,
  [SMALL_STATE(1807)] = 94521,
  [SMALL_STATE(1808)] = 94531,
  [SMALL_STATE(1809)] = 94541,
  [SMALL_STATE(1810)] = 94551,
  [SMALL_STATE(1811)] = 94561,
  [SMALL_STATE(1812)] = 94571,
  [SMALL_STATE(1813)] = 94581,
  [SMALL_STATE(1814)] = 94591,
  [SMALL_STATE(1815)] = 94601,
  [SMALL_STATE(1816)] = 94611,
  [SMALL_STATE(1817)] = 94621,
  [SMALL_STATE(1818)] = 94631,
  [SMALL_STATE(1819)] = 94641,
  [SMALL_STATE(1820)] = 94651,
  [SMALL_STATE(1821)] = 94661,
  [SMALL_STATE(1822)] = 94671,
  [SMALL_STATE(1823)] = 94681,
  [SMALL_STATE(1824)] = 94691,
  [SMALL_STATE(1825)] = 94701,
  [SMALL_STATE(1826)] = 94711,
  [SMALL_STATE(1827)] = 94721,
  [SMALL_STATE(1828)] = 94731,
  [SMALL_STATE(1829)] = 94741,
  [SMALL_STATE(1830)] = 94751,
  [SMALL_STATE(1831)] = 94761,
  [SMALL_STATE(1832)] = 94771,
  [SMALL_STATE(1833)] = 94781,
  [SMALL_STATE(1834)] = 94791,
  [SMALL_STATE(1835)] = 94801,
  [SMALL_STATE(1836)] = 94811,
  [SMALL_STATE(1837)] = 94821,
  [SMALL_STATE(1838)] = 94831,
  [SMALL_STATE(1839)] = 94841,
  [SMALL_STATE(1840)] = 94851,
  [SMALL_STATE(1841)] = 94861,
  [SMALL_STATE(1842)] = 94871,
  [SMALL_STATE(1843)] = 94881,
  [SMALL_STATE(1844)] = 94891,
  [SMALL_STATE(1845)] = 94901,
  [SMALL_STATE(1846)] = 94911,
  [SMALL_STATE(1847)] = 94921,
  [SMALL_STATE(1848)] = 94931,
  [SMALL_STATE(1849)] = 94941,
  [SMALL_STATE(1850)] = 94951,
  [SMALL_STATE(1851)] = 94961,
  [SMALL_STATE(1852)] = 94971,
  [SMALL_STATE(1853)] = 94981,
  [SMALL_STATE(1854)] = 94991,
  [SMALL_STATE(1855)] = 95001,
  [SMALL_STATE(1856)] = 95011,
  [SMALL_STATE(1857)] = 95021,
  [SMALL_STATE(1858)] = 95031,
  [SMALL_STATE(1859)] = 95041,
  [SMALL_STATE(1860)] = 95051,
  [SMALL_STATE(1861)] = 95061,
  [SMALL_STATE(1862)] = 95071,
  [SMALL_STATE(1863)] = 95081,
  [SMALL_STATE(1864)] = 95091,
  [SMALL_STATE(1865)] = 95101,
  [SMALL_STATE(1866)] = 95111,
  [SMALL_STATE(1867)] = 95121,
  [SMALL_STATE(1868)] = 95131,
  [SMALL_STATE(1869)] = 95141,
  [SMALL_STATE(1870)] = 95151,
  [SMALL_STATE(1871)] = 95161,
  [SMALL_STATE(1872)] = 95171,
  [SMALL_STATE(1873)] = 95181,
  [SMALL_STATE(1874)] = 95191,
  [SMALL_STATE(1875)] = 95201,
  [SMALL_STATE(1876)] = 95211,
  [SMALL_STATE(1877)] = 95221,
  [SMALL_STATE(1878)] = 95231,
  [SMALL_STATE(1879)] = 95241,
  [SMALL_STATE(1880)] = 95251,
  [SMALL_STATE(1881)] = 95261,
  [SMALL_STATE(1882)] = 95271,
  [SMALL_STATE(1883)] = 95281,
  [SMALL_STATE(1884)] = 95291,
  [SMALL_STATE(1885)] = 95301,
  [SMALL_STATE(1886)] = 95311,
  [SMALL_STATE(1887)] = 95321,
  [SMALL_STATE(1888)] = 95331,
  [SMALL_STATE(1889)] = 95341,
  [SMALL_STATE(1890)] = 95351,
  [SMALL_STATE(1891)] = 95361,
  [SMALL_STATE(1892)] = 95371,
  [SMALL_STATE(1893)] = 95381,
  [SMALL_STATE(1894)] = 95391,
  [SMALL_STATE(1895)] = 95401,
  [SMALL_STATE(1896)] = 95411,
  [SMALL_STATE(1897)] = 95421,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1767),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(322),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1419),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1691),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(451),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1886),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(754),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1580),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1582),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1624),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1657),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(512),
  [39] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement, 1),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1891),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(985),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1795),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(56),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1890),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1037),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1638),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(519),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(518),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1819),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1148),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1046),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(430),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(602),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1732),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(837),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1561),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(766),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1555),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1178),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1629),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1767),
  [85] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 1),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(523),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1889),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(994),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1875),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(42),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1895),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1108),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1641),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(524),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(528),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1797),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1166),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1131),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(436),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(600),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1735),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(841),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1607),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(773),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1575),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1232),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1617),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(129),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1846),
  [135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1841),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1840),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(276),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(302),
  [145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1413),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(277),
  [151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(187),
  [153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(613),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1768),
  [157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1078),
  [159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1558),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1029),
  [165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1564),
  [167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1608),
  [171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(129),
  [182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1846),
  [185] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1003),
  [188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1841),
  [191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(42),
  [194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1840),
  [197] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1108),
  [200] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1641),
  [203] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(276),
  [206] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(302),
  [209] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1797),
  [212] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(6),
  [215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2),
  [217] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(277),
  [220] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1131),
  [223] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(187),
  [226] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(613),
  [229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1768),
  [232] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1078),
  [235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1078),
  [238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1558),
  [241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1029),
  [244] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1564),
  [247] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(330),
  [250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(1608),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(531),
  [261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1874),
  [263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1876),
  [265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(541),
  [267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(540),
  [269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1189),
  [271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(437),
  [273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(619),
  [275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1742),
  [277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1016),
  [279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1590),
  [281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(835),
  [283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1591),
  [285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1726),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1742),
  [295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1591),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1732),
  [313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1555),
  [321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(105),
  [323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1896),
  [327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1728),
  [331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1818),
  [333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(271),
  [337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(267),
  [339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(615),
  [343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1752),
  [345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1021),
  [347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 3, .production_id = 26),
  [363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_case, 3, .production_id = 26),
  [365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1735),
  [367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1617),
  [379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1548),
  [383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(549),
  [385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1816),
  [387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1893),
  [389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(579),
  [391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(563),
  [393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1274),
  [395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(438),
  [397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(590),
  [399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1737),
  [401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1030),
  [403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1571),
  [405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(865),
  [407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1598),
  [409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1817),
  [413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1737),
  [415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1598),
  [423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__exp, 1),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(119),
  [429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(628),
  [431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace, 1, .production_id = 1),
  [433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exp, 1),
  [435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_concat, 3, .production_id = 6),
  [437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1385),
  [439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_concat, 3, .production_id = 6),
  [441] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_exp, 2, .production_id = 2),
  [443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_exp, 2, .production_id = 2),
  [445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(645),
  [449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(186),
  [451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ns_qualified_name, 4),
  [453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ns_qualified_name, 4),
  [455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(296),
  [459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(912),
  [461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1055),
  [463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(359),
  [465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(883),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_getline_input, 2),
  [471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_getline_input, 2),
  [473] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_ref, 4, .production_id = 14),
  [475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_ref, 4, .production_id = 14),
  [477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indirect_func_call, 2),
  [479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indirect_func_call, 2),
  [481] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_grouping, 3),
  [483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_grouping, 3),
  [485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_regex_constant, 2),
  [487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_regex_constant, 2),
  [489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_exp, 2, .production_id = 3),
  [491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_exp, 2, .production_id = 3),
  [493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_getline_file, 3, .production_id = 4),
  [495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_getline_file, 3, .production_id = 4),
  [497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_getline_input, 1),
  [501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_getline_input, 1),
  [503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2),
  [505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2),
  [507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_piped_io_exp, 3, .production_id = 10),
  [509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_piped_io_exp, 3, .production_id = 10),
  [511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_getline_file, 4, .production_id = 12),
  [513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_getline_file, 4, .production_id = 12),
  [515] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__primitive, 1),
  [517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__primitive, 1),
  [519] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_regex, 4, .production_id = 13),
  [521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_regex, 4, .production_id = 13),
  [523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(654),
  [525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(407),
  [527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1038),
  [529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3),
  [533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3),
  [535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_call, 3, .production_id = 7),
  [537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_call, 3, .production_id = 7),
  [539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_exp, 3, .production_id = 9),
  [541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_exp, 3, .production_id = 9),
  [543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_print_statement, 1),
  [545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(990),
  [547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1752),
  [551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1574),
  [553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1013),
  [555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1581),
  [557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1622),
  [561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 1),
  [563] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__getline_exp, 1),
  [565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__getline_exp, 1),
  [567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(183),
  [569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(931),
  [571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(372),
  [573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(907),
  [575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_ref, 2),
  [577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_ref, 2),
  [579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_call, 4, .production_id = 7),
  [581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_call, 4, .production_id = 7),
  [583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(788),
  [587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_regex, 3, .production_id = 5),
  [589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(127),
  [591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_regex, 3, .production_id = 5),
  [593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(140),
  [595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(942),
  [597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1003),
  [599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1768),
  [603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1558),
  [605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1029),
  [607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1564),
  [609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(330),
  [611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1608),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(811),
  [615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(745),
  [617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(746),
  [619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(744),
  [621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1660),
  [623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(747),
  [625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(743),
  [627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(748),
  [629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(749),
  [631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ternary_exp, 5, .production_id = 16),
  [633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(986),
  [635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(750),
  [637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ternary_exp, 5, .production_id = 16),
  [639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_exp, 3, .production_id = 6),
  [641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_exp, 3, .production_id = 6),
  [643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(173),
  [645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_exp, 2, .production_id = 2),
  [647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_exp, 2, .production_id = 2),
  [649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(877),
  [651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(876),
  [653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1677),
  [655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(875),
  [657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(874),
  [659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(872),
  [661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(871),
  [663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(829),
  [665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(991),
  [667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(869),
  [669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1385),
  [677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(256),
  [679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(626),
  [681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(266),
  [683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(902),
  [685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(301),
  [689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(657),
  [691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(325),
  [693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(752),
  [695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(306),
  [697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(914),
  [699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(303),
  [701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(873),
  [703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exit_statement, 1),
  [705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exit_statement, 1),
  [707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 1),
  [709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 1),
  [711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(630),
  [713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(281),
  [715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(373),
  [717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1040),
  [719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2),
  [721] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(322),
  [724] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1419),
  [727] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1691),
  [730] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(751),
  [733] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(7),
  [736] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(451),
  [739] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1886),
  [742] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(754),
  [745] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(754),
  [748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1580),
  [751] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(755),
  [754] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1582),
  [757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(479),
  [760] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1624),
  [763] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1657),
  [766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(343),
  [768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(780),
  [770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(779),
  [772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1685),
  [774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(989),
  [776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(775),
  [780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(774),
  [782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(771),
  [786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(770),
  [788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(885),
  [790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 1),
  [792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(366),
  [796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(809),
  [800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(377),
  [806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(753),
  [808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(640),
  [810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(948),
  [814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1686),
  [818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1034),
  [820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1033),
  [822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1681),
  [824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1002),
  [826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1031),
  [828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1026),
  [830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1025),
  [832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1022),
  [834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1017),
  [836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1014),
  [838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(235),
  [840] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__print_args, 1),
  [842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1543),
  [844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__print_args, 1),
  [846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(983),
  [848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(406),
  [850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(395),
  [852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(925),
  [854] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exp_list, 2),
  [856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exp_list, 2),
  [858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(269),
  [860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(910),
  [862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1695),
  [864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(945),
  [866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(944),
  [870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(946),
  [872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1661),
  [874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1661),
  [876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(943),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(947),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_piped_io_statement, 3, .production_id = 11),
  [892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_piped_io_statement, 3, .production_id = 11),
  [894] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exit_statement, 2),
  [896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exit_statement, 2),
  [898] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2),
  [900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2),
  [902] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_redirected_io_statement, 3, .production_id = 4),
  [904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_redirected_io_statement, 3, .production_id = 4),
  [906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(447),
  [910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(443),
  [912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(740),
  [914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(481),
  [916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(935),
  [918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(461),
  [922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(456),
  [924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(787),
  [926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(848),
  [930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(849),
  [934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(862),
  [936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1673),
  [938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1673),
  [940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(823),
  [942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(821),
  [948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(487),
  [956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(867),
  [962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(530),
  [966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1707),
  [970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1707),
  [972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1230),
  [974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(878),
  [976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [978] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern, 1),
  [980] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern, 1),
  [982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(535),
  [986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(785),
  [988] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_pattern, 3, .production_id = 8),
  [990] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_pattern, 3, .production_id = 8),
  [992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1188),
  [994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(886),
  [996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1252),
  [998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(926),
  [1000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [1002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(998),
  [1004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(777),
  [1006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(969),
  [1008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [1010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(580),
  [1012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(882),
  [1014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(783),
  [1016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(796),
  [1018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1672),
  [1020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(794),
  [1022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(793),
  [1024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [1026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(797),
  [1028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(764),
  [1030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(791),
  [1032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(790),
  [1034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [1036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(608),
  [1038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(900),
  [1040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(782),
  [1042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [1044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(852),
  [1046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(819),
  [1048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1671),
  [1050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(818),
  [1052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(817),
  [1054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(816),
  [1056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(815),
  [1058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(820),
  [1060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(814),
  [1062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_printf_statement, 2),
  [1064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_printf_statement, 2),
  [1066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(765),
  [1068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(813),
  [1070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [1074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(879),
  [1076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [1078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_printf_statement, 4),
  [1080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_printf_statement, 4),
  [1082] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_print_statement, 4),
  [1084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 4),
  [1086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(881),
  [1088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [1090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(673),
  [1092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(965),
  [1094] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_print_statement, 2),
  [1096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 2),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [1100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(913),
  [1102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(911),
  [1104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(827),
  [1106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(909),
  [1108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(908),
  [1110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(741),
  [1112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(906),
  [1114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(905),
  [1116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(904),
  [1118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(581),
  [1120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [1122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1304),
  [1124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1789),
  [1126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1027),
  [1128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [1130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1599),
  [1132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [1134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1593),
  [1136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1372),
  [1138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [1140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [1142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(889),
  [1144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [1146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(949),
  [1148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [1150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(951),
  [1152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(950),
  [1154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(828),
  [1156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(938),
  [1158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(937),
  [1160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(936),
  [1162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(934),
  [1164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(932),
  [1166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_statement, 2),
  [1168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 2),
  [1170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [1172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [1174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [1176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [1180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [1182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [1184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1213),
  [1188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [1190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [1192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__io_statement, 1),
  [1196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1071),
  [1198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1069),
  [1200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__io_statement, 1),
  [1202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1369),
  [1204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(955),
  [1206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [1208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(762),
  [1210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [1212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(760),
  [1214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [1216] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exp_list_repeat1, 2), SHIFT_REPEAT(581),
  [1219] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exp_list_repeat1, 2), SHIFT_REPEAT(1008),
  [1222] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exp_list_repeat1, 2), SHIFT_REPEAT(1304),
  [1225] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exp_list_repeat1, 2), SHIFT_REPEAT(1789),
  [1228] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_exp_list_repeat1, 2), SHIFT_REPEAT(1027),
  [1231] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exp_list_repeat1, 2), SHIFT_REPEAT(1027),
  [1234] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exp_list_repeat1, 2), SHIFT_REPEAT(1599),
  [1237] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exp_list_repeat1, 2), SHIFT_REPEAT(982),
  [1240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exp_list_repeat1, 2), SHIFT_REPEAT(1593),
  [1243] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exp_list_repeat1, 2), SHIFT_REPEAT(1372),
  [1246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exp_list_repeat1, 2), SHIFT_REPEAT(1631),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(976),
  [1251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1689),
  [1253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [1255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(975),
  [1257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [1259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(974),
  [1261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(973),
  [1263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [1265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [1267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [1269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [1271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [1273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [1275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [1277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [1279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [1281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [1283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [1285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [1287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [1289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [1291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [1293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [1297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(903),
  [1299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [1301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [1305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [1307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(860),
  [1309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(861),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [1315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [1317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(757),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [1337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(978),
  [1339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(731),
  [1341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [1343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [1351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(822),
  [1353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [1357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [1359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [1361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [1363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [1365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(328),
  [1367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(441),
  [1369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1586),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [1375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(93),
  [1377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [1379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(533),
  [1381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1738),
  [1383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(838),
  [1385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [1387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1565),
  [1389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [1391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [1393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1612),
  [1395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(143),
  [1397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1745),
  [1399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1019),
  [1401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [1403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [1407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(144),
  [1409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(242),
  [1411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [1413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1557),
  [1415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1559),
  [1417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(219),
  [1419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [1421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(379),
  [1423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1778),
  [1425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1045),
  [1427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [1429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1553),
  [1431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [1433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [1435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1609),
  [1437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(102),
  [1439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(233),
  [1441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [1443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1583),
  [1445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [1447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1635),
  [1449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(492),
  [1451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(498),
  [1453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1640),
  [1455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1637),
  [1457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(508),
  [1459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1730),
  [1461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(767),
  [1463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [1465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1602),
  [1467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [1469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(97),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [1473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(515),
  [1475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1733),
  [1477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(769),
  [1479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [1481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1606),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [1485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [1487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [1489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(110),
  [1491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1582),
  [1493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [1495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [1497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1024),
  [1499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1560),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [1505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(317),
  [1507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(527),
  [1509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [1511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1740),
  [1513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1594),
  [1515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [1517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1636),
  [1519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(493),
  [1521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1134),
  [1523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1731),
  [1525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1554),
  [1527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1604),
  [1529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(521),
  [1531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1140),
  [1533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [1535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1568),
  [1537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1566),
  [1539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(546),
  [1541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1755),
  [1543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(840),
  [1545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [1547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [1549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
  [1551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(553),
  [1553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1220),
  [1555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1758),
  [1557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1567),
  [1559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1569),
  [1561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(584),
  [1563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1772),
  [1565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(847),
  [1567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [1569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1579),
  [1571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1578),
  [1573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(573),
  [1575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1245),
  [1577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1775),
  [1579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1592),
  [1581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1642),
  [1585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3),
  [1587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3),
  [1589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [1591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, .production_id = 27),
  [1593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1072),
  [1595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, .production_id = 27),
  [1597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1143),
  [1599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__control_statement, 1),
  [1601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__control_statement, 1),
  [1603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(132),
  [1605] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2),
  [1607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2),
  [1609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement, 2),
  [1611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 2),
  [1613] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 25),
  [1615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 25),
  [1617] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 24),
  [1619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 24),
  [1621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(586),
  [1623] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 23),
  [1625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 23),
  [1627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2),
  [1629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2),
  [1631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_body, 3),
  [1633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_body, 3),
  [1635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement_separated, 2),
  [1637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement_separated, 2),
  [1639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 22),
  [1641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 22),
  [1643] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_in_statement, 7, .production_id = 21),
  [1645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_statement, 7, .production_id = 21),
  [1647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 20),
  [1649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 20),
  [1651] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 19),
  [1653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 19),
  [1655] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, .production_id = 17),
  [1657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, .production_id = 17),
  [1659] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_body, 2),
  [1661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_body, 2),
  [1663] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6),
  [1665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6),
  [1667] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_while_statement, 6, .production_id = 18),
  [1669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_while_statement, 6, .production_id = 18),
  [1671] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 5),
  [1673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 5),
  [1675] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, .production_id = 17),
  [1677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, .production_id = 17),
  [1679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1160),
  [1681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1101),
  [1683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(636),
  [1685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1182),
  [1687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1174),
  [1689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(868),
  [1691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1241),
  [1693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(655),
  [1695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1235),
  [1697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(887),
  [1699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(635),
  [1701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, .production_id = 17),
  [1703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1678),
  [1705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1698),
  [1707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1221),
  [1709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(880),
  [1711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1150),
  [1713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(627),
  [1715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1260),
  [1717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(988),
  [1719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1250),
  [1721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(927),
  [1723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(866),
  [1725] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__block_content, 1),
  [1727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [1729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1301),
  [1731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(959),
  [1733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(898),
  [1735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1663),
  [1737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(895),
  [1739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(894),
  [1741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(893),
  [1743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(899),
  [1745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(826),
  [1747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(892),
  [1749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(890),
  [1751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1224),
  [1753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1298),
  [1755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(842),
  [1757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(870),
  [1759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1204),
  [1761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(884),
  [1763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(964),
  [1765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(963),
  [1767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1690),
  [1769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(830),
  [1771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(962),
  [1773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(961),
  [1775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(960),
  [1777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(958),
  [1779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(957),
  [1781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(956),
  [1783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1309),
  [1785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(891),
  [1787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1662),
  [1789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(924),
  [1791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1000),
  [1793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1307),
  [1795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1275),
  [1797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1316),
  [1799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(795),
  [1801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(803),
  [1803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(804),
  [1805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(805),
  [1807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [1809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(801),
  [1811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(802),
  [1813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(984),
  [1815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [1817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(807),
  [1819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(808),
  [1821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__block_content, 1),
  [1823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1345),
  [1825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1708),
  [1827] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 1),
  [1829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 1),
  [1831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(855),
  [1833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(971),
  [1835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1357),
  [1837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1053),
  [1839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(856),
  [1841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(922),
  [1843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(921),
  [1845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(920),
  [1847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(919),
  [1849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(918),
  [1851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(917),
  [1853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(916),
  [1855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(768),
  [1857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1342),
  [1859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(993),
  [1861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(915),
  [1863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [1865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [1867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1057),
  [1869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1700),
  [1871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1700),
  [1873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [1875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [1877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1059),
  [1879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [1881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [1883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [1885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [1887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [1889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [1891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1080),
  [1893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1387),
  [1895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1679),
  [1897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1679),
  [1899] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule, 1),
  [1901] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rule, 1),
  [1903] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule, 2),
  [1905] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rule, 2),
  [1907] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_def, 6, .production_id = 15),
  [1909] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_def, 6, .production_id = 15),
  [1911] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 1),
  [1913] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 1),
  [1915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__special_pattern, 1),
  [1917] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__special_pattern, 1),
  [1919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_def, 5, .production_id = 15),
  [1921] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_def, 5, .production_id = 15),
  [1923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [1925] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_args, 1),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1543),
  [1929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive, 2),
  [1931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive, 2),
  [1933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [1935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [1937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [1941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [1949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1306),
  [1955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_args_repeat1, 2),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [1959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [1961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1147),
  [1963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [1965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [1967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [1969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [1971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [1973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [1975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [1979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [1983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [1989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [1991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [1999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [2001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [2003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [2005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [2007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [2009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [2011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [2013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [2017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1223),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [2023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [2027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [2029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [2031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [2033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [2035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [2037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1710),
  [2043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [2045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [2049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [2051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [2053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [2057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [2059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [2061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [2063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [2065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [2069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [2071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [2073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [2077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [2081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [2085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [2087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [2093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [2097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [2101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [2113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1683),
  [2115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [2117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [2119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [2121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [2123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [2125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [2127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [2129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [2131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [2133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [2135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [2137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [2139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [2141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [2143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [2145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [2149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [2151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [2153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [2155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [2157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [2159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [2161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [2163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [2165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [2167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [2169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [2171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [2173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [2175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [2177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [2179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [2181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [2183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [2185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [2187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [2189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [2191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [2193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [2195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [2197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [2199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [2201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [2203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [2205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [2207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [2209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [2211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [2213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [2215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [2217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [2219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [2221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [2223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [2225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [2227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [2229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [2231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [2233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [2235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [2237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [2239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [2241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [2243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [2245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [2247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [2249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [2253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [2255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [2257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [2259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [2261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [2263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [2265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [2267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [2269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [2271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [2273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [2275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(774),
  [2277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [2279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [2281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [2283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [2285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [2287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [2289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [2291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [2293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [2295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [2297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [2299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [2301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [2303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [2305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [2307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [2309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [2311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [2313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [2315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [2317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [2319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [2321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [2323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [2325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [2327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [2329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [2331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [2333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [2335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [2337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [2339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [2341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [2343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [2345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [2347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [2349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [2351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [2353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [2355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [2357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [2359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [2361] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_exp_list_repeat1, 2),
  [2363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_exp_list_repeat1, 2),
  [2365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(844),
  [2367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(843),
  [2369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(864),
  [2371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(863),
  [2373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1036),
  [2375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1035),
  [2377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1048),
  [2379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1049),
  [2381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1676),
  [2383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [2385] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_default, 3),
  [2387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [2389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [2391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [2393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1704),
  [2395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [2397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [2399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1783),
  [2401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [2403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [2405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [2407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1043),
  [2409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1693),
  [2411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [2413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [2415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [2417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [2419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1694),
  [2421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1667),
  [2423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [2425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [2427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [2429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [2431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [2433] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_case, 4, .production_id = 26),
  [2435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1156),
  [2437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [2439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [2441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [2443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1687),
  [2445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [2447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [2449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [2451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [2453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [2455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [2457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1688),
  [2459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [2461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [2463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [2465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [2467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [2469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1658),
  [2471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1682),
  [2473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [2475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [2477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [2479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [2481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [2483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [2485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [2487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1712),
  [2489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1616),
  [2491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [2493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [2495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [2497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_body_repeat1, 2),
  [2499] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_body_repeat1, 2), SHIFT_REPEAT(1597),
  [2502] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_body_repeat1, 2), SHIFT_REPEAT(1783),
  [2505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [2507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(350),
  [2509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1634),
  [2511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [2513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(260),
  [2515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [2517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [2519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(123),
  [2521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(263),
  [2523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1684),
  [2525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1407),
  [2527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1219),
  [2529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(374),
  [2531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(321),
  [2533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [2535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(282),
  [2537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1412),
  [2539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(478),
  [2541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1185),
  [2543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2),
  [2545] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(1634),
  [2548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(1634),
  [2551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1338),
  [2553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1179),
  [2555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1176),
  [2557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(472),
  [2559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1366),
  [2561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(131),
  [2563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1650),
  [2565] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 1),
  [2567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 1),
  [2569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [2571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [2573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1655),
  [2575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [2577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1720),
  [2579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1653),
  [2581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [2583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [2585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1727),
  [2587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_args, 2),
  [2589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1724),
  [2591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_param_list, 1),
  [2593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_param_list, 2),
  [2595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [2597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1674),
  [2599] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_args_repeat1, 2), SHIFT_REPEAT(930),
  [2602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [2604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [2606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [2608] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_param_list_repeat1, 2), SHIFT_REPEAT(1724),
  [2611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_param_list_repeat1, 2),
  [2613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [2615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [2617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [2619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_body_repeat1, 1),
  [2621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1702),
  [2623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [2625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [2627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [2629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [2631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [2633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [2635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(653),
  [2637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [2639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [2641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [2643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [2645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [2647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [2649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [2651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1287),
  [2653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [2655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [2657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [2659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [2661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [2663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(651),
  [2665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [2667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [2669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [2671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [2673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [2675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [2679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1647),
  [2681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
  [2683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [2685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [2687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [2689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1577),
  [2691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [2693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1720),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [2697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1719),
  [2699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1800),
  [2701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [2703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [2705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [2707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [2709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1670),
  [2711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [2713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1782),
  [2715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [2717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [2721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1787),
  [2723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1790),
  [2725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1791),
  [2727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1792),
  [2729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1793),
  [2731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1796),
  [2733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1798),
  [2735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1799),
  [2737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1785),
  [2739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1802),
  [2741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1820),
  [2743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1822),
  [2745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1823),
  [2747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1824),
  [2749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1825),
  [2751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1828),
  [2753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1829),
  [2755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1832),
  [2757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1833),
  [2759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1836),
  [2761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [2763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1842),
  [2765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [2767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1847),
  [2769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1848),
  [2771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1850),
  [2773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1851),
  [2775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1855),
  [2777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1856),
  [2779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1897),
  [2781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1859),
  [2783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [2785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1860),
  [2787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1864),
  [2789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1865),
  [2791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1868),
  [2793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1869),
  [2795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1872),
  [2797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1873),
  [2799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1879),
  [2801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1887),
  [2803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [2805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1331),
  [2807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [2809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1883),
  [2811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1880),
  [2813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [2815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1153),
  [2817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [2819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [2821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1779),
  [2823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [2825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [2827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [2829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1268),
  [2831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1709),
  [2833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [2835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [2837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [2839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1773),
  [2841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1770),
  [2843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1765),
  [2845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1762),
  [2847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1759),
  [2849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1756),
  [2851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1753),
  [2853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1749),
  [2855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1746),
  [2857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1743),
  [2859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [2861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1739),
  [2863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1718),
  [2865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [2867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [2869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [2871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [2873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [2875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [2877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [2879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [2881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [2883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [2885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [2887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [2889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [2891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1154),
  [2893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [2895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [2897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [2899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [2901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1181),
  [2903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [2905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [2907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [2909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [2911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [2913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [2915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [2917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [2919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [2921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [2923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1226),
  [2925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [2927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [2929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [2931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [2933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [2935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [2937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [2939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [2941] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [2945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [2947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [2949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [2951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [2953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [2955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [2957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [2959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [2961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [2963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [2965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [2967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [2969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1365),
  [2971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1383),
  [2973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [2975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [2977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [2979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1769),
  [2981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [2983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [2985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [2987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [2989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [2991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [2993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [2995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [2997] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment, 2),
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_awk_external_scanner_create(void);
void tree_sitter_awk_external_scanner_destroy(void *);
bool tree_sitter_awk_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_awk_external_scanner_serialize(void *, char *);
void tree_sitter_awk_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef _WIN32
#define extern __declspec(dllexport)
#endif

extern const TSLanguage *tree_sitter_awk(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_awk_external_scanner_create,
      tree_sitter_awk_external_scanner_destroy,
      tree_sitter_awk_external_scanner_scan,
      tree_sitter_awk_external_scanner_serialize,
      tree_sitter_awk_external_scanner_deserialize,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
