#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 924
#define LARGE_STATE_COUNT 234
#define SYMBOL_COUNT 268
#define ALIAS_COUNT 0
#define TOKEN_COUNT 143
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 35
#define MAX_ALIAS_SEQUENCE_LENGTH 14
#define PRODUCTION_ID_COUNT 89

enum ts_symbol_identifiers {
  sym_export = 1,
  anon_sym_LBRACE = 2,
  anon_sym_COMMA = 3,
  anon_sym_RBRACE = 4,
  anon_sym_import = 5,
  anon_sym_from = 6,
  anon_sym_SEMI = 7,
  anon_sym_as = 8,
  anon_sym_COLON_EQ = 9,
  anon_sym_component = 10,
  anon_sym_inherits = 11,
  anon_sym_LT = 12,
  anon_sym_GT = 13,
  anon_sym_return = 14,
  anon_sym_property = 15,
  anon_sym_COLON = 16,
  anon_sym_LT_EQ_GT = 17,
  anon_sym_global = 18,
  anon_sym_struct = 19,
  anon_sym_enum = 20,
  anon_sym_in = 21,
  anon_sym_out = 22,
  anon_sym_transitions = 23,
  anon_sym_LBRACK = 24,
  anon_sym_RBRACK = 25,
  anon_sym_states = 26,
  anon_sym_when = 27,
  anon_sym_animate = 28,
  anon_sym_delay = 29,
  anon_sym_duration = 30,
  anon_sym_iteration_DASHcount = 31,
  anon_sym_direction = 32,
  anon_sym_easing = 33,
  anon_sym_if = 34,
  anon_sym_else = 35,
  anon_sym_for = 36,
  anon_sym_LPAREN = 37,
  anon_sym_RPAREN = 38,
  anon_sym_ATtr = 39,
  anon_sym_EQ_GT = 40,
  anon_sym_PIPE = 41,
  anon_sym_PERCENT = 42,
  anon_sym_DOT = 43,
  sym_logical_and = 44,
  sym_logical_or = 45,
  anon_sym_QMARK = 46,
  anon_sym_callback = 47,
  anon_sym_DASH_GT = 48,
  anon_sym_pure = 49,
  anon_sym_public = 50,
  anon_sym_private = 51,
  anon_sym_function = 52,
  anon_sym_changed = 53,
  anon_sym_ATimage_DASHurl = 54,
  anon_sym_nine_DASHslice = 55,
  anon_sym_BANG = 56,
  anon_sym_DASH = 57,
  anon_sym_PLUS = 58,
  anon_sym_STAR = 59,
  anon_sym_SLASH = 60,
  anon_sym_GT_EQ = 61,
  anon_sym_LT_EQ = 62,
  anon_sym_EQ_EQ = 63,
  anon_sym_BANG_EQ = 64,
  anon_sym_EQ = 65,
  anon_sym_PLUS_EQ = 66,
  anon_sym_DASH_EQ = 67,
  anon_sym_STAR_EQ = 68,
  anon_sym_SLASH_EQ = 69,
  anon_sym_DQUOTE = 70,
  sym__unescaped_string_fragment = 71,
  anon_sym_BSLASH = 72,
  aux_sym_escape_sequence_token1 = 73,
  anon_sym_n = 74,
  anon_sym_in_DASHout = 75,
  sym__identifier = 76,
  anon_sym_int = 77,
  anon_sym_float = 78,
  anon_sym_bool = 79,
  anon_sym_string = 80,
  anon_sym_color = 81,
  anon_sym_brush = 82,
  anon_sym_physical_DASHlength = 83,
  anon_sym_length = 84,
  anon_sym_angle = 85,
  anon_sym_percent = 86,
  anon_sym_image = 87,
  anon_sym_relative_DASHfont_DASHsize = 88,
  anon_sym_linear = 89,
  anon_sym_ease_DASHin_DASHquad = 90,
  anon_sym_ease_DASHout_DASHquad = 91,
  anon_sym_ease_DASHin_DASHout_DASHquad = 92,
  anon_sym_ease = 93,
  anon_sym_ease_DASHin = 94,
  anon_sym_ease_DASHout = 95,
  anon_sym_ease_DASHin_DASHout = 96,
  anon_sym_ease_DASHin_DASHquart = 97,
  anon_sym_ease_DASHout_DASHquart = 98,
  anon_sym_ease_DASHin_DASHout_DASHquart = 99,
  anon_sym_ease_DASHin_DASHquint = 100,
  anon_sym_ease_DASHout_DASHquint = 101,
  anon_sym_ease_DASHin_DASHout_DASHquint = 102,
  anon_sym_ease_DASHin_DASHexpo = 103,
  anon_sym_ease_DASHout_DASHexpo = 104,
  anon_sym_ease_DASHin_DASHout_DASHexpo = 105,
  anon_sym_ease_DASHin_DASHsine = 106,
  anon_sym_ease_DASHout_DASHsine = 107,
  anon_sym_ease_DASHin_DASHout_DASHsine = 108,
  anon_sym_ease_DASHin_DASHback = 109,
  anon_sym_ease_DASHout_DASHback = 110,
  anon_sym_ease_DASHin_DASHout_DASHback = 111,
  anon_sym_ease_DASHin_DASHcirc = 112,
  anon_sym_ease_DASHout_DASHcirc = 113,
  anon_sym_ease_DASHin_DASHout_DASHcirc = 114,
  anon_sym_ease_DASHin_DASHelastic = 115,
  anon_sym_ease_DASHout_DASHelastic = 116,
  anon_sym_ease_DASHin_DASHout_DASHelastic = 117,
  anon_sym_ease_DASHin_DASHbounce = 118,
  anon_sym_ease_DASHout_DASHbounce = 119,
  anon_sym_ease_DASHin_DASHout_DASHbounce = 120,
  anon_sym_cubic_DASHbezier = 121,
  sym_children_identifier = 122,
  anon_sym_ATlinear_DASHgradient = 123,
  anon_sym_ATlinear_gradient = 124,
  anon_sym_ATradial_DASHgradient = 125,
  anon_sym_ATradial_gradient = 126,
  anon_sym_circle = 127,
  anon_sym_parent = 128,
  anon_sym_root = 129,
  anon_sym_self = 130,
  sym__int_number = 131,
  sym__float_number = 132,
  anon_sym_true = 133,
  anon_sym_false = 134,
  sym_color_value = 135,
  anon_sym_phx = 136,
  aux_sym_length_value_token1 = 137,
  aux_sym_duration_value_token1 = 138,
  aux_sym_angle_value_token1 = 139,
  anon_sym_PERCENT2 = 140,
  anon_sym_rem = 141,
  sym_comment = 142,
  sym_sourcefile = 143,
  sym__definition = 144,
  sym__local_type = 145,
  sym__exported_type = 146,
  sym_import_statement = 147,
  sym_export_type = 148,
  sym_import_type = 149,
  sym_component = 150,
  sym_component_definition = 151,
  sym__property_type = 152,
  sym_imperative_block = 153,
  sym__imperative_block_statement = 154,
  sym__binding = 155,
  sym_property = 156,
  sym_binding_alias = 157,
  sym_binding = 158,
  sym_global_block = 159,
  sym_global_definition = 160,
  sym_struct_block = 161,
  sym_struct_definition = 162,
  sym_enum_block = 163,
  sym_enum_definition = 164,
  sym_anon_struct_block = 165,
  sym_block = 166,
  sym__block_statement = 167,
  sym_property_assignment = 168,
  sym_in_out_transition = 169,
  sym_transitions_definition = 170,
  sym_states_definition = 171,
  sym_animate_statement = 172,
  sym_animate_option_identifier = 173,
  sym_animate_option = 174,
  sym_animate_body = 175,
  sym_if_expr = 176,
  sym_if_statement = 177,
  sym_for_loop = 178,
  sym_for_range = 179,
  sym_type_list = 180,
  sym_type = 181,
  sym__assignment_setup = 182,
  sym__assignment_value_block = 183,
  sym_assignment_block = 184,
  sym_assignment_expr = 185,
  sym_expression = 186,
  sym_parens_op = 187,
  sym_index_op = 188,
  sym_tr = 189,
  sym_member_access = 190,
  sym_unary_expression = 191,
  sym_binary_expression = 192,
  sym__add_binary_expression = 193,
  sym__comparison_binary_expression = 194,
  sym__logic_binary_expression = 195,
  sym__mult_binary_expression = 196,
  sym_ternary_expression = 197,
  sym_callback = 198,
  sym_purity = 199,
  sym_function_visibility = 200,
  sym_function_definition = 201,
  sym_callback_alias = 202,
  sym_callback_event = 203,
  sym_changed_callback = 204,
  sym_function_call = 205,
  sym_gradient_call = 206,
  sym_gradient_color = 207,
  sym_image_call = 208,
  sym_typed_identifier = 209,
  sym__function_signature = 210,
  sym__callback_signature = 211,
  sym_argument = 212,
  sym_arguments = 213,
  sym_unary_prec_operator = 214,
  sym_add_prec_operator = 215,
  sym_mult_prec_operator = 216,
  sym_comparison_operator = 217,
  sym_assignment_prec_operator = 218,
  sym__string = 219,
  sym_escape_sequence = 220,
  sym_property_visibility = 221,
  sym_simple_identifier = 222,
  sym_simple_indexed_identifier = 223,
  sym_builtin_type_identifier = 224,
  sym_easing_kind_identifier = 225,
  sym_user_type_identifier = 226,
  sym__type_identifier = 227,
  sym_value_list = 228,
  sym_value = 229,
  sym_linear_gradient_identifier = 230,
  sym_radial_gradient_identifier = 231,
  sym_radial_gradient_kind = 232,
  sym_reference_identifier = 233,
  sym__number = 234,
  sym_int_value = 235,
  sym_float_value = 236,
  sym_bool_value = 237,
  sym_string_value = 238,
  sym_physical_length_value = 239,
  sym_length_value = 240,
  sym_duration_value = 241,
  sym_angle_value = 242,
  sym_percent_value = 243,
  sym_relative_font_size_value = 244,
  sym__basic_value = 245,
  aux_sym_sourcefile_repeat1 = 246,
  aux_sym__exported_type_repeat1 = 247,
  aux_sym_import_statement_repeat1 = 248,
  aux_sym_imperative_block_repeat1 = 249,
  aux_sym_global_block_repeat1 = 250,
  aux_sym_struct_block_repeat1 = 251,
  aux_sym_enum_block_repeat1 = 252,
  aux_sym_anon_struct_block_repeat1 = 253,
  aux_sym_block_repeat1 = 254,
  aux_sym_in_out_transition_repeat1 = 255,
  aux_sym_transitions_definition_repeat1 = 256,
  aux_sym_states_definition_repeat1 = 257,
  aux_sym_states_definition_repeat2 = 258,
  aux_sym_animate_body_repeat1 = 259,
  aux_sym_type_list_repeat1 = 260,
  aux_sym_tr_repeat1 = 261,
  aux_sym_function_definition_repeat1 = 262,
  aux_sym_gradient_call_repeat1 = 263,
  aux_sym_image_call_repeat1 = 264,
  aux_sym__function_signature_repeat1 = 265,
  aux_sym_arguments_repeat1 = 266,
  aux_sym__string_repeat1 = 267,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_export] = "export",
  [anon_sym_LBRACE] = "{",
  [anon_sym_COMMA] = ",",
  [anon_sym_RBRACE] = "}",
  [anon_sym_import] = "import",
  [anon_sym_from] = "from",
  [anon_sym_SEMI] = ";",
  [anon_sym_as] = "as",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_component] = "component",
  [anon_sym_inherits] = "inherits",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [anon_sym_return] = "return",
  [anon_sym_property] = "property",
  [anon_sym_COLON] = ":",
  [anon_sym_LT_EQ_GT] = "<=>",
  [anon_sym_global] = "global",
  [anon_sym_struct] = "struct",
  [anon_sym_enum] = "enum",
  [anon_sym_in] = "in",
  [anon_sym_out] = "out",
  [anon_sym_transitions] = "transitions",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_states] = "states",
  [anon_sym_when] = "when",
  [anon_sym_animate] = "animate",
  [anon_sym_delay] = "delay",
  [anon_sym_duration] = "duration",
  [anon_sym_iteration_DASHcount] = "iteration-count",
  [anon_sym_direction] = "direction",
  [anon_sym_easing] = "easing",
  [anon_sym_if] = "if",
  [anon_sym_else] = "else",
  [anon_sym_for] = "for",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_ATtr] = "@tr",
  [anon_sym_EQ_GT] = "=>",
  [anon_sym_PIPE] = "|",
  [anon_sym_PERCENT] = "%",
  [anon_sym_DOT] = ".",
  [sym_logical_and] = "logical_and",
  [sym_logical_or] = "logical_or",
  [anon_sym_QMARK] = "\?",
  [anon_sym_callback] = "callback",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_pure] = "pure",
  [anon_sym_public] = "public",
  [anon_sym_private] = "private",
  [anon_sym_function] = "function",
  [anon_sym_changed] = "changed",
  [anon_sym_ATimage_DASHurl] = "@image-url",
  [anon_sym_nine_DASHslice] = "nine-slice",
  [anon_sym_BANG] = "!",
  [anon_sym_DASH] = "-",
  [anon_sym_PLUS] = "+",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_EQ] = "=",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_DQUOTE] = "\"",
  [sym__unescaped_string_fragment] = "_unescaped_string_fragment",
  [anon_sym_BSLASH] = "\\",
  [aux_sym_escape_sequence_token1] = "escape_sequence_token1",
  [anon_sym_n] = "n",
  [anon_sym_in_DASHout] = "in-out",
  [sym__identifier] = "_identifier",
  [anon_sym_int] = "int",
  [anon_sym_float] = "float",
  [anon_sym_bool] = "bool",
  [anon_sym_string] = "string",
  [anon_sym_color] = "color",
  [anon_sym_brush] = "brush",
  [anon_sym_physical_DASHlength] = "physical-length",
  [anon_sym_length] = "length",
  [anon_sym_angle] = "angle",
  [anon_sym_percent] = "percent",
  [anon_sym_image] = "image",
  [anon_sym_relative_DASHfont_DASHsize] = "relative-font-size",
  [anon_sym_linear] = "linear",
  [anon_sym_ease_DASHin_DASHquad] = "ease-in-quad",
  [anon_sym_ease_DASHout_DASHquad] = "ease-out-quad",
  [anon_sym_ease_DASHin_DASHout_DASHquad] = "ease-in-out-quad",
  [anon_sym_ease] = "ease",
  [anon_sym_ease_DASHin] = "ease-in",
  [anon_sym_ease_DASHout] = "ease-out",
  [anon_sym_ease_DASHin_DASHout] = "ease-in-out",
  [anon_sym_ease_DASHin_DASHquart] = "ease-in-quart",
  [anon_sym_ease_DASHout_DASHquart] = "ease-out-quart",
  [anon_sym_ease_DASHin_DASHout_DASHquart] = "ease-in-out-quart",
  [anon_sym_ease_DASHin_DASHquint] = "ease-in-quint",
  [anon_sym_ease_DASHout_DASHquint] = "ease-out-quint",
  [anon_sym_ease_DASHin_DASHout_DASHquint] = "ease-in-out-quint",
  [anon_sym_ease_DASHin_DASHexpo] = "ease-in-expo",
  [anon_sym_ease_DASHout_DASHexpo] = "ease-out-expo",
  [anon_sym_ease_DASHin_DASHout_DASHexpo] = "ease-in-out-expo",
  [anon_sym_ease_DASHin_DASHsine] = "ease-in-sine",
  [anon_sym_ease_DASHout_DASHsine] = "ease-out-sine",
  [anon_sym_ease_DASHin_DASHout_DASHsine] = "ease-in-out-sine",
  [anon_sym_ease_DASHin_DASHback] = "ease-in-back",
  [anon_sym_ease_DASHout_DASHback] = "ease-out-back",
  [anon_sym_ease_DASHin_DASHout_DASHback] = "ease-in-out-back",
  [anon_sym_ease_DASHin_DASHcirc] = "ease-in-circ",
  [anon_sym_ease_DASHout_DASHcirc] = "ease-out-circ",
  [anon_sym_ease_DASHin_DASHout_DASHcirc] = "ease-in-out-circ",
  [anon_sym_ease_DASHin_DASHelastic] = "ease-in-elastic",
  [anon_sym_ease_DASHout_DASHelastic] = "ease-out-elastic",
  [anon_sym_ease_DASHin_DASHout_DASHelastic] = "ease-in-out-elastic",
  [anon_sym_ease_DASHin_DASHbounce] = "ease-in-bounce",
  [anon_sym_ease_DASHout_DASHbounce] = "ease-out-bounce",
  [anon_sym_ease_DASHin_DASHout_DASHbounce] = "ease-in-out-bounce",
  [anon_sym_cubic_DASHbezier] = "cubic-bezier",
  [sym_children_identifier] = "children_identifier",
  [anon_sym_ATlinear_DASHgradient] = "@linear-gradient",
  [anon_sym_ATlinear_gradient] = "@linear_gradient",
  [anon_sym_ATradial_DASHgradient] = "@radial-gradient",
  [anon_sym_ATradial_gradient] = "@radial_gradient",
  [anon_sym_circle] = "circle",
  [anon_sym_parent] = "parent",
  [anon_sym_root] = "root",
  [anon_sym_self] = "self",
  [sym__int_number] = "_int_number",
  [sym__float_number] = "_float_number",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [sym_color_value] = "color_value",
  [anon_sym_phx] = "phx",
  [aux_sym_length_value_token1] = "length_value_token1",
  [aux_sym_duration_value_token1] = "duration_value_token1",
  [aux_sym_angle_value_token1] = "angle_value_token1",
  [anon_sym_PERCENT2] = "%",
  [anon_sym_rem] = "rem",
  [sym_comment] = "comment",
  [sym_sourcefile] = "sourcefile",
  [sym__definition] = "_definition",
  [sym__local_type] = "_local_type",
  [sym__exported_type] = "_exported_type",
  [sym_import_statement] = "import_statement",
  [sym_export_type] = "export_type",
  [sym_import_type] = "import_type",
  [sym_component] = "component",
  [sym_component_definition] = "component_definition",
  [sym__property_type] = "_property_type",
  [sym_imperative_block] = "imperative_block",
  [sym__imperative_block_statement] = "_imperative_block_statement",
  [sym__binding] = "_binding",
  [sym_property] = "property",
  [sym_binding_alias] = "binding_alias",
  [sym_binding] = "binding",
  [sym_global_block] = "global_block",
  [sym_global_definition] = "global_definition",
  [sym_struct_block] = "struct_block",
  [sym_struct_definition] = "struct_definition",
  [sym_enum_block] = "enum_block",
  [sym_enum_definition] = "enum_definition",
  [sym_anon_struct_block] = "anon_struct_block",
  [sym_block] = "block",
  [sym__block_statement] = "_block_statement",
  [sym_property_assignment] = "property_assignment",
  [sym_in_out_transition] = "in_out_transition",
  [sym_transitions_definition] = "transitions_definition",
  [sym_states_definition] = "states_definition",
  [sym_animate_statement] = "animate_statement",
  [sym_animate_option_identifier] = "animate_option_identifier",
  [sym_animate_option] = "animate_option",
  [sym_animate_body] = "animate_body",
  [sym_if_expr] = "if_expr",
  [sym_if_statement] = "if_statement",
  [sym_for_loop] = "for_loop",
  [sym_for_range] = "for_range",
  [sym_type_list] = "type_list",
  [sym_type] = "type",
  [sym__assignment_setup] = "_assignment_setup",
  [sym__assignment_value_block] = "_assignment_value_block",
  [sym_assignment_block] = "assignment_block",
  [sym_assignment_expr] = "assignment_expr",
  [sym_expression] = "expression",
  [sym_parens_op] = "parens_op",
  [sym_index_op] = "index_op",
  [sym_tr] = "tr",
  [sym_member_access] = "member_access",
  [sym_unary_expression] = "unary_expression",
  [sym_binary_expression] = "binary_expression",
  [sym__add_binary_expression] = "_add_binary_expression",
  [sym__comparison_binary_expression] = "_comparison_binary_expression",
  [sym__logic_binary_expression] = "_logic_binary_expression",
  [sym__mult_binary_expression] = "_mult_binary_expression",
  [sym_ternary_expression] = "ternary_expression",
  [sym_callback] = "callback",
  [sym_purity] = "purity",
  [sym_function_visibility] = "function_visibility",
  [sym_function_definition] = "function_definition",
  [sym_callback_alias] = "callback_alias",
  [sym_callback_event] = "callback_event",
  [sym_changed_callback] = "changed_callback",
  [sym_function_call] = "function_call",
  [sym_gradient_call] = "gradient_call",
  [sym_gradient_color] = "gradient_color",
  [sym_image_call] = "image_call",
  [sym_typed_identifier] = "typed_identifier",
  [sym__function_signature] = "_function_signature",
  [sym__callback_signature] = "_callback_signature",
  [sym_argument] = "argument",
  [sym_arguments] = "arguments",
  [sym_unary_prec_operator] = "unary_prec_operator",
  [sym_add_prec_operator] = "add_prec_operator",
  [sym_mult_prec_operator] = "mult_prec_operator",
  [sym_comparison_operator] = "comparison_operator",
  [sym_assignment_prec_operator] = "assignment_prec_operator",
  [sym__string] = "_string",
  [sym_escape_sequence] = "escape_sequence",
  [sym_property_visibility] = "property_visibility",
  [sym_simple_identifier] = "simple_identifier",
  [sym_simple_indexed_identifier] = "simple_indexed_identifier",
  [sym_builtin_type_identifier] = "builtin_type_identifier",
  [sym_easing_kind_identifier] = "easing_kind_identifier",
  [sym_user_type_identifier] = "user_type_identifier",
  [sym__type_identifier] = "_type_identifier",
  [sym_value_list] = "value_list",
  [sym_value] = "value",
  [sym_linear_gradient_identifier] = "linear_gradient_identifier",
  [sym_radial_gradient_identifier] = "radial_gradient_identifier",
  [sym_radial_gradient_kind] = "radial_gradient_kind",
  [sym_reference_identifier] = "reference_identifier",
  [sym__number] = "_number",
  [sym_int_value] = "int_value",
  [sym_float_value] = "float_value",
  [sym_bool_value] = "bool_value",
  [sym_string_value] = "string_value",
  [sym_physical_length_value] = "physical_length_value",
  [sym_length_value] = "length_value",
  [sym_duration_value] = "duration_value",
  [sym_angle_value] = "angle_value",
  [sym_percent_value] = "percent_value",
  [sym_relative_font_size_value] = "relative_font_size_value",
  [sym__basic_value] = "_basic_value",
  [aux_sym_sourcefile_repeat1] = "sourcefile_repeat1",
  [aux_sym__exported_type_repeat1] = "_exported_type_repeat1",
  [aux_sym_import_statement_repeat1] = "import_statement_repeat1",
  [aux_sym_imperative_block_repeat1] = "imperative_block_repeat1",
  [aux_sym_global_block_repeat1] = "global_block_repeat1",
  [aux_sym_struct_block_repeat1] = "struct_block_repeat1",
  [aux_sym_enum_block_repeat1] = "enum_block_repeat1",
  [aux_sym_anon_struct_block_repeat1] = "anon_struct_block_repeat1",
  [aux_sym_block_repeat1] = "block_repeat1",
  [aux_sym_in_out_transition_repeat1] = "in_out_transition_repeat1",
  [aux_sym_transitions_definition_repeat1] = "transitions_definition_repeat1",
  [aux_sym_states_definition_repeat1] = "states_definition_repeat1",
  [aux_sym_states_definition_repeat2] = "states_definition_repeat2",
  [aux_sym_animate_body_repeat1] = "animate_body_repeat1",
  [aux_sym_type_list_repeat1] = "type_list_repeat1",
  [aux_sym_tr_repeat1] = "tr_repeat1",
  [aux_sym_function_definition_repeat1] = "function_definition_repeat1",
  [aux_sym_gradient_call_repeat1] = "gradient_call_repeat1",
  [aux_sym_image_call_repeat1] = "image_call_repeat1",
  [aux_sym__function_signature_repeat1] = "_function_signature_repeat1",
  [aux_sym_arguments_repeat1] = "arguments_repeat1",
  [aux_sym__string_repeat1] = "_string_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_export] = sym_export,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_from] = anon_sym_from,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_component] = anon_sym_component,
  [anon_sym_inherits] = anon_sym_inherits,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_property] = anon_sym_property,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_LT_EQ_GT] = anon_sym_LT_EQ_GT,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_out] = anon_sym_out,
  [anon_sym_transitions] = anon_sym_transitions,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_states] = anon_sym_states,
  [anon_sym_when] = anon_sym_when,
  [anon_sym_animate] = anon_sym_animate,
  [anon_sym_delay] = anon_sym_delay,
  [anon_sym_duration] = anon_sym_duration,
  [anon_sym_iteration_DASHcount] = anon_sym_iteration_DASHcount,
  [anon_sym_direction] = anon_sym_direction,
  [anon_sym_easing] = anon_sym_easing,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_ATtr] = anon_sym_ATtr,
  [anon_sym_EQ_GT] = anon_sym_EQ_GT,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_DOT] = anon_sym_DOT,
  [sym_logical_and] = sym_logical_and,
  [sym_logical_or] = sym_logical_or,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_callback] = anon_sym_callback,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_pure] = anon_sym_pure,
  [anon_sym_public] = anon_sym_public,
  [anon_sym_private] = anon_sym_private,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_changed] = anon_sym_changed,
  [anon_sym_ATimage_DASHurl] = anon_sym_ATimage_DASHurl,
  [anon_sym_nine_DASHslice] = anon_sym_nine_DASHslice,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [sym__unescaped_string_fragment] = sym__unescaped_string_fragment,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [aux_sym_escape_sequence_token1] = aux_sym_escape_sequence_token1,
  [anon_sym_n] = anon_sym_n,
  [anon_sym_in_DASHout] = anon_sym_in_DASHout,
  [sym__identifier] = sym__identifier,
  [anon_sym_int] = anon_sym_int,
  [anon_sym_float] = anon_sym_float,
  [anon_sym_bool] = anon_sym_bool,
  [anon_sym_string] = anon_sym_string,
  [anon_sym_color] = anon_sym_color,
  [anon_sym_brush] = anon_sym_brush,
  [anon_sym_physical_DASHlength] = anon_sym_physical_DASHlength,
  [anon_sym_length] = anon_sym_length,
  [anon_sym_angle] = anon_sym_angle,
  [anon_sym_percent] = anon_sym_percent,
  [anon_sym_image] = anon_sym_image,
  [anon_sym_relative_DASHfont_DASHsize] = anon_sym_relative_DASHfont_DASHsize,
  [anon_sym_linear] = anon_sym_linear,
  [anon_sym_ease_DASHin_DASHquad] = anon_sym_ease_DASHin_DASHquad,
  [anon_sym_ease_DASHout_DASHquad] = anon_sym_ease_DASHout_DASHquad,
  [anon_sym_ease_DASHin_DASHout_DASHquad] = anon_sym_ease_DASHin_DASHout_DASHquad,
  [anon_sym_ease] = anon_sym_ease,
  [anon_sym_ease_DASHin] = anon_sym_ease_DASHin,
  [anon_sym_ease_DASHout] = anon_sym_ease_DASHout,
  [anon_sym_ease_DASHin_DASHout] = anon_sym_ease_DASHin_DASHout,
  [anon_sym_ease_DASHin_DASHquart] = anon_sym_ease_DASHin_DASHquart,
  [anon_sym_ease_DASHout_DASHquart] = anon_sym_ease_DASHout_DASHquart,
  [anon_sym_ease_DASHin_DASHout_DASHquart] = anon_sym_ease_DASHin_DASHout_DASHquart,
  [anon_sym_ease_DASHin_DASHquint] = anon_sym_ease_DASHin_DASHquint,
  [anon_sym_ease_DASHout_DASHquint] = anon_sym_ease_DASHout_DASHquint,
  [anon_sym_ease_DASHin_DASHout_DASHquint] = anon_sym_ease_DASHin_DASHout_DASHquint,
  [anon_sym_ease_DASHin_DASHexpo] = anon_sym_ease_DASHin_DASHexpo,
  [anon_sym_ease_DASHout_DASHexpo] = anon_sym_ease_DASHout_DASHexpo,
  [anon_sym_ease_DASHin_DASHout_DASHexpo] = anon_sym_ease_DASHin_DASHout_DASHexpo,
  [anon_sym_ease_DASHin_DASHsine] = anon_sym_ease_DASHin_DASHsine,
  [anon_sym_ease_DASHout_DASHsine] = anon_sym_ease_DASHout_DASHsine,
  [anon_sym_ease_DASHin_DASHout_DASHsine] = anon_sym_ease_DASHin_DASHout_DASHsine,
  [anon_sym_ease_DASHin_DASHback] = anon_sym_ease_DASHin_DASHback,
  [anon_sym_ease_DASHout_DASHback] = anon_sym_ease_DASHout_DASHback,
  [anon_sym_ease_DASHin_DASHout_DASHback] = anon_sym_ease_DASHin_DASHout_DASHback,
  [anon_sym_ease_DASHin_DASHcirc] = anon_sym_ease_DASHin_DASHcirc,
  [anon_sym_ease_DASHout_DASHcirc] = anon_sym_ease_DASHout_DASHcirc,
  [anon_sym_ease_DASHin_DASHout_DASHcirc] = anon_sym_ease_DASHin_DASHout_DASHcirc,
  [anon_sym_ease_DASHin_DASHelastic] = anon_sym_ease_DASHin_DASHelastic,
  [anon_sym_ease_DASHout_DASHelastic] = anon_sym_ease_DASHout_DASHelastic,
  [anon_sym_ease_DASHin_DASHout_DASHelastic] = anon_sym_ease_DASHin_DASHout_DASHelastic,
  [anon_sym_ease_DASHin_DASHbounce] = anon_sym_ease_DASHin_DASHbounce,
  [anon_sym_ease_DASHout_DASHbounce] = anon_sym_ease_DASHout_DASHbounce,
  [anon_sym_ease_DASHin_DASHout_DASHbounce] = anon_sym_ease_DASHin_DASHout_DASHbounce,
  [anon_sym_cubic_DASHbezier] = anon_sym_cubic_DASHbezier,
  [sym_children_identifier] = sym_children_identifier,
  [anon_sym_ATlinear_DASHgradient] = anon_sym_ATlinear_DASHgradient,
  [anon_sym_ATlinear_gradient] = anon_sym_ATlinear_gradient,
  [anon_sym_ATradial_DASHgradient] = anon_sym_ATradial_DASHgradient,
  [anon_sym_ATradial_gradient] = anon_sym_ATradial_gradient,
  [anon_sym_circle] = anon_sym_circle,
  [anon_sym_parent] = anon_sym_parent,
  [anon_sym_root] = anon_sym_root,
  [anon_sym_self] = anon_sym_self,
  [sym__int_number] = sym__int_number,
  [sym__float_number] = sym__float_number,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [sym_color_value] = sym_color_value,
  [anon_sym_phx] = anon_sym_phx,
  [aux_sym_length_value_token1] = aux_sym_length_value_token1,
  [aux_sym_duration_value_token1] = aux_sym_duration_value_token1,
  [aux_sym_angle_value_token1] = aux_sym_angle_value_token1,
  [anon_sym_PERCENT2] = anon_sym_PERCENT,
  [anon_sym_rem] = anon_sym_rem,
  [sym_comment] = sym_comment,
  [sym_sourcefile] = sym_sourcefile,
  [sym__definition] = sym__definition,
  [sym__local_type] = sym__local_type,
  [sym__exported_type] = sym__exported_type,
  [sym_import_statement] = sym_import_statement,
  [sym_export_type] = sym_export_type,
  [sym_import_type] = sym_import_type,
  [sym_component] = sym_component,
  [sym_component_definition] = sym_component_definition,
  [sym__property_type] = sym__property_type,
  [sym_imperative_block] = sym_imperative_block,
  [sym__imperative_block_statement] = sym__imperative_block_statement,
  [sym__binding] = sym__binding,
  [sym_property] = sym_property,
  [sym_binding_alias] = sym_binding_alias,
  [sym_binding] = sym_binding,
  [sym_global_block] = sym_global_block,
  [sym_global_definition] = sym_global_definition,
  [sym_struct_block] = sym_struct_block,
  [sym_struct_definition] = sym_struct_definition,
  [sym_enum_block] = sym_enum_block,
  [sym_enum_definition] = sym_enum_definition,
  [sym_anon_struct_block] = sym_anon_struct_block,
  [sym_block] = sym_block,
  [sym__block_statement] = sym__block_statement,
  [sym_property_assignment] = sym_property_assignment,
  [sym_in_out_transition] = sym_in_out_transition,
  [sym_transitions_definition] = sym_transitions_definition,
  [sym_states_definition] = sym_states_definition,
  [sym_animate_statement] = sym_animate_statement,
  [sym_animate_option_identifier] = sym_animate_option_identifier,
  [sym_animate_option] = sym_animate_option,
  [sym_animate_body] = sym_animate_body,
  [sym_if_expr] = sym_if_expr,
  [sym_if_statement] = sym_if_statement,
  [sym_for_loop] = sym_for_loop,
  [sym_for_range] = sym_for_range,
  [sym_type_list] = sym_type_list,
  [sym_type] = sym_type,
  [sym__assignment_setup] = sym__assignment_setup,
  [sym__assignment_value_block] = sym__assignment_value_block,
  [sym_assignment_block] = sym_assignment_block,
  [sym_assignment_expr] = sym_assignment_expr,
  [sym_expression] = sym_expression,
  [sym_parens_op] = sym_parens_op,
  [sym_index_op] = sym_index_op,
  [sym_tr] = sym_tr,
  [sym_member_access] = sym_member_access,
  [sym_unary_expression] = sym_unary_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym__add_binary_expression] = sym__add_binary_expression,
  [sym__comparison_binary_expression] = sym__comparison_binary_expression,
  [sym__logic_binary_expression] = sym__logic_binary_expression,
  [sym__mult_binary_expression] = sym__mult_binary_expression,
  [sym_ternary_expression] = sym_ternary_expression,
  [sym_callback] = sym_callback,
  [sym_purity] = sym_purity,
  [sym_function_visibility] = sym_function_visibility,
  [sym_function_definition] = sym_function_definition,
  [sym_callback_alias] = sym_callback_alias,
  [sym_callback_event] = sym_callback_event,
  [sym_changed_callback] = sym_changed_callback,
  [sym_function_call] = sym_function_call,
  [sym_gradient_call] = sym_gradient_call,
  [sym_gradient_color] = sym_gradient_color,
  [sym_image_call] = sym_image_call,
  [sym_typed_identifier] = sym_typed_identifier,
  [sym__function_signature] = sym__function_signature,
  [sym__callback_signature] = sym__callback_signature,
  [sym_argument] = sym_argument,
  [sym_arguments] = sym_arguments,
  [sym_unary_prec_operator] = sym_unary_prec_operator,
  [sym_add_prec_operator] = sym_add_prec_operator,
  [sym_mult_prec_operator] = sym_mult_prec_operator,
  [sym_comparison_operator] = sym_comparison_operator,
  [sym_assignment_prec_operator] = sym_assignment_prec_operator,
  [sym__string] = sym__string,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_property_visibility] = sym_property_visibility,
  [sym_simple_identifier] = sym_simple_identifier,
  [sym_simple_indexed_identifier] = sym_simple_indexed_identifier,
  [sym_builtin_type_identifier] = sym_builtin_type_identifier,
  [sym_easing_kind_identifier] = sym_easing_kind_identifier,
  [sym_user_type_identifier] = sym_user_type_identifier,
  [sym__type_identifier] = sym__type_identifier,
  [sym_value_list] = sym_value_list,
  [sym_value] = sym_value,
  [sym_linear_gradient_identifier] = sym_linear_gradient_identifier,
  [sym_radial_gradient_identifier] = sym_radial_gradient_identifier,
  [sym_radial_gradient_kind] = sym_radial_gradient_kind,
  [sym_reference_identifier] = sym_reference_identifier,
  [sym__number] = sym__number,
  [sym_int_value] = sym_int_value,
  [sym_float_value] = sym_float_value,
  [sym_bool_value] = sym_bool_value,
  [sym_string_value] = sym_string_value,
  [sym_physical_length_value] = sym_physical_length_value,
  [sym_length_value] = sym_length_value,
  [sym_duration_value] = sym_duration_value,
  [sym_angle_value] = sym_angle_value,
  [sym_percent_value] = sym_percent_value,
  [sym_relative_font_size_value] = sym_relative_font_size_value,
  [sym__basic_value] = sym__basic_value,
  [aux_sym_sourcefile_repeat1] = aux_sym_sourcefile_repeat1,
  [aux_sym__exported_type_repeat1] = aux_sym__exported_type_repeat1,
  [aux_sym_import_statement_repeat1] = aux_sym_import_statement_repeat1,
  [aux_sym_imperative_block_repeat1] = aux_sym_imperative_block_repeat1,
  [aux_sym_global_block_repeat1] = aux_sym_global_block_repeat1,
  [aux_sym_struct_block_repeat1] = aux_sym_struct_block_repeat1,
  [aux_sym_enum_block_repeat1] = aux_sym_enum_block_repeat1,
  [aux_sym_anon_struct_block_repeat1] = aux_sym_anon_struct_block_repeat1,
  [aux_sym_block_repeat1] = aux_sym_block_repeat1,
  [aux_sym_in_out_transition_repeat1] = aux_sym_in_out_transition_repeat1,
  [aux_sym_transitions_definition_repeat1] = aux_sym_transitions_definition_repeat1,
  [aux_sym_states_definition_repeat1] = aux_sym_states_definition_repeat1,
  [aux_sym_states_definition_repeat2] = aux_sym_states_definition_repeat2,
  [aux_sym_animate_body_repeat1] = aux_sym_animate_body_repeat1,
  [aux_sym_type_list_repeat1] = aux_sym_type_list_repeat1,
  [aux_sym_tr_repeat1] = aux_sym_tr_repeat1,
  [aux_sym_function_definition_repeat1] = aux_sym_function_definition_repeat1,
  [aux_sym_gradient_call_repeat1] = aux_sym_gradient_call_repeat1,
  [aux_sym_image_call_repeat1] = aux_sym_image_call_repeat1,
  [aux_sym__function_signature_repeat1] = aux_sym__function_signature_repeat1,
  [aux_sym_arguments_repeat1] = aux_sym_arguments_repeat1,
  [aux_sym__string_repeat1] = aux_sym__string_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_export] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_from] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_component] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_inherits] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_property] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_out] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_transitions] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_states] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_when] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_animate] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_delay] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_duration] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_iteration_DASHcount] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_direction] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_easing] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATtr] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [sym_logical_and] = {
    .visible = true,
    .named = true,
  },
  [sym_logical_or] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_callback] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pure] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_public] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_private] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_changed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATimage_DASHurl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nine_DASHslice] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym__unescaped_string_fragment] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_escape_sequence_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_n] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in_DASHout] = {
    .visible = true,
    .named = false,
  },
  [sym__identifier] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_int] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_float] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bool] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_string] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_color] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_brush] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_physical_DASHlength] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_length] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_angle] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_percent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_image] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_relative_DASHfont_DASHsize] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_linear] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHquad] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHout_DASHquad] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHout_DASHquad] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHout] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHout] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHquart] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHout_DASHquart] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHout_DASHquart] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHquint] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHout_DASHquint] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHout_DASHquint] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHexpo] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHout_DASHexpo] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHout_DASHexpo] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHsine] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHout_DASHsine] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHout_DASHsine] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHback] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHout_DASHback] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHout_DASHback] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHcirc] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHout_DASHcirc] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHout_DASHcirc] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHelastic] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHout_DASHelastic] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHout_DASHelastic] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHbounce] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHout_DASHbounce] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ease_DASHin_DASHout_DASHbounce] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cubic_DASHbezier] = {
    .visible = true,
    .named = false,
  },
  [sym_children_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_ATlinear_DASHgradient] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATlinear_gradient] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATradial_DASHgradient] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATradial_gradient] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_circle] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_parent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_root] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_self] = {
    .visible = true,
    .named = false,
  },
  [sym__int_number] = {
    .visible = false,
    .named = true,
  },
  [sym__float_number] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [sym_color_value] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_phx] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_length_value_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_duration_value_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_angle_value_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_PERCENT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rem] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_sourcefile] = {
    .visible = true,
    .named = true,
  },
  [sym__definition] = {
    .visible = false,
    .named = true,
  },
  [sym__local_type] = {
    .visible = false,
    .named = true,
  },
  [sym__exported_type] = {
    .visible = false,
    .named = true,
  },
  [sym_import_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_export_type] = {
    .visible = true,
    .named = true,
  },
  [sym_import_type] = {
    .visible = true,
    .named = true,
  },
  [sym_component] = {
    .visible = true,
    .named = true,
  },
  [sym_component_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__property_type] = {
    .visible = false,
    .named = true,
  },
  [sym_imperative_block] = {
    .visible = true,
    .named = true,
  },
  [sym__imperative_block_statement] = {
    .visible = false,
    .named = true,
  },
  [sym__binding] = {
    .visible = false,
    .named = true,
  },
  [sym_property] = {
    .visible = true,
    .named = true,
  },
  [sym_binding_alias] = {
    .visible = true,
    .named = true,
  },
  [sym_binding] = {
    .visible = true,
    .named = true,
  },
  [sym_global_block] = {
    .visible = true,
    .named = true,
  },
  [sym_global_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_block] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_block] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_anon_struct_block] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym__block_statement] = {
    .visible = false,
    .named = true,
  },
  [sym_property_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_in_out_transition] = {
    .visible = true,
    .named = true,
  },
  [sym_transitions_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_states_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_animate_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_animate_option_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_animate_option] = {
    .visible = true,
    .named = true,
  },
  [sym_animate_body] = {
    .visible = true,
    .named = true,
  },
  [sym_if_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_loop] = {
    .visible = true,
    .named = true,
  },
  [sym_for_range] = {
    .visible = true,
    .named = true,
  },
  [sym_type_list] = {
    .visible = true,
    .named = true,
  },
  [sym_type] = {
    .visible = true,
    .named = true,
  },
  [sym__assignment_setup] = {
    .visible = false,
    .named = true,
  },
  [sym__assignment_value_block] = {
    .visible = false,
    .named = true,
  },
  [sym_assignment_block] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parens_op] = {
    .visible = true,
    .named = true,
  },
  [sym_index_op] = {
    .visible = true,
    .named = true,
  },
  [sym_tr] = {
    .visible = true,
    .named = true,
  },
  [sym_member_access] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__add_binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__comparison_binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__logic_binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__mult_binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_ternary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_callback] = {
    .visible = true,
    .named = true,
  },
  [sym_purity] = {
    .visible = true,
    .named = true,
  },
  [sym_function_visibility] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_callback_alias] = {
    .visible = true,
    .named = true,
  },
  [sym_callback_event] = {
    .visible = true,
    .named = true,
  },
  [sym_changed_callback] = {
    .visible = true,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_gradient_call] = {
    .visible = true,
    .named = true,
  },
  [sym_gradient_color] = {
    .visible = true,
    .named = true,
  },
  [sym_image_call] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__function_signature] = {
    .visible = false,
    .named = true,
  },
  [sym__callback_signature] = {
    .visible = false,
    .named = true,
  },
  [sym_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_prec_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_add_prec_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_mult_prec_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_prec_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__string] = {
    .visible = false,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_property_visibility] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_indexed_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_builtin_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_easing_kind_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_user_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__type_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_value_list] = {
    .visible = true,
    .named = true,
  },
  [sym_value] = {
    .visible = true,
    .named = true,
  },
  [sym_linear_gradient_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_radial_gradient_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_radial_gradient_kind] = {
    .visible = true,
    .named = true,
  },
  [sym_reference_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__number] = {
    .visible = false,
    .named = true,
  },
  [sym_int_value] = {
    .visible = true,
    .named = true,
  },
  [sym_float_value] = {
    .visible = true,
    .named = true,
  },
  [sym_bool_value] = {
    .visible = true,
    .named = true,
  },
  [sym_string_value] = {
    .visible = true,
    .named = true,
  },
  [sym_physical_length_value] = {
    .visible = true,
    .named = true,
  },
  [sym_length_value] = {
    .visible = true,
    .named = true,
  },
  [sym_duration_value] = {
    .visible = true,
    .named = true,
  },
  [sym_angle_value] = {
    .visible = true,
    .named = true,
  },
  [sym_percent_value] = {
    .visible = true,
    .named = true,
  },
  [sym_relative_font_size_value] = {
    .visible = true,
    .named = true,
  },
  [sym__basic_value] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_sourcefile_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__exported_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_import_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_imperative_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_global_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_anon_struct_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_in_out_transition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_transitions_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_states_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_states_definition_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_animate_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gradient_call_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_image_call_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__function_signature_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__string_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_action = 1,
  field_alias = 2,
  field_angle = 3,
  field_arguments = 4,
  field_base = 5,
  field_base_type = 6,
  field_binding = 7,
  field_binding_op = 8,
  field_colors = 9,
  field_condition = 10,
  field_context = 11,
  field_export_name = 12,
  field_expression = 13,
  field_id = 14,
  field_identifier = 15,
  field_image = 16,
  field_import_name = 17,
  field_index = 18,
  field_index_var = 19,
  field_left = 20,
  field_local_name = 21,
  field_member = 22,
  field_message = 23,
  field_name = 24,
  field_op = 25,
  field_option = 26,
  field_percent = 27,
  field_pipe = 28,
  field_property = 29,
  field_range = 30,
  field_return_type = 31,
  field_right = 32,
  field_type = 33,
  field_value = 34,
  field_visibility = 35,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_action] = "action",
  [field_alias] = "alias",
  [field_angle] = "angle",
  [field_arguments] = "arguments",
  [field_base] = "base",
  [field_base_type] = "base_type",
  [field_binding] = "binding",
  [field_binding_op] = "binding_op",
  [field_colors] = "colors",
  [field_condition] = "condition",
  [field_context] = "context",
  [field_export_name] = "export_name",
  [field_expression] = "expression",
  [field_id] = "id",
  [field_identifier] = "identifier",
  [field_image] = "image",
  [field_import_name] = "import_name",
  [field_index] = "index",
  [field_index_var] = "index_var",
  [field_left] = "left",
  [field_local_name] = "local_name",
  [field_member] = "member",
  [field_message] = "message",
  [field_name] = "name",
  [field_op] = "op",
  [field_option] = "option",
  [field_percent] = "percent",
  [field_pipe] = "pipe",
  [field_property] = "property",
  [field_range] = "range",
  [field_return_type] = "return_type",
  [field_right] = "right",
  [field_type] = "type",
  [field_value] = "value",
  [field_visibility] = "visibility",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 1},
  [5] = {.index = 4, .length = 2},
  [6] = {.index = 6, .length = 2},
  [7] = {.index = 8, .length = 2},
  [8] = {.index = 10, .length = 3},
  [9] = {.index = 13, .length = 1},
  [10] = {.index = 14, .length = 2},
  [11] = {.index = 16, .length = 1},
  [12] = {.index = 17, .length = 2},
  [13] = {.index = 19, .length = 2},
  [14] = {.index = 21, .length = 2},
  [15] = {.index = 23, .length = 2},
  [16] = {.index = 25, .length = 2},
  [17] = {.index = 27, .length = 2},
  [18] = {.index = 29, .length = 1},
  [19] = {.index = 30, .length = 2},
  [20] = {.index = 32, .length = 3},
  [21] = {.index = 35, .length = 1},
  [22] = {.index = 36, .length = 2},
  [23] = {.index = 38, .length = 1},
  [24] = {.index = 39, .length = 1},
  [25] = {.index = 40, .length = 2},
  [26] = {.index = 42, .length = 2},
  [27] = {.index = 44, .length = 1},
  [28] = {.index = 45, .length = 2},
  [29] = {.index = 47, .length = 3},
  [30] = {.index = 50, .length = 2},
  [31] = {.index = 52, .length = 2},
  [32] = {.index = 54, .length = 1},
  [33] = {.index = 55, .length = 2},
  [34] = {.index = 57, .length = 2},
  [35] = {.index = 59, .length = 1},
  [36] = {.index = 60, .length = 4},
  [37] = {.index = 64, .length = 2},
  [38] = {.index = 66, .length = 2},
  [39] = {.index = 68, .length = 1},
  [40] = {.index = 69, .length = 2},
  [41] = {.index = 71, .length = 3},
  [42] = {.index = 74, .length = 3},
  [43] = {.index = 77, .length = 2},
  [44] = {.index = 79, .length = 2},
  [45] = {.index = 81, .length = 3},
  [46] = {.index = 84, .length = 3},
  [47] = {.index = 87, .length = 4},
  [48] = {.index = 91, .length = 4},
  [49] = {.index = 95, .length = 3},
  [50] = {.index = 98, .length = 2},
  [51] = {.index = 100, .length = 3},
  [52] = {.index = 103, .length = 2},
  [53] = {.index = 105, .length = 2},
  [54] = {.index = 107, .length = 3},
  [55] = {.index = 110, .length = 2},
  [56] = {.index = 112, .length = 2},
  [57] = {.index = 114, .length = 2},
  [58] = {.index = 116, .length = 2},
  [59] = {.index = 118, .length = 2},
  [60] = {.index = 120, .length = 5},
  [61] = {.index = 125, .length = 3},
  [62] = {.index = 128, .length = 3},
  [63] = {.index = 131, .length = 3},
  [64] = {.index = 134, .length = 2},
  [65] = {.index = 136, .length = 3},
  [66] = {.index = 139, .length = 3},
  [67] = {.index = 142, .length = 4},
  [68] = {.index = 146, .length = 4},
  [69] = {.index = 150, .length = 5},
  [70] = {.index = 155, .length = 5},
  [71] = {.index = 160, .length = 3},
  [72] = {.index = 163, .length = 6},
  [73] = {.index = 169, .length = 6},
  [74] = {.index = 175, .length = 6},
  [75] = {.index = 181, .length = 7},
  [76] = {.index = 188, .length = 7},
  [77] = {.index = 195, .length = 7},
  [78] = {.index = 202, .length = 7},
  [79] = {.index = 209, .length = 7},
  [80] = {.index = 216, .length = 5},
  [81] = {.index = 221, .length = 5},
  [82] = {.index = 226, .length = 8},
  [83] = {.index = 234, .length = 8},
  [84] = {.index = 242, .length = 6},
  [85] = {.index = 248, .length = 7},
  [86] = {.index = 255, .length = 7},
  [87] = {.index = 262, .length = 8},
  [88] = {.index = 270, .length = 9},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_local_name, 0},
  [1] =
    {field_import_name, 0},
  [2] =
    {field_name, 1},
  [3] =
    {field_value, 0},
  [4] =
    {field_base_type, 2},
    {field_name, 0},
  [6] =
    {field_export_name, 2},
    {field_local_name, 0},
  [8] =
    {field_import_name, 0},
    {field_local_name, 2},
  [10] =
    {field_left, 0, .inherited = true},
    {field_op, 0, .inherited = true},
    {field_right, 0, .inherited = true},
  [13] =
    {field_name, 0},
  [14] =
    {field_arguments, 1},
    {field_name, 0},
  [16] =
    {field_type, 0},
  [17] =
    {field_base_type, 3},
    {field_name, 1},
  [19] =
    {field_left, 1},
    {field_op, 0},
  [21] =
    {field_action, 2},
    {field_name, 0},
  [23] =
    {field_property, 0},
    {field_value, 2},
  [25] =
    {field_name, 1},
    {field_name, 2, .inherited = true},
  [27] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [29] =
    {field_left, 1},
  [30] =
    {field_base, 0},
    {field_member, 2},
  [32] =
    {field_left, 0},
    {field_op, 1},
    {field_right, 2},
  [35] =
    {field_type, 1},
  [36] =
    {field_name, 2},
    {field_type, 1, .inherited = true},
  [38] =
    {field_name, 2, .inherited = true},
  [39] =
    {field_condition, 1},
  [40] =
    {field_arguments, 2, .inherited = true},
    {field_name, 1},
  [42] =
    {field_action, 3},
    {field_name, 1},
  [44] =
    {field_name, 2},
  [45] =
    {field_id, 0},
    {field_type, 2},
  [47] =
    {field_property, 0},
    {field_value, 2},
    {field_value, 3},
  [50] =
    {field_alias, 2},
    {field_name, 0},
  [52] =
    {field_name, 1},
    {field_type, 3},
  [54] =
    {field_message, 2},
  [55] =
    {field_image, 2},
    {field_name, 0},
  [57] =
    {field_index, 2},
    {field_left, 0},
  [59] =
    {field_binding, 0},
  [60] =
    {field_binding, 4, .inherited = true},
    {field_binding_op, 3},
    {field_name, 2},
    {field_type, 1, .inherited = true},
  [64] =
    {field_alias, 3},
    {field_name, 1},
  [66] =
    {field_index_var, 2},
    {field_name, 0},
  [68] =
    {field_arguments, 1},
  [69] =
    {field_name, 1},
    {field_return_type, 3},
  [71] =
    {field_name, 0, .inherited = true},
    {field_op, 0, .inherited = true},
    {field_value, 1, .inherited = true},
  [74] =
    {field_name, 0, .inherited = true},
    {field_op, 0, .inherited = true},
    {field_value, 1},
  [77] =
    {field_name, 0},
    {field_op, 1},
  [79] =
    {field_arguments, 3, .inherited = true},
    {field_name, 2},
  [81] =
    {field_name, 3},
    {field_type, 2, .inherited = true},
    {field_visibility, 0},
  [84] =
    {field_alias, 3},
    {field_name, 1},
    {field_visibility, 0},
  [87] =
    {field_name, 1},
    {field_name, 4, .inherited = true},
    {field_type, 3},
    {field_type, 4, .inherited = true},
  [91] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type, 0, .inherited = true},
    {field_type, 1, .inherited = true},
  [95] =
    {field_condition, 0},
    {field_left, 2},
    {field_right, 4},
  [98] =
    {field_binding, 0},
    {field_binding, 1},
  [100] =
    {field_binding_op, 3},
    {field_name, 2},
    {field_type, 1, .inherited = true},
  [103] =
    {field_identifier, 1},
    {field_range, 3},
  [105] =
    {field_arguments, 1},
    {field_arguments, 2},
  [107] =
    {field_arguments, 2, .inherited = true},
    {field_name, 1},
    {field_return_type, 4},
  [110] =
    {field_value, 0},
    {field_value, 1},
  [112] =
    {field_binding, 2, .inherited = true},
    {field_name, 0},
  [114] =
    {field_name, 0},
    {field_type, 2},
  [116] =
    {field_alias, 4},
    {field_name, 2},
  [118] =
    {field_name, 2},
    {field_return_type, 4},
  [120] =
    {field_binding, 5, .inherited = true},
    {field_binding_op, 4},
    {field_name, 3},
    {field_type, 2, .inherited = true},
    {field_visibility, 0},
  [125] =
    {field_alias, 4},
    {field_name, 2},
    {field_visibility, 0},
  [128] =
    {field_arguments, 3},
    {field_arguments, 4},
    {field_message, 2},
  [131] =
    {field_context, 2},
    {field_context, 3},
    {field_message, 4},
  [134] =
    {field_expression, 2},
    {field_option, 0},
  [136] =
    {field_arguments, 1},
    {field_arguments, 2},
    {field_arguments, 3},
  [139] =
    {field_arguments, 3, .inherited = true},
    {field_name, 2},
    {field_return_type, 5},
  [142] =
    {field_binding_op, 4},
    {field_name, 3},
    {field_type, 2, .inherited = true},
    {field_visibility, 0},
  [146] =
    {field_arguments, 3},
    {field_arguments, 4},
    {field_arguments, 5},
    {field_message, 2},
  [150] =
    {field_arguments, 3},
    {field_arguments, 4},
    {field_arguments, 5},
    {field_arguments, 6},
    {field_message, 2},
  [155] =
    {field_arguments, 5},
    {field_arguments, 6},
    {field_context, 2},
    {field_context, 3},
    {field_message, 4},
  [160] =
    {field_message, 2},
    {field_percent, 6},
    {field_pipe, 4},
  [163] =
    {field_angle, 2},
    {field_arguments, 3},
    {field_colors, 4},
    {field_colors, 5},
    {field_colors, 6},
    {field_name, 0},
  [169] =
    {field_arguments, 3},
    {field_colors, 4},
    {field_colors, 5},
    {field_colors, 6},
    {field_name, 0},
    {field_type, 2},
  [175] =
    {field_arguments, 5},
    {field_arguments, 6},
    {field_arguments, 7},
    {field_context, 2},
    {field_context, 3},
    {field_message, 4},
  [181] =
    {field_angle, 2},
    {field_arguments, 3},
    {field_arguments, 7},
    {field_colors, 4},
    {field_colors, 5},
    {field_colors, 6},
    {field_name, 0},
  [188] =
    {field_angle, 2},
    {field_arguments, 3},
    {field_colors, 4},
    {field_colors, 5},
    {field_colors, 6},
    {field_colors, 7},
    {field_name, 0},
  [195] =
    {field_arguments, 3},
    {field_arguments, 7},
    {field_colors, 4},
    {field_colors, 5},
    {field_colors, 6},
    {field_name, 0},
    {field_type, 2},
  [202] =
    {field_arguments, 3},
    {field_colors, 4},
    {field_colors, 5},
    {field_colors, 6},
    {field_colors, 7},
    {field_name, 0},
    {field_type, 2},
  [209] =
    {field_arguments, 5},
    {field_arguments, 6},
    {field_arguments, 7},
    {field_arguments, 8},
    {field_context, 2},
    {field_context, 3},
    {field_message, 4},
  [216] =
    {field_context, 2},
    {field_context, 3},
    {field_message, 4},
    {field_percent, 8},
    {field_pipe, 6},
  [221] =
    {field_arguments, 7},
    {field_arguments, 8},
    {field_message, 2},
    {field_percent, 6},
    {field_pipe, 4},
  [226] =
    {field_angle, 2},
    {field_arguments, 3},
    {field_arguments, 8},
    {field_colors, 4},
    {field_colors, 5},
    {field_colors, 6},
    {field_colors, 7},
    {field_name, 0},
  [234] =
    {field_arguments, 3},
    {field_arguments, 8},
    {field_colors, 4},
    {field_colors, 5},
    {field_colors, 6},
    {field_colors, 7},
    {field_name, 0},
    {field_type, 2},
  [242] =
    {field_arguments, 7},
    {field_arguments, 8},
    {field_arguments, 9},
    {field_message, 2},
    {field_percent, 6},
    {field_pipe, 4},
  [248] =
    {field_arguments, 9},
    {field_arguments, 10},
    {field_context, 2},
    {field_context, 3},
    {field_message, 4},
    {field_percent, 8},
    {field_pipe, 6},
  [255] =
    {field_arguments, 7},
    {field_arguments, 8},
    {field_arguments, 9},
    {field_arguments, 10},
    {field_message, 2},
    {field_percent, 6},
    {field_pipe, 4},
  [262] =
    {field_arguments, 9},
    {field_arguments, 10},
    {field_arguments, 11},
    {field_context, 2},
    {field_context, 3},
    {field_message, 4},
    {field_percent, 8},
    {field_pipe, 6},
  [270] =
    {field_arguments, 9},
    {field_arguments, 10},
    {field_arguments, 11},
    {field_arguments, 12},
    {field_context, 2},
    {field_context, 3},
    {field_message, 4},
    {field_percent, 8},
    {field_pipe, 6},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 2,
  [5] = 2,
  [6] = 2,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 9,
  [11] = 9,
  [12] = 7,
  [13] = 9,
  [14] = 7,
  [15] = 7,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 22,
  [24] = 21,
  [25] = 20,
  [26] = 19,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 32,
  [34] = 29,
  [35] = 35,
  [36] = 36,
  [37] = 27,
  [38] = 38,
  [39] = 28,
  [40] = 35,
  [41] = 41,
  [42] = 42,
  [43] = 41,
  [44] = 44,
  [45] = 42,
  [46] = 46,
  [47] = 47,
  [48] = 36,
  [49] = 46,
  [50] = 47,
  [51] = 29,
  [52] = 30,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 53,
  [62] = 55,
  [63] = 63,
  [64] = 64,
  [65] = 63,
  [66] = 66,
  [67] = 67,
  [68] = 54,
  [69] = 56,
  [70] = 59,
  [71] = 66,
  [72] = 72,
  [73] = 57,
  [74] = 58,
  [75] = 72,
  [76] = 67,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 79,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 86,
  [106] = 88,
  [107] = 91,
  [108] = 92,
  [109] = 95,
  [110] = 110,
  [111] = 104,
  [112] = 86,
  [113] = 79,
  [114] = 88,
  [115] = 91,
  [116] = 92,
  [117] = 95,
  [118] = 110,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 110,
  [127] = 104,
  [128] = 128,
  [129] = 100,
  [130] = 122,
  [131] = 83,
  [132] = 132,
  [133] = 89,
  [134] = 96,
  [135] = 97,
  [136] = 101,
  [137] = 103,
  [138] = 119,
  [139] = 124,
  [140] = 125,
  [141] = 81,
  [142] = 84,
  [143] = 85,
  [144] = 93,
  [145] = 94,
  [146] = 99,
  [147] = 89,
  [148] = 132,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 170,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 194,
  [195] = 195,
  [196] = 196,
  [197] = 197,
  [198] = 198,
  [199] = 199,
  [200] = 200,
  [201] = 201,
  [202] = 202,
  [203] = 203,
  [204] = 204,
  [205] = 205,
  [206] = 206,
  [207] = 207,
  [208] = 208,
  [209] = 209,
  [210] = 210,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 216,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 225,
  [226] = 226,
  [227] = 227,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 230,
  [232] = 230,
  [233] = 228,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 238,
  [239] = 239,
  [240] = 240,
  [241] = 241,
  [242] = 242,
  [243] = 241,
  [244] = 244,
  [245] = 242,
  [246] = 246,
  [247] = 235,
  [248] = 237,
  [249] = 238,
  [250] = 236,
  [251] = 251,
  [252] = 252,
  [253] = 253,
  [254] = 239,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 261,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 265,
  [266] = 266,
  [267] = 267,
  [268] = 267,
  [269] = 267,
  [270] = 270,
  [271] = 271,
  [272] = 272,
  [273] = 270,
  [274] = 270,
  [275] = 270,
  [276] = 271,
  [277] = 228,
  [278] = 228,
  [279] = 166,
  [280] = 150,
  [281] = 149,
  [282] = 154,
  [283] = 176,
  [284] = 163,
  [285] = 160,
  [286] = 157,
  [287] = 173,
  [288] = 165,
  [289] = 172,
  [290] = 156,
  [291] = 158,
  [292] = 159,
  [293] = 152,
  [294] = 164,
  [295] = 153,
  [296] = 155,
  [297] = 162,
  [298] = 161,
  [299] = 200,
  [300] = 204,
  [301] = 206,
  [302] = 207,
  [303] = 208,
  [304] = 209,
  [305] = 210,
  [306] = 174,
  [307] = 175,
  [308] = 177,
  [309] = 178,
  [310] = 179,
  [311] = 180,
  [312] = 181,
  [313] = 182,
  [314] = 183,
  [315] = 184,
  [316] = 185,
  [317] = 186,
  [318] = 187,
  [319] = 188,
  [320] = 189,
  [321] = 190,
  [322] = 191,
  [323] = 192,
  [324] = 212,
  [325] = 193,
  [326] = 194,
  [327] = 214,
  [328] = 167,
  [329] = 195,
  [330] = 196,
  [331] = 197,
  [332] = 198,
  [333] = 199,
  [334] = 215,
  [335] = 225,
  [336] = 205,
  [337] = 216,
  [338] = 217,
  [339] = 218,
  [340] = 219,
  [341] = 220,
  [342] = 221,
  [343] = 228,
  [344] = 222,
  [345] = 223,
  [346] = 224,
  [347] = 168,
  [348] = 169,
  [349] = 170,
  [350] = 171,
  [351] = 202,
  [352] = 203,
  [353] = 201,
  [354] = 354,
  [355] = 355,
  [356] = 150,
  [357] = 149,
  [358] = 358,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 362,
  [363] = 363,
  [364] = 364,
  [365] = 365,
  [366] = 366,
  [367] = 367,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 366,
  [372] = 372,
  [373] = 373,
  [374] = 365,
  [375] = 364,
  [376] = 376,
  [377] = 370,
  [378] = 378,
  [379] = 154,
  [380] = 380,
  [381] = 159,
  [382] = 157,
  [383] = 163,
  [384] = 160,
  [385] = 165,
  [386] = 158,
  [387] = 387,
  [388] = 387,
  [389] = 156,
  [390] = 390,
  [391] = 391,
  [392] = 392,
  [393] = 393,
  [394] = 394,
  [395] = 395,
  [396] = 391,
  [397] = 392,
  [398] = 395,
  [399] = 399,
  [400] = 394,
  [401] = 393,
  [402] = 402,
  [403] = 402,
  [404] = 404,
  [405] = 405,
  [406] = 406,
  [407] = 407,
  [408] = 380,
  [409] = 227,
  [410] = 410,
  [411] = 411,
  [412] = 410,
  [413] = 405,
  [414] = 411,
  [415] = 415,
  [416] = 416,
  [417] = 417,
  [418] = 418,
  [419] = 419,
  [420] = 420,
  [421] = 421,
  [422] = 422,
  [423] = 423,
  [424] = 424,
  [425] = 425,
  [426] = 426,
  [427] = 416,
  [428] = 418,
  [429] = 419,
  [430] = 424,
  [431] = 431,
  [432] = 432,
  [433] = 433,
  [434] = 434,
  [435] = 423,
  [436] = 436,
  [437] = 425,
  [438] = 418,
  [439] = 439,
  [440] = 440,
  [441] = 246,
  [442] = 439,
  [443] = 432,
  [444] = 229,
  [445] = 445,
  [446] = 446,
  [447] = 235,
  [448] = 448,
  [449] = 426,
  [450] = 420,
  [451] = 433,
  [452] = 439,
  [453] = 453,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 457,
  [458] = 458,
  [459] = 459,
  [460] = 460,
  [461] = 461,
  [462] = 462,
  [463] = 463,
  [464] = 464,
  [465] = 465,
  [466] = 466,
  [467] = 467,
  [468] = 468,
  [469] = 469,
  [470] = 470,
  [471] = 471,
  [472] = 472,
  [473] = 251,
  [474] = 474,
  [475] = 255,
  [476] = 476,
  [477] = 477,
  [478] = 478,
  [479] = 479,
  [480] = 238,
  [481] = 481,
  [482] = 236,
  [483] = 483,
  [484] = 484,
  [485] = 485,
  [486] = 486,
  [487] = 487,
  [488] = 488,
  [489] = 472,
  [490] = 490,
  [491] = 491,
  [492] = 481,
  [493] = 493,
  [494] = 454,
  [495] = 495,
  [496] = 496,
  [497] = 497,
  [498] = 463,
  [499] = 499,
  [500] = 500,
  [501] = 501,
  [502] = 502,
  [503] = 503,
  [504] = 504,
  [505] = 505,
  [506] = 506,
  [507] = 507,
  [508] = 508,
  [509] = 509,
  [510] = 510,
  [511] = 511,
  [512] = 512,
  [513] = 513,
  [514] = 514,
  [515] = 515,
  [516] = 516,
  [517] = 517,
  [518] = 235,
  [519] = 246,
  [520] = 501,
  [521] = 484,
  [522] = 487,
  [523] = 453,
  [524] = 502,
  [525] = 476,
  [526] = 500,
  [527] = 455,
  [528] = 478,
  [529] = 251,
  [530] = 479,
  [531] = 462,
  [532] = 470,
  [533] = 486,
  [534] = 488,
  [535] = 490,
  [536] = 469,
  [537] = 497,
  [538] = 499,
  [539] = 466,
  [540] = 474,
  [541] = 255,
  [542] = 460,
  [543] = 509,
  [544] = 236,
  [545] = 506,
  [546] = 508,
  [547] = 461,
  [548] = 496,
  [549] = 549,
  [550] = 550,
  [551] = 551,
  [552] = 550,
  [553] = 551,
  [554] = 554,
  [555] = 555,
  [556] = 556,
  [557] = 557,
  [558] = 558,
  [559] = 238,
  [560] = 560,
  [561] = 561,
  [562] = 562,
  [563] = 563,
  [564] = 564,
  [565] = 565,
  [566] = 566,
  [567] = 567,
  [568] = 568,
  [569] = 569,
  [570] = 570,
  [571] = 571,
  [572] = 572,
  [573] = 573,
  [574] = 505,
  [575] = 575,
  [576] = 576,
  [577] = 577,
  [578] = 578,
  [579] = 579,
  [580] = 580,
  [581] = 581,
  [582] = 582,
  [583] = 583,
  [584] = 584,
  [585] = 582,
  [586] = 584,
  [587] = 587,
  [588] = 588,
  [589] = 589,
  [590] = 587,
  [591] = 591,
  [592] = 592,
  [593] = 593,
  [594] = 594,
  [595] = 595,
  [596] = 596,
  [597] = 597,
  [598] = 598,
  [599] = 599,
  [600] = 588,
  [601] = 601,
  [602] = 593,
  [603] = 603,
  [604] = 604,
  [605] = 603,
  [606] = 606,
  [607] = 606,
  [608] = 608,
  [609] = 609,
  [610] = 610,
  [611] = 611,
  [612] = 612,
  [613] = 613,
  [614] = 604,
  [615] = 615,
  [616] = 610,
  [617] = 617,
  [618] = 618,
  [619] = 619,
  [620] = 620,
  [621] = 621,
  [622] = 622,
  [623] = 623,
  [624] = 624,
  [625] = 621,
  [626] = 626,
  [627] = 627,
  [628] = 628,
  [629] = 629,
  [630] = 630,
  [631] = 631,
  [632] = 632,
  [633] = 633,
  [634] = 634,
  [635] = 634,
  [636] = 636,
  [637] = 637,
  [638] = 638,
  [639] = 639,
  [640] = 640,
  [641] = 641,
  [642] = 622,
  [643] = 643,
  [644] = 631,
  [645] = 645,
  [646] = 646,
  [647] = 647,
  [648] = 648,
  [649] = 649,
  [650] = 633,
  [651] = 649,
  [652] = 652,
  [653] = 643,
  [654] = 654,
  [655] = 655,
  [656] = 656,
  [657] = 657,
  [658] = 658,
  [659] = 659,
  [660] = 660,
  [661] = 661,
  [662] = 662,
  [663] = 663,
  [664] = 664,
  [665] = 665,
  [666] = 666,
  [667] = 667,
  [668] = 663,
  [669] = 669,
  [670] = 670,
  [671] = 256,
  [672] = 672,
  [673] = 664,
  [674] = 666,
  [675] = 675,
  [676] = 676,
  [677] = 258,
  [678] = 678,
  [679] = 679,
  [680] = 680,
  [681] = 681,
  [682] = 682,
  [683] = 683,
  [684] = 684,
  [685] = 685,
  [686] = 686,
  [687] = 687,
  [688] = 688,
  [689] = 689,
  [690] = 690,
  [691] = 691,
  [692] = 692,
  [693] = 687,
  [694] = 694,
  [695] = 695,
  [696] = 696,
  [697] = 697,
  [698] = 698,
  [699] = 699,
  [700] = 672,
  [701] = 701,
  [702] = 680,
  [703] = 703,
  [704] = 678,
  [705] = 705,
  [706] = 667,
  [707] = 707,
  [708] = 708,
  [709] = 682,
  [710] = 701,
  [711] = 711,
  [712] = 665,
  [713] = 713,
  [714] = 714,
  [715] = 715,
  [716] = 676,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 719,
  [721] = 721,
  [722] = 722,
  [723] = 723,
  [724] = 656,
  [725] = 725,
  [726] = 690,
  [727] = 727,
  [728] = 728,
  [729] = 685,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 733,
  [734] = 659,
  [735] = 257,
  [736] = 661,
  [737] = 737,
  [738] = 733,
  [739] = 713,
  [740] = 740,
  [741] = 660,
  [742] = 717,
  [743] = 662,
  [744] = 744,
  [745] = 745,
  [746] = 740,
  [747] = 692,
  [748] = 748,
  [749] = 749,
  [750] = 688,
  [751] = 751,
  [752] = 691,
  [753] = 753,
  [754] = 754,
  [755] = 755,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 761,
  [762] = 762,
  [763] = 467,
  [764] = 764,
  [765] = 765,
  [766] = 766,
  [767] = 767,
  [768] = 768,
  [769] = 769,
  [770] = 770,
  [771] = 771,
  [772] = 772,
  [773] = 757,
  [774] = 774,
  [775] = 775,
  [776] = 776,
  [777] = 491,
  [778] = 778,
  [779] = 779,
  [780] = 774,
  [781] = 781,
  [782] = 782,
  [783] = 783,
  [784] = 771,
  [785] = 785,
  [786] = 782,
  [787] = 787,
  [788] = 788,
  [789] = 789,
  [790] = 790,
  [791] = 772,
  [792] = 792,
  [793] = 793,
  [794] = 794,
  [795] = 795,
  [796] = 796,
  [797] = 797,
  [798] = 798,
  [799] = 799,
  [800] = 800,
  [801] = 801,
  [802] = 802,
  [803] = 803,
  [804] = 804,
  [805] = 754,
  [806] = 806,
  [807] = 807,
  [808] = 808,
  [809] = 766,
  [810] = 755,
  [811] = 811,
  [812] = 808,
  [813] = 759,
  [814] = 814,
  [815] = 797,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 785,
  [821] = 821,
  [822] = 822,
  [823] = 787,
  [824] = 824,
  [825] = 754,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 458,
  [834] = 778,
  [835] = 835,
  [836] = 836,
  [837] = 837,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 842,
  [843] = 843,
  [844] = 844,
  [845] = 845,
  [846] = 846,
  [847] = 847,
  [848] = 848,
  [849] = 849,
  [850] = 850,
  [851] = 851,
  [852] = 852,
  [853] = 853,
  [854] = 854,
  [855] = 855,
  [856] = 856,
  [857] = 856,
  [858] = 858,
  [859] = 859,
  [860] = 860,
  [861] = 861,
  [862] = 862,
  [863] = 863,
  [864] = 855,
  [865] = 865,
  [866] = 866,
  [867] = 867,
  [868] = 868,
  [869] = 869,
  [870] = 870,
  [871] = 871,
  [872] = 872,
  [873] = 848,
  [874] = 874,
  [875] = 875,
  [876] = 876,
  [877] = 877,
  [878] = 854,
  [879] = 879,
  [880] = 880,
  [881] = 881,
  [882] = 837,
  [883] = 883,
  [884] = 865,
  [885] = 842,
  [886] = 886,
  [887] = 887,
  [888] = 888,
  [889] = 889,
  [890] = 890,
  [891] = 891,
  [892] = 892,
  [893] = 893,
  [894] = 894,
  [895] = 895,
  [896] = 883,
  [897] = 897,
  [898] = 840,
  [899] = 852,
  [900] = 853,
  [901] = 901,
  [902] = 890,
  [903] = 871,
  [904] = 850,
  [905] = 905,
  [906] = 891,
  [907] = 892,
  [908] = 901,
  [909] = 909,
  [910] = 863,
  [911] = 911,
  [912] = 909,
  [913] = 866,
  [914] = 914,
  [915] = 915,
  [916] = 916,
  [917] = 874,
  [918] = 876,
  [919] = 869,
  [920] = 920,
  [921] = 845,
  [922] = 846,
  [923] = 889,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(445);
      ADVANCE_MAP(
        '!', 531,
        '"', 552,
        '#', 441,
        '%', 1013,
        '&', 18,
        '(', 503,
        ')', 504,
        '*', 538,
        '+', 536,
        ',', 449,
        '-', 534,
        '.', 511,
        '/', 540,
        ':', 470,
        ';', 454,
        '<', 461,
        '=', 547,
        '>', 464,
        '?', 514,
        '@', 101,
        '[', 484,
        '\\', 559,
        ']', 485,
        'a', 264,
        'b', 306,
        'c', 43,
        'd', 126,
        'e', 45,
        'f', 51,
        'g', 241,
        'i', 172,
        'l', 147,
        'm', 258,
        'n', 561,
        'o', 413,
        'p', 60,
        'r', 47,
        's', 1008,
        't', 333,
        'u', 437,
        'w', 193,
        '{', 448,
        '|', 508,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(443);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(995);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '!', 531,
        '"', 552,
        '#', 441,
        '%', 1013,
        '&', 18,
        '(', 503,
        ')', 504,
        '*', 538,
        '+', 536,
        ',', 449,
        '-', 533,
        '.', 511,
        '/', 540,
        ':', 469,
        ';', 454,
        '<', 462,
        '=', 547,
        '>', 464,
        '?', 514,
        '@', 195,
        '[', 484,
        'c', 872,
        'e', 568,
        'f', 575,
        'i', 666,
        'l', 698,
        'p', 579,
        'r', 654,
        's', 652,
        't', 806,
        '{', 448,
        '|', 438,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(995);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '!', 531,
        '"', 552,
        '#', 441,
        '%', 1013,
        '&', 18,
        '(', 503,
        '*', 538,
        '+', 536,
        '-', 533,
        '.', 511,
        '/', 540,
        ':', 469,
        ';', 454,
        '<', 462,
        '=', 546,
        '>', 464,
        '?', 514,
        '@', 195,
        '[', 484,
        'c', 728,
        'd', 641,
        'e', 568,
        'f', 575,
        'g', 808,
        'i', 664,
        'l', 698,
        'm', 727,
        'p', 578,
        'r', 570,
        's', 1009,
        't', 805,
        '{', 448,
        '|', 438,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(995);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '!', 531,
        '"', 552,
        '#', 441,
        '&', 18,
        '(', 503,
        ')', 504,
        '*', 538,
        '+', 536,
        ',', 449,
        '-', 533,
        '.', 511,
        '/', 540,
        ':', 469,
        ';', 454,
        '<', 462,
        '=', 547,
        '>', 464,
        '?', 514,
        '@', 195,
        '[', 484,
        'c', 872,
        'e', 568,
        'f', 575,
        'i', 666,
        'l', 698,
        'p', 579,
        'r', 654,
        's', 652,
        't', 806,
        '{', 448,
        '|', 438,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(995);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '!', 531,
        '"', 552,
        '#', 441,
        '&', 18,
        '(', 503,
        '*', 538,
        '+', 536,
        '-', 533,
        '.', 511,
        '/', 540,
        ':', 469,
        ';', 454,
        '<', 462,
        '=', 546,
        '>', 464,
        '?', 514,
        '@', 195,
        '[', 484,
        'c', 872,
        'e', 568,
        'f', 575,
        'i', 666,
        'l', 698,
        'p', 579,
        'r', 654,
        's', 652,
        't', 806,
        '{', 448,
        '|', 438,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(995);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '!', 531,
        '"', 552,
        '#', 441,
        '&', 18,
        '(', 503,
        '*', 537,
        '+', 535,
        '-', 532,
        '.', 511,
        '/', 539,
        ':', 469,
        ';', 454,
        '<', 462,
        '=', 38,
        '>', 464,
        '?', 514,
        '@', 195,
        '[', 484,
        'c', 872,
        'e', 568,
        'f', 575,
        'i', 738,
        'l', 698,
        'o', 881,
        'p', 579,
        'r', 775,
        's', 652,
        't', 806,
        '{', 448,
        '|', 438,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(5);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(995);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '!', 36,
        '%', 1013,
        '&', 18,
        ')', 504,
        '*', 538,
        '+', 536,
        ',', 449,
        '-', 533,
        '.', 510,
        '/', 540,
        ':', 469,
        ';', 454,
        '<', 462,
        '=', 546,
        '>', 464,
        '?', 514,
        '[', 484,
        ']', 485,
        'c', 257,
        'd', 152,
        'g', 354,
        'i', 265,
        'm', 258,
        'p', 191,
        'r', 48,
        's', 1007,
        't', 417,
        '{', 448,
        '|', 438,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '!', 36,
        '%', 1013,
        '&', 18,
        ')', 504,
        '*', 537,
        '+', 535,
        ',', 449,
        '-', 532,
        '.', 511,
        '/', 539,
        '<', 462,
        '=', 38,
        '>', 464,
        '?', 514,
        '[', 484,
        'c', 257,
        'd', 152,
        'g', 354,
        'i', 265,
        'm', 258,
        'p', 191,
        'r', 48,
        's', 1007,
        't', 417,
        '|', 438,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(995);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 36,
        '%', 509,
        '&', 18,
        ')', 504,
        '*', 538,
        '+', 536,
        ',', 449,
        '-', 533,
        '.', 510,
        '/', 540,
        ':', 469,
        ';', 454,
        '<', 462,
        '=', 547,
        '>', 464,
        '?', 514,
        '[', 484,
        ']', 485,
        'a', 745,
        'b', 780,
        'c', 784,
        'd', 880,
        'e', 595,
        'f', 716,
        'i', 730,
        'l', 658,
        'p', 661,
        'r', 655,
        's', 861,
        '{', 448,
        '|', 508,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '!', 36,
        '&', 18,
        '(', 503,
        ')', 504,
        '*', 538,
        '+', 536,
        ',', 449,
        '-', 534,
        '.', 510,
        '/', 540,
        ':', 469,
        ';', 454,
        '<', 461,
        '=', 547,
        '>', 464,
        '?', 514,
        '[', 484,
        ']', 485,
        'i', 266,
        'n', 220,
        'o', 413,
        'w', 193,
        '{', 448,
        '|', 438,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '!', 36,
        '&', 18,
        ')', 504,
        '*', 538,
        '+', 536,
        ',', 449,
        '-', 533,
        '.', 510,
        '/', 540,
        ':', 469,
        ';', 454,
        '<', 462,
        '=', 546,
        '>', 464,
        '?', 514,
        '[', 484,
        ']', 485,
        '{', 448,
        '|', 438,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '!', 36,
        '&', 18,
        ')', 504,
        '*', 537,
        '+', 535,
        ',', 449,
        '-', 532,
        '.', 511,
        '/', 539,
        '<', 462,
        '=', 38,
        '>', 464,
        '?', 514,
        '[', 484,
        '|', 438,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(995);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '!', 36,
        '&', 18,
        '*', 537,
        '+', 535,
        ',', 449,
        '-', 532,
        '.', 510,
        '/', 539,
        ';', 454,
        '<', 462,
        '=', 38,
        '>', 464,
        '?', 514,
        '@', 100,
        '[', 484,
        'a', 752,
        'c', 580,
        'f', 781,
        'i', 665,
        'o', 881,
        'p', 802,
        's', 858,
        't', 815,
        '|', 438,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '!', 36,
        '&', 18,
        '*', 537,
        '+', 535,
        '-', 532,
        '.', 510,
        '/', 539,
        ':', 469,
        '<', 462,
        '=', 38,
        '>', 464,
        '?', 514,
        '[', 484,
        ']', 485,
        'i', 266,
        'o', 413,
        '|', 438,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(13);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '!', 36,
        '&', 18,
        '*', 537,
        '+', 535,
        '-', 532,
        '.', 510,
        '/', 539,
        ';', 454,
        '<', 462,
        '=', 38,
        '>', 464,
        '?', 514,
        '[', 484,
        'c', 581,
        'f', 878,
        'i', 740,
        'o', 881,
        'p', 802,
        '|', 438,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '!', 530,
        '"', 552,
        '#', 441,
        '(', 503,
        ')', 504,
        '+', 535,
        ',', 449,
        '-', 532,
        '.', 440,
        '/', 21,
        ':', 470,
        ';', 454,
        '<', 39,
        '=', 41,
        '@', 195,
        '[', 484,
        ']', 485,
        'c', 872,
        'e', 568,
        'f', 575,
        'l', 698,
        'p', 579,
        'r', 775,
        's', 652,
        't', 806,
        '{', 448,
        '|', 507,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(995);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '!', 530,
        '"', 552,
        '#', 441,
        '(', 503,
        '+', 535,
        '-', 532,
        '.', 440,
        '/', 21,
        ';', 454,
        '@', 195,
        '[', 484,
        'c', 872,
        'e', 567,
        'f', 575,
        'i', 666,
        'l', 698,
        'p', 579,
        'r', 654,
        's', 652,
        't', 806,
        '{', 448,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(995);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 17:
      if (lookahead == '"') ADVANCE(552);
      if (lookahead == '/') ADVANCE(553);
      if (lookahead == '\\') ADVANCE(559);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(556);
      if (lookahead != 0) ADVANCE(558);
      END_STATE();
    case 18:
      if (lookahead == '&') ADVANCE(512);
      END_STATE();
    case 19:
      ADVANCE_MAP(
        '(', 503,
        ')', 504,
        ',', 449,
        '-', 40,
        '/', 21,
        ':', 37,
        ';', 454,
        '<', 39,
        '>', 463,
        ']', 485,
        'a', 362,
        'i', 299,
        '{', 448,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      END_STATE();
    case 20:
      if (lookahead == ')') ADVANCE(504);
      if (lookahead == ',') ADVANCE(449);
      if (lookahead == '/') ADVANCE(21);
      if (lookahead == '<') ADVANCE(460);
      if (lookahead == ']') ADVANCE(485);
      if (lookahead == '}') ADVANCE(450);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 21:
      if (lookahead == '*') ADVANCE(23);
      if (lookahead == '/') ADVANCE(1017);
      END_STATE();
    case 22:
      if (lookahead == '*') ADVANCE(22);
      if (lookahead == '/') ADVANCE(1016);
      if (lookahead != 0) ADVANCE(23);
      END_STATE();
    case 23:
      if (lookahead == '*') ADVANCE(22);
      if (lookahead != 0) ADVANCE(23);
      END_STATE();
    case 24:
      if (lookahead == ',') ADVANCE(449);
      if (lookahead == '/') ADVANCE(21);
      if (lookahead == 'a') ADVANCE(752);
      if (lookahead == '}') ADVANCE(450);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(24);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 25:
      if (lookahead == '-') ADVANCE(174);
      END_STATE();
    case 26:
      if (lookahead == '-') ADVANCE(88);
      END_STATE();
    case 27:
      if (lookahead == '-') ADVANCE(183);
      if (lookahead == '_') ADVANCE(185);
      END_STATE();
    case 28:
      if (lookahead == '-') ADVANCE(373);
      END_STATE();
    case 29:
      if (lookahead == '-') ADVANCE(105);
      END_STATE();
    case 30:
      if (lookahead == '-') ADVANCE(421);
      END_STATE();
    case 31:
      if (lookahead == '-') ADVANCE(370);
      END_STATE();
    case 32:
      if (lookahead == '-') ADVANCE(247);
      END_STATE();
    case 33:
      if (lookahead == '-') ADVANCE(186);
      if (lookahead == '_') ADVANCE(187);
      END_STATE();
    case 34:
      if (lookahead == '/') ADVANCE(21);
      if (lookahead == 'f') ADVANCE(878);
      if (lookahead == 'p') ADVANCE(802);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(34);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 35:
      if (lookahead == '/') ADVANCE(21);
      if (lookahead == 'p') ADVANCE(813);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(35);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 36:
      if (lookahead == '=') ADVANCE(545);
      END_STATE();
    case 37:
      if (lookahead == '=') ADVANCE(456);
      END_STATE();
    case 38:
      if (lookahead == '=') ADVANCE(544);
      END_STATE();
    case 39:
      if (lookahead == '=') ADVANCE(42);
      END_STATE();
    case 40:
      if (lookahead == '>') ADVANCE(517);
      END_STATE();
    case 41:
      if (lookahead == '>') ADVANCE(506);
      END_STATE();
    case 42:
      if (lookahead == '>') ADVANCE(471);
      END_STATE();
    case 43:
      if (lookahead == 'a') ADVANCE(243);
      if (lookahead == 'h') ADVANCE(57);
      if (lookahead == 'i') ADVANCE(335);
      if (lookahead == 'm') ADVANCE(1005);
      if (lookahead == 'o') ADVANCE(242);
      if (lookahead == 'u') ADVANCE(84);
      END_STATE();
    case 44:
      if (lookahead == 'a') ADVANCE(243);
      if (lookahead == 'h') ADVANCE(57);
      if (lookahead == 'i') ADVANCE(335);
      if (lookahead == 'o') ADVANCE(242);
      if (lookahead == 'u') ADVANCE(84);
      END_STATE();
    case 45:
      if (lookahead == 'a') ADVANCE(365);
      if (lookahead == 'l') ADVANCE(367);
      if (lookahead == 'n') ADVANCE(415);
      if (lookahead == 'x') ADVANCE(331);
      END_STATE();
    case 46:
      if (lookahead == 'a') ADVANCE(115);
      END_STATE();
    case 47:
      if (lookahead == 'a') ADVANCE(115);
      if (lookahead == 'e') ADVANCE(250);
      if (lookahead == 'o') ADVANCE(311);
      END_STATE();
    case 48:
      if (lookahead == 'a') ADVANCE(115);
      if (lookahead == 'e') ADVANCE(259);
      END_STATE();
    case 49:
      if (lookahead == 'a') ADVANCE(180);
      if (lookahead == 'p') ADVANCE(319);
      END_STATE();
    case 50:
      if (lookahead == 'a') ADVANCE(117);
      if (lookahead == 'i') ADVANCE(286);
      END_STATE();
    case 51:
      if (lookahead == 'a') ADVANCE(249);
      if (lookahead == 'l') ADVANCE(313);
      if (lookahead == 'o') ADVANCE(336);
      if (lookahead == 'r') ADVANCE(312);
      if (lookahead == 'u') ADVANCE(275);
      END_STATE();
    case 52:
      if (lookahead == 'a') ADVANCE(120);
      END_STATE();
    case 53:
      if (lookahead == 'a') ADVANCE(432);
      END_STATE();
    case 54:
      if (lookahead == 'a') ADVANCE(118);
      if (lookahead == 'i') ADVANCE(289);
      END_STATE();
    case 55:
      if (lookahead == 'a') ADVANCE(400);
      END_STATE();
    case 56:
      if (lookahead == 'a') ADVANCE(119);
      if (lookahead == 'i') ADVANCE(298);
      END_STATE();
    case 57:
      if (lookahead == 'a') ADVANCE(302);
      END_STATE();
    case 58:
      if (lookahead == 'a') ADVANCE(378);
      END_STATE();
    case 59:
      if (lookahead == 'a') ADVANCE(278);
      if (lookahead == 'u') ADVANCE(131);
      END_STATE();
    case 60:
      if (lookahead == 'a') ADVANCE(355);
      if (lookahead == 'e') ADVANCE(341);
      if (lookahead == 'h') ADVANCE(431);
      if (lookahead == 'r') ADVANCE(196);
      if (lookahead == 'u') ADVANCE(86);
      if (lookahead == 't' ||
          lookahead == 'x') ADVANCE(1005);
      END_STATE();
    case 61:
      if (lookahead == 'a') ADVANCE(355);
      if (lookahead == 'e') ADVANCE(341);
      if (lookahead == 'h') ADVANCE(434);
      if (lookahead == 'r') ADVANCE(196);
      if (lookahead == 'u') ADVANCE(86);
      END_STATE();
    case 62:
      if (lookahead == 'a') ADVANCE(404);
      END_STATE();
    case 63:
      if (lookahead == 'a') ADVANCE(371);
      END_STATE();
    case 64:
      if (lookahead == 'a') ADVANCE(93);
      END_STATE();
    case 65:
      if (lookahead == 'a') ADVANCE(102);
      if (lookahead == 'o') ADVANCE(422);
      END_STATE();
    case 66:
      if (lookahead == 'a') ADVANCE(235);
      END_STATE();
    case 67:
      if (lookahead == 'a') ADVANCE(103);
      if (lookahead == 'o') ADVANCE(424);
      END_STATE();
    case 68:
      if (lookahead == 'a') ADVANCE(256);
      END_STATE();
    case 69:
      if (lookahead == 'a') ADVANCE(238);
      END_STATE();
    case 70:
      if (lookahead == 'a') ADVANCE(338);
      END_STATE();
    case 71:
      if (lookahead == 'a') ADVANCE(104);
      if (lookahead == 'o') ADVANCE(426);
      END_STATE();
    case 72:
      if (lookahead == 'a') ADVANCE(339);
      END_STATE();
    case 73:
      if (lookahead == 'a') ADVANCE(181);
      END_STATE();
    case 74:
      if (lookahead == 'a') ADVANCE(121);
      END_STATE();
    case 75:
      if (lookahead == 'a') ADVANCE(401);
      END_STATE();
    case 76:
      if (lookahead == 'a') ADVANCE(405);
      END_STATE();
    case 77:
      if (lookahead == 'a') ADVANCE(374);
      END_STATE();
    case 78:
      if (lookahead == 'a') ADVANCE(123);
      END_STATE();
    case 79:
      if (lookahead == 'a') ADVANCE(375);
      END_STATE();
    case 80:
      if (lookahead == 'a') ADVANCE(124);
      END_STATE();
    case 81:
      if (lookahead == 'a') ADVANCE(411);
      END_STATE();
    case 82:
      if (lookahead == 'a') ADVANCE(125);
      END_STATE();
    case 83:
      if (lookahead == 'b') ADVANCE(65);
      if (lookahead == 'c') ADVANCE(207);
      if (lookahead == 'e') ADVANCE(245);
      if (lookahead == 'o') ADVANCE(420);
      if (lookahead == 'q') ADVANCE(414);
      if (lookahead == 's') ADVANCE(211);
      END_STATE();
    case 84:
      if (lookahead == 'b') ADVANCE(199);
      END_STATE();
    case 85:
      if (lookahead == 'b') ADVANCE(66);
      END_STATE();
    case 86:
      if (lookahead == 'b') ADVANCE(252);
      if (lookahead == 'r') ADVANCE(130);
      END_STATE();
    case 87:
      if (lookahead == 'b') ADVANCE(64);
      END_STATE();
    case 88:
      if (lookahead == 'b') ADVANCE(138);
      END_STATE();
    case 89:
      if (lookahead == 'b') ADVANCE(67);
      if (lookahead == 'c') ADVANCE(208);
      if (lookahead == 'e') ADVANCE(254);
      if (lookahead == 'q') ADVANCE(423);
      if (lookahead == 's') ADVANCE(215);
      END_STATE();
    case 90:
      if (lookahead == 'b') ADVANCE(71);
      if (lookahead == 'c') ADVANCE(209);
      if (lookahead == 'e') ADVANCE(255);
      if (lookahead == 'q') ADVANCE(425);
      if (lookahead == 's') ADVANCE(217);
      END_STATE();
    case 91:
      if (lookahead == 'c') ADVANCE(26);
      END_STATE();
    case 92:
      if (lookahead == 'c') ADVANCE(520);
      END_STATE();
    case 93:
      if (lookahead == 'c') ADVANCE(229);
      END_STATE();
    case 94:
      if (lookahead == 'c') ADVANCE(963);
      END_STATE();
    case 95:
      if (lookahead == 'c') ADVANCE(965);
      END_STATE();
    case 96:
      if (lookahead == 'c') ADVANCE(969);
      END_STATE();
    case 97:
      if (lookahead == 'c') ADVANCE(967);
      END_STATE();
    case 98:
      if (lookahead == 'c') ADVANCE(971);
      END_STATE();
    case 99:
      if (lookahead == 'c') ADVANCE(973);
      END_STATE();
    case 100:
      if (lookahead == 'c') ADVANCE(192);
      END_STATE();
    case 101:
      if (lookahead == 'c') ADVANCE(192);
      if (lookahead == 'i') ADVANCE(262);
      if (lookahead == 'l') ADVANCE(227);
      if (lookahead == 'r') ADVANCE(52);
      if (lookahead == 't') ADVANCE(334);
      END_STATE();
    case 102:
      if (lookahead == 'c') ADVANCE(230);
      END_STATE();
    case 103:
      if (lookahead == 'c') ADVANCE(231);
      END_STATE();
    case 104:
      if (lookahead == 'c') ADVANCE(232);
      END_STATE();
    case 105:
      if (lookahead == 'c') ADVANCE(315);
      END_STATE();
    case 106:
      if (lookahead == 'c') ADVANCE(141);
      END_STATE();
    case 107:
      if (lookahead == 'c') ADVANCE(142);
      END_STATE();
    case 108:
      if (lookahead == 'c') ADVANCE(144);
      END_STATE();
    case 109:
      if (lookahead == 'c') ADVANCE(146);
      END_STATE();
    case 110:
      if (lookahead == 'c') ADVANCE(246);
      END_STATE();
    case 111:
      if (lookahead == 'c') ADVANCE(162);
      END_STATE();
    case 112:
      if (lookahead == 'c') ADVANCE(69);
      END_STATE();
    case 113:
      if (lookahead == 'c') ADVANCE(409);
      END_STATE();
    case 114:
      if (lookahead == 'c') ADVANCE(410);
      END_STATE();
    case 115:
      if (lookahead == 'd') ADVANCE(1011);
      END_STATE();
    case 116:
      if (lookahead == 'd') ADVANCE(526);
      END_STATE();
    case 117:
      if (lookahead == 'd') ADVANCE(919);
      if (lookahead == 'r') ADVANCE(386);
      END_STATE();
    case 118:
      if (lookahead == 'd') ADVANCE(921);
      if (lookahead == 'r') ADVANCE(388);
      END_STATE();
    case 119:
      if (lookahead == 'd') ADVANCE(923);
      if (lookahead == 'r') ADVANCE(395);
      END_STATE();
    case 120:
      if (lookahead == 'd') ADVANCE(213);
      END_STATE();
    case 121:
      if (lookahead == 'd') ADVANCE(222);
      END_STATE();
    case 122:
      if (lookahead == 'd') ADVANCE(356);
      END_STATE();
    case 123:
      if (lookahead == 'd') ADVANCE(224);
      END_STATE();
    case 124:
      if (lookahead == 'd') ADVANCE(225);
      END_STATE();
    case 125:
      if (lookahead == 'd') ADVANCE(226);
      END_STATE();
    case 126:
      if (lookahead == 'e') ADVANCE(176);
      if (lookahead == 'i') ADVANCE(342);
      if (lookahead == 'u') ADVANCE(343);
      END_STATE();
    case 127:
      if (lookahead == 'e') ADVANCE(251);
      if (lookahead == 'o') ADVANCE(311);
      END_STATE();
    case 128:
      if (lookahead == 'e') ADVANCE(926);
      if (lookahead == 'i') ADVANCE(277);
      END_STATE();
    case 129:
      if (lookahead == 'e') ADVANCE(499);
      END_STATE();
    case 130:
      if (lookahead == 'e') ADVANCE(518);
      END_STATE();
    case 131:
      if (lookahead == 'e') ADVANCE(998);
      END_STATE();
    case 132:
      if (lookahead == 'e') ADVANCE(909);
      END_STATE();
    case 133:
      if (lookahead == 'e') ADVANCE(1000);
      END_STATE();
    case 134:
      if (lookahead == 'e') ADVANCE(913);
      END_STATE();
    case 135:
      if (lookahead == 'e') ADVANCE(988);
      END_STATE();
    case 136:
      if (lookahead == 'e') ADVANCE(488);
      END_STATE();
    case 137:
      if (lookahead == 'e') ADVANCE(522);
      END_STATE();
    case 138:
      if (lookahead == 'e') ADVANCE(435);
      END_STATE();
    case 139:
      if (lookahead == 'e') ADVANCE(951);
      END_STATE();
    case 140:
      if (lookahead == 'e') ADVANCE(953);
      END_STATE();
    case 141:
      if (lookahead == 'e') ADVANCE(975);
      END_STATE();
    case 142:
      if (lookahead == 'e') ADVANCE(977);
      END_STATE();
    case 143:
      if (lookahead == 'e') ADVANCE(955);
      END_STATE();
    case 144:
      if (lookahead == 'e') ADVANCE(979);
      END_STATE();
    case 145:
      if (lookahead == 'e') ADVANCE(915);
      END_STATE();
    case 146:
      if (lookahead == 'e') ADVANCE(529);
      END_STATE();
    case 147:
      if (lookahead == 'e') ADVANCE(276);
      if (lookahead == 'i') ADVANCE(281);
      END_STATE();
    case 148:
      if (lookahead == 'e') ADVANCE(30);
      END_STATE();
    case 149:
      if (lookahead == 'e') ADVANCE(233);
      END_STATE();
    case 150:
      if (lookahead == 'e') ADVANCE(116);
      END_STATE();
    case 151:
      if (lookahead == 'e') ADVANCE(25);
      END_STATE();
    case 152:
      if (lookahead == 'e') ADVANCE(175);
      END_STATE();
    case 153:
      if (lookahead == 'e') ADVANCE(268);
      END_STATE();
    case 154:
      if (lookahead == 'e') ADVANCE(28);
      END_STATE();
    case 155:
      if (lookahead == 'e') ADVANCE(282);
      END_STATE();
    case 156:
      if (lookahead == 'e') ADVANCE(70);
      END_STATE();
    case 157:
      if (lookahead == 'e') ADVANCE(239);
      if (lookahead == 'i') ADVANCE(342);
      if (lookahead == 'u') ADVANCE(343);
      END_STATE();
    case 158:
      if (lookahead == 'e') ADVANCE(273);
      END_STATE();
    case 159:
      if (lookahead == 'e') ADVANCE(349);
      END_STATE();
    case 160:
      if (lookahead == 'e') ADVANCE(340);
      END_STATE();
    case 161:
      if (lookahead == 'e') ADVANCE(350);
      END_STATE();
    case 162:
      if (lookahead == 'e') ADVANCE(283);
      END_STATE();
    case 163:
      if (lookahead == 'e') ADVANCE(72);
      END_STATE();
    case 164:
      if (lookahead == 'e') ADVANCE(285);
      END_STATE();
    case 165:
      if (lookahead == 'e') ADVANCE(292);
      END_STATE();
    case 166:
      if (lookahead == 'e') ADVANCE(294);
      END_STATE();
    case 167:
      if (lookahead == 'e') ADVANCE(295);
      END_STATE();
    case 168:
      if (lookahead == 'e') ADVANCE(296);
      END_STATE();
    case 169:
      if (lookahead == 'e') ADVANCE(300);
      END_STATE();
    case 170:
      if (lookahead == 'e') ADVANCE(114);
      END_STATE();
    case 171:
      if (lookahead == 'e') ADVANCE(358);
      END_STATE();
    case 172:
      if (lookahead == 'f') ADVANCE(497);
      if (lookahead == 'm') ADVANCE(49);
      if (lookahead == 'n') ADVANCE(477);
      if (lookahead == 't') ADVANCE(171);
      END_STATE();
    case 173:
      if (lookahead == 'f') ADVANCE(993);
      END_STATE();
    case 174:
      if (lookahead == 'f') ADVANCE(325);
      END_STATE();
    case 175:
      if (lookahead == 'g') ADVANCE(1011);
      END_STATE();
    case 176:
      if (lookahead == 'g') ADVANCE(1011);
      if (lookahead == 'l') ADVANCE(53);
      END_STATE();
    case 177:
      if (lookahead == 'g') ADVANCE(495);
      END_STATE();
    case 178:
      if (lookahead == 'g') ADVANCE(244);
      if (lookahead == 'i') ADVANCE(263);
      END_STATE();
    case 179:
      if (lookahead == 'g') ADVANCE(398);
      END_STATE();
    case 180:
      if (lookahead == 'g') ADVANCE(134);
      END_STATE();
    case 181:
      if (lookahead == 'g') ADVANCE(148);
      END_STATE();
    case 182:
      if (lookahead == 'g') ADVANCE(150);
      END_STATE();
    case 183:
      if (lookahead == 'g') ADVANCE(357);
      END_STATE();
    case 184:
      if (lookahead == 'g') ADVANCE(399);
      END_STATE();
    case 185:
      if (lookahead == 'g') ADVANCE(359);
      END_STATE();
    case 186:
      if (lookahead == 'g') ADVANCE(360);
      END_STATE();
    case 187:
      if (lookahead == 'g') ADVANCE(361);
      END_STATE();
    case 188:
      if (lookahead == 'h') ADVANCE(903);
      END_STATE();
    case 189:
      if (lookahead == 'h') ADVANCE(907);
      END_STATE();
    case 190:
      if (lookahead == 'h') ADVANCE(905);
      END_STATE();
    case 191:
      if (lookahead == 'h') ADVANCE(430);
      if (lookahead == 't' ||
          lookahead == 'x') ADVANCE(1005);
      END_STATE();
    case 192:
      if (lookahead == 'h') ADVANCE(202);
      END_STATE();
    case 193:
      if (lookahead == 'h') ADVANCE(153);
      END_STATE();
    case 194:
      if (lookahead == 'h') ADVANCE(161);
      END_STATE();
    case 195:
      if (lookahead == 'i') ADVANCE(262);
      if (lookahead == 'l') ADVANCE(227);
      if (lookahead == 'r') ADVANCE(52);
      if (lookahead == 't') ADVANCE(334);
      END_STATE();
    case 196:
      if (lookahead == 'i') ADVANCE(429);
      if (lookahead == 'o') ADVANCE(330);
      END_STATE();
    case 197:
      if (lookahead == 'i') ADVANCE(428);
      END_STATE();
    case 198:
      if (lookahead == 'i') ADVANCE(436);
      END_STATE();
    case 199:
      if (lookahead == 'i') ADVANCE(91);
      END_STATE();
    case 200:
      if (lookahead == 'i') ADVANCE(112);
      END_STATE();
    case 201:
      if (lookahead == 'i') ADVANCE(92);
      END_STATE();
    case 202:
      if (lookahead == 'i') ADVANCE(237);
      END_STATE();
    case 203:
      if (lookahead == 'i') ADVANCE(270);
      if (lookahead == 'o') ADVANCE(418);
      END_STATE();
    case 204:
      if (lookahead == 'i') ADVANCE(96);
      END_STATE();
    case 205:
      if (lookahead == 'i') ADVANCE(98);
      END_STATE();
    case 206:
      if (lookahead == 'i') ADVANCE(99);
      END_STATE();
    case 207:
      if (lookahead == 'i') ADVANCE(348);
      END_STATE();
    case 208:
      if (lookahead == 'i') ADVANCE(351);
      END_STATE();
    case 209:
      if (lookahead == 'i') ADVANCE(353);
      END_STATE();
    case 210:
      if (lookahead == 'i') ADVANCE(403);
      END_STATE();
    case 211:
      if (lookahead == 'i') ADVANCE(288);
      END_STATE();
    case 212:
      if (lookahead == 'i') ADVANCE(320);
      END_STATE();
    case 213:
      if (lookahead == 'i') ADVANCE(68);
      END_STATE();
    case 214:
      if (lookahead == 'i') ADVANCE(160);
      END_STATE();
    case 215:
      if (lookahead == 'i') ADVANCE(290);
      END_STATE();
    case 216:
      if (lookahead == 'i') ADVANCE(321);
      END_STATE();
    case 217:
      if (lookahead == 'i') ADVANCE(293);
      END_STATE();
    case 218:
      if (lookahead == 'i') ADVANCE(322);
      END_STATE();
    case 219:
      if (lookahead == 'i') ADVANCE(109);
      END_STATE();
    case 220:
      if (lookahead == 'i') ADVANCE(297);
      END_STATE();
    case 221:
      if (lookahead == 'i') ADVANCE(323);
      END_STATE();
    case 222:
      if (lookahead == 'i') ADVANCE(165);
      END_STATE();
    case 223:
      if (lookahead == 'i') ADVANCE(324);
      END_STATE();
    case 224:
      if (lookahead == 'i') ADVANCE(166);
      END_STATE();
    case 225:
      if (lookahead == 'i') ADVANCE(167);
      END_STATE();
    case 226:
      if (lookahead == 'i') ADVANCE(168);
      END_STATE();
    case 227:
      if (lookahead == 'i') ADVANCE(305);
      END_STATE();
    case 228:
      if (lookahead == 'i') ADVANCE(412);
      END_STATE();
    case 229:
      if (lookahead == 'k') ADVANCE(515);
      END_STATE();
    case 230:
      if (lookahead == 'k') ADVANCE(957);
      END_STATE();
    case 231:
      if (lookahead == 'k') ADVANCE(959);
      END_STATE();
    case 232:
      if (lookahead == 'k') ADVANCE(961);
      END_STATE();
    case 233:
      if (lookahead == 'l') ADVANCE(173);
      END_STATE();
    case 234:
      if (lookahead == 'l') ADVANCE(898);
      END_STATE();
    case 235:
      if (lookahead == 'l') ADVANCE(472);
      END_STATE();
    case 236:
      if (lookahead == 'l') ADVANCE(528);
      END_STATE();
    case 237:
      if (lookahead == 'l') ADVANCE(122);
      END_STATE();
    case 238:
      if (lookahead == 'l') ADVANCE(32);
      END_STATE();
    case 239:
      if (lookahead == 'l') ADVANCE(53);
      END_STATE();
    case 240:
      if (lookahead == 'l') ADVANCE(310);
      END_STATE();
    case 241:
      if (lookahead == 'l') ADVANCE(310);
      if (lookahead == 'r') ADVANCE(46);
      END_STATE();
    case 242:
      if (lookahead == 'l') ADVANCE(317);
      if (lookahead == 'm') ADVANCE(326);
      END_STATE();
    case 243:
      if (lookahead == 'l') ADVANCE(248);
      END_STATE();
    case 244:
      if (lookahead == 'l') ADVANCE(132);
      END_STATE();
    case 245:
      if (lookahead == 'l') ADVANCE(63);
      if (lookahead == 'x') ADVANCE(327);
      END_STATE();
    case 246:
      if (lookahead == 'l') ADVANCE(135);
      END_STATE();
    case 247:
      if (lookahead == 'l') ADVANCE(169);
      END_STATE();
    case 248:
      if (lookahead == 'l') ADVANCE(87);
      END_STATE();
    case 249:
      if (lookahead == 'l') ADVANCE(369);
      END_STATE();
    case 250:
      if (lookahead == 'l') ADVANCE(75);
      if (lookahead == 'm') ADVANCE(1014);
      if (lookahead == 't') ADVANCE(419);
      END_STATE();
    case 251:
      if (lookahead == 'l') ADVANCE(75);
      if (lookahead == 't') ADVANCE(419);
      END_STATE();
    case 252:
      if (lookahead == 'l') ADVANCE(201);
      END_STATE();
    case 253:
      if (lookahead == 'l') ADVANCE(219);
      END_STATE();
    case 254:
      if (lookahead == 'l') ADVANCE(77);
      if (lookahead == 'x') ADVANCE(328);
      END_STATE();
    case 255:
      if (lookahead == 'l') ADVANCE(79);
      if (lookahead == 'x') ADVANCE(329);
      END_STATE();
    case 256:
      if (lookahead == 'l') ADVANCE(33);
      END_STATE();
    case 257:
      if (lookahead == 'm') ADVANCE(1005);
      END_STATE();
    case 258:
      if (lookahead == 'm') ADVANCE(1005);
      if (lookahead == 's') ADVANCE(1007);
      END_STATE();
    case 259:
      if (lookahead == 'm') ADVANCE(1014);
      END_STATE();
    case 260:
      if (lookahead == 'm') ADVANCE(475);
      END_STATE();
    case 261:
      if (lookahead == 'm') ADVANCE(453);
      END_STATE();
    case 262:
      if (lookahead == 'm') ADVANCE(73);
      END_STATE();
    case 263:
      if (lookahead == 'm') ADVANCE(62);
      END_STATE();
    case 264:
      if (lookahead == 'n') ADVANCE(178);
      if (lookahead == 's') ADVANCE(455);
      END_STATE();
    case 265:
      if (lookahead == 'n') ADVANCE(1005);
      END_STATE();
    case 266:
      if (lookahead == 'n') ADVANCE(477);
      END_STATE();
    case 267:
      if (lookahead == 'n') ADVANCE(1011);
      END_STATE();
    case 268:
      if (lookahead == 'n') ADVANCE(487);
      END_STATE();
    case 269:
      if (lookahead == 'n') ADVANCE(465);
      END_STATE();
    case 270:
      if (lookahead == 'n') ADVANCE(927);
      END_STATE();
    case 271:
      if (lookahead == 'n') ADVANCE(491);
      END_STATE();
    case 272:
      if (lookahead == 'n') ADVANCE(524);
      END_STATE();
    case 273:
      if (lookahead == 'n') ADVANCE(983);
      END_STATE();
    case 274:
      if (lookahead == 'n') ADVANCE(494);
      END_STATE();
    case 275:
      if (lookahead == 'n') ADVANCE(113);
      END_STATE();
    case 276:
      if (lookahead == 'n') ADVANCE(179);
      END_STATE();
    case 277:
      if (lookahead == 'n') ADVANCE(177);
      END_STATE();
    case 278:
      if (lookahead == 'n') ADVANCE(368);
      END_STATE();
    case 279:
      if (lookahead == 'n') ADVANCE(29);
      END_STATE();
    case 280:
      if (lookahead == 'n') ADVANCE(363);
      END_STATE();
    case 281:
      if (lookahead == 'n') ADVANCE(156);
      END_STATE();
    case 282:
      if (lookahead == 'n') ADVANCE(381);
      END_STATE();
    case 283:
      if (lookahead == 'n') ADVANCE(382);
      END_STATE();
    case 284:
      if (lookahead == 'n') ADVANCE(106);
      END_STATE();
    case 285:
      if (lookahead == 'n') ADVANCE(384);
      END_STATE();
    case 286:
      if (lookahead == 'n') ADVANCE(387);
      END_STATE();
    case 287:
      if (lookahead == 'n') ADVANCE(402);
      END_STATE();
    case 288:
      if (lookahead == 'n') ADVANCE(139);
      END_STATE();
    case 289:
      if (lookahead == 'n') ADVANCE(389);
      END_STATE();
    case 290:
      if (lookahead == 'n') ADVANCE(140);
      END_STATE();
    case 291:
      if (lookahead == 'n') ADVANCE(390);
      END_STATE();
    case 292:
      if (lookahead == 'n') ADVANCE(391);
      END_STATE();
    case 293:
      if (lookahead == 'n') ADVANCE(143);
      END_STATE();
    case 294:
      if (lookahead == 'n') ADVANCE(392);
      END_STATE();
    case 295:
      if (lookahead == 'n') ADVANCE(393);
      END_STATE();
    case 296:
      if (lookahead == 'n') ADVANCE(394);
      END_STATE();
    case 297:
      if (lookahead == 'n') ADVANCE(154);
      END_STATE();
    case 298:
      if (lookahead == 'n') ADVANCE(396);
      END_STATE();
    case 299:
      if (lookahead == 'n') ADVANCE(194);
      END_STATE();
    case 300:
      if (lookahead == 'n') ADVANCE(184);
      END_STATE();
    case 301:
      if (lookahead == 'n') ADVANCE(107);
      END_STATE();
    case 302:
      if (lookahead == 'n') ADVANCE(182);
      END_STATE();
    case 303:
      if (lookahead == 'n') ADVANCE(108);
      END_STATE();
    case 304:
      if (lookahead == 'n') ADVANCE(164);
      END_STATE();
    case 305:
      if (lookahead == 'n') ADVANCE(163);
      END_STATE();
    case 306:
      if (lookahead == 'o') ADVANCE(314);
      if (lookahead == 'r') ADVANCE(416);
      END_STATE();
    case 307:
      if (lookahead == 'o') ADVANCE(945);
      END_STATE();
    case 308:
      if (lookahead == 'o') ADVANCE(947);
      END_STATE();
    case 309:
      if (lookahead == 'o') ADVANCE(949);
      END_STATE();
    case 310:
      if (lookahead == 'o') ADVANCE(85);
      END_STATE();
    case 311:
      if (lookahead == 'o') ADVANCE(377);
      END_STATE();
    case 312:
      if (lookahead == 'o') ADVANCE(261);
      END_STATE();
    case 313:
      if (lookahead == 'o') ADVANCE(58);
      END_STATE();
    case 314:
      if (lookahead == 'o') ADVANCE(234);
      END_STATE();
    case 315:
      if (lookahead == 'o') ADVANCE(427);
      END_STATE();
    case 316:
      if (lookahead == 'o') ADVANCE(304);
      END_STATE();
    case 317:
      if (lookahead == 'o') ADVANCE(337);
      END_STATE();
    case 318:
      if (lookahead == 'o') ADVANCE(345);
      END_STATE();
    case 319:
      if (lookahead == 'o') ADVANCE(346);
      END_STATE();
    case 320:
      if (lookahead == 'o') ADVANCE(271);
      END_STATE();
    case 321:
      if (lookahead == 'o') ADVANCE(272);
      END_STATE();
    case 322:
      if (lookahead == 'o') ADVANCE(274);
      END_STATE();
    case 323:
      if (lookahead == 'o') ADVANCE(279);
      END_STATE();
    case 324:
      if (lookahead == 'o') ADVANCE(280);
      END_STATE();
    case 325:
      if (lookahead == 'o') ADVANCE(287);
      END_STATE();
    case 326:
      if (lookahead == 'p') ADVANCE(316);
      END_STATE();
    case 327:
      if (lookahead == 'p') ADVANCE(307);
      END_STATE();
    case 328:
      if (lookahead == 'p') ADVANCE(308);
      END_STATE();
    case 329:
      if (lookahead == 'p') ADVANCE(309);
      END_STATE();
    case 330:
      if (lookahead == 'p') ADVANCE(159);
      END_STATE();
    case 331:
      if (lookahead == 'p') ADVANCE(318);
      END_STATE();
    case 332:
      if (lookahead == 'r') ADVANCE(59);
      END_STATE();
    case 333:
      if (lookahead == 'r') ADVANCE(59);
      if (lookahead == 'u') ADVANCE(344);
      END_STATE();
    case 334:
      if (lookahead == 'r') ADVANCE(505);
      END_STATE();
    case 335:
      if (lookahead == 'r') ADVANCE(110);
      END_STATE();
    case 336:
      if (lookahead == 'r') ADVANCE(501);
      END_STATE();
    case 337:
      if (lookahead == 'r') ADVANCE(901);
      END_STATE();
    case 338:
      if (lookahead == 'r') ADVANCE(917);
      END_STATE();
    case 339:
      if (lookahead == 'r') ADVANCE(27);
      END_STATE();
    case 340:
      if (lookahead == 'r') ADVANCE(981);
      END_STATE();
    case 341:
      if (lookahead == 'r') ADVANCE(111);
      END_STATE();
    case 342:
      if (lookahead == 'r') ADVANCE(170);
      END_STATE();
    case 343:
      if (lookahead == 'r') ADVANCE(55);
      END_STATE();
    case 344:
      if (lookahead == 'r') ADVANCE(267);
      END_STATE();
    case 345:
      if (lookahead == 'r') ADVANCE(379);
      END_STATE();
    case 346:
      if (lookahead == 'r') ADVANCE(380);
      END_STATE();
    case 347:
      if (lookahead == 'r') ADVANCE(269);
      END_STATE();
    case 348:
      if (lookahead == 'r') ADVANCE(94);
      END_STATE();
    case 349:
      if (lookahead == 'r') ADVANCE(397);
      END_STATE();
    case 350:
      if (lookahead == 'r') ADVANCE(210);
      END_STATE();
    case 351:
      if (lookahead == 'r') ADVANCE(95);
      END_STATE();
    case 352:
      if (lookahead == 'r') ADVANCE(236);
      END_STATE();
    case 353:
      if (lookahead == 'r') ADVANCE(97);
      END_STATE();
    case 354:
      if (lookahead == 'r') ADVANCE(46);
      END_STATE();
    case 355:
      if (lookahead == 'r') ADVANCE(155);
      END_STATE();
    case 356:
      if (lookahead == 'r') ADVANCE(158);
      END_STATE();
    case 357:
      if (lookahead == 'r') ADVANCE(74);
      END_STATE();
    case 358:
      if (lookahead == 'r') ADVANCE(81);
      END_STATE();
    case 359:
      if (lookahead == 'r') ADVANCE(78);
      END_STATE();
    case 360:
      if (lookahead == 'r') ADVANCE(80);
      END_STATE();
    case 361:
      if (lookahead == 'r') ADVANCE(82);
      END_STATE();
    case 362:
      if (lookahead == 's') ADVANCE(455);
      END_STATE();
    case 363:
      if (lookahead == 's') ADVANCE(482);
      END_STATE();
    case 364:
      if (lookahead == 's') ADVANCE(459);
      END_STATE();
    case 365:
      if (lookahead == 's') ADVANCE(128);
      END_STATE();
    case 366:
      if (lookahead == 's') ADVANCE(188);
      END_STATE();
    case 367:
      if (lookahead == 's') ADVANCE(129);
      END_STATE();
    case 368:
      if (lookahead == 's') ADVANCE(228);
      END_STATE();
    case 369:
      if (lookahead == 's') ADVANCE(133);
      END_STATE();
    case 370:
      if (lookahead == 's') ADVANCE(198);
      END_STATE();
    case 371:
      if (lookahead == 's') ADVANCE(406);
      END_STATE();
    case 372:
      if (lookahead == 's') ADVANCE(200);
      END_STATE();
    case 373:
      if (lookahead == 's') ADVANCE(253);
      END_STATE();
    case 374:
      if (lookahead == 's') ADVANCE(407);
      END_STATE();
    case 375:
      if (lookahead == 's') ADVANCE(408);
      END_STATE();
    case 376:
      if (lookahead == 't') ADVANCE(480);
      END_STATE();
    case 377:
      if (lookahead == 't') ADVANCE(991);
      END_STATE();
    case 378:
      if (lookahead == 't') ADVANCE(896);
      END_STATE();
    case 379:
      if (lookahead == 't') ADVANCE(446);
      END_STATE();
    case 380:
      if (lookahead == 't') ADVANCE(451);
      END_STATE();
    case 381:
      if (lookahead == 't') ADVANCE(989);
      END_STATE();
    case 382:
      if (lookahead == 't') ADVANCE(911);
      END_STATE();
    case 383:
      if (lookahead == 't') ADVANCE(929);
      END_STATE();
    case 384:
      if (lookahead == 't') ADVANCE(457);
      END_STATE();
    case 385:
      if (lookahead == 't') ADVANCE(931);
      END_STATE();
    case 386:
      if (lookahead == 't') ADVANCE(933);
      END_STATE();
    case 387:
      if (lookahead == 't') ADVANCE(939);
      END_STATE();
    case 388:
      if (lookahead == 't') ADVANCE(935);
      END_STATE();
    case 389:
      if (lookahead == 't') ADVANCE(941);
      END_STATE();
    case 390:
      if (lookahead == 't') ADVANCE(493);
      END_STATE();
    case 391:
      if (lookahead == 't') ADVANCE(984);
      END_STATE();
    case 392:
      if (lookahead == 't') ADVANCE(985);
      END_STATE();
    case 393:
      if (lookahead == 't') ADVANCE(986);
      END_STATE();
    case 394:
      if (lookahead == 't') ADVANCE(987);
      END_STATE();
    case 395:
      if (lookahead == 't') ADVANCE(937);
      END_STATE();
    case 396:
      if (lookahead == 't') ADVANCE(943);
      END_STATE();
    case 397:
      if (lookahead == 't') ADVANCE(433);
      END_STATE();
    case 398:
      if (lookahead == 't') ADVANCE(189);
      END_STATE();
    case 399:
      if (lookahead == 't') ADVANCE(190);
      END_STATE();
    case 400:
      if (lookahead == 't') ADVANCE(212);
      END_STATE();
    case 401:
      if (lookahead == 't') ADVANCE(197);
      END_STATE();
    case 402:
      if (lookahead == 't') ADVANCE(31);
      END_STATE();
    case 403:
      if (lookahead == 't') ADVANCE(364);
      END_STATE();
    case 404:
      if (lookahead == 't') ADVANCE(136);
      END_STATE();
    case 405:
      if (lookahead == 't') ADVANCE(137);
      END_STATE();
    case 406:
      if (lookahead == 't') ADVANCE(204);
      END_STATE();
    case 407:
      if (lookahead == 't') ADVANCE(205);
      END_STATE();
    case 408:
      if (lookahead == 't') ADVANCE(206);
      END_STATE();
    case 409:
      if (lookahead == 't') ADVANCE(216);
      END_STATE();
    case 410:
      if (lookahead == 't') ADVANCE(218);
      END_STATE();
    case 411:
      if (lookahead == 't') ADVANCE(221);
      END_STATE();
    case 412:
      if (lookahead == 't') ADVANCE(223);
      END_STATE();
    case 413:
      if (lookahead == 'u') ADVANCE(376);
      END_STATE();
    case 414:
      if (lookahead == 'u') ADVANCE(50);
      END_STATE();
    case 415:
      if (lookahead == 'u') ADVANCE(260);
      END_STATE();
    case 416:
      if (lookahead == 'u') ADVANCE(366);
      END_STATE();
    case 417:
      if (lookahead == 'u') ADVANCE(344);
      END_STATE();
    case 418:
      if (lookahead == 'u') ADVANCE(383);
      END_STATE();
    case 419:
      if (lookahead == 'u') ADVANCE(347);
      END_STATE();
    case 420:
      if (lookahead == 'u') ADVANCE(385);
      END_STATE();
    case 421:
      if (lookahead == 'u') ADVANCE(352);
      END_STATE();
    case 422:
      if (lookahead == 'u') ADVANCE(284);
      END_STATE();
    case 423:
      if (lookahead == 'u') ADVANCE(54);
      END_STATE();
    case 424:
      if (lookahead == 'u') ADVANCE(301);
      END_STATE();
    case 425:
      if (lookahead == 'u') ADVANCE(56);
      END_STATE();
    case 426:
      if (lookahead == 'u') ADVANCE(303);
      END_STATE();
    case 427:
      if (lookahead == 'u') ADVANCE(291);
      END_STATE();
    case 428:
      if (lookahead == 'v') ADVANCE(151);
      END_STATE();
    case 429:
      if (lookahead == 'v') ADVANCE(76);
      END_STATE();
    case 430:
      if (lookahead == 'x') ADVANCE(1003);
      END_STATE();
    case 431:
      if (lookahead == 'x') ADVANCE(1003);
      if (lookahead == 'y') ADVANCE(372);
      END_STATE();
    case 432:
      if (lookahead == 'y') ADVANCE(490);
      END_STATE();
    case 433:
      if (lookahead == 'y') ADVANCE(467);
      END_STATE();
    case 434:
      if (lookahead == 'y') ADVANCE(372);
      END_STATE();
    case 435:
      if (lookahead == 'z') ADVANCE(214);
      END_STATE();
    case 436:
      if (lookahead == 'z') ADVANCE(145);
      END_STATE();
    case 437:
      if (lookahead == '{') ADVANCE(442);
      END_STATE();
    case 438:
      if (lookahead == '|') ADVANCE(513);
      END_STATE();
    case 439:
      if (lookahead == '}') ADVANCE(560);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(439);
      END_STATE();
    case 440:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(997);
      END_STATE();
    case 441:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(1002);
      END_STATE();
    case 442:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(439);
      END_STATE();
    case 443:
      if (eof) ADVANCE(445);
      ADVANCE_MAP(
        '!', 531,
        '"', 552,
        '#', 441,
        '%', 509,
        '&', 18,
        '(', 503,
        ')', 504,
        '*', 538,
        '+', 536,
        ',', 449,
        '-', 534,
        '.', 511,
        '/', 540,
        ':', 470,
        ';', 454,
        '<', 461,
        '=', 547,
        '>', 464,
        '?', 514,
        '@', 101,
        '[', 484,
        '\\', 559,
        ']', 485,
        'a', 264,
        'b', 306,
        'c', 44,
        'd', 157,
        'e', 45,
        'f', 51,
        'g', 240,
        'i', 172,
        'l', 147,
        'n', 561,
        'o', 413,
        'p', 61,
        'r', 127,
        's', 149,
        't', 332,
        'u', 437,
        'w', 193,
        '{', 448,
        '|', 508,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(443);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(995);
      END_STATE();
    case 444:
      if (eof) ADVANCE(445);
      ADVANCE_MAP(
        '!', 36,
        '%', 509,
        '&', 18,
        '(', 503,
        ')', 504,
        '*', 538,
        '+', 536,
        ',', 449,
        '-', 533,
        '.', 510,
        '/', 540,
        ':', 469,
        ';', 454,
        '<', 462,
        '=', 547,
        '>', 464,
        '?', 514,
        '[', 484,
        ']', 485,
        'c', 788,
        'e', 734,
        'g', 711,
        'i', 731,
        's', 832,
        '{', 448,
        '|', 438,
        '}', 450,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(444);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(996);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 446:
      ACCEPT_TOKEN(sym_export);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(sym_export);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 448:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 449:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 450:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 451:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 452:
      ACCEPT_TOKEN(anon_sym_import);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 453:
      ACCEPT_TOKEN(anon_sym_from);
      END_STATE();
    case 454:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(anon_sym_as);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 457:
      ACCEPT_TOKEN(anon_sym_component);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(anon_sym_component);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 459:
      ACCEPT_TOKEN(anon_sym_inherits);
      END_STATE();
    case 460:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(543);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(542);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(541);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(anon_sym_return);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(anon_sym_property);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(anon_sym_property);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '=') ADVANCE(456);
      END_STATE();
    case 471:
      ACCEPT_TOKEN(anon_sym_LT_EQ_GT);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 473:
      ACCEPT_TOKEN(anon_sym_global);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(anon_sym_struct);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(anon_sym_enum);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 478:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == '-') ADVANCE(785);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 479:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(anon_sym_out);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(anon_sym_out);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(anon_sym_transitions);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(anon_sym_transitions);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(anon_sym_states);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(anon_sym_when);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(anon_sym_animate);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(anon_sym_animate);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(anon_sym_delay);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(anon_sym_duration);
      END_STATE();
    case 492:
      ACCEPT_TOKEN(anon_sym_duration);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(anon_sym_iteration_DASHcount);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(anon_sym_direction);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(anon_sym_easing);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(anon_sym_easing);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(anon_sym_if);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(anon_sym_else);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(anon_sym_for);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(anon_sym_ATtr);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(513);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(997);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(sym_logical_and);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(sym_logical_or);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(anon_sym_callback);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(anon_sym_callback);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(anon_sym_pure);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(anon_sym_pure);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(anon_sym_public);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(anon_sym_public);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(anon_sym_private);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(anon_sym_private);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(anon_sym_function);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(anon_sym_changed);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(anon_sym_changed);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_ATimage_DASHurl);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(anon_sym_nine_DASHslice);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(545);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(549);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(549);
      if (lookahead == '>') ADVANCE(517);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(548);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(550);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(23);
      if (lookahead == '/') ADVANCE(1017);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(23);
      if (lookahead == '/') ADVANCE(1017);
      if (lookahead == '=') ADVANCE(551);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      if (lookahead == '>') ADVANCE(471);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(544);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(544);
      if (lookahead == '>') ADVANCE(506);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(sym__unescaped_string_fragment);
      if (lookahead == '*') ADVANCE(555);
      if (lookahead == '/') ADVANCE(557);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(558);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(sym__unescaped_string_fragment);
      if (lookahead == '*') ADVANCE(554);
      if (lookahead == '/') ADVANCE(558);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(555);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(sym__unescaped_string_fragment);
      if (lookahead == '*') ADVANCE(554);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(555);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(sym__unescaped_string_fragment);
      if (lookahead == '/') ADVANCE(553);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(556);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(558);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(sym__unescaped_string_fragment);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(558);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(557);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(sym__unescaped_string_fragment);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(558);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token1);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(anon_sym_n);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(anon_sym_in_DASHout);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == '-') ADVANCE(603);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == '-') ADVANCE(668);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == '-') ADVANCE(721);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == '-') ADVANCE(827);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(822);
      if (lookahead == 'l') ADVANCE(828);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(822);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(626);
      if (lookahead == 'i') ADVANCE(757);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(629);
      if (lookahead == 'e') ADVANCE(729);
      if (lookahead == 'o') ADVANCE(776);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(629);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(709);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(826);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(627);
      if (lookahead == 'i') ADVANCE(759);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(720);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(608);
      if (lookahead == 'o') ADVANCE(874);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(628);
      if (lookahead == 'i') ADVANCE(760);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(818);
      if (lookahead == 'h') ADVANCE(889);
      if (lookahead == 't' ||
          lookahead == 'x') ADVANCE(1006);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(818);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(715);
      if (lookahead == 'h') ADVANCE(585);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(715);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(616);
      if (lookahead == 'o') ADVANCE(885);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(796);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(617);
      if (lookahead == 'o') ADVANCE(886);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(743);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(713);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(744);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(619);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(862);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(863);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(864);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(851);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(860);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(674);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(825);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(829);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(830);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'a') ADVANCE(868);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'b') ADVANCE(572);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'b') ADVANCE(576);
      if (lookahead == 'c') ADVANCE(686);
      if (lookahead == 'e') ADVANCE(714);
      if (lookahead == 'o') ADVANCE(879);
      if (lookahead == 'q') ADVANCE(870);
      if (lookahead == 's') ADVANCE(700);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'b') ADVANCE(681);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'b') ADVANCE(722);
      if (lookahead == 'r') ADVANCE(643);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'b') ADVANCE(634);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'b') ADVANCE(588);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'b') ADVANCE(582);
      if (lookahead == 'c') ADVANCE(689);
      if (lookahead == 'e') ADVANCE(724);
      if (lookahead == 'q') ADVANCE(883);
      if (lookahead == 's') ADVANCE(702);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'b') ADVANCE(584);
      if (lookahead == 'c') ADVANCE(690);
      if (lookahead == 'e') ADVANCE(725);
      if (lookahead == 'q') ADVANCE(884);
      if (lookahead == 's') ADVANCE(703);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(563);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(705);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(964);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(966);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(970);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(968);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(972);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(974);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(521);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(706);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(707);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(835);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(708);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(637);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(638);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 622:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(640);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(859);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(586);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'c') ADVANCE(663);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'd') ADVANCE(920);
      if (lookahead == 'r') ADVANCE(841);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'd') ADVANCE(922);
      if (lookahead == 'r') ADVANCE(843);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'd') ADVANCE(924);
      if (lookahead == 'r') ADVANCE(845);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'd') ADVANCE(1012);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'd') ADVANCE(527);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(925);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(999);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 633:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(1001);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(892);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(952);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(954);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(976);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(978);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(956);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(980);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(669);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(500);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(519);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(489);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(523);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(910);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(914);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(916);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(748);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 650:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(630);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(564);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(712);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(819);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 654:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(856);
      if (lookahead == 'o') ADVANCE(776);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(723);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(797);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(814);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 658:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(747);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(754);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 660:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(583);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 661:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(812);
      if (lookahead == 'h') ADVANCE(891);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 662:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(764);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 663:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'e') ADVANCE(761);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 664:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'f') ADVANCE(498);
      if (lookahead == 'n') ADVANCE(1006);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 665:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'f') ADVANCE(498);
      if (lookahead == 'n') ADVANCE(478);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'f') ADVANCE(498);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 667:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'f') ADVANCE(994);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'f') ADVANCE(787);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 669:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'g') ADVANCE(1012);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 670:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'g') ADVANCE(496);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 671:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'g') ADVANCE(900);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'g') ADVANCE(718);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'g') ADVANCE(650);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'g') ADVANCE(647);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 675:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'g') ADVANCE(853);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 676:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'g') ADVANCE(854);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 677:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'h') ADVANCE(904);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 678:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'h') ADVANCE(908);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 679:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'h') ADVANCE(906);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 680:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(888);
      if (lookahead == 'o') ADVANCE(795);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 681:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(607);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 682:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(893);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 683:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(887);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 684:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(732);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 685:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(737);
      if (lookahead == 'o') ADVANCE(877);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 686:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(807);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 687:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(611);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 688:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(656);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 689:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(809);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 690:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(811);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 691:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(613);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 692:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(778);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 693:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(614);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 694:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(615);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 695:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(624);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 696:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(750);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 697:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(753);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 698:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(746);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 699:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(779);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 700:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(755);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 701:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(783);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 702:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(756);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 703:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(758);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 704:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'i') ADVANCE(867);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 705:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'k') ADVANCE(958);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 706:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'k') ADVANCE(960);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 707:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'k') ADVANCE(962);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 708:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'k') ADVANCE(516);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 709:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(473);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 710:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(899);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 711:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(767);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 712:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(667);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 713:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(565);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 714:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(573);
      if (lookahead == 'x') ADVANCE(792);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 715:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(719);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 716:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(786);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 717:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(782);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 718:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(646);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 719:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(604);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 720:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(823);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 721:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(662);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 722:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(694);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 723:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(593);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 724:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(596);
      if (lookahead == 'x') ADVANCE(793);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 725:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'l') ADVANCE(597);
      if (lookahead == 'x') ADVANCE(794);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 726:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'm') ADVANCE(476);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 727:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'm') ADVANCE(1006);
      if (lookahead == 's') ADVANCE(1010);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 728:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'm') ADVANCE(1006);
      if (lookahead == 'u') ADVANCE(601);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 729:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'm') ADVANCE(1015);
      if (lookahead == 't') ADVANCE(873);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 730:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'm') ADVANCE(594);
      if (lookahead == 'n') ADVANCE(850);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 731:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'm') ADVANCE(790);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 732:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'm') ADVANCE(590);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 733:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'm') ADVANCE(791);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 734:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(871);
      if (lookahead == 'x') ADVANCE(789);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 735:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(649);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 736:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(466);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 737:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(928);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 738:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(479);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 739:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(1012);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 740:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(478);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 741:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(525);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 742:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(492);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 743:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(673);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 744:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(824);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 745:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(672);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 746:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(660);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 747:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(675);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 748:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(836);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 749:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(820);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 750:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(670);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 751:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(620);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 752:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(684);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 753:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(671);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 754:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(838);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 755:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(635);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 756:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(636);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 757:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(842);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 758:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(639);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 759:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(844);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 760:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(846);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 761:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(852);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 762:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(855);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 763:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(623);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 764:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(676);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 765:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(621);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 766:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'n') ADVANCE(622);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 767:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(599);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 768:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(735);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 769:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(946);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 770:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(948);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 771:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(950);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 772:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(795);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 773:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(800);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 774:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(803);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 775:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(776);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 776:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(837);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 777:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(710);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 778:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(741);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 779:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(749);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 780:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(777);
      if (lookahead == 'r') ADVANCE(876);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 781:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(798);
      if (lookahead == 'u') ADVANCE(763);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 782:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(799);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 783:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(742);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 784:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(717);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 785:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(882);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 786:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(592);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 787:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(762);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 788:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'o') ADVANCE(733);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 789:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'p') ADVANCE(773);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 790:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'p') ADVANCE(774);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 791:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'p') ADVANCE(768);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 792:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'p') ADVANCE(769);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 793:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'p') ADVANCE(770);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 794:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'p') ADVANCE(771);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 795:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'p') ADVANCE(657);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 796:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(918);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 797:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(982);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 798:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(502);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 799:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(902);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 800:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(833);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 801:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(869);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 802:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(680);
      if (lookahead == 'u') ADVANCE(602);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 803:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(834);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 804:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(736);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 805:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(875);
      if (lookahead == 'u') ADVANCE(810);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 806:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(875);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 807:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(609);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 808:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(571);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 809:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(610);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 810:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(739);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 811:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(612);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 812:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(625);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 813:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(772);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 814:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(849);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 815:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(587);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 816:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(697);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 817:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(598);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 818:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'r') ADVANCE(659);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 819:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 's') ADVANCE(486);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 820:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 's') ADVANCE(483);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 821:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 's') ADVANCE(677);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 822:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 's') ADVANCE(631);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 823:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 's') ADVANCE(633);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 824:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 's') ADVANCE(704);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 825:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 's') ADVANCE(696);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 826:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 's') ADVANCE(857);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 827:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 's') ADVANCE(682);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 828:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 's') ADVANCE(642);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 829:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 's') ADVANCE(865);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 830:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 's') ADVANCE(866);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 831:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 's') ADVANCE(695);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 832:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(801);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 833:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(447);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 834:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(452);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 835:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(474);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 836:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(458);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 837:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(992);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 838:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(990);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 839:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(930);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 840:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(932);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 841:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(934);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 842:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(940);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 843:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(936);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 844:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(942);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 845:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(938);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 846:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(944);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 847:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(481);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 848:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(562);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 849:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(890);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 850:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(895);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 851:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(897);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 852:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(912);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 853:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(678);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 854:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(679);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 855:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(566);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 856:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(873);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 857:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(687);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 858:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(589);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 859:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(692);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 860:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(683);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 861:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(816);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 862:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(653);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 863:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(644);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 864:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(645);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 865:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(691);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 866:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(693);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 867:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(699);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 868:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 't') ADVANCE(701);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 869:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(618);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 870:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(569);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 871:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(726);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 872:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(601);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 873:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(804);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 874:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(751);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 875:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(632);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 876:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(821);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 877:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(839);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 878:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(763);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 879:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(840);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 880:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(817);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 881:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(847);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 882:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(848);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 883:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(574);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 884:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(577);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 885:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(765);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 886:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'u') ADVANCE(766);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 887:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'v') ADVANCE(651);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 888:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'v') ADVANCE(591);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 889:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'x') ADVANCE(1004);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 890:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'y') ADVANCE(468);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 891:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'y') ADVANCE(831);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 892:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'z') ADVANCE(688);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'y')) ADVANCE(894);
      END_STATE();
    case 893:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == 'z') ADVANCE(648);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'y')) ADVANCE(894);
      END_STATE();
    case 894:
      ACCEPT_TOKEN(sym__identifier);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 895:
      ACCEPT_TOKEN(anon_sym_int);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 896:
      ACCEPT_TOKEN(anon_sym_float);
      END_STATE();
    case 897:
      ACCEPT_TOKEN(anon_sym_float);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 898:
      ACCEPT_TOKEN(anon_sym_bool);
      END_STATE();
    case 899:
      ACCEPT_TOKEN(anon_sym_bool);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 900:
      ACCEPT_TOKEN(anon_sym_string);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 901:
      ACCEPT_TOKEN(anon_sym_color);
      END_STATE();
    case 902:
      ACCEPT_TOKEN(anon_sym_color);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 903:
      ACCEPT_TOKEN(anon_sym_brush);
      END_STATE();
    case 904:
      ACCEPT_TOKEN(anon_sym_brush);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 905:
      ACCEPT_TOKEN(anon_sym_physical_DASHlength);
      END_STATE();
    case 906:
      ACCEPT_TOKEN(anon_sym_physical_DASHlength);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 907:
      ACCEPT_TOKEN(anon_sym_length);
      END_STATE();
    case 908:
      ACCEPT_TOKEN(anon_sym_length);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 909:
      ACCEPT_TOKEN(anon_sym_angle);
      END_STATE();
    case 910:
      ACCEPT_TOKEN(anon_sym_angle);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 911:
      ACCEPT_TOKEN(anon_sym_percent);
      END_STATE();
    case 912:
      ACCEPT_TOKEN(anon_sym_percent);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 913:
      ACCEPT_TOKEN(anon_sym_image);
      END_STATE();
    case 914:
      ACCEPT_TOKEN(anon_sym_image);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 915:
      ACCEPT_TOKEN(anon_sym_relative_DASHfont_DASHsize);
      END_STATE();
    case 916:
      ACCEPT_TOKEN(anon_sym_relative_DASHfont_DASHsize);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 917:
      ACCEPT_TOKEN(anon_sym_linear);
      END_STATE();
    case 918:
      ACCEPT_TOKEN(anon_sym_linear);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 919:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHquad);
      END_STATE();
    case 920:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHquad);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 921:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHquad);
      END_STATE();
    case 922:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHquad);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 923:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHquad);
      END_STATE();
    case 924:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHquad);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 925:
      ACCEPT_TOKEN(anon_sym_ease);
      if (lookahead == '-') ADVANCE(685);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 926:
      ACCEPT_TOKEN(anon_sym_ease);
      if (lookahead == '-') ADVANCE(203);
      END_STATE();
    case 927:
      ACCEPT_TOKEN(anon_sym_ease_DASHin);
      if (lookahead == '-') ADVANCE(83);
      END_STATE();
    case 928:
      ACCEPT_TOKEN(anon_sym_ease_DASHin);
      if (lookahead == '-') ADVANCE(600);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 929:
      ACCEPT_TOKEN(anon_sym_ease_DASHout);
      if (lookahead == '-') ADVANCE(89);
      END_STATE();
    case 930:
      ACCEPT_TOKEN(anon_sym_ease_DASHout);
      if (lookahead == '-') ADVANCE(605);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 931:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout);
      if (lookahead == '-') ADVANCE(90);
      END_STATE();
    case 932:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout);
      if (lookahead == '-') ADVANCE(606);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 933:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHquart);
      END_STATE();
    case 934:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHquart);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 935:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHquart);
      END_STATE();
    case 936:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHquart);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 937:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHquart);
      END_STATE();
    case 938:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHquart);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 939:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHquint);
      END_STATE();
    case 940:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHquint);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 941:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHquint);
      END_STATE();
    case 942:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHquint);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 943:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHquint);
      END_STATE();
    case 944:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHquint);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 945:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHexpo);
      END_STATE();
    case 946:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHexpo);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 947:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHexpo);
      END_STATE();
    case 948:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHexpo);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 949:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHexpo);
      END_STATE();
    case 950:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHexpo);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 951:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHsine);
      END_STATE();
    case 952:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHsine);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 953:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHsine);
      END_STATE();
    case 954:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHsine);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 955:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHsine);
      END_STATE();
    case 956:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHsine);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 957:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHback);
      END_STATE();
    case 958:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHback);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 959:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHback);
      END_STATE();
    case 960:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHback);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 961:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHback);
      END_STATE();
    case 962:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHback);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 963:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHcirc);
      END_STATE();
    case 964:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHcirc);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 965:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHcirc);
      END_STATE();
    case 966:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHcirc);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 967:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHcirc);
      END_STATE();
    case 968:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHcirc);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 969:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHelastic);
      END_STATE();
    case 970:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHelastic);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 971:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHelastic);
      END_STATE();
    case 972:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHelastic);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 973:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHelastic);
      END_STATE();
    case 974:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHelastic);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 975:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHbounce);
      END_STATE();
    case 976:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHbounce);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 977:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHbounce);
      END_STATE();
    case 978:
      ACCEPT_TOKEN(anon_sym_ease_DASHout_DASHbounce);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 979:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHbounce);
      END_STATE();
    case 980:
      ACCEPT_TOKEN(anon_sym_ease_DASHin_DASHout_DASHbounce);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 981:
      ACCEPT_TOKEN(anon_sym_cubic_DASHbezier);
      END_STATE();
    case 982:
      ACCEPT_TOKEN(anon_sym_cubic_DASHbezier);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 983:
      ACCEPT_TOKEN(sym_children_identifier);
      END_STATE();
    case 984:
      ACCEPT_TOKEN(anon_sym_ATlinear_DASHgradient);
      END_STATE();
    case 985:
      ACCEPT_TOKEN(anon_sym_ATlinear_gradient);
      END_STATE();
    case 986:
      ACCEPT_TOKEN(anon_sym_ATradial_DASHgradient);
      END_STATE();
    case 987:
      ACCEPT_TOKEN(anon_sym_ATradial_gradient);
      END_STATE();
    case 988:
      ACCEPT_TOKEN(anon_sym_circle);
      END_STATE();
    case 989:
      ACCEPT_TOKEN(anon_sym_parent);
      END_STATE();
    case 990:
      ACCEPT_TOKEN(anon_sym_parent);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 991:
      ACCEPT_TOKEN(anon_sym_root);
      END_STATE();
    case 992:
      ACCEPT_TOKEN(anon_sym_root);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 993:
      ACCEPT_TOKEN(anon_sym_self);
      END_STATE();
    case 994:
      ACCEPT_TOKEN(anon_sym_self);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 995:
      ACCEPT_TOKEN(sym__int_number);
      if (lookahead == '.') ADVANCE(997);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(995);
      END_STATE();
    case 996:
      ACCEPT_TOKEN(sym__int_number);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(996);
      END_STATE();
    case 997:
      ACCEPT_TOKEN(sym__float_number);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(997);
      END_STATE();
    case 998:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 999:
      ACCEPT_TOKEN(anon_sym_true);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 1000:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 1001:
      ACCEPT_TOKEN(anon_sym_false);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 1002:
      ACCEPT_TOKEN(sym_color_value);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(1002);
      END_STATE();
    case 1003:
      ACCEPT_TOKEN(anon_sym_phx);
      END_STATE();
    case 1004:
      ACCEPT_TOKEN(anon_sym_phx);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 1005:
      ACCEPT_TOKEN(aux_sym_length_value_token1);
      END_STATE();
    case 1006:
      ACCEPT_TOKEN(aux_sym_length_value_token1);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 1007:
      ACCEPT_TOKEN(aux_sym_duration_value_token1);
      END_STATE();
    case 1008:
      ACCEPT_TOKEN(aux_sym_duration_value_token1);
      if (lookahead == 'e') ADVANCE(233);
      END_STATE();
    case 1009:
      ACCEPT_TOKEN(aux_sym_duration_value_token1);
      if (lookahead == 'e') ADVANCE(712);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 1010:
      ACCEPT_TOKEN(aux_sym_duration_value_token1);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 1011:
      ACCEPT_TOKEN(aux_sym_angle_value_token1);
      END_STATE();
    case 1012:
      ACCEPT_TOKEN(aux_sym_angle_value_token1);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 1013:
      ACCEPT_TOKEN(anon_sym_PERCENT2);
      END_STATE();
    case 1014:
      ACCEPT_TOKEN(anon_sym_rem);
      END_STATE();
    case 1015:
      ACCEPT_TOKEN(anon_sym_rem);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(894);
      END_STATE();
    case 1016:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 1017:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(1017);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 444},
  [2] = {.lex_state = 1},
  [3] = {.lex_state = 1},
  [4] = {.lex_state = 1},
  [5] = {.lex_state = 1},
  [6] = {.lex_state = 1},
  [7] = {.lex_state = 1},
  [8] = {.lex_state = 1},
  [9] = {.lex_state = 1},
  [10] = {.lex_state = 1},
  [11] = {.lex_state = 1},
  [12] = {.lex_state = 1},
  [13] = {.lex_state = 1},
  [14] = {.lex_state = 1},
  [15] = {.lex_state = 1},
  [16] = {.lex_state = 5},
  [17] = {.lex_state = 5},
  [18] = {.lex_state = 5},
  [19] = {.lex_state = 15},
  [20] = {.lex_state = 15},
  [21] = {.lex_state = 15},
  [22] = {.lex_state = 15},
  [23] = {.lex_state = 15},
  [24] = {.lex_state = 15},
  [25] = {.lex_state = 15},
  [26] = {.lex_state = 15},
  [27] = {.lex_state = 15},
  [28] = {.lex_state = 15},
  [29] = {.lex_state = 15},
  [30] = {.lex_state = 15},
  [31] = {.lex_state = 15},
  [32] = {.lex_state = 15},
  [33] = {.lex_state = 15},
  [34] = {.lex_state = 15},
  [35] = {.lex_state = 15},
  [36] = {.lex_state = 15},
  [37] = {.lex_state = 15},
  [38] = {.lex_state = 15},
  [39] = {.lex_state = 15},
  [40] = {.lex_state = 15},
  [41] = {.lex_state = 15},
  [42] = {.lex_state = 15},
  [43] = {.lex_state = 15},
  [44] = {.lex_state = 15},
  [45] = {.lex_state = 15},
  [46] = {.lex_state = 15},
  [47] = {.lex_state = 15},
  [48] = {.lex_state = 15},
  [49] = {.lex_state = 15},
  [50] = {.lex_state = 15},
  [51] = {.lex_state = 15},
  [52] = {.lex_state = 15},
  [53] = {.lex_state = 15},
  [54] = {.lex_state = 15},
  [55] = {.lex_state = 15},
  [56] = {.lex_state = 15},
  [57] = {.lex_state = 15},
  [58] = {.lex_state = 15},
  [59] = {.lex_state = 15},
  [60] = {.lex_state = 15},
  [61] = {.lex_state = 15},
  [62] = {.lex_state = 15},
  [63] = {.lex_state = 15},
  [64] = {.lex_state = 15},
  [65] = {.lex_state = 15},
  [66] = {.lex_state = 15},
  [67] = {.lex_state = 15},
  [68] = {.lex_state = 15},
  [69] = {.lex_state = 15},
  [70] = {.lex_state = 15},
  [71] = {.lex_state = 15},
  [72] = {.lex_state = 15},
  [73] = {.lex_state = 15},
  [74] = {.lex_state = 15},
  [75] = {.lex_state = 15},
  [76] = {.lex_state = 15},
  [77] = {.lex_state = 15},
  [78] = {.lex_state = 15},
  [79] = {.lex_state = 15},
  [80] = {.lex_state = 15},
  [81] = {.lex_state = 15},
  [82] = {.lex_state = 15},
  [83] = {.lex_state = 15},
  [84] = {.lex_state = 15},
  [85] = {.lex_state = 15},
  [86] = {.lex_state = 15},
  [87] = {.lex_state = 15},
  [88] = {.lex_state = 15},
  [89] = {.lex_state = 15},
  [90] = {.lex_state = 15},
  [91] = {.lex_state = 15},
  [92] = {.lex_state = 15},
  [93] = {.lex_state = 15},
  [94] = {.lex_state = 15},
  [95] = {.lex_state = 15},
  [96] = {.lex_state = 15},
  [97] = {.lex_state = 15},
  [98] = {.lex_state = 15},
  [99] = {.lex_state = 15},
  [100] = {.lex_state = 15},
  [101] = {.lex_state = 15},
  [102] = {.lex_state = 15},
  [103] = {.lex_state = 15},
  [104] = {.lex_state = 15},
  [105] = {.lex_state = 15},
  [106] = {.lex_state = 15},
  [107] = {.lex_state = 15},
  [108] = {.lex_state = 15},
  [109] = {.lex_state = 15},
  [110] = {.lex_state = 15},
  [111] = {.lex_state = 15},
  [112] = {.lex_state = 15},
  [113] = {.lex_state = 15},
  [114] = {.lex_state = 15},
  [115] = {.lex_state = 15},
  [116] = {.lex_state = 15},
  [117] = {.lex_state = 15},
  [118] = {.lex_state = 15},
  [119] = {.lex_state = 15},
  [120] = {.lex_state = 15},
  [121] = {.lex_state = 15},
  [122] = {.lex_state = 15},
  [123] = {.lex_state = 15},
  [124] = {.lex_state = 15},
  [125] = {.lex_state = 15},
  [126] = {.lex_state = 15},
  [127] = {.lex_state = 15},
  [128] = {.lex_state = 15},
  [129] = {.lex_state = 15},
  [130] = {.lex_state = 15},
  [131] = {.lex_state = 15},
  [132] = {.lex_state = 15},
  [133] = {.lex_state = 15},
  [134] = {.lex_state = 15},
  [135] = {.lex_state = 15},
  [136] = {.lex_state = 15},
  [137] = {.lex_state = 15},
  [138] = {.lex_state = 15},
  [139] = {.lex_state = 15},
  [140] = {.lex_state = 15},
  [141] = {.lex_state = 15},
  [142] = {.lex_state = 15},
  [143] = {.lex_state = 15},
  [144] = {.lex_state = 15},
  [145] = {.lex_state = 15},
  [146] = {.lex_state = 15},
  [147] = {.lex_state = 15},
  [148] = {.lex_state = 15},
  [149] = {.lex_state = 2},
  [150] = {.lex_state = 2},
  [151] = {.lex_state = 1},
  [152] = {.lex_state = 1},
  [153] = {.lex_state = 1},
  [154] = {.lex_state = 1},
  [155] = {.lex_state = 1},
  [156] = {.lex_state = 1},
  [157] = {.lex_state = 1},
  [158] = {.lex_state = 1},
  [159] = {.lex_state = 1},
  [160] = {.lex_state = 1},
  [161] = {.lex_state = 1},
  [162] = {.lex_state = 1},
  [163] = {.lex_state = 1},
  [164] = {.lex_state = 1},
  [165] = {.lex_state = 1},
  [166] = {.lex_state = 1},
  [167] = {.lex_state = 1},
  [168] = {.lex_state = 1},
  [169] = {.lex_state = 1},
  [170] = {.lex_state = 1},
  [171] = {.lex_state = 1},
  [172] = {.lex_state = 1},
  [173] = {.lex_state = 1},
  [174] = {.lex_state = 1},
  [175] = {.lex_state = 1},
  [176] = {.lex_state = 1},
  [177] = {.lex_state = 1},
  [178] = {.lex_state = 1},
  [179] = {.lex_state = 1},
  [180] = {.lex_state = 1},
  [181] = {.lex_state = 1},
  [182] = {.lex_state = 1},
  [183] = {.lex_state = 1},
  [184] = {.lex_state = 1},
  [185] = {.lex_state = 1},
  [186] = {.lex_state = 1},
  [187] = {.lex_state = 1},
  [188] = {.lex_state = 1},
  [189] = {.lex_state = 1},
  [190] = {.lex_state = 1},
  [191] = {.lex_state = 1},
  [192] = {.lex_state = 1},
  [193] = {.lex_state = 1},
  [194] = {.lex_state = 1},
  [195] = {.lex_state = 1},
  [196] = {.lex_state = 1},
  [197] = {.lex_state = 1},
  [198] = {.lex_state = 1},
  [199] = {.lex_state = 1},
  [200] = {.lex_state = 1},
  [201] = {.lex_state = 1},
  [202] = {.lex_state = 1},
  [203] = {.lex_state = 1},
  [204] = {.lex_state = 1},
  [205] = {.lex_state = 1},
  [206] = {.lex_state = 1},
  [207] = {.lex_state = 1},
  [208] = {.lex_state = 1},
  [209] = {.lex_state = 1},
  [210] = {.lex_state = 1},
  [211] = {.lex_state = 1},
  [212] = {.lex_state = 1},
  [213] = {.lex_state = 1},
  [214] = {.lex_state = 1},
  [215] = {.lex_state = 1},
  [216] = {.lex_state = 1},
  [217] = {.lex_state = 1},
  [218] = {.lex_state = 1},
  [219] = {.lex_state = 1},
  [220] = {.lex_state = 1},
  [221] = {.lex_state = 1},
  [222] = {.lex_state = 1},
  [223] = {.lex_state = 1},
  [224] = {.lex_state = 1},
  [225] = {.lex_state = 1},
  [226] = {.lex_state = 1},
  [227] = {.lex_state = 1},
  [228] = {.lex_state = 1},
  [229] = {.lex_state = 5},
  [230] = {.lex_state = 5},
  [231] = {.lex_state = 5},
  [232] = {.lex_state = 1},
  [233] = {.lex_state = 1},
  [234] = {.lex_state = 16},
  [235] = {.lex_state = 16},
  [236] = {.lex_state = 16},
  [237] = {.lex_state = 5},
  [238] = {.lex_state = 1},
  [239] = {.lex_state = 1},
  [240] = {.lex_state = 1},
  [241] = {.lex_state = 1},
  [242] = {.lex_state = 1},
  [243] = {.lex_state = 5},
  [244] = {.lex_state = 1},
  [245] = {.lex_state = 5},
  [246] = {.lex_state = 1},
  [247] = {.lex_state = 1},
  [248] = {.lex_state = 1},
  [249] = {.lex_state = 5},
  [250] = {.lex_state = 1},
  [251] = {.lex_state = 1},
  [252] = {.lex_state = 5},
  [253] = {.lex_state = 1},
  [254] = {.lex_state = 5},
  [255] = {.lex_state = 1},
  [256] = {.lex_state = 5},
  [257] = {.lex_state = 5},
  [258] = {.lex_state = 5},
  [259] = {.lex_state = 1},
  [260] = {.lex_state = 1},
  [261] = {.lex_state = 15},
  [262] = {.lex_state = 15},
  [263] = {.lex_state = 15},
  [264] = {.lex_state = 15},
  [265] = {.lex_state = 15},
  [266] = {.lex_state = 15},
  [267] = {.lex_state = 12},
  [268] = {.lex_state = 12},
  [269] = {.lex_state = 12},
  [270] = {.lex_state = 12},
  [271] = {.lex_state = 12},
  [272] = {.lex_state = 12},
  [273] = {.lex_state = 12},
  [274] = {.lex_state = 12},
  [275] = {.lex_state = 12},
  [276] = {.lex_state = 12},
  [277] = {.lex_state = 12},
  [278] = {.lex_state = 12},
  [279] = {.lex_state = 9},
  [280] = {.lex_state = 6},
  [281] = {.lex_state = 6},
  [282] = {.lex_state = 444},
  [283] = {.lex_state = 8},
  [284] = {.lex_state = 444},
  [285] = {.lex_state = 444},
  [286] = {.lex_state = 444},
  [287] = {.lex_state = 8},
  [288] = {.lex_state = 444},
  [289] = {.lex_state = 8},
  [290] = {.lex_state = 444},
  [291] = {.lex_state = 444},
  [292] = {.lex_state = 444},
  [293] = {.lex_state = 444},
  [294] = {.lex_state = 444},
  [295] = {.lex_state = 444},
  [296] = {.lex_state = 444},
  [297] = {.lex_state = 444},
  [298] = {.lex_state = 444},
  [299] = {.lex_state = 444},
  [300] = {.lex_state = 444},
  [301] = {.lex_state = 444},
  [302] = {.lex_state = 444},
  [303] = {.lex_state = 444},
  [304] = {.lex_state = 444},
  [305] = {.lex_state = 444},
  [306] = {.lex_state = 444},
  [307] = {.lex_state = 444},
  [308] = {.lex_state = 444},
  [309] = {.lex_state = 444},
  [310] = {.lex_state = 444},
  [311] = {.lex_state = 444},
  [312] = {.lex_state = 444},
  [313] = {.lex_state = 444},
  [314] = {.lex_state = 444},
  [315] = {.lex_state = 444},
  [316] = {.lex_state = 444},
  [317] = {.lex_state = 444},
  [318] = {.lex_state = 444},
  [319] = {.lex_state = 444},
  [320] = {.lex_state = 444},
  [321] = {.lex_state = 444},
  [322] = {.lex_state = 444},
  [323] = {.lex_state = 444},
  [324] = {.lex_state = 444},
  [325] = {.lex_state = 444},
  [326] = {.lex_state = 444},
  [327] = {.lex_state = 444},
  [328] = {.lex_state = 444},
  [329] = {.lex_state = 444},
  [330] = {.lex_state = 444},
  [331] = {.lex_state = 444},
  [332] = {.lex_state = 444},
  [333] = {.lex_state = 444},
  [334] = {.lex_state = 444},
  [335] = {.lex_state = 444},
  [336] = {.lex_state = 444},
  [337] = {.lex_state = 444},
  [338] = {.lex_state = 444},
  [339] = {.lex_state = 444},
  [340] = {.lex_state = 444},
  [341] = {.lex_state = 444},
  [342] = {.lex_state = 444},
  [343] = {.lex_state = 14},
  [344] = {.lex_state = 444},
  [345] = {.lex_state = 444},
  [346] = {.lex_state = 444},
  [347] = {.lex_state = 444},
  [348] = {.lex_state = 444},
  [349] = {.lex_state = 444},
  [350] = {.lex_state = 444},
  [351] = {.lex_state = 444},
  [352] = {.lex_state = 444},
  [353] = {.lex_state = 444},
  [354] = {.lex_state = 444},
  [355] = {.lex_state = 8},
  [356] = {.lex_state = 7},
  [357] = {.lex_state = 7},
  [358] = {.lex_state = 8},
  [359] = {.lex_state = 8},
  [360] = {.lex_state = 8},
  [361] = {.lex_state = 8},
  [362] = {.lex_state = 8},
  [363] = {.lex_state = 8},
  [364] = {.lex_state = 8},
  [365] = {.lex_state = 8},
  [366] = {.lex_state = 8},
  [367] = {.lex_state = 14},
  [368] = {.lex_state = 8},
  [369] = {.lex_state = 14},
  [370] = {.lex_state = 8},
  [371] = {.lex_state = 8},
  [372] = {.lex_state = 8},
  [373] = {.lex_state = 14},
  [374] = {.lex_state = 8},
  [375] = {.lex_state = 8},
  [376] = {.lex_state = 8},
  [377] = {.lex_state = 8},
  [378] = {.lex_state = 8},
  [379] = {.lex_state = 1},
  [380] = {.lex_state = 1},
  [381] = {.lex_state = 1},
  [382] = {.lex_state = 1},
  [383] = {.lex_state = 1},
  [384] = {.lex_state = 1},
  [385] = {.lex_state = 1},
  [386] = {.lex_state = 1},
  [387] = {.lex_state = 444},
  [388] = {.lex_state = 444},
  [389] = {.lex_state = 1},
  [390] = {.lex_state = 444},
  [391] = {.lex_state = 444},
  [392] = {.lex_state = 444},
  [393] = {.lex_state = 444},
  [394] = {.lex_state = 444},
  [395] = {.lex_state = 444},
  [396] = {.lex_state = 444},
  [397] = {.lex_state = 444},
  [398] = {.lex_state = 444},
  [399] = {.lex_state = 444},
  [400] = {.lex_state = 444},
  [401] = {.lex_state = 444},
  [402] = {.lex_state = 444},
  [403] = {.lex_state = 444},
  [404] = {.lex_state = 444},
  [405] = {.lex_state = 444},
  [406] = {.lex_state = 444},
  [407] = {.lex_state = 8},
  [408] = {.lex_state = 444},
  [409] = {.lex_state = 444},
  [410] = {.lex_state = 444},
  [411] = {.lex_state = 444},
  [412] = {.lex_state = 444},
  [413] = {.lex_state = 444},
  [414] = {.lex_state = 444},
  [415] = {.lex_state = 444},
  [416] = {.lex_state = 444},
  [417] = {.lex_state = 444},
  [418] = {.lex_state = 444},
  [419] = {.lex_state = 444},
  [420] = {.lex_state = 444},
  [421] = {.lex_state = 444},
  [422] = {.lex_state = 444},
  [423] = {.lex_state = 444},
  [424] = {.lex_state = 444},
  [425] = {.lex_state = 444},
  [426] = {.lex_state = 444},
  [427] = {.lex_state = 444},
  [428] = {.lex_state = 444},
  [429] = {.lex_state = 444},
  [430] = {.lex_state = 444},
  [431] = {.lex_state = 8},
  [432] = {.lex_state = 444},
  [433] = {.lex_state = 444},
  [434] = {.lex_state = 444},
  [435] = {.lex_state = 444},
  [436] = {.lex_state = 12},
  [437] = {.lex_state = 444},
  [438] = {.lex_state = 444},
  [439] = {.lex_state = 444},
  [440] = {.lex_state = 444},
  [441] = {.lex_state = 12},
  [442] = {.lex_state = 444},
  [443] = {.lex_state = 444},
  [444] = {.lex_state = 13},
  [445] = {.lex_state = 444},
  [446] = {.lex_state = 444},
  [447] = {.lex_state = 12},
  [448] = {.lex_state = 444},
  [449] = {.lex_state = 444},
  [450] = {.lex_state = 444},
  [451] = {.lex_state = 444},
  [452] = {.lex_state = 444},
  [453] = {.lex_state = 12},
  [454] = {.lex_state = 8},
  [455] = {.lex_state = 12},
  [456] = {.lex_state = 12},
  [457] = {.lex_state = 12},
  [458] = {.lex_state = 12},
  [459] = {.lex_state = 12},
  [460] = {.lex_state = 12},
  [461] = {.lex_state = 12},
  [462] = {.lex_state = 12},
  [463] = {.lex_state = 8},
  [464] = {.lex_state = 12},
  [465] = {.lex_state = 12},
  [466] = {.lex_state = 12},
  [467] = {.lex_state = 12},
  [468] = {.lex_state = 12},
  [469] = {.lex_state = 12},
  [470] = {.lex_state = 12},
  [471] = {.lex_state = 12},
  [472] = {.lex_state = 8},
  [473] = {.lex_state = 12},
  [474] = {.lex_state = 12},
  [475] = {.lex_state = 12},
  [476] = {.lex_state = 12},
  [477] = {.lex_state = 8},
  [478] = {.lex_state = 12},
  [479] = {.lex_state = 12},
  [480] = {.lex_state = 12},
  [481] = {.lex_state = 8},
  [482] = {.lex_state = 12},
  [483] = {.lex_state = 12},
  [484] = {.lex_state = 12},
  [485] = {.lex_state = 12},
  [486] = {.lex_state = 12},
  [487] = {.lex_state = 12},
  [488] = {.lex_state = 12},
  [489] = {.lex_state = 8},
  [490] = {.lex_state = 12},
  [491] = {.lex_state = 12},
  [492] = {.lex_state = 8},
  [493] = {.lex_state = 12},
  [494] = {.lex_state = 8},
  [495] = {.lex_state = 12},
  [496] = {.lex_state = 12},
  [497] = {.lex_state = 12},
  [498] = {.lex_state = 8},
  [499] = {.lex_state = 12},
  [500] = {.lex_state = 12},
  [501] = {.lex_state = 12},
  [502] = {.lex_state = 12},
  [503] = {.lex_state = 444},
  [504] = {.lex_state = 444},
  [505] = {.lex_state = 12},
  [506] = {.lex_state = 12},
  [507] = {.lex_state = 12},
  [508] = {.lex_state = 12},
  [509] = {.lex_state = 12},
  [510] = {.lex_state = 444},
  [511] = {.lex_state = 444},
  [512] = {.lex_state = 444},
  [513] = {.lex_state = 444},
  [514] = {.lex_state = 444},
  [515] = {.lex_state = 444},
  [516] = {.lex_state = 444},
  [517] = {.lex_state = 444},
  [518] = {.lex_state = 14},
  [519] = {.lex_state = 14},
  [520] = {.lex_state = 14},
  [521] = {.lex_state = 14},
  [522] = {.lex_state = 14},
  [523] = {.lex_state = 14},
  [524] = {.lex_state = 14},
  [525] = {.lex_state = 14},
  [526] = {.lex_state = 14},
  [527] = {.lex_state = 14},
  [528] = {.lex_state = 14},
  [529] = {.lex_state = 14},
  [530] = {.lex_state = 14},
  [531] = {.lex_state = 14},
  [532] = {.lex_state = 14},
  [533] = {.lex_state = 14},
  [534] = {.lex_state = 14},
  [535] = {.lex_state = 14},
  [536] = {.lex_state = 14},
  [537] = {.lex_state = 14},
  [538] = {.lex_state = 14},
  [539] = {.lex_state = 14},
  [540] = {.lex_state = 14},
  [541] = {.lex_state = 14},
  [542] = {.lex_state = 14},
  [543] = {.lex_state = 14},
  [544] = {.lex_state = 14},
  [545] = {.lex_state = 14},
  [546] = {.lex_state = 14},
  [547] = {.lex_state = 14},
  [548] = {.lex_state = 14},
  [549] = {.lex_state = 19},
  [550] = {.lex_state = 0},
  [551] = {.lex_state = 0},
  [552] = {.lex_state = 0},
  [553] = {.lex_state = 0},
  [554] = {.lex_state = 0},
  [555] = {.lex_state = 444},
  [556] = {.lex_state = 444},
  [557] = {.lex_state = 444},
  [558] = {.lex_state = 444},
  [559] = {.lex_state = 444},
  [560] = {.lex_state = 444},
  [561] = {.lex_state = 444},
  [562] = {.lex_state = 444},
  [563] = {.lex_state = 444},
  [564] = {.lex_state = 444},
  [565] = {.lex_state = 444},
  [566] = {.lex_state = 444},
  [567] = {.lex_state = 444},
  [568] = {.lex_state = 444},
  [569] = {.lex_state = 444},
  [570] = {.lex_state = 444},
  [571] = {.lex_state = 444},
  [572] = {.lex_state = 444},
  [573] = {.lex_state = 444},
  [574] = {.lex_state = 444},
  [575] = {.lex_state = 444},
  [576] = {.lex_state = 444},
  [577] = {.lex_state = 444},
  [578] = {.lex_state = 444},
  [579] = {.lex_state = 444},
  [580] = {.lex_state = 0},
  [581] = {.lex_state = 444},
  [582] = {.lex_state = 24},
  [583] = {.lex_state = 0},
  [584] = {.lex_state = 0},
  [585] = {.lex_state = 24},
  [586] = {.lex_state = 0},
  [587] = {.lex_state = 0},
  [588] = {.lex_state = 15},
  [589] = {.lex_state = 0},
  [590] = {.lex_state = 0},
  [591] = {.lex_state = 15},
  [592] = {.lex_state = 0},
  [593] = {.lex_state = 6},
  [594] = {.lex_state = 0},
  [595] = {.lex_state = 34},
  [596] = {.lex_state = 0},
  [597] = {.lex_state = 0},
  [598] = {.lex_state = 0},
  [599] = {.lex_state = 0},
  [600] = {.lex_state = 15},
  [601] = {.lex_state = 15},
  [602] = {.lex_state = 6},
  [603] = {.lex_state = 17},
  [604] = {.lex_state = 19},
  [605] = {.lex_state = 17},
  [606] = {.lex_state = 17},
  [607] = {.lex_state = 17},
  [608] = {.lex_state = 9},
  [609] = {.lex_state = 19},
  [610] = {.lex_state = 19},
  [611] = {.lex_state = 0},
  [612] = {.lex_state = 0},
  [613] = {.lex_state = 19},
  [614] = {.lex_state = 19},
  [615] = {.lex_state = 9},
  [616] = {.lex_state = 19},
  [617] = {.lex_state = 0},
  [618] = {.lex_state = 17},
  [619] = {.lex_state = 9},
  [620] = {.lex_state = 0},
  [621] = {.lex_state = 15},
  [622] = {.lex_state = 20},
  [623] = {.lex_state = 20},
  [624] = {.lex_state = 20},
  [625] = {.lex_state = 15},
  [626] = {.lex_state = 20},
  [627] = {.lex_state = 0},
  [628] = {.lex_state = 0},
  [629] = {.lex_state = 20},
  [630] = {.lex_state = 20},
  [631] = {.lex_state = 0},
  [632] = {.lex_state = 20},
  [633] = {.lex_state = 0},
  [634] = {.lex_state = 0},
  [635] = {.lex_state = 0},
  [636] = {.lex_state = 0},
  [637] = {.lex_state = 20},
  [638] = {.lex_state = 0},
  [639] = {.lex_state = 19},
  [640] = {.lex_state = 20},
  [641] = {.lex_state = 15},
  [642] = {.lex_state = 20},
  [643] = {.lex_state = 20},
  [644] = {.lex_state = 0},
  [645] = {.lex_state = 20},
  [646] = {.lex_state = 0},
  [647] = {.lex_state = 20},
  [648] = {.lex_state = 0},
  [649] = {.lex_state = 20},
  [650] = {.lex_state = 0},
  [651] = {.lex_state = 20},
  [652] = {.lex_state = 20},
  [653] = {.lex_state = 20},
  [654] = {.lex_state = 19},
  [655] = {.lex_state = 0},
  [656] = {.lex_state = 19},
  [657] = {.lex_state = 0},
  [658] = {.lex_state = 20},
  [659] = {.lex_state = 20},
  [660] = {.lex_state = 0},
  [661] = {.lex_state = 444},
  [662] = {.lex_state = 15},
  [663] = {.lex_state = 0},
  [664] = {.lex_state = 0},
  [665] = {.lex_state = 20},
  [666] = {.lex_state = 0},
  [667] = {.lex_state = 0},
  [668] = {.lex_state = 0},
  [669] = {.lex_state = 0},
  [670] = {.lex_state = 0},
  [671] = {.lex_state = 9},
  [672] = {.lex_state = 15},
  [673] = {.lex_state = 0},
  [674] = {.lex_state = 0},
  [675] = {.lex_state = 0},
  [676] = {.lex_state = 0},
  [677] = {.lex_state = 9},
  [678] = {.lex_state = 0},
  [679] = {.lex_state = 0},
  [680] = {.lex_state = 0},
  [681] = {.lex_state = 0},
  [682] = {.lex_state = 0},
  [683] = {.lex_state = 0},
  [684] = {.lex_state = 19},
  [685] = {.lex_state = 0},
  [686] = {.lex_state = 0},
  [687] = {.lex_state = 0},
  [688] = {.lex_state = 0},
  [689] = {.lex_state = 0},
  [690] = {.lex_state = 0},
  [691] = {.lex_state = 0},
  [692] = {.lex_state = 0},
  [693] = {.lex_state = 0},
  [694] = {.lex_state = 0},
  [695] = {.lex_state = 20},
  [696] = {.lex_state = 0},
  [697] = {.lex_state = 0},
  [698] = {.lex_state = 0},
  [699] = {.lex_state = 0},
  [700] = {.lex_state = 15},
  [701] = {.lex_state = 0},
  [702] = {.lex_state = 0},
  [703] = {.lex_state = 0},
  [704] = {.lex_state = 0},
  [705] = {.lex_state = 0},
  [706] = {.lex_state = 0},
  [707] = {.lex_state = 0},
  [708] = {.lex_state = 0},
  [709] = {.lex_state = 0},
  [710] = {.lex_state = 0},
  [711] = {.lex_state = 0},
  [712] = {.lex_state = 20},
  [713] = {.lex_state = 15},
  [714] = {.lex_state = 0},
  [715] = {.lex_state = 0},
  [716] = {.lex_state = 0},
  [717] = {.lex_state = 19},
  [718] = {.lex_state = 20},
  [719] = {.lex_state = 0},
  [720] = {.lex_state = 0},
  [721] = {.lex_state = 0},
  [722] = {.lex_state = 17},
  [723] = {.lex_state = 20},
  [724] = {.lex_state = 19},
  [725] = {.lex_state = 0},
  [726] = {.lex_state = 0},
  [727] = {.lex_state = 17},
  [728] = {.lex_state = 0},
  [729] = {.lex_state = 0},
  [730] = {.lex_state = 20},
  [731] = {.lex_state = 0},
  [732] = {.lex_state = 0},
  [733] = {.lex_state = 444},
  [734] = {.lex_state = 20},
  [735] = {.lex_state = 9},
  [736] = {.lex_state = 444},
  [737] = {.lex_state = 20},
  [738] = {.lex_state = 444},
  [739] = {.lex_state = 15},
  [740] = {.lex_state = 35},
  [741] = {.lex_state = 0},
  [742] = {.lex_state = 19},
  [743] = {.lex_state = 15},
  [744] = {.lex_state = 0},
  [745] = {.lex_state = 444},
  [746] = {.lex_state = 35},
  [747] = {.lex_state = 0},
  [748] = {.lex_state = 20},
  [749] = {.lex_state = 0},
  [750] = {.lex_state = 0},
  [751] = {.lex_state = 0},
  [752] = {.lex_state = 0},
  [753] = {.lex_state = 20},
  [754] = {.lex_state = 0},
  [755] = {.lex_state = 20},
  [756] = {.lex_state = 19},
  [757] = {.lex_state = 19},
  [758] = {.lex_state = 19},
  [759] = {.lex_state = 20},
  [760] = {.lex_state = 20},
  [761] = {.lex_state = 0},
  [762] = {.lex_state = 19},
  [763] = {.lex_state = 0},
  [764] = {.lex_state = 0},
  [765] = {.lex_state = 20},
  [766] = {.lex_state = 0},
  [767] = {.lex_state = 20},
  [768] = {.lex_state = 20},
  [769] = {.lex_state = 19},
  [770] = {.lex_state = 20},
  [771] = {.lex_state = 0},
  [772] = {.lex_state = 19},
  [773] = {.lex_state = 19},
  [774] = {.lex_state = 0},
  [775] = {.lex_state = 0},
  [776] = {.lex_state = 0},
  [777] = {.lex_state = 0},
  [778] = {.lex_state = 0},
  [779] = {.lex_state = 0},
  [780] = {.lex_state = 0},
  [781] = {.lex_state = 19},
  [782] = {.lex_state = 0},
  [783] = {.lex_state = 0},
  [784] = {.lex_state = 0},
  [785] = {.lex_state = 20},
  [786] = {.lex_state = 0},
  [787] = {.lex_state = 0},
  [788] = {.lex_state = 20},
  [789] = {.lex_state = 0},
  [790] = {.lex_state = 0},
  [791] = {.lex_state = 19},
  [792] = {.lex_state = 20},
  [793] = {.lex_state = 0},
  [794] = {.lex_state = 20},
  [795] = {.lex_state = 0},
  [796] = {.lex_state = 0},
  [797] = {.lex_state = 0},
  [798] = {.lex_state = 20},
  [799] = {.lex_state = 20},
  [800] = {.lex_state = 0},
  [801] = {.lex_state = 0},
  [802] = {.lex_state = 20},
  [803] = {.lex_state = 20},
  [804] = {.lex_state = 35},
  [805] = {.lex_state = 0},
  [806] = {.lex_state = 20},
  [807] = {.lex_state = 19},
  [808] = {.lex_state = 20},
  [809] = {.lex_state = 0},
  [810] = {.lex_state = 20},
  [811] = {.lex_state = 0},
  [812] = {.lex_state = 20},
  [813] = {.lex_state = 20},
  [814] = {.lex_state = 20},
  [815] = {.lex_state = 0},
  [816] = {.lex_state = 19},
  [817] = {.lex_state = 0},
  [818] = {.lex_state = 9},
  [819] = {.lex_state = 0},
  [820] = {.lex_state = 20},
  [821] = {.lex_state = 20},
  [822] = {.lex_state = 0},
  [823] = {.lex_state = 0},
  [824] = {.lex_state = 20},
  [825] = {.lex_state = 0},
  [826] = {.lex_state = 20},
  [827] = {.lex_state = 20},
  [828] = {.lex_state = 20},
  [829] = {.lex_state = 0},
  [830] = {.lex_state = 0},
  [831] = {.lex_state = 19},
  [832] = {.lex_state = 0},
  [833] = {.lex_state = 0},
  [834] = {.lex_state = 0},
  [835] = {.lex_state = 0},
  [836] = {.lex_state = 0},
  [837] = {.lex_state = 0},
  [838] = {.lex_state = 0},
  [839] = {.lex_state = 0},
  [840] = {.lex_state = 0},
  [841] = {.lex_state = 0},
  [842] = {.lex_state = 0},
  [843] = {.lex_state = 0},
  [844] = {.lex_state = 0},
  [845] = {.lex_state = 0},
  [846] = {.lex_state = 0},
  [847] = {.lex_state = 0},
  [848] = {.lex_state = 0},
  [849] = {.lex_state = 0},
  [850] = {.lex_state = 15},
  [851] = {.lex_state = 0},
  [852] = {.lex_state = 0},
  [853] = {.lex_state = 15},
  [854] = {.lex_state = 0},
  [855] = {.lex_state = 0},
  [856] = {.lex_state = 0},
  [857] = {.lex_state = 0},
  [858] = {.lex_state = 0},
  [859] = {.lex_state = 0},
  [860] = {.lex_state = 0},
  [861] = {.lex_state = 0},
  [862] = {.lex_state = 0},
  [863] = {.lex_state = 444},
  [864] = {.lex_state = 0},
  [865] = {.lex_state = 0},
  [866] = {.lex_state = 9},
  [867] = {.lex_state = 0},
  [868] = {.lex_state = 0},
  [869] = {.lex_state = 0},
  [870] = {.lex_state = 9},
  [871] = {.lex_state = 0},
  [872] = {.lex_state = 0},
  [873] = {.lex_state = 0},
  [874] = {.lex_state = 0},
  [875] = {.lex_state = 0},
  [876] = {.lex_state = 0},
  [877] = {.lex_state = 0},
  [878] = {.lex_state = 0},
  [879] = {.lex_state = 0},
  [880] = {.lex_state = 0},
  [881] = {.lex_state = 20},
  [882] = {.lex_state = 0},
  [883] = {.lex_state = 0},
  [884] = {.lex_state = 0},
  [885] = {.lex_state = 0},
  [886] = {.lex_state = 0},
  [887] = {.lex_state = 0},
  [888] = {.lex_state = 0},
  [889] = {.lex_state = 0},
  [890] = {.lex_state = 15},
  [891] = {.lex_state = 444},
  [892] = {.lex_state = 0},
  [893] = {.lex_state = 0},
  [894] = {.lex_state = 9},
  [895] = {.lex_state = 0},
  [896] = {.lex_state = 0},
  [897] = {.lex_state = 0},
  [898] = {.lex_state = 0},
  [899] = {.lex_state = 0},
  [900] = {.lex_state = 15},
  [901] = {.lex_state = 0},
  [902] = {.lex_state = 15},
  [903] = {.lex_state = 0},
  [904] = {.lex_state = 15},
  [905] = {.lex_state = 1},
  [906] = {.lex_state = 444},
  [907] = {.lex_state = 0},
  [908] = {.lex_state = 0},
  [909] = {.lex_state = 0},
  [910] = {.lex_state = 444},
  [911] = {.lex_state = 0},
  [912] = {.lex_state = 0},
  [913] = {.lex_state = 9},
  [914] = {.lex_state = 0},
  [915] = {.lex_state = 0},
  [916] = {.lex_state = 0},
  [917] = {.lex_state = 0},
  [918] = {.lex_state = 0},
  [919] = {.lex_state = 0},
  [920] = {.lex_state = 0},
  [921] = {.lex_state = 0},
  [922] = {.lex_state = 0},
  [923] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_export] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_from] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_component] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_property] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_LT_EQ_GT] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_out] = ACTIONS(1),
    [anon_sym_transitions] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_when] = ACTIONS(1),
    [anon_sym_animate] = ACTIONS(1),
    [anon_sym_delay] = ACTIONS(1),
    [anon_sym_duration] = ACTIONS(1),
    [anon_sym_iteration_DASHcount] = ACTIONS(1),
    [anon_sym_direction] = ACTIONS(1),
    [anon_sym_easing] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_ATtr] = ACTIONS(1),
    [anon_sym_EQ_GT] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [sym_logical_and] = ACTIONS(1),
    [sym_logical_or] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_callback] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_pure] = ACTIONS(1),
    [anon_sym_public] = ACTIONS(1),
    [anon_sym_private] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_changed] = ACTIONS(1),
    [anon_sym_ATimage_DASHurl] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_BSLASH] = ACTIONS(1),
    [aux_sym_escape_sequence_token1] = ACTIONS(1),
    [anon_sym_n] = ACTIONS(1),
    [anon_sym_float] = ACTIONS(1),
    [anon_sym_bool] = ACTIONS(1),
    [anon_sym_color] = ACTIONS(1),
    [anon_sym_brush] = ACTIONS(1),
    [anon_sym_physical_DASHlength] = ACTIONS(1),
    [anon_sym_length] = ACTIONS(1),
    [anon_sym_angle] = ACTIONS(1),
    [anon_sym_percent] = ACTIONS(1),
    [anon_sym_image] = ACTIONS(1),
    [anon_sym_relative_DASHfont_DASHsize] = ACTIONS(1),
    [anon_sym_linear] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(1),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(1),
    [anon_sym_ease] = ACTIONS(1),
    [anon_sym_ease_DASHin] = ACTIONS(1),
    [anon_sym_ease_DASHout] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(1),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(1),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(1),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(1),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(1),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(1),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(1),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(1),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(1),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(1),
    [anon_sym_cubic_DASHbezier] = ACTIONS(1),
    [sym_children_identifier] = ACTIONS(1),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(1),
    [anon_sym_ATlinear_gradient] = ACTIONS(1),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(1),
    [anon_sym_ATradial_gradient] = ACTIONS(1),
    [anon_sym_circle] = ACTIONS(1),
    [anon_sym_parent] = ACTIONS(1),
    [anon_sym_root] = ACTIONS(1),
    [anon_sym_self] = ACTIONS(1),
    [sym__int_number] = ACTIONS(1),
    [sym__float_number] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [sym_color_value] = ACTIONS(1),
    [anon_sym_phx] = ACTIONS(1),
    [aux_sym_length_value_token1] = ACTIONS(1),
    [aux_sym_duration_value_token1] = ACTIONS(1),
    [aux_sym_angle_value_token1] = ACTIONS(1),
    [anon_sym_PERCENT2] = ACTIONS(1),
    [anon_sym_rem] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
  },
  [1] = {
    [sym_sourcefile] = STATE(862),
    [sym__definition] = STATE(504),
    [sym__local_type] = STATE(504),
    [sym__exported_type] = STATE(504),
    [sym_import_statement] = STATE(504),
    [sym_component_definition] = STATE(504),
    [sym_global_definition] = STATE(504),
    [sym_struct_definition] = STATE(504),
    [sym_enum_definition] = STATE(504),
    [sym_user_type_identifier] = STATE(886),
    [aux_sym_sourcefile_repeat1] = STATE(504),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_export] = ACTIONS(7),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_component] = ACTIONS(11),
    [anon_sym_global] = ACTIONS(13),
    [anon_sym_struct] = ACTIONS(15),
    [anon_sym_enum] = ACTIONS(17),
    [sym__identifier] = ACTIONS(19),
    [sym_comment] = ACTIONS(3),
  },
  [2] = {
    [sym__imperative_block_statement] = STATE(7),
    [sym_binding] = STATE(7),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(7),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(213),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(7),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_COMMA] = ACTIONS(23),
    [anon_sym_RBRACE] = ACTIONS(25),
    [anon_sym_return] = ACTIONS(27),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_if] = ACTIONS(31),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [3] = {
    [sym__imperative_block_statement] = STATE(7),
    [sym_binding] = STATE(7),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(7),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(213),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(7),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_COMMA] = ACTIONS(23),
    [anon_sym_RBRACE] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(27),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_if] = ACTIONS(31),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [4] = {
    [sym__imperative_block_statement] = STATE(14),
    [sym_binding] = STATE(14),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(14),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(213),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(14),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_COMMA] = ACTIONS(23),
    [anon_sym_RBRACE] = ACTIONS(65),
    [anon_sym_return] = ACTIONS(27),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_if] = ACTIONS(31),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [5] = {
    [sym__imperative_block_statement] = STATE(15),
    [sym_binding] = STATE(15),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(15),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(213),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(15),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_COMMA] = ACTIONS(23),
    [anon_sym_RBRACE] = ACTIONS(67),
    [anon_sym_return] = ACTIONS(27),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_if] = ACTIONS(31),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [6] = {
    [sym__imperative_block_statement] = STATE(15),
    [sym_binding] = STATE(15),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(15),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(213),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(15),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_COMMA] = ACTIONS(23),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_return] = ACTIONS(27),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_if] = ACTIONS(31),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [7] = {
    [sym__imperative_block_statement] = STATE(8),
    [sym_binding] = STATE(8),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(8),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(211),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(8),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(71),
    [anon_sym_return] = ACTIONS(27),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_if] = ACTIONS(31),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [8] = {
    [sym__imperative_block_statement] = STATE(8),
    [sym_binding] = STATE(8),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(8),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(211),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(8),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_RBRACE] = ACTIONS(76),
    [anon_sym_return] = ACTIONS(78),
    [anon_sym_LBRACK] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(84),
    [anon_sym_LPAREN] = ACTIONS(87),
    [anon_sym_ATtr] = ACTIONS(90),
    [anon_sym_ATimage_DASHurl] = ACTIONS(93),
    [anon_sym_BANG] = ACTIONS(96),
    [anon_sym_DASH] = ACTIONS(96),
    [anon_sym_PLUS] = ACTIONS(96),
    [anon_sym_DQUOTE] = ACTIONS(99),
    [sym__identifier] = ACTIONS(102),
    [anon_sym_linear] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(105),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(105),
    [anon_sym_ease] = ACTIONS(105),
    [anon_sym_ease_DASHin] = ACTIONS(105),
    [anon_sym_ease_DASHout] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(105),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(105),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(105),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(105),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(105),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(105),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(105),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(105),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(105),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(105),
    [anon_sym_cubic_DASHbezier] = ACTIONS(108),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(111),
    [anon_sym_ATlinear_gradient] = ACTIONS(111),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(114),
    [anon_sym_ATradial_gradient] = ACTIONS(114),
    [anon_sym_parent] = ACTIONS(117),
    [anon_sym_root] = ACTIONS(117),
    [anon_sym_self] = ACTIONS(117),
    [sym__int_number] = ACTIONS(120),
    [sym__float_number] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(126),
    [anon_sym_false] = ACTIONS(126),
    [sym_color_value] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
  },
  [9] = {
    [sym__imperative_block_statement] = STATE(7),
    [sym_binding] = STATE(7),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(7),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(211),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(7),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(132),
    [anon_sym_return] = ACTIONS(27),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_if] = ACTIONS(31),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [10] = {
    [sym__imperative_block_statement] = STATE(14),
    [sym_binding] = STATE(14),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(14),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(211),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(14),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(134),
    [anon_sym_return] = ACTIONS(27),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_if] = ACTIONS(31),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [11] = {
    [sym__imperative_block_statement] = STATE(15),
    [sym_binding] = STATE(15),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(15),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(211),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(15),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(136),
    [anon_sym_return] = ACTIONS(27),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_if] = ACTIONS(31),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [12] = {
    [sym__imperative_block_statement] = STATE(8),
    [sym_binding] = STATE(8),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(8),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(211),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(8),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(138),
    [anon_sym_return] = ACTIONS(27),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_if] = ACTIONS(31),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [13] = {
    [sym__imperative_block_statement] = STATE(12),
    [sym_binding] = STATE(12),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(12),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(211),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(12),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(140),
    [anon_sym_return] = ACTIONS(27),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_if] = ACTIONS(31),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [14] = {
    [sym__imperative_block_statement] = STATE(8),
    [sym_binding] = STATE(8),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(8),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(211),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(8),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(142),
    [anon_sym_return] = ACTIONS(27),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_if] = ACTIONS(31),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [15] = {
    [sym__imperative_block_statement] = STATE(8),
    [sym_binding] = STATE(8),
    [sym_anon_struct_block] = STATE(205),
    [sym_if_expr] = STATE(244),
    [sym__assignment_setup] = STATE(29),
    [sym_assignment_block] = STATE(244),
    [sym_assignment_expr] = STATE(244),
    [sym_expression] = STATE(151),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_callback_event] = STATE(8),
    [sym_function_call] = STATE(226),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(211),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [aux_sym_imperative_block_repeat1] = STATE(8),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(144),
    [anon_sym_return] = ACTIONS(27),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_if] = ACTIONS(31),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [16] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_in_out_transition] = STATE(17),
    [sym__assignment_setup] = STATE(34),
    [sym_assignment_block] = STATE(17),
    [sym_assignment_expr] = STATE(775),
    [sym_expression] = STATE(354),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [aux_sym_states_definition_repeat1] = STATE(17),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_RBRACE] = ACTIONS(148),
    [anon_sym_in] = ACTIONS(150),
    [anon_sym_out] = ACTIONS(150),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [17] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_in_out_transition] = STATE(18),
    [sym__assignment_setup] = STATE(34),
    [sym_assignment_block] = STATE(18),
    [sym_assignment_expr] = STATE(793),
    [sym_expression] = STATE(354),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [aux_sym_states_definition_repeat1] = STATE(18),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_RBRACE] = ACTIONS(178),
    [anon_sym_in] = ACTIONS(150),
    [anon_sym_out] = ACTIONS(150),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [18] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_in_out_transition] = STATE(18),
    [sym__assignment_setup] = STATE(51),
    [sym_assignment_block] = STATE(18),
    [sym_assignment_expr] = STATE(838),
    [sym_expression] = STATE(354),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [aux_sym_states_definition_repeat1] = STATE(18),
    [anon_sym_LBRACE] = ACTIONS(180),
    [anon_sym_RBRACE] = ACTIONS(183),
    [anon_sym_in] = ACTIONS(185),
    [anon_sym_out] = ACTIONS(185),
    [anon_sym_LBRACK] = ACTIONS(188),
    [anon_sym_LPAREN] = ACTIONS(191),
    [anon_sym_ATtr] = ACTIONS(194),
    [anon_sym_ATimage_DASHurl] = ACTIONS(197),
    [anon_sym_BANG] = ACTIONS(200),
    [anon_sym_DASH] = ACTIONS(200),
    [anon_sym_PLUS] = ACTIONS(200),
    [anon_sym_DQUOTE] = ACTIONS(203),
    [sym__identifier] = ACTIONS(206),
    [anon_sym_linear] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(209),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(209),
    [anon_sym_ease] = ACTIONS(209),
    [anon_sym_ease_DASHin] = ACTIONS(209),
    [anon_sym_ease_DASHout] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(209),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(209),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(209),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(209),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(209),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(209),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(209),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(209),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(209),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(209),
    [anon_sym_cubic_DASHbezier] = ACTIONS(212),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(215),
    [anon_sym_ATlinear_gradient] = ACTIONS(215),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(218),
    [anon_sym_ATradial_gradient] = ACTIONS(218),
    [anon_sym_parent] = ACTIONS(221),
    [anon_sym_root] = ACTIONS(221),
    [anon_sym_self] = ACTIONS(221),
    [sym__int_number] = ACTIONS(224),
    [sym__float_number] = ACTIONS(227),
    [anon_sym_true] = ACTIONS(230),
    [anon_sym_false] = ACTIONS(230),
    [sym_color_value] = ACTIONS(233),
    [sym_comment] = ACTIONS(3),
  },
  [19] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(835),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_RPAREN] = ACTIONS(236),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [20] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(835),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_RPAREN] = ACTIONS(242),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [21] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(835),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_RPAREN] = ACTIONS(244),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [22] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(835),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_RPAREN] = ACTIONS(246),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [23] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(835),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_RPAREN] = ACTIONS(248),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [24] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(835),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_RPAREN] = ACTIONS(250),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [25] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(835),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_RPAREN] = ACTIONS(252),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [26] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(835),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_RPAREN] = ACTIONS(254),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [27] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(909),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [28] = {
    [sym_imperative_block] = STATE(441),
    [sym__binding] = STATE(484),
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(442),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(256),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [29] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_block] = STATE(241),
    [sym__assignment_value_block] = STATE(242),
    [sym_expression] = STATE(227),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(258),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [30] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(408),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_argument] = STATE(783),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(260),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [31] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(835),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [32] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(901),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [33] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(908),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [34] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_block] = STATE(243),
    [sym__assignment_value_block] = STATE(245),
    [sym_expression] = STATE(409),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(262),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [35] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(394),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_RBRACK] = ACTIONS(266),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [36] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(408),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_argument] = STATE(663),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(268),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [37] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(912),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [38] = {
    [sym_imperative_block] = STATE(246),
    [sym__binding] = STATE(253),
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(439),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(270),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [39] = {
    [sym_imperative_block] = STATE(519),
    [sym__binding] = STATE(521),
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(452),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(272),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [40] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(400),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_COMMA] = ACTIONS(274),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_RBRACK] = ACTIONS(276),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [41] = {
    [sym_imperative_block] = STATE(519),
    [sym__binding] = STATE(534),
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(452),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(272),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [42] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(408),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_argument] = STATE(783),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(278),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [43] = {
    [sym_imperative_block] = STATE(441),
    [sym__binding] = STATE(488),
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(442),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(256),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [44] = {
    [sym_imperative_block] = STATE(246),
    [sym__binding] = STATE(253),
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(390),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(280),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [45] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(408),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_argument] = STATE(783),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(282),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [46] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(664),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [47] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(666),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [48] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(408),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_argument] = STATE(668),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(284),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [49] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(673),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [50] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(380),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_gradient_color] = STATE(674),
    [sym_image_call] = STATE(206),
    [sym_argument] = STATE(597),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [51] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_block] = STATE(243),
    [sym__assignment_value_block] = STATE(245),
    [sym_expression] = STATE(409),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(286),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [52] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(408),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_argument] = STATE(783),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [53] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_RBRACK] = ACTIONS(290),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [54] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(292),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [55] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(294),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [56] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(296),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [57] = {
    [sym_imperative_block] = STATE(436),
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(387),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [58] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(300),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [59] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(302),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [60] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(448),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_SEMI] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [61] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_RBRACK] = ACTIONS(306),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [62] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(308),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [63] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(310),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [64] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(408),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_argument] = STATE(783),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [65] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(312),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [66] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [67] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(316),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [68] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(318),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [69] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(320),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [70] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(322),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [71] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(324),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [72] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_RBRACK] = ACTIONS(326),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [73] = {
    [sym_imperative_block] = STATE(436),
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(388),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [74] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(328),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [75] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_RBRACK] = ACTIONS(330),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [76] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_RPAREN] = ACTIONS(332),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [77] = {
    [sym_imperative_block] = STATE(436),
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(440),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(256),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [78] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_for_range] = STATE(916),
    [sym_expression] = STATE(421),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(510),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [79] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(157),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [80] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(415),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [81] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(423),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [82] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(399),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [83] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(449),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [84] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(392),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [85] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(405),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [86] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(290),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [87] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(286),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [88] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(291),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [89] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(418),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [90] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(406),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [91] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(292),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [92] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(285),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [93] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(411),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [94] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(393),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [95] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(284),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [96] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(419),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [97] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(420),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [98] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(422),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [99] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(403),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [100] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(410),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [101] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(424),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [102] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(417),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [103] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(398),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [104] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(154),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [105] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(156),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [106] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(158),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [107] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(159),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [108] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(160),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [109] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(163),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [110] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(165),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(104),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(55),
    [sym__float_number] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [111] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(379),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [112] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(389),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [113] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(382),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [114] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(386),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [115] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(381),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [116] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(384),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [117] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(383),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [118] = {
    [sym_anon_struct_block] = STATE(205),
    [sym_expression] = STATE(385),
    [sym_parens_op] = STATE(206),
    [sym_index_op] = STATE(206),
    [sym_tr] = STATE(206),
    [sym_member_access] = STATE(206),
    [sym_unary_expression] = STATE(206),
    [sym_binary_expression] = STATE(206),
    [sym__add_binary_expression] = STATE(207),
    [sym__comparison_binary_expression] = STATE(208),
    [sym__logic_binary_expression] = STATE(209),
    [sym__mult_binary_expression] = STATE(210),
    [sym_ternary_expression] = STATE(206),
    [sym_function_call] = STATE(206),
    [sym_gradient_call] = STATE(206),
    [sym_image_call] = STATE(206),
    [sym_unary_prec_operator] = STATE(111),
    [sym__string] = STATE(172),
    [sym_simple_identifier] = STATE(152),
    [sym_easing_kind_identifier] = STATE(205),
    [sym_value_list] = STATE(205),
    [sym_value] = STATE(206),
    [sym_linear_gradient_identifier] = STATE(921),
    [sym_radial_gradient_identifier] = STATE(922),
    [sym_reference_identifier] = STATE(206),
    [sym__number] = STATE(602),
    [sym_int_value] = STATE(205),
    [sym_float_value] = STATE(205),
    [sym_bool_value] = STATE(205),
    [sym_string_value] = STATE(205),
    [sym_physical_length_value] = STATE(205),
    [sym_length_value] = STATE(205),
    [sym_duration_value] = STATE(205),
    [sym_angle_value] = STATE(205),
    [sym_percent_value] = STATE(205),
    [sym_relative_font_size_value] = STATE(205),
    [sym__basic_value] = STATE(205),
    [anon_sym_LBRACE] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(33),
    [anon_sym_ATtr] = ACTIONS(35),
    [anon_sym_ATimage_DASHurl] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [sym__identifier] = ACTIONS(43),
    [anon_sym_linear] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(45),
    [anon_sym_ease] = ACTIONS(45),
    [anon_sym_ease_DASHin] = ACTIONS(45),
    [anon_sym_ease_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(45),
    [anon_sym_cubic_DASHbezier] = ACTIONS(47),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(53),
    [anon_sym_root] = ACTIONS(53),
    [anon_sym_self] = ACTIONS(53),
    [sym__int_number] = ACTIONS(238),
    [sym__float_number] = ACTIONS(240),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_color_value] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [119] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(443),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [120] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(445),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [121] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(404),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [122] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(437),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [123] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(446),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [124] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(451),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [125] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(391),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [126] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(288),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [127] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(282),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [128] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(434),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [129] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(412),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [130] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(425),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [131] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(426),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [132] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(427),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [133] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(428),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [134] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(429),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [135] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(450),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(336),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [136] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(430),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [137] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(395),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [138] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(432),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [139] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(433),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [140] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(396),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [141] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(435),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [142] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(397),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [143] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(413),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [144] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(414),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [145] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(401),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [146] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(402),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [147] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(438),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [148] = {
    [sym_anon_struct_block] = STATE(336),
    [sym_expression] = STATE(416),
    [sym_parens_op] = STATE(301),
    [sym_index_op] = STATE(301),
    [sym_tr] = STATE(301),
    [sym_member_access] = STATE(301),
    [sym_unary_expression] = STATE(301),
    [sym_binary_expression] = STATE(301),
    [sym__add_binary_expression] = STATE(302),
    [sym__comparison_binary_expression] = STATE(303),
    [sym__logic_binary_expression] = STATE(304),
    [sym__mult_binary_expression] = STATE(305),
    [sym_ternary_expression] = STATE(301),
    [sym_function_call] = STATE(301),
    [sym_gradient_call] = STATE(301),
    [sym_image_call] = STATE(301),
    [sym_unary_prec_operator] = STATE(127),
    [sym__string] = STATE(289),
    [sym_simple_identifier] = STATE(293),
    [sym_easing_kind_identifier] = STATE(336),
    [sym_value_list] = STATE(336),
    [sym_value] = STATE(301),
    [sym_linear_gradient_identifier] = STATE(845),
    [sym_radial_gradient_identifier] = STATE(846),
    [sym_reference_identifier] = STATE(301),
    [sym__number] = STATE(593),
    [sym_int_value] = STATE(336),
    [sym_float_value] = STATE(336),
    [sym_bool_value] = STATE(336),
    [sym_string_value] = STATE(336),
    [sym_physical_length_value] = STATE(336),
    [sym_length_value] = STATE(336),
    [sym_duration_value] = STATE(336),
    [sym_angle_value] = STATE(336),
    [sym_percent_value] = STATE(336),
    [sym_relative_font_size_value] = STATE(336),
    [sym__basic_value] = STATE(336),
    [anon_sym_LBRACE] = ACTIONS(146),
    [anon_sym_LBRACK] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_ATtr] = ACTIONS(156),
    [anon_sym_ATimage_DASHurl] = ACTIONS(158),
    [anon_sym_BANG] = ACTIONS(39),
    [anon_sym_DASH] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(160),
    [sym__identifier] = ACTIONS(162),
    [anon_sym_linear] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(164),
    [anon_sym_ease] = ACTIONS(164),
    [anon_sym_ease_DASHin] = ACTIONS(164),
    [anon_sym_ease_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(164),
    [anon_sym_cubic_DASHbezier] = ACTIONS(166),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(49),
    [anon_sym_ATlinear_gradient] = ACTIONS(49),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(51),
    [anon_sym_ATradial_gradient] = ACTIONS(51),
    [anon_sym_parent] = ACTIONS(168),
    [anon_sym_root] = ACTIONS(168),
    [anon_sym_self] = ACTIONS(168),
    [sym__int_number] = ACTIONS(170),
    [sym__float_number] = ACTIONS(172),
    [anon_sym_true] = ACTIONS(174),
    [anon_sym_false] = ACTIONS(174),
    [sym_color_value] = ACTIONS(176),
    [sym_comment] = ACTIONS(3),
  },
  [149] = {
    [anon_sym_LBRACE] = ACTIONS(338),
    [anon_sym_RBRACE] = ACTIONS(338),
    [anon_sym_SEMI] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_return] = ACTIONS(340),
    [anon_sym_COLON] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_if] = ACTIONS(340),
    [anon_sym_LPAREN] = ACTIONS(338),
    [anon_sym_ATtr] = ACTIONS(338),
    [anon_sym_DOT] = ACTIONS(340),
    [sym_logical_and] = ACTIONS(338),
    [sym_logical_or] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_ATimage_DASHurl] = ACTIONS(338),
    [anon_sym_BANG] = ACTIONS(340),
    [anon_sym_DASH] = ACTIONS(340),
    [anon_sym_PLUS] = ACTIONS(340),
    [anon_sym_STAR] = ACTIONS(340),
    [anon_sym_SLASH] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_EQ] = ACTIONS(340),
    [anon_sym_PLUS_EQ] = ACTIONS(338),
    [anon_sym_DASH_EQ] = ACTIONS(338),
    [anon_sym_STAR_EQ] = ACTIONS(338),
    [anon_sym_SLASH_EQ] = ACTIONS(338),
    [anon_sym_DQUOTE] = ACTIONS(338),
    [sym__identifier] = ACTIONS(340),
    [anon_sym_linear] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(340),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(340),
    [anon_sym_ease] = ACTIONS(340),
    [anon_sym_ease_DASHin] = ACTIONS(340),
    [anon_sym_ease_DASHout] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(340),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(340),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(340),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(340),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(340),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(340),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(340),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(340),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(340),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(340),
    [anon_sym_cubic_DASHbezier] = ACTIONS(340),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(338),
    [anon_sym_ATlinear_gradient] = ACTIONS(338),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(338),
    [anon_sym_ATradial_gradient] = ACTIONS(338),
    [anon_sym_parent] = ACTIONS(340),
    [anon_sym_root] = ACTIONS(340),
    [anon_sym_self] = ACTIONS(340),
    [sym__int_number] = ACTIONS(340),
    [sym__float_number] = ACTIONS(338),
    [anon_sym_true] = ACTIONS(340),
    [anon_sym_false] = ACTIONS(340),
    [sym_color_value] = ACTIONS(338),
    [anon_sym_phx] = ACTIONS(342),
    [aux_sym_length_value_token1] = ACTIONS(342),
    [aux_sym_duration_value_token1] = ACTIONS(342),
    [aux_sym_angle_value_token1] = ACTIONS(342),
    [anon_sym_PERCENT2] = ACTIONS(344),
    [anon_sym_rem] = ACTIONS(342),
    [sym_comment] = ACTIONS(3),
  },
  [150] = {
    [anon_sym_LBRACE] = ACTIONS(346),
    [anon_sym_RBRACE] = ACTIONS(346),
    [anon_sym_SEMI] = ACTIONS(346),
    [anon_sym_LT] = ACTIONS(348),
    [anon_sym_GT] = ACTIONS(348),
    [anon_sym_return] = ACTIONS(348),
    [anon_sym_COLON] = ACTIONS(346),
    [anon_sym_LBRACK] = ACTIONS(346),
    [anon_sym_if] = ACTIONS(348),
    [anon_sym_LPAREN] = ACTIONS(346),
    [anon_sym_ATtr] = ACTIONS(346),
    [anon_sym_DOT] = ACTIONS(348),
    [sym_logical_and] = ACTIONS(346),
    [sym_logical_or] = ACTIONS(346),
    [anon_sym_QMARK] = ACTIONS(346),
    [anon_sym_ATimage_DASHurl] = ACTIONS(346),
    [anon_sym_BANG] = ACTIONS(348),
    [anon_sym_DASH] = ACTIONS(348),
    [anon_sym_PLUS] = ACTIONS(348),
    [anon_sym_STAR] = ACTIONS(348),
    [anon_sym_SLASH] = ACTIONS(348),
    [anon_sym_GT_EQ] = ACTIONS(346),
    [anon_sym_LT_EQ] = ACTIONS(346),
    [anon_sym_EQ_EQ] = ACTIONS(346),
    [anon_sym_BANG_EQ] = ACTIONS(346),
    [anon_sym_EQ] = ACTIONS(348),
    [anon_sym_PLUS_EQ] = ACTIONS(346),
    [anon_sym_DASH_EQ] = ACTIONS(346),
    [anon_sym_STAR_EQ] = ACTIONS(346),
    [anon_sym_SLASH_EQ] = ACTIONS(346),
    [anon_sym_DQUOTE] = ACTIONS(346),
    [sym__identifier] = ACTIONS(348),
    [anon_sym_linear] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(348),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(348),
    [anon_sym_ease] = ACTIONS(348),
    [anon_sym_ease_DASHin] = ACTIONS(348),
    [anon_sym_ease_DASHout] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(348),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(348),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(348),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(348),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(348),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(348),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(348),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(348),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(348),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(348),
    [anon_sym_cubic_DASHbezier] = ACTIONS(348),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(346),
    [anon_sym_ATlinear_gradient] = ACTIONS(346),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(346),
    [anon_sym_ATradial_gradient] = ACTIONS(346),
    [anon_sym_parent] = ACTIONS(348),
    [anon_sym_root] = ACTIONS(348),
    [anon_sym_self] = ACTIONS(348),
    [sym__int_number] = ACTIONS(348),
    [sym__float_number] = ACTIONS(346),
    [anon_sym_true] = ACTIONS(348),
    [anon_sym_false] = ACTIONS(348),
    [sym_color_value] = ACTIONS(346),
    [anon_sym_phx] = ACTIONS(342),
    [aux_sym_length_value_token1] = ACTIONS(342),
    [aux_sym_duration_value_token1] = ACTIONS(342),
    [aux_sym_angle_value_token1] = ACTIONS(342),
    [anon_sym_PERCENT2] = ACTIONS(344),
    [anon_sym_rem] = ACTIONS(342),
    [sym_comment] = ACTIONS(3),
  },
  [151] = {
    [sym_add_prec_operator] = STATE(107),
    [sym_mult_prec_operator] = STATE(108),
    [sym_comparison_operator] = STATE(109),
    [sym_assignment_prec_operator] = STATE(265),
    [anon_sym_LBRACE] = ACTIONS(350),
    [anon_sym_RBRACE] = ACTIONS(350),
    [anon_sym_SEMI] = ACTIONS(304),
    [anon_sym_LT] = ACTIONS(352),
    [anon_sym_GT] = ACTIONS(352),
    [anon_sym_return] = ACTIONS(354),
    [anon_sym_COLON] = ACTIONS(356),
    [anon_sym_LBRACK] = ACTIONS(358),
    [anon_sym_if] = ACTIONS(354),
    [anon_sym_LPAREN] = ACTIONS(350),
    [anon_sym_ATtr] = ACTIONS(350),
    [anon_sym_DOT] = ACTIONS(360),
    [sym_logical_and] = ACTIONS(362),
    [sym_logical_or] = ACTIONS(364),
    [anon_sym_QMARK] = ACTIONS(366),
    [anon_sym_ATimage_DASHurl] = ACTIONS(350),
    [anon_sym_BANG] = ACTIONS(354),
    [anon_sym_DASH] = ACTIONS(368),
    [anon_sym_PLUS] = ACTIONS(368),
    [anon_sym_STAR] = ACTIONS(370),
    [anon_sym_SLASH] = ACTIONS(370),
    [anon_sym_GT_EQ] = ACTIONS(372),
    [anon_sym_LT_EQ] = ACTIONS(372),
    [anon_sym_EQ_EQ] = ACTIONS(372),
    [anon_sym_BANG_EQ] = ACTIONS(372),
    [anon_sym_EQ] = ACTIONS(374),
    [anon_sym_PLUS_EQ] = ACTIONS(356),
    [anon_sym_DASH_EQ] = ACTIONS(356),
    [anon_sym_STAR_EQ] = ACTIONS(356),
    [anon_sym_SLASH_EQ] = ACTIONS(356),
    [anon_sym_DQUOTE] = ACTIONS(350),
    [sym__identifier] = ACTIONS(354),
    [anon_sym_linear] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(354),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(354),
    [anon_sym_ease] = ACTIONS(354),
    [anon_sym_ease_DASHin] = ACTIONS(354),
    [anon_sym_ease_DASHout] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(354),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(354),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(354),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(354),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(354),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(354),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(354),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(354),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(354),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(354),
    [anon_sym_cubic_DASHbezier] = ACTIONS(354),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(350),
    [anon_sym_ATlinear_gradient] = ACTIONS(350),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(350),
    [anon_sym_ATradial_gradient] = ACTIONS(350),
    [anon_sym_parent] = ACTIONS(354),
    [anon_sym_root] = ACTIONS(354),
    [anon_sym_self] = ACTIONS(354),
    [sym__int_number] = ACTIONS(354),
    [sym__float_number] = ACTIONS(350),
    [anon_sym_true] = ACTIONS(354),
    [anon_sym_false] = ACTIONS(354),
    [sym_color_value] = ACTIONS(350),
    [sym_comment] = ACTIONS(3),
  },
  [152] = {
    [sym_arguments] = STATE(153),
    [anon_sym_LBRACE] = ACTIONS(376),
    [anon_sym_COMMA] = ACTIONS(376),
    [anon_sym_RBRACE] = ACTIONS(376),
    [anon_sym_SEMI] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(378),
    [anon_sym_GT] = ACTIONS(378),
    [anon_sym_return] = ACTIONS(378),
    [anon_sym_COLON] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(376),
    [anon_sym_if] = ACTIONS(378),
    [anon_sym_LPAREN] = ACTIONS(380),
    [anon_sym_RPAREN] = ACTIONS(376),
    [anon_sym_ATtr] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(378),
    [sym_logical_and] = ACTIONS(376),
    [sym_logical_or] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(376),
    [anon_sym_ATimage_DASHurl] = ACTIONS(376),
    [anon_sym_BANG] = ACTIONS(378),
    [anon_sym_DASH] = ACTIONS(378),
    [anon_sym_PLUS] = ACTIONS(378),
    [anon_sym_STAR] = ACTIONS(378),
    [anon_sym_SLASH] = ACTIONS(378),
    [anon_sym_GT_EQ] = ACTIONS(376),
    [anon_sym_LT_EQ] = ACTIONS(376),
    [anon_sym_EQ_EQ] = ACTIONS(376),
    [anon_sym_BANG_EQ] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(378),
    [anon_sym_PLUS_EQ] = ACTIONS(376),
    [anon_sym_DASH_EQ] = ACTIONS(376),
    [anon_sym_STAR_EQ] = ACTIONS(376),
    [anon_sym_SLASH_EQ] = ACTIONS(376),
    [anon_sym_DQUOTE] = ACTIONS(376),
    [sym__identifier] = ACTIONS(378),
    [anon_sym_linear] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(378),
    [anon_sym_ease] = ACTIONS(378),
    [anon_sym_ease_DASHin] = ACTIONS(378),
    [anon_sym_ease_DASHout] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(378),
    [anon_sym_cubic_DASHbezier] = ACTIONS(378),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(376),
    [anon_sym_ATlinear_gradient] = ACTIONS(376),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(376),
    [anon_sym_ATradial_gradient] = ACTIONS(376),
    [anon_sym_parent] = ACTIONS(378),
    [anon_sym_root] = ACTIONS(378),
    [anon_sym_self] = ACTIONS(378),
    [sym__int_number] = ACTIONS(378),
    [sym__float_number] = ACTIONS(376),
    [anon_sym_true] = ACTIONS(378),
    [anon_sym_false] = ACTIONS(378),
    [sym_color_value] = ACTIONS(376),
    [sym_comment] = ACTIONS(3),
  },
  [153] = {
    [anon_sym_LBRACE] = ACTIONS(382),
    [anon_sym_COMMA] = ACTIONS(382),
    [anon_sym_RBRACE] = ACTIONS(382),
    [anon_sym_SEMI] = ACTIONS(382),
    [anon_sym_LT] = ACTIONS(384),
    [anon_sym_GT] = ACTIONS(384),
    [anon_sym_return] = ACTIONS(384),
    [anon_sym_COLON] = ACTIONS(382),
    [anon_sym_LBRACK] = ACTIONS(382),
    [anon_sym_if] = ACTIONS(384),
    [anon_sym_LPAREN] = ACTIONS(382),
    [anon_sym_RPAREN] = ACTIONS(382),
    [anon_sym_ATtr] = ACTIONS(382),
    [anon_sym_EQ_GT] = ACTIONS(382),
    [anon_sym_DOT] = ACTIONS(384),
    [sym_logical_and] = ACTIONS(382),
    [sym_logical_or] = ACTIONS(382),
    [anon_sym_QMARK] = ACTIONS(382),
    [anon_sym_ATimage_DASHurl] = ACTIONS(382),
    [anon_sym_BANG] = ACTIONS(384),
    [anon_sym_DASH] = ACTIONS(384),
    [anon_sym_PLUS] = ACTIONS(384),
    [anon_sym_STAR] = ACTIONS(384),
    [anon_sym_SLASH] = ACTIONS(384),
    [anon_sym_GT_EQ] = ACTIONS(382),
    [anon_sym_LT_EQ] = ACTIONS(382),
    [anon_sym_EQ_EQ] = ACTIONS(382),
    [anon_sym_BANG_EQ] = ACTIONS(382),
    [anon_sym_EQ] = ACTIONS(384),
    [anon_sym_PLUS_EQ] = ACTIONS(382),
    [anon_sym_DASH_EQ] = ACTIONS(382),
    [anon_sym_STAR_EQ] = ACTIONS(382),
    [anon_sym_SLASH_EQ] = ACTIONS(382),
    [anon_sym_DQUOTE] = ACTIONS(382),
    [sym__identifier] = ACTIONS(384),
    [anon_sym_linear] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(384),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(384),
    [anon_sym_ease] = ACTIONS(384),
    [anon_sym_ease_DASHin] = ACTIONS(384),
    [anon_sym_ease_DASHout] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(384),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(384),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(384),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(384),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(384),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(384),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(384),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(384),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(384),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(384),
    [anon_sym_cubic_DASHbezier] = ACTIONS(384),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(382),
    [anon_sym_ATlinear_gradient] = ACTIONS(382),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(382),
    [anon_sym_ATradial_gradient] = ACTIONS(382),
    [anon_sym_parent] = ACTIONS(384),
    [anon_sym_root] = ACTIONS(384),
    [anon_sym_self] = ACTIONS(384),
    [sym__int_number] = ACTIONS(384),
    [sym__float_number] = ACTIONS(382),
    [anon_sym_true] = ACTIONS(384),
    [anon_sym_false] = ACTIONS(384),
    [sym_color_value] = ACTIONS(382),
    [sym_comment] = ACTIONS(3),
  },
  [154] = {
    [sym_add_prec_operator] = STATE(107),
    [sym_mult_prec_operator] = STATE(108),
    [sym_comparison_operator] = STATE(109),
    [anon_sym_LBRACE] = ACTIONS(386),
    [anon_sym_RBRACE] = ACTIONS(386),
    [anon_sym_SEMI] = ACTIONS(386),
    [anon_sym_LT] = ACTIONS(388),
    [anon_sym_GT] = ACTIONS(388),
    [anon_sym_return] = ACTIONS(388),
    [anon_sym_COLON] = ACTIONS(386),
    [anon_sym_LBRACK] = ACTIONS(358),
    [anon_sym_if] = ACTIONS(388),
    [anon_sym_LPAREN] = ACTIONS(386),
    [anon_sym_ATtr] = ACTIONS(386),
    [anon_sym_DOT] = ACTIONS(360),
    [sym_logical_and] = ACTIONS(386),
    [sym_logical_or] = ACTIONS(386),
    [anon_sym_QMARK] = ACTIONS(386),
    [anon_sym_ATimage_DASHurl] = ACTIONS(386),
    [anon_sym_BANG] = ACTIONS(388),
    [anon_sym_DASH] = ACTIONS(388),
    [anon_sym_PLUS] = ACTIONS(388),
    [anon_sym_STAR] = ACTIONS(388),
    [anon_sym_SLASH] = ACTIONS(388),
    [anon_sym_GT_EQ] = ACTIONS(386),
    [anon_sym_LT_EQ] = ACTIONS(386),
    [anon_sym_EQ_EQ] = ACTIONS(386),
    [anon_sym_BANG_EQ] = ACTIONS(386),
    [anon_sym_EQ] = ACTIONS(388),
    [anon_sym_PLUS_EQ] = ACTIONS(386),
    [anon_sym_DASH_EQ] = ACTIONS(386),
    [anon_sym_STAR_EQ] = ACTIONS(386),
    [anon_sym_SLASH_EQ] = ACTIONS(386),
    [anon_sym_DQUOTE] = ACTIONS(386),
    [sym__identifier] = ACTIONS(388),
    [anon_sym_linear] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(388),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(388),
    [anon_sym_ease] = ACTIONS(388),
    [anon_sym_ease_DASHin] = ACTIONS(388),
    [anon_sym_ease_DASHout] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(388),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(388),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(388),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(388),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(388),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(388),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(388),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(388),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(388),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(388),
    [anon_sym_cubic_DASHbezier] = ACTIONS(388),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(386),
    [anon_sym_ATlinear_gradient] = ACTIONS(386),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(386),
    [anon_sym_ATradial_gradient] = ACTIONS(386),
    [anon_sym_parent] = ACTIONS(388),
    [anon_sym_root] = ACTIONS(388),
    [anon_sym_self] = ACTIONS(388),
    [sym__int_number] = ACTIONS(388),
    [sym__float_number] = ACTIONS(386),
    [anon_sym_true] = ACTIONS(388),
    [anon_sym_false] = ACTIONS(388),
    [sym_color_value] = ACTIONS(386),
    [sym_comment] = ACTIONS(3),
  },
  [155] = {
    [anon_sym_LBRACE] = ACTIONS(390),
    [anon_sym_COMMA] = ACTIONS(390),
    [anon_sym_RBRACE] = ACTIONS(390),
    [anon_sym_SEMI] = ACTIONS(390),
    [anon_sym_LT] = ACTIONS(392),
    [anon_sym_GT] = ACTIONS(392),
    [anon_sym_return] = ACTIONS(392),
    [anon_sym_COLON] = ACTIONS(390),
    [anon_sym_LBRACK] = ACTIONS(390),
    [anon_sym_if] = ACTIONS(392),
    [anon_sym_LPAREN] = ACTIONS(390),
    [anon_sym_RPAREN] = ACTIONS(390),
    [anon_sym_ATtr] = ACTIONS(390),
    [anon_sym_EQ_GT] = ACTIONS(390),
    [anon_sym_DOT] = ACTIONS(392),
    [sym_logical_and] = ACTIONS(390),
    [sym_logical_or] = ACTIONS(390),
    [anon_sym_QMARK] = ACTIONS(390),
    [anon_sym_ATimage_DASHurl] = ACTIONS(390),
    [anon_sym_BANG] = ACTIONS(392),
    [anon_sym_DASH] = ACTIONS(392),
    [anon_sym_PLUS] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(392),
    [anon_sym_SLASH] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(390),
    [anon_sym_LT_EQ] = ACTIONS(390),
    [anon_sym_EQ_EQ] = ACTIONS(390),
    [anon_sym_BANG_EQ] = ACTIONS(390),
    [anon_sym_EQ] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(390),
    [anon_sym_DASH_EQ] = ACTIONS(390),
    [anon_sym_STAR_EQ] = ACTIONS(390),
    [anon_sym_SLASH_EQ] = ACTIONS(390),
    [anon_sym_DQUOTE] = ACTIONS(390),
    [sym__identifier] = ACTIONS(392),
    [anon_sym_linear] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(392),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(392),
    [anon_sym_ease] = ACTIONS(392),
    [anon_sym_ease_DASHin] = ACTIONS(392),
    [anon_sym_ease_DASHout] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(392),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(392),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(392),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(392),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(392),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(392),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(392),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(392),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(392),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(392),
    [anon_sym_cubic_DASHbezier] = ACTIONS(392),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(390),
    [anon_sym_ATlinear_gradient] = ACTIONS(390),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(390),
    [anon_sym_ATradial_gradient] = ACTIONS(390),
    [anon_sym_parent] = ACTIONS(392),
    [anon_sym_root] = ACTIONS(392),
    [anon_sym_self] = ACTIONS(392),
    [sym__int_number] = ACTIONS(392),
    [sym__float_number] = ACTIONS(390),
    [anon_sym_true] = ACTIONS(392),
    [anon_sym_false] = ACTIONS(392),
    [sym_color_value] = ACTIONS(390),
    [sym_comment] = ACTIONS(3),
  },
  [156] = {
    [sym_add_prec_operator] = STATE(107),
    [sym_mult_prec_operator] = STATE(108),
    [sym_comparison_operator] = STATE(109),
    [anon_sym_LBRACE] = ACTIONS(394),
    [anon_sym_RBRACE] = ACTIONS(394),
    [anon_sym_SEMI] = ACTIONS(394),
    [anon_sym_LT] = ACTIONS(396),
    [anon_sym_GT] = ACTIONS(396),
    [anon_sym_return] = ACTIONS(396),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_LBRACK] = ACTIONS(358),
    [anon_sym_if] = ACTIONS(396),
    [anon_sym_LPAREN] = ACTIONS(394),
    [anon_sym_ATtr] = ACTIONS(394),
    [anon_sym_DOT] = ACTIONS(396),
    [sym_logical_and] = ACTIONS(394),
    [sym_logical_or] = ACTIONS(394),
    [anon_sym_QMARK] = ACTIONS(394),
    [anon_sym_ATimage_DASHurl] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(396),
    [anon_sym_DASH] = ACTIONS(396),
    [anon_sym_PLUS] = ACTIONS(396),
    [anon_sym_STAR] = ACTIONS(396),
    [anon_sym_SLASH] = ACTIONS(396),
    [anon_sym_GT_EQ] = ACTIONS(394),
    [anon_sym_LT_EQ] = ACTIONS(394),
    [anon_sym_EQ_EQ] = ACTIONS(394),
    [anon_sym_BANG_EQ] = ACTIONS(394),
    [anon_sym_EQ] = ACTIONS(396),
    [anon_sym_PLUS_EQ] = ACTIONS(394),
    [anon_sym_DASH_EQ] = ACTIONS(394),
    [anon_sym_STAR_EQ] = ACTIONS(394),
    [anon_sym_SLASH_EQ] = ACTIONS(394),
    [anon_sym_DQUOTE] = ACTIONS(394),
    [sym__identifier] = ACTIONS(396),
    [anon_sym_linear] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(396),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(396),
    [anon_sym_ease] = ACTIONS(396),
    [anon_sym_ease_DASHin] = ACTIONS(396),
    [anon_sym_ease_DASHout] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(396),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(396),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(396),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(396),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(396),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(396),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(396),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(396),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(396),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(396),
    [anon_sym_cubic_DASHbezier] = ACTIONS(396),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(394),
    [anon_sym_ATlinear_gradient] = ACTIONS(394),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(394),
    [anon_sym_ATradial_gradient] = ACTIONS(394),
    [anon_sym_parent] = ACTIONS(396),
    [anon_sym_root] = ACTIONS(396),
    [anon_sym_self] = ACTIONS(396),
    [sym__int_number] = ACTIONS(396),
    [sym__float_number] = ACTIONS(394),
    [anon_sym_true] = ACTIONS(396),
    [anon_sym_false] = ACTIONS(396),
    [sym_color_value] = ACTIONS(394),
    [sym_comment] = ACTIONS(3),
  },
  [157] = {
    [sym_add_prec_operator] = STATE(107),
    [sym_mult_prec_operator] = STATE(108),
    [sym_comparison_operator] = STATE(109),
    [anon_sym_LBRACE] = ACTIONS(398),
    [anon_sym_RBRACE] = ACTIONS(398),
    [anon_sym_SEMI] = ACTIONS(398),
    [anon_sym_LT] = ACTIONS(352),
    [anon_sym_GT] = ACTIONS(352),
    [anon_sym_return] = ACTIONS(400),
    [anon_sym_COLON] = ACTIONS(398),
    [anon_sym_LBRACK] = ACTIONS(358),
    [anon_sym_if] = ACTIONS(400),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym_ATtr] = ACTIONS(398),
    [anon_sym_DOT] = ACTIONS(360),
    [sym_logical_and] = ACTIONS(398),
    [sym_logical_or] = ACTIONS(398),
    [anon_sym_QMARK] = ACTIONS(398),
    [anon_sym_ATimage_DASHurl] = ACTIONS(398),
    [anon_sym_BANG] = ACTIONS(400),
    [anon_sym_DASH] = ACTIONS(368),
    [anon_sym_PLUS] = ACTIONS(368),
    [anon_sym_STAR] = ACTIONS(370),
    [anon_sym_SLASH] = ACTIONS(370),
    [anon_sym_GT_EQ] = ACTIONS(372),
    [anon_sym_LT_EQ] = ACTIONS(372),
    [anon_sym_EQ_EQ] = ACTIONS(372),
    [anon_sym_BANG_EQ] = ACTIONS(372),
    [anon_sym_EQ] = ACTIONS(400),
    [anon_sym_PLUS_EQ] = ACTIONS(398),
    [anon_sym_DASH_EQ] = ACTIONS(398),
    [anon_sym_STAR_EQ] = ACTIONS(398),
    [anon_sym_SLASH_EQ] = ACTIONS(398),
    [anon_sym_DQUOTE] = ACTIONS(398),
    [sym__identifier] = ACTIONS(400),
    [anon_sym_linear] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(400),
    [anon_sym_ease] = ACTIONS(400),
    [anon_sym_ease_DASHin] = ACTIONS(400),
    [anon_sym_ease_DASHout] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(400),
    [anon_sym_cubic_DASHbezier] = ACTIONS(400),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(398),
    [anon_sym_ATlinear_gradient] = ACTIONS(398),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(398),
    [anon_sym_ATradial_gradient] = ACTIONS(398),
    [anon_sym_parent] = ACTIONS(400),
    [anon_sym_root] = ACTIONS(400),
    [anon_sym_self] = ACTIONS(400),
    [sym__int_number] = ACTIONS(400),
    [sym__float_number] = ACTIONS(398),
    [anon_sym_true] = ACTIONS(400),
    [anon_sym_false] = ACTIONS(400),
    [sym_color_value] = ACTIONS(398),
    [sym_comment] = ACTIONS(3),
  },
  [158] = {
    [sym_add_prec_operator] = STATE(107),
    [sym_mult_prec_operator] = STATE(108),
    [sym_comparison_operator] = STATE(109),
    [anon_sym_LBRACE] = ACTIONS(398),
    [anon_sym_RBRACE] = ACTIONS(398),
    [anon_sym_SEMI] = ACTIONS(398),
    [anon_sym_LT] = ACTIONS(352),
    [anon_sym_GT] = ACTIONS(352),
    [anon_sym_return] = ACTIONS(400),
    [anon_sym_COLON] = ACTIONS(398),
    [anon_sym_LBRACK] = ACTIONS(358),
    [anon_sym_if] = ACTIONS(400),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym_ATtr] = ACTIONS(398),
    [anon_sym_DOT] = ACTIONS(360),
    [sym_logical_and] = ACTIONS(362),
    [sym_logical_or] = ACTIONS(398),
    [anon_sym_QMARK] = ACTIONS(398),
    [anon_sym_ATimage_DASHurl] = ACTIONS(398),
    [anon_sym_BANG] = ACTIONS(400),
    [anon_sym_DASH] = ACTIONS(368),
    [anon_sym_PLUS] = ACTIONS(368),
    [anon_sym_STAR] = ACTIONS(370),
    [anon_sym_SLASH] = ACTIONS(370),
    [anon_sym_GT_EQ] = ACTIONS(372),
    [anon_sym_LT_EQ] = ACTIONS(372),
    [anon_sym_EQ_EQ] = ACTIONS(372),
    [anon_sym_BANG_EQ] = ACTIONS(372),
    [anon_sym_EQ] = ACTIONS(400),
    [anon_sym_PLUS_EQ] = ACTIONS(398),
    [anon_sym_DASH_EQ] = ACTIONS(398),
    [anon_sym_STAR_EQ] = ACTIONS(398),
    [anon_sym_SLASH_EQ] = ACTIONS(398),
    [anon_sym_DQUOTE] = ACTIONS(398),
    [sym__identifier] = ACTIONS(400),
    [anon_sym_linear] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(400),
    [anon_sym_ease] = ACTIONS(400),
    [anon_sym_ease_DASHin] = ACTIONS(400),
    [anon_sym_ease_DASHout] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(400),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(400),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(400),
    [anon_sym_cubic_DASHbezier] = ACTIONS(400),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(398),
    [anon_sym_ATlinear_gradient] = ACTIONS(398),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(398),
    [anon_sym_ATradial_gradient] = ACTIONS(398),
    [anon_sym_parent] = ACTIONS(400),
    [anon_sym_root] = ACTIONS(400),
    [anon_sym_self] = ACTIONS(400),
    [sym__int_number] = ACTIONS(400),
    [sym__float_number] = ACTIONS(398),
    [anon_sym_true] = ACTIONS(400),
    [anon_sym_false] = ACTIONS(400),
    [sym_color_value] = ACTIONS(398),
    [sym_comment] = ACTIONS(3),
  },
  [159] = {
    [sym_add_prec_operator] = STATE(107),
    [sym_mult_prec_operator] = STATE(108),
    [sym_comparison_operator] = STATE(109),
    [anon_sym_LBRACE] = ACTIONS(402),
    [anon_sym_RBRACE] = ACTIONS(402),
    [anon_sym_SEMI] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(404),
    [anon_sym_GT] = ACTIONS(404),
    [anon_sym_return] = ACTIONS(404),
    [anon_sym_COLON] = ACTIONS(402),
    [anon_sym_LBRACK] = ACTIONS(358),
    [anon_sym_if] = ACTIONS(404),
    [anon_sym_LPAREN] = ACTIONS(402),
    [anon_sym_ATtr] = ACTIONS(402),
    [anon_sym_DOT] = ACTIONS(360),
    [sym_logical_and] = ACTIONS(402),
    [sym_logical_or] = ACTIONS(402),
    [anon_sym_QMARK] = ACTIONS(402),
    [anon_sym_ATimage_DASHurl] = ACTIONS(402),
    [anon_sym_BANG] = ACTIONS(404),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_PLUS] = ACTIONS(404),
    [anon_sym_STAR] = ACTIONS(370),
    [anon_sym_SLASH] = ACTIONS(370),
    [anon_sym_GT_EQ] = ACTIONS(402),
    [anon_sym_LT_EQ] = ACTIONS(402),
    [anon_sym_EQ_EQ] = ACTIONS(402),
    [anon_sym_BANG_EQ] = ACTIONS(402),
    [anon_sym_EQ] = ACTIONS(404),
    [anon_sym_PLUS_EQ] = ACTIONS(402),
    [anon_sym_DASH_EQ] = ACTIONS(402),
    [anon_sym_STAR_EQ] = ACTIONS(402),
    [anon_sym_SLASH_EQ] = ACTIONS(402),
    [anon_sym_DQUOTE] = ACTIONS(402),
    [sym__identifier] = ACTIONS(404),
    [anon_sym_linear] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(404),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(404),
    [anon_sym_ease] = ACTIONS(404),
    [anon_sym_ease_DASHin] = ACTIONS(404),
    [anon_sym_ease_DASHout] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(404),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(404),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(404),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(404),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(404),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(404),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(404),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(404),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(404),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(404),
    [anon_sym_cubic_DASHbezier] = ACTIONS(404),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(402),
    [anon_sym_ATlinear_gradient] = ACTIONS(402),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(402),
    [anon_sym_ATradial_gradient] = ACTIONS(402),
    [anon_sym_parent] = ACTIONS(404),
    [anon_sym_root] = ACTIONS(404),
    [anon_sym_self] = ACTIONS(404),
    [sym__int_number] = ACTIONS(404),
    [sym__float_number] = ACTIONS(402),
    [anon_sym_true] = ACTIONS(404),
    [anon_sym_false] = ACTIONS(404),
    [sym_color_value] = ACTIONS(402),
    [sym_comment] = ACTIONS(3),
  },
  [160] = {
    [sym_add_prec_operator] = STATE(107),
    [sym_mult_prec_operator] = STATE(108),
    [sym_comparison_operator] = STATE(109),
    [anon_sym_LBRACE] = ACTIONS(406),
    [anon_sym_RBRACE] = ACTIONS(406),
    [anon_sym_SEMI] = ACTIONS(406),
    [anon_sym_LT] = ACTIONS(408),
    [anon_sym_GT] = ACTIONS(408),
    [anon_sym_return] = ACTIONS(408),
    [anon_sym_COLON] = ACTIONS(406),
    [anon_sym_LBRACK] = ACTIONS(358),
    [anon_sym_if] = ACTIONS(408),
    [anon_sym_LPAREN] = ACTIONS(406),
    [anon_sym_ATtr] = ACTIONS(406),
    [anon_sym_DOT] = ACTIONS(360),
    [sym_logical_and] = ACTIONS(406),
    [sym_logical_or] = ACTIONS(406),
    [anon_sym_QMARK] = ACTIONS(406),
    [anon_sym_ATimage_DASHurl] = ACTIONS(406),
    [anon_sym_BANG] = ACTIONS(408),
    [anon_sym_DASH] = ACTIONS(408),
    [anon_sym_PLUS] = ACTIONS(408),
    [anon_sym_STAR] = ACTIONS(408),
    [anon_sym_SLASH] = ACTIONS(408),
    [anon_sym_GT_EQ] = ACTIONS(406),
    [anon_sym_LT_EQ] = ACTIONS(406),
    [anon_sym_EQ_EQ] = ACTIONS(406),
    [anon_sym_BANG_EQ] = ACTIONS(406),
    [anon_sym_EQ] = ACTIONS(408),
    [anon_sym_PLUS_EQ] = ACTIONS(406),
    [anon_sym_DASH_EQ] = ACTIONS(406),
    [anon_sym_STAR_EQ] = ACTIONS(406),
    [anon_sym_SLASH_EQ] = ACTIONS(406),
    [anon_sym_DQUOTE] = ACTIONS(406),
    [sym__identifier] = ACTIONS(408),
    [anon_sym_linear] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(408),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(408),
    [anon_sym_ease] = ACTIONS(408),
    [anon_sym_ease_DASHin] = ACTIONS(408),
    [anon_sym_ease_DASHout] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(408),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(408),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(408),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(408),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(408),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(408),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(408),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(408),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(408),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(408),
    [anon_sym_cubic_DASHbezier] = ACTIONS(408),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(406),
    [anon_sym_ATlinear_gradient] = ACTIONS(406),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(406),
    [anon_sym_ATradial_gradient] = ACTIONS(406),
    [anon_sym_parent] = ACTIONS(408),
    [anon_sym_root] = ACTIONS(408),
    [anon_sym_self] = ACTIONS(408),
    [sym__int_number] = ACTIONS(408),
    [sym__float_number] = ACTIONS(406),
    [anon_sym_true] = ACTIONS(408),
    [anon_sym_false] = ACTIONS(408),
    [sym_color_value] = ACTIONS(406),
    [sym_comment] = ACTIONS(3),
  },
  [161] = {
    [anon_sym_LBRACE] = ACTIONS(410),
    [anon_sym_COMMA] = ACTIONS(410),
    [anon_sym_RBRACE] = ACTIONS(410),
    [anon_sym_SEMI] = ACTIONS(410),
    [anon_sym_LT] = ACTIONS(412),
    [anon_sym_GT] = ACTIONS(412),
    [anon_sym_return] = ACTIONS(412),
    [anon_sym_COLON] = ACTIONS(410),
    [anon_sym_LBRACK] = ACTIONS(410),
    [anon_sym_if] = ACTIONS(412),
    [anon_sym_LPAREN] = ACTIONS(410),
    [anon_sym_RPAREN] = ACTIONS(410),
    [anon_sym_ATtr] = ACTIONS(410),
    [anon_sym_EQ_GT] = ACTIONS(410),
    [anon_sym_DOT] = ACTIONS(412),
    [sym_logical_and] = ACTIONS(410),
    [sym_logical_or] = ACTIONS(410),
    [anon_sym_QMARK] = ACTIONS(410),
    [anon_sym_ATimage_DASHurl] = ACTIONS(410),
    [anon_sym_BANG] = ACTIONS(412),
    [anon_sym_DASH] = ACTIONS(412),
    [anon_sym_PLUS] = ACTIONS(412),
    [anon_sym_STAR] = ACTIONS(412),
    [anon_sym_SLASH] = ACTIONS(412),
    [anon_sym_GT_EQ] = ACTIONS(410),
    [anon_sym_LT_EQ] = ACTIONS(410),
    [anon_sym_EQ_EQ] = ACTIONS(410),
    [anon_sym_BANG_EQ] = ACTIONS(410),
    [anon_sym_EQ] = ACTIONS(412),
    [anon_sym_PLUS_EQ] = ACTIONS(410),
    [anon_sym_DASH_EQ] = ACTIONS(410),
    [anon_sym_STAR_EQ] = ACTIONS(410),
    [anon_sym_SLASH_EQ] = ACTIONS(410),
    [anon_sym_DQUOTE] = ACTIONS(410),
    [sym__identifier] = ACTIONS(412),
    [anon_sym_linear] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(412),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(412),
    [anon_sym_ease] = ACTIONS(412),
    [anon_sym_ease_DASHin] = ACTIONS(412),
    [anon_sym_ease_DASHout] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(412),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(412),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(412),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(412),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(412),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(412),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(412),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(412),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(412),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(412),
    [anon_sym_cubic_DASHbezier] = ACTIONS(412),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(410),
    [anon_sym_ATlinear_gradient] = ACTIONS(410),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(410),
    [anon_sym_ATradial_gradient] = ACTIONS(410),
    [anon_sym_parent] = ACTIONS(412),
    [anon_sym_root] = ACTIONS(412),
    [anon_sym_self] = ACTIONS(412),
    [sym__int_number] = ACTIONS(412),
    [sym__float_number] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [sym_color_value] = ACTIONS(410),
    [sym_comment] = ACTIONS(3),
  },
  [162] = {
    [anon_sym_LBRACE] = ACTIONS(414),
    [anon_sym_COMMA] = ACTIONS(414),
    [anon_sym_RBRACE] = ACTIONS(414),
    [anon_sym_SEMI] = ACTIONS(414),
    [anon_sym_LT] = ACTIONS(416),
    [anon_sym_GT] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(414),
    [anon_sym_LBRACK] = ACTIONS(414),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_LPAREN] = ACTIONS(414),
    [anon_sym_RPAREN] = ACTIONS(414),
    [anon_sym_ATtr] = ACTIONS(414),
    [anon_sym_EQ_GT] = ACTIONS(414),
    [anon_sym_DOT] = ACTIONS(416),
    [sym_logical_and] = ACTIONS(414),
    [sym_logical_or] = ACTIONS(414),
    [anon_sym_QMARK] = ACTIONS(414),
    [anon_sym_ATimage_DASHurl] = ACTIONS(414),
    [anon_sym_BANG] = ACTIONS(416),
    [anon_sym_DASH] = ACTIONS(416),
    [anon_sym_PLUS] = ACTIONS(416),
    [anon_sym_STAR] = ACTIONS(416),
    [anon_sym_SLASH] = ACTIONS(416),
    [anon_sym_GT_EQ] = ACTIONS(414),
    [anon_sym_LT_EQ] = ACTIONS(414),
    [anon_sym_EQ_EQ] = ACTIONS(414),
    [anon_sym_BANG_EQ] = ACTIONS(414),
    [anon_sym_EQ] = ACTIONS(416),
    [anon_sym_PLUS_EQ] = ACTIONS(414),
    [anon_sym_DASH_EQ] = ACTIONS(414),
    [anon_sym_STAR_EQ] = ACTIONS(414),
    [anon_sym_SLASH_EQ] = ACTIONS(414),
    [anon_sym_DQUOTE] = ACTIONS(414),
    [sym__identifier] = ACTIONS(416),
    [anon_sym_linear] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(416),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(416),
    [anon_sym_ease] = ACTIONS(416),
    [anon_sym_ease_DASHin] = ACTIONS(416),
    [anon_sym_ease_DASHout] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(416),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(416),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(416),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(416),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(416),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(416),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(416),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(416),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(416),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(416),
    [anon_sym_cubic_DASHbezier] = ACTIONS(416),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(414),
    [anon_sym_ATlinear_gradient] = ACTIONS(414),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(414),
    [anon_sym_ATradial_gradient] = ACTIONS(414),
    [anon_sym_parent] = ACTIONS(416),
    [anon_sym_root] = ACTIONS(416),
    [anon_sym_self] = ACTIONS(416),
    [sym__int_number] = ACTIONS(416),
    [sym__float_number] = ACTIONS(414),
    [anon_sym_true] = ACTIONS(416),
    [anon_sym_false] = ACTIONS(416),
    [sym_color_value] = ACTIONS(414),
    [sym_comment] = ACTIONS(3),
  },
  [163] = {
    [sym_add_prec_operator] = STATE(107),
    [sym_mult_prec_operator] = STATE(108),
    [sym_comparison_operator] = STATE(109),
    [anon_sym_LBRACE] = ACTIONS(418),
    [anon_sym_RBRACE] = ACTIONS(418),
    [anon_sym_SEMI] = ACTIONS(418),
    [anon_sym_LT] = ACTIONS(420),
    [anon_sym_GT] = ACTIONS(420),
    [anon_sym_return] = ACTIONS(420),
    [anon_sym_COLON] = ACTIONS(418),
    [anon_sym_LBRACK] = ACTIONS(358),
    [anon_sym_if] = ACTIONS(420),
    [anon_sym_LPAREN] = ACTIONS(418),
    [anon_sym_ATtr] = ACTIONS(418),
    [anon_sym_DOT] = ACTIONS(360),
    [sym_logical_and] = ACTIONS(418),
    [sym_logical_or] = ACTIONS(418),
    [anon_sym_QMARK] = ACTIONS(418),
    [anon_sym_ATimage_DASHurl] = ACTIONS(418),
    [anon_sym_BANG] = ACTIONS(420),
    [anon_sym_DASH] = ACTIONS(368),
    [anon_sym_PLUS] = ACTIONS(368),
    [anon_sym_STAR] = ACTIONS(370),
    [anon_sym_SLASH] = ACTIONS(370),
    [anon_sym_GT_EQ] = ACTIONS(418),
    [anon_sym_LT_EQ] = ACTIONS(418),
    [anon_sym_EQ_EQ] = ACTIONS(418),
    [anon_sym_BANG_EQ] = ACTIONS(418),
    [anon_sym_EQ] = ACTIONS(420),
    [anon_sym_PLUS_EQ] = ACTIONS(418),
    [anon_sym_DASH_EQ] = ACTIONS(418),
    [anon_sym_STAR_EQ] = ACTIONS(418),
    [anon_sym_SLASH_EQ] = ACTIONS(418),
    [anon_sym_DQUOTE] = ACTIONS(418),
    [sym__identifier] = ACTIONS(420),
    [anon_sym_linear] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(420),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(420),
    [anon_sym_ease] = ACTIONS(420),
    [anon_sym_ease_DASHin] = ACTIONS(420),
    [anon_sym_ease_DASHout] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(420),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(420),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(420),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(420),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(420),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(420),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(420),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(420),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(420),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(420),
    [anon_sym_cubic_DASHbezier] = ACTIONS(420),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(418),
    [anon_sym_ATlinear_gradient] = ACTIONS(418),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(418),
    [anon_sym_ATradial_gradient] = ACTIONS(418),
    [anon_sym_parent] = ACTIONS(420),
    [anon_sym_root] = ACTIONS(420),
    [anon_sym_self] = ACTIONS(420),
    [sym__int_number] = ACTIONS(420),
    [sym__float_number] = ACTIONS(418),
    [anon_sym_true] = ACTIONS(420),
    [anon_sym_false] = ACTIONS(420),
    [sym_color_value] = ACTIONS(418),
    [sym_comment] = ACTIONS(3),
  },
  [164] = {
    [anon_sym_LBRACE] = ACTIONS(422),
    [anon_sym_COMMA] = ACTIONS(422),
    [anon_sym_RBRACE] = ACTIONS(422),
    [anon_sym_SEMI] = ACTIONS(422),
    [anon_sym_LT] = ACTIONS(424),
    [anon_sym_GT] = ACTIONS(424),
    [anon_sym_return] = ACTIONS(424),
    [anon_sym_COLON] = ACTIONS(422),
    [anon_sym_LBRACK] = ACTIONS(422),
    [anon_sym_if] = ACTIONS(424),
    [anon_sym_LPAREN] = ACTIONS(422),
    [anon_sym_RPAREN] = ACTIONS(422),
    [anon_sym_ATtr] = ACTIONS(422),
    [anon_sym_EQ_GT] = ACTIONS(422),
    [anon_sym_DOT] = ACTIONS(424),
    [sym_logical_and] = ACTIONS(422),
    [sym_logical_or] = ACTIONS(422),
    [anon_sym_QMARK] = ACTIONS(422),
    [anon_sym_ATimage_DASHurl] = ACTIONS(422),
    [anon_sym_BANG] = ACTIONS(424),
    [anon_sym_DASH] = ACTIONS(424),
    [anon_sym_PLUS] = ACTIONS(424),
    [anon_sym_STAR] = ACTIONS(424),
    [anon_sym_SLASH] = ACTIONS(424),
    [anon_sym_GT_EQ] = ACTIONS(422),
    [anon_sym_LT_EQ] = ACTIONS(422),
    [anon_sym_EQ_EQ] = ACTIONS(422),
    [anon_sym_BANG_EQ] = ACTIONS(422),
    [anon_sym_EQ] = ACTIONS(424),
    [anon_sym_PLUS_EQ] = ACTIONS(422),
    [anon_sym_DASH_EQ] = ACTIONS(422),
    [anon_sym_STAR_EQ] = ACTIONS(422),
    [anon_sym_SLASH_EQ] = ACTIONS(422),
    [anon_sym_DQUOTE] = ACTIONS(422),
    [sym__identifier] = ACTIONS(424),
    [anon_sym_linear] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(424),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(424),
    [anon_sym_ease] = ACTIONS(424),
    [anon_sym_ease_DASHin] = ACTIONS(424),
    [anon_sym_ease_DASHout] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(424),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(424),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(424),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(424),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(424),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(424),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(424),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(424),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(424),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(424),
    [anon_sym_cubic_DASHbezier] = ACTIONS(424),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(422),
    [anon_sym_ATlinear_gradient] = ACTIONS(422),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(422),
    [anon_sym_ATradial_gradient] = ACTIONS(422),
    [anon_sym_parent] = ACTIONS(424),
    [anon_sym_root] = ACTIONS(424),
    [anon_sym_self] = ACTIONS(424),
    [sym__int_number] = ACTIONS(424),
    [sym__float_number] = ACTIONS(422),
    [anon_sym_true] = ACTIONS(424),
    [anon_sym_false] = ACTIONS(424),
    [sym_color_value] = ACTIONS(422),
    [sym_comment] = ACTIONS(3),
  },
  [165] = {
    [sym_add_prec_operator] = STATE(107),
    [sym_mult_prec_operator] = STATE(108),
    [sym_comparison_operator] = STATE(109),
    [anon_sym_LBRACE] = ACTIONS(426),
    [anon_sym_RBRACE] = ACTIONS(426),
    [anon_sym_SEMI] = ACTIONS(426),
    [anon_sym_LT] = ACTIONS(352),
    [anon_sym_GT] = ACTIONS(352),
    [anon_sym_return] = ACTIONS(428),
    [anon_sym_COLON] = ACTIONS(426),
    [anon_sym_LBRACK] = ACTIONS(358),
    [anon_sym_if] = ACTIONS(428),
    [anon_sym_LPAREN] = ACTIONS(426),
    [anon_sym_ATtr] = ACTIONS(426),
    [anon_sym_DOT] = ACTIONS(360),
    [sym_logical_and] = ACTIONS(362),
    [sym_logical_or] = ACTIONS(426),
    [anon_sym_QMARK] = ACTIONS(426),
    [anon_sym_ATimage_DASHurl] = ACTIONS(426),
    [anon_sym_BANG] = ACTIONS(428),
    [anon_sym_DASH] = ACTIONS(368),
    [anon_sym_PLUS] = ACTIONS(368),
    [anon_sym_STAR] = ACTIONS(370),
    [anon_sym_SLASH] = ACTIONS(370),
    [anon_sym_GT_EQ] = ACTIONS(372),
    [anon_sym_LT_EQ] = ACTIONS(372),
    [anon_sym_EQ_EQ] = ACTIONS(372),
    [anon_sym_BANG_EQ] = ACTIONS(372),
    [anon_sym_EQ] = ACTIONS(428),
    [anon_sym_PLUS_EQ] = ACTIONS(426),
    [anon_sym_DASH_EQ] = ACTIONS(426),
    [anon_sym_STAR_EQ] = ACTIONS(426),
    [anon_sym_SLASH_EQ] = ACTIONS(426),
    [anon_sym_DQUOTE] = ACTIONS(426),
    [sym__identifier] = ACTIONS(428),
    [anon_sym_linear] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(428),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(428),
    [anon_sym_ease] = ACTIONS(428),
    [anon_sym_ease_DASHin] = ACTIONS(428),
    [anon_sym_ease_DASHout] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(428),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(428),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(428),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(428),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(428),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(428),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(428),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(428),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(428),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(428),
    [anon_sym_cubic_DASHbezier] = ACTIONS(428),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(426),
    [anon_sym_ATlinear_gradient] = ACTIONS(426),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(426),
    [anon_sym_ATradial_gradient] = ACTIONS(426),
    [anon_sym_parent] = ACTIONS(428),
    [anon_sym_root] = ACTIONS(428),
    [anon_sym_self] = ACTIONS(428),
    [sym__int_number] = ACTIONS(428),
    [sym__float_number] = ACTIONS(426),
    [anon_sym_true] = ACTIONS(428),
    [anon_sym_false] = ACTIONS(428),
    [sym_color_value] = ACTIONS(426),
    [sym_comment] = ACTIONS(3),
  },
  [166] = {
    [anon_sym_LBRACE] = ACTIONS(430),
    [anon_sym_COMMA] = ACTIONS(430),
    [anon_sym_RBRACE] = ACTIONS(430),
    [anon_sym_SEMI] = ACTIONS(430),
    [anon_sym_LT] = ACTIONS(432),
    [anon_sym_GT] = ACTIONS(432),
    [anon_sym_return] = ACTIONS(432),
    [anon_sym_COLON] = ACTIONS(430),
    [anon_sym_LBRACK] = ACTIONS(430),
    [anon_sym_if] = ACTIONS(432),
    [anon_sym_LPAREN] = ACTIONS(430),
    [anon_sym_RPAREN] = ACTIONS(430),
    [anon_sym_ATtr] = ACTIONS(430),
    [anon_sym_EQ_GT] = ACTIONS(430),
    [anon_sym_DOT] = ACTIONS(432),
    [sym_logical_and] = ACTIONS(430),
    [sym_logical_or] = ACTIONS(430),
    [anon_sym_QMARK] = ACTIONS(430),
    [anon_sym_ATimage_DASHurl] = ACTIONS(430),
    [anon_sym_BANG] = ACTIONS(432),
    [anon_sym_DASH] = ACTIONS(432),
    [anon_sym_PLUS] = ACTIONS(432),
    [anon_sym_STAR] = ACTIONS(432),
    [anon_sym_SLASH] = ACTIONS(432),
    [anon_sym_GT_EQ] = ACTIONS(430),
    [anon_sym_LT_EQ] = ACTIONS(430),
    [anon_sym_EQ_EQ] = ACTIONS(430),
    [anon_sym_BANG_EQ] = ACTIONS(430),
    [anon_sym_EQ] = ACTIONS(432),
    [anon_sym_PLUS_EQ] = ACTIONS(430),
    [anon_sym_DASH_EQ] = ACTIONS(430),
    [anon_sym_STAR_EQ] = ACTIONS(430),
    [anon_sym_SLASH_EQ] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(430),
    [sym__identifier] = ACTIONS(432),
    [anon_sym_linear] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(432),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(432),
    [anon_sym_ease] = ACTIONS(432),
    [anon_sym_ease_DASHin] = ACTIONS(432),
    [anon_sym_ease_DASHout] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(432),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(432),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(432),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(432),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(432),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(432),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(432),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(432),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(432),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(432),
    [anon_sym_cubic_DASHbezier] = ACTIONS(432),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(430),
    [anon_sym_ATlinear_gradient] = ACTIONS(430),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(430),
    [anon_sym_ATradial_gradient] = ACTIONS(430),
    [anon_sym_parent] = ACTIONS(432),
    [anon_sym_root] = ACTIONS(432),
    [anon_sym_self] = ACTIONS(432),
    [sym__int_number] = ACTIONS(432),
    [sym__float_number] = ACTIONS(430),
    [anon_sym_true] = ACTIONS(432),
    [anon_sym_false] = ACTIONS(432),
    [sym_color_value] = ACTIONS(430),
    [sym_comment] = ACTIONS(3),
  },
  [167] = {
    [anon_sym_LBRACE] = ACTIONS(434),
    [anon_sym_COMMA] = ACTIONS(434),
    [anon_sym_RBRACE] = ACTIONS(434),
    [anon_sym_SEMI] = ACTIONS(434),
    [anon_sym_LT] = ACTIONS(436),
    [anon_sym_GT] = ACTIONS(436),
    [anon_sym_return] = ACTIONS(436),
    [anon_sym_COLON] = ACTIONS(434),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(436),
    [anon_sym_LPAREN] = ACTIONS(434),
    [anon_sym_RPAREN] = ACTIONS(434),
    [anon_sym_ATtr] = ACTIONS(434),
    [anon_sym_DOT] = ACTIONS(436),
    [sym_logical_and] = ACTIONS(434),
    [sym_logical_or] = ACTIONS(434),
    [anon_sym_QMARK] = ACTIONS(434),
    [anon_sym_ATimage_DASHurl] = ACTIONS(434),
    [anon_sym_BANG] = ACTIONS(436),
    [anon_sym_DASH] = ACTIONS(436),
    [anon_sym_PLUS] = ACTIONS(436),
    [anon_sym_STAR] = ACTIONS(436),
    [anon_sym_SLASH] = ACTIONS(436),
    [anon_sym_GT_EQ] = ACTIONS(434),
    [anon_sym_LT_EQ] = ACTIONS(434),
    [anon_sym_EQ_EQ] = ACTIONS(434),
    [anon_sym_BANG_EQ] = ACTIONS(434),
    [anon_sym_EQ] = ACTIONS(436),
    [anon_sym_PLUS_EQ] = ACTIONS(434),
    [anon_sym_DASH_EQ] = ACTIONS(434),
    [anon_sym_STAR_EQ] = ACTIONS(434),
    [anon_sym_SLASH_EQ] = ACTIONS(434),
    [anon_sym_DQUOTE] = ACTIONS(434),
    [sym__identifier] = ACTIONS(436),
    [anon_sym_linear] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(436),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(436),
    [anon_sym_ease] = ACTIONS(436),
    [anon_sym_ease_DASHin] = ACTIONS(436),
    [anon_sym_ease_DASHout] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(436),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(436),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(436),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(436),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(436),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(436),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(436),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(436),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(436),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(436),
    [anon_sym_cubic_DASHbezier] = ACTIONS(436),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(434),
    [anon_sym_ATlinear_gradient] = ACTIONS(434),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(434),
    [anon_sym_ATradial_gradient] = ACTIONS(434),
    [anon_sym_parent] = ACTIONS(436),
    [anon_sym_root] = ACTIONS(436),
    [anon_sym_self] = ACTIONS(436),
    [sym__int_number] = ACTIONS(436),
    [sym__float_number] = ACTIONS(434),
    [anon_sym_true] = ACTIONS(436),
    [anon_sym_false] = ACTIONS(436),
    [sym_color_value] = ACTIONS(434),
    [sym_comment] = ACTIONS(3),
  },
  [168] = {
    [anon_sym_LBRACE] = ACTIONS(438),
    [anon_sym_COMMA] = ACTIONS(438),
    [anon_sym_RBRACE] = ACTIONS(438),
    [anon_sym_SEMI] = ACTIONS(438),
    [anon_sym_LT] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(440),
    [anon_sym_return] = ACTIONS(440),
    [anon_sym_COLON] = ACTIONS(438),
    [anon_sym_LBRACK] = ACTIONS(438),
    [anon_sym_if] = ACTIONS(440),
    [anon_sym_LPAREN] = ACTIONS(438),
    [anon_sym_RPAREN] = ACTIONS(438),
    [anon_sym_ATtr] = ACTIONS(438),
    [anon_sym_DOT] = ACTIONS(440),
    [sym_logical_and] = ACTIONS(438),
    [sym_logical_or] = ACTIONS(438),
    [anon_sym_QMARK] = ACTIONS(438),
    [anon_sym_ATimage_DASHurl] = ACTIONS(438),
    [anon_sym_BANG] = ACTIONS(440),
    [anon_sym_DASH] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(440),
    [anon_sym_STAR] = ACTIONS(440),
    [anon_sym_SLASH] = ACTIONS(440),
    [anon_sym_GT_EQ] = ACTIONS(438),
    [anon_sym_LT_EQ] = ACTIONS(438),
    [anon_sym_EQ_EQ] = ACTIONS(438),
    [anon_sym_BANG_EQ] = ACTIONS(438),
    [anon_sym_EQ] = ACTIONS(440),
    [anon_sym_PLUS_EQ] = ACTIONS(438),
    [anon_sym_DASH_EQ] = ACTIONS(438),
    [anon_sym_STAR_EQ] = ACTIONS(438),
    [anon_sym_SLASH_EQ] = ACTIONS(438),
    [anon_sym_DQUOTE] = ACTIONS(438),
    [sym__identifier] = ACTIONS(440),
    [anon_sym_linear] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(440),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(440),
    [anon_sym_ease] = ACTIONS(440),
    [anon_sym_ease_DASHin] = ACTIONS(440),
    [anon_sym_ease_DASHout] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(440),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(440),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(440),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(440),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(440),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(440),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(440),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(440),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(440),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(440),
    [anon_sym_cubic_DASHbezier] = ACTIONS(440),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(438),
    [anon_sym_ATlinear_gradient] = ACTIONS(438),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(438),
    [anon_sym_ATradial_gradient] = ACTIONS(438),
    [anon_sym_parent] = ACTIONS(440),
    [anon_sym_root] = ACTIONS(440),
    [anon_sym_self] = ACTIONS(440),
    [sym__int_number] = ACTIONS(440),
    [sym__float_number] = ACTIONS(438),
    [anon_sym_true] = ACTIONS(440),
    [anon_sym_false] = ACTIONS(440),
    [sym_color_value] = ACTIONS(438),
    [sym_comment] = ACTIONS(3),
  },
  [169] = {
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_COMMA] = ACTIONS(442),
    [anon_sym_RBRACE] = ACTIONS(442),
    [anon_sym_SEMI] = ACTIONS(442),
    [anon_sym_LT] = ACTIONS(444),
    [anon_sym_GT] = ACTIONS(444),
    [anon_sym_return] = ACTIONS(444),
    [anon_sym_COLON] = ACTIONS(442),
    [anon_sym_LBRACK] = ACTIONS(442),
    [anon_sym_if] = ACTIONS(444),
    [anon_sym_LPAREN] = ACTIONS(442),
    [anon_sym_RPAREN] = ACTIONS(442),
    [anon_sym_ATtr] = ACTIONS(442),
    [anon_sym_DOT] = ACTIONS(444),
    [sym_logical_and] = ACTIONS(442),
    [sym_logical_or] = ACTIONS(442),
    [anon_sym_QMARK] = ACTIONS(442),
    [anon_sym_ATimage_DASHurl] = ACTIONS(442),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_DASH] = ACTIONS(444),
    [anon_sym_PLUS] = ACTIONS(444),
    [anon_sym_STAR] = ACTIONS(444),
    [anon_sym_SLASH] = ACTIONS(444),
    [anon_sym_GT_EQ] = ACTIONS(442),
    [anon_sym_LT_EQ] = ACTIONS(442),
    [anon_sym_EQ_EQ] = ACTIONS(442),
    [anon_sym_BANG_EQ] = ACTIONS(442),
    [anon_sym_EQ] = ACTIONS(444),
    [anon_sym_PLUS_EQ] = ACTIONS(442),
    [anon_sym_DASH_EQ] = ACTIONS(442),
    [anon_sym_STAR_EQ] = ACTIONS(442),
    [anon_sym_SLASH_EQ] = ACTIONS(442),
    [anon_sym_DQUOTE] = ACTIONS(442),
    [sym__identifier] = ACTIONS(444),
    [anon_sym_linear] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(444),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(444),
    [anon_sym_ease] = ACTIONS(444),
    [anon_sym_ease_DASHin] = ACTIONS(444),
    [anon_sym_ease_DASHout] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(444),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(444),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(444),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(444),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(444),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(444),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(444),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(444),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(444),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(444),
    [anon_sym_cubic_DASHbezier] = ACTIONS(444),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(442),
    [anon_sym_ATlinear_gradient] = ACTIONS(442),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(442),
    [anon_sym_ATradial_gradient] = ACTIONS(442),
    [anon_sym_parent] = ACTIONS(444),
    [anon_sym_root] = ACTIONS(444),
    [anon_sym_self] = ACTIONS(444),
    [sym__int_number] = ACTIONS(444),
    [sym__float_number] = ACTIONS(442),
    [anon_sym_true] = ACTIONS(444),
    [anon_sym_false] = ACTIONS(444),
    [sym_color_value] = ACTIONS(442),
    [sym_comment] = ACTIONS(3),
  },
  [170] = {
    [anon_sym_LBRACE] = ACTIONS(446),
    [anon_sym_COMMA] = ACTIONS(446),
    [anon_sym_RBRACE] = ACTIONS(446),
    [anon_sym_SEMI] = ACTIONS(446),
    [anon_sym_LT] = ACTIONS(448),
    [anon_sym_GT] = ACTIONS(448),
    [anon_sym_return] = ACTIONS(448),
    [anon_sym_COLON] = ACTIONS(446),
    [anon_sym_LBRACK] = ACTIONS(446),
    [anon_sym_if] = ACTIONS(448),
    [anon_sym_LPAREN] = ACTIONS(446),
    [anon_sym_RPAREN] = ACTIONS(446),
    [anon_sym_ATtr] = ACTIONS(446),
    [anon_sym_DOT] = ACTIONS(448),
    [sym_logical_and] = ACTIONS(446),
    [sym_logical_or] = ACTIONS(446),
    [anon_sym_QMARK] = ACTIONS(446),
    [anon_sym_ATimage_DASHurl] = ACTIONS(446),
    [anon_sym_BANG] = ACTIONS(448),
    [anon_sym_DASH] = ACTIONS(448),
    [anon_sym_PLUS] = ACTIONS(448),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_SLASH] = ACTIONS(448),
    [anon_sym_GT_EQ] = ACTIONS(446),
    [anon_sym_LT_EQ] = ACTIONS(446),
    [anon_sym_EQ_EQ] = ACTIONS(446),
    [anon_sym_BANG_EQ] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(448),
    [anon_sym_PLUS_EQ] = ACTIONS(446),
    [anon_sym_DASH_EQ] = ACTIONS(446),
    [anon_sym_STAR_EQ] = ACTIONS(446),
    [anon_sym_SLASH_EQ] = ACTIONS(446),
    [anon_sym_DQUOTE] = ACTIONS(446),
    [sym__identifier] = ACTIONS(448),
    [anon_sym_linear] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(448),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(448),
    [anon_sym_ease] = ACTIONS(448),
    [anon_sym_ease_DASHin] = ACTIONS(448),
    [anon_sym_ease_DASHout] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(448),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(448),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(448),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(448),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(448),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(448),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(448),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(448),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(448),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(448),
    [anon_sym_cubic_DASHbezier] = ACTIONS(448),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(446),
    [anon_sym_ATlinear_gradient] = ACTIONS(446),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(446),
    [anon_sym_ATradial_gradient] = ACTIONS(446),
    [anon_sym_parent] = ACTIONS(448),
    [anon_sym_root] = ACTIONS(448),
    [anon_sym_self] = ACTIONS(448),
    [sym__int_number] = ACTIONS(448),
    [sym__float_number] = ACTIONS(446),
    [anon_sym_true] = ACTIONS(448),
    [anon_sym_false] = ACTIONS(448),
    [sym_color_value] = ACTIONS(446),
    [sym_comment] = ACTIONS(3),
  },
  [171] = {
    [anon_sym_LBRACE] = ACTIONS(450),
    [anon_sym_COMMA] = ACTIONS(450),
    [anon_sym_RBRACE] = ACTIONS(450),
    [anon_sym_SEMI] = ACTIONS(450),
    [anon_sym_LT] = ACTIONS(452),
    [anon_sym_GT] = ACTIONS(452),
    [anon_sym_return] = ACTIONS(452),
    [anon_sym_COLON] = ACTIONS(450),
    [anon_sym_LBRACK] = ACTIONS(450),
    [anon_sym_if] = ACTIONS(452),
    [anon_sym_LPAREN] = ACTIONS(450),
    [anon_sym_RPAREN] = ACTIONS(450),
    [anon_sym_ATtr] = ACTIONS(450),
    [anon_sym_DOT] = ACTIONS(452),
    [sym_logical_and] = ACTIONS(450),
    [sym_logical_or] = ACTIONS(450),
    [anon_sym_QMARK] = ACTIONS(450),
    [anon_sym_ATimage_DASHurl] = ACTIONS(450),
    [anon_sym_BANG] = ACTIONS(452),
    [anon_sym_DASH] = ACTIONS(452),
    [anon_sym_PLUS] = ACTIONS(452),
    [anon_sym_STAR] = ACTIONS(452),
    [anon_sym_SLASH] = ACTIONS(452),
    [anon_sym_GT_EQ] = ACTIONS(450),
    [anon_sym_LT_EQ] = ACTIONS(450),
    [anon_sym_EQ_EQ] = ACTIONS(450),
    [anon_sym_BANG_EQ] = ACTIONS(450),
    [anon_sym_EQ] = ACTIONS(452),
    [anon_sym_PLUS_EQ] = ACTIONS(450),
    [anon_sym_DASH_EQ] = ACTIONS(450),
    [anon_sym_STAR_EQ] = ACTIONS(450),
    [anon_sym_SLASH_EQ] = ACTIONS(450),
    [anon_sym_DQUOTE] = ACTIONS(450),
    [sym__identifier] = ACTIONS(452),
    [anon_sym_linear] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(452),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(452),
    [anon_sym_ease] = ACTIONS(452),
    [anon_sym_ease_DASHin] = ACTIONS(452),
    [anon_sym_ease_DASHout] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(452),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(452),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(452),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(452),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(452),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(452),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(452),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(452),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(452),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(452),
    [anon_sym_cubic_DASHbezier] = ACTIONS(452),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(450),
    [anon_sym_ATlinear_gradient] = ACTIONS(450),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(450),
    [anon_sym_ATradial_gradient] = ACTIONS(450),
    [anon_sym_parent] = ACTIONS(452),
    [anon_sym_root] = ACTIONS(452),
    [anon_sym_self] = ACTIONS(452),
    [sym__int_number] = ACTIONS(452),
    [sym__float_number] = ACTIONS(450),
    [anon_sym_true] = ACTIONS(452),
    [anon_sym_false] = ACTIONS(452),
    [sym_color_value] = ACTIONS(450),
    [sym_comment] = ACTIONS(3),
  },
  [172] = {
    [anon_sym_LBRACE] = ACTIONS(454),
    [anon_sym_COMMA] = ACTIONS(454),
    [anon_sym_RBRACE] = ACTIONS(454),
    [anon_sym_SEMI] = ACTIONS(454),
    [anon_sym_LT] = ACTIONS(456),
    [anon_sym_GT] = ACTIONS(456),
    [anon_sym_return] = ACTIONS(456),
    [anon_sym_COLON] = ACTIONS(454),
    [anon_sym_LBRACK] = ACTIONS(454),
    [anon_sym_if] = ACTIONS(456),
    [anon_sym_LPAREN] = ACTIONS(454),
    [anon_sym_RPAREN] = ACTIONS(454),
    [anon_sym_ATtr] = ACTIONS(454),
    [anon_sym_DOT] = ACTIONS(456),
    [sym_logical_and] = ACTIONS(454),
    [sym_logical_or] = ACTIONS(454),
    [anon_sym_QMARK] = ACTIONS(454),
    [anon_sym_ATimage_DASHurl] = ACTIONS(454),
    [anon_sym_BANG] = ACTIONS(456),
    [anon_sym_DASH] = ACTIONS(456),
    [anon_sym_PLUS] = ACTIONS(456),
    [anon_sym_STAR] = ACTIONS(456),
    [anon_sym_SLASH] = ACTIONS(456),
    [anon_sym_GT_EQ] = ACTIONS(454),
    [anon_sym_LT_EQ] = ACTIONS(454),
    [anon_sym_EQ_EQ] = ACTIONS(454),
    [anon_sym_BANG_EQ] = ACTIONS(454),
    [anon_sym_EQ] = ACTIONS(456),
    [anon_sym_PLUS_EQ] = ACTIONS(454),
    [anon_sym_DASH_EQ] = ACTIONS(454),
    [anon_sym_STAR_EQ] = ACTIONS(454),
    [anon_sym_SLASH_EQ] = ACTIONS(454),
    [anon_sym_DQUOTE] = ACTIONS(454),
    [sym__identifier] = ACTIONS(456),
    [anon_sym_linear] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(456),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(456),
    [anon_sym_ease] = ACTIONS(456),
    [anon_sym_ease_DASHin] = ACTIONS(456),
    [anon_sym_ease_DASHout] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(456),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(456),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(456),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(456),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(456),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(456),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(456),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(456),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(456),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(456),
    [anon_sym_cubic_DASHbezier] = ACTIONS(456),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(454),
    [anon_sym_ATlinear_gradient] = ACTIONS(454),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(454),
    [anon_sym_ATradial_gradient] = ACTIONS(454),
    [anon_sym_parent] = ACTIONS(456),
    [anon_sym_root] = ACTIONS(456),
    [anon_sym_self] = ACTIONS(456),
    [sym__int_number] = ACTIONS(456),
    [sym__float_number] = ACTIONS(454),
    [anon_sym_true] = ACTIONS(456),
    [anon_sym_false] = ACTIONS(456),
    [sym_color_value] = ACTIONS(454),
    [sym_comment] = ACTIONS(3),
  },
  [173] = {
    [anon_sym_LBRACE] = ACTIONS(458),
    [anon_sym_COMMA] = ACTIONS(458),
    [anon_sym_RBRACE] = ACTIONS(458),
    [anon_sym_SEMI] = ACTIONS(458),
    [anon_sym_LT] = ACTIONS(460),
    [anon_sym_GT] = ACTIONS(460),
    [anon_sym_return] = ACTIONS(460),
    [anon_sym_COLON] = ACTIONS(458),
    [anon_sym_LBRACK] = ACTIONS(458),
    [anon_sym_if] = ACTIONS(460),
    [anon_sym_LPAREN] = ACTIONS(458),
    [anon_sym_RPAREN] = ACTIONS(458),
    [anon_sym_ATtr] = ACTIONS(458),
    [anon_sym_DOT] = ACTIONS(460),
    [sym_logical_and] = ACTIONS(458),
    [sym_logical_or] = ACTIONS(458),
    [anon_sym_QMARK] = ACTIONS(458),
    [anon_sym_ATimage_DASHurl] = ACTIONS(458),
    [anon_sym_BANG] = ACTIONS(460),
    [anon_sym_DASH] = ACTIONS(460),
    [anon_sym_PLUS] = ACTIONS(460),
    [anon_sym_STAR] = ACTIONS(460),
    [anon_sym_SLASH] = ACTIONS(460),
    [anon_sym_GT_EQ] = ACTIONS(458),
    [anon_sym_LT_EQ] = ACTIONS(458),
    [anon_sym_EQ_EQ] = ACTIONS(458),
    [anon_sym_BANG_EQ] = ACTIONS(458),
    [anon_sym_EQ] = ACTIONS(460),
    [anon_sym_PLUS_EQ] = ACTIONS(458),
    [anon_sym_DASH_EQ] = ACTIONS(458),
    [anon_sym_STAR_EQ] = ACTIONS(458),
    [anon_sym_SLASH_EQ] = ACTIONS(458),
    [anon_sym_DQUOTE] = ACTIONS(458),
    [sym__identifier] = ACTIONS(460),
    [anon_sym_linear] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(460),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(460),
    [anon_sym_ease] = ACTIONS(460),
    [anon_sym_ease_DASHin] = ACTIONS(460),
    [anon_sym_ease_DASHout] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(460),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(460),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(460),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(460),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(460),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(460),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(460),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(460),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(460),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(460),
    [anon_sym_cubic_DASHbezier] = ACTIONS(460),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(458),
    [anon_sym_ATlinear_gradient] = ACTIONS(458),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(458),
    [anon_sym_ATradial_gradient] = ACTIONS(458),
    [anon_sym_parent] = ACTIONS(460),
    [anon_sym_root] = ACTIONS(460),
    [anon_sym_self] = ACTIONS(460),
    [sym__int_number] = ACTIONS(460),
    [sym__float_number] = ACTIONS(458),
    [anon_sym_true] = ACTIONS(460),
    [anon_sym_false] = ACTIONS(460),
    [sym_color_value] = ACTIONS(458),
    [sym_comment] = ACTIONS(3),
  },
  [174] = {
    [anon_sym_LBRACE] = ACTIONS(462),
    [anon_sym_COMMA] = ACTIONS(462),
    [anon_sym_RBRACE] = ACTIONS(462),
    [anon_sym_SEMI] = ACTIONS(462),
    [anon_sym_LT] = ACTIONS(464),
    [anon_sym_GT] = ACTIONS(464),
    [anon_sym_return] = ACTIONS(464),
    [anon_sym_COLON] = ACTIONS(462),
    [anon_sym_LBRACK] = ACTIONS(462),
    [anon_sym_if] = ACTIONS(464),
    [anon_sym_LPAREN] = ACTIONS(462),
    [anon_sym_RPAREN] = ACTIONS(462),
    [anon_sym_ATtr] = ACTIONS(462),
    [anon_sym_DOT] = ACTIONS(464),
    [sym_logical_and] = ACTIONS(462),
    [sym_logical_or] = ACTIONS(462),
    [anon_sym_QMARK] = ACTIONS(462),
    [anon_sym_ATimage_DASHurl] = ACTIONS(462),
    [anon_sym_BANG] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_GT_EQ] = ACTIONS(462),
    [anon_sym_LT_EQ] = ACTIONS(462),
    [anon_sym_EQ_EQ] = ACTIONS(462),
    [anon_sym_BANG_EQ] = ACTIONS(462),
    [anon_sym_EQ] = ACTIONS(464),
    [anon_sym_PLUS_EQ] = ACTIONS(462),
    [anon_sym_DASH_EQ] = ACTIONS(462),
    [anon_sym_STAR_EQ] = ACTIONS(462),
    [anon_sym_SLASH_EQ] = ACTIONS(462),
    [anon_sym_DQUOTE] = ACTIONS(462),
    [sym__identifier] = ACTIONS(464),
    [anon_sym_linear] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(464),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(464),
    [anon_sym_ease] = ACTIONS(464),
    [anon_sym_ease_DASHin] = ACTIONS(464),
    [anon_sym_ease_DASHout] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(464),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(464),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(464),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(464),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(464),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(464),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(464),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(464),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(464),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(464),
    [anon_sym_cubic_DASHbezier] = ACTIONS(464),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(462),
    [anon_sym_ATlinear_gradient] = ACTIONS(462),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(462),
    [anon_sym_ATradial_gradient] = ACTIONS(462),
    [anon_sym_parent] = ACTIONS(464),
    [anon_sym_root] = ACTIONS(464),
    [anon_sym_self] = ACTIONS(464),
    [sym__int_number] = ACTIONS(464),
    [sym__float_number] = ACTIONS(462),
    [anon_sym_true] = ACTIONS(464),
    [anon_sym_false] = ACTIONS(464),
    [sym_color_value] = ACTIONS(462),
    [sym_comment] = ACTIONS(3),
  },
  [175] = {
    [anon_sym_LBRACE] = ACTIONS(466),
    [anon_sym_COMMA] = ACTIONS(466),
    [anon_sym_RBRACE] = ACTIONS(466),
    [anon_sym_SEMI] = ACTIONS(466),
    [anon_sym_LT] = ACTIONS(468),
    [anon_sym_GT] = ACTIONS(468),
    [anon_sym_return] = ACTIONS(468),
    [anon_sym_COLON] = ACTIONS(466),
    [anon_sym_LBRACK] = ACTIONS(466),
    [anon_sym_if] = ACTIONS(468),
    [anon_sym_LPAREN] = ACTIONS(466),
    [anon_sym_RPAREN] = ACTIONS(466),
    [anon_sym_ATtr] = ACTIONS(466),
    [anon_sym_DOT] = ACTIONS(468),
    [sym_logical_and] = ACTIONS(466),
    [sym_logical_or] = ACTIONS(466),
    [anon_sym_QMARK] = ACTIONS(466),
    [anon_sym_ATimage_DASHurl] = ACTIONS(466),
    [anon_sym_BANG] = ACTIONS(468),
    [anon_sym_DASH] = ACTIONS(468),
    [anon_sym_PLUS] = ACTIONS(468),
    [anon_sym_STAR] = ACTIONS(468),
    [anon_sym_SLASH] = ACTIONS(468),
    [anon_sym_GT_EQ] = ACTIONS(466),
    [anon_sym_LT_EQ] = ACTIONS(466),
    [anon_sym_EQ_EQ] = ACTIONS(466),
    [anon_sym_BANG_EQ] = ACTIONS(466),
    [anon_sym_EQ] = ACTIONS(468),
    [anon_sym_PLUS_EQ] = ACTIONS(466),
    [anon_sym_DASH_EQ] = ACTIONS(466),
    [anon_sym_STAR_EQ] = ACTIONS(466),
    [anon_sym_SLASH_EQ] = ACTIONS(466),
    [anon_sym_DQUOTE] = ACTIONS(466),
    [sym__identifier] = ACTIONS(468),
    [anon_sym_linear] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(468),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(468),
    [anon_sym_ease] = ACTIONS(468),
    [anon_sym_ease_DASHin] = ACTIONS(468),
    [anon_sym_ease_DASHout] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(468),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(468),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(468),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(468),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(468),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(468),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(468),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(468),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(468),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(468),
    [anon_sym_cubic_DASHbezier] = ACTIONS(468),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(466),
    [anon_sym_ATlinear_gradient] = ACTIONS(466),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(466),
    [anon_sym_ATradial_gradient] = ACTIONS(466),
    [anon_sym_parent] = ACTIONS(468),
    [anon_sym_root] = ACTIONS(468),
    [anon_sym_self] = ACTIONS(468),
    [sym__int_number] = ACTIONS(468),
    [sym__float_number] = ACTIONS(466),
    [anon_sym_true] = ACTIONS(468),
    [anon_sym_false] = ACTIONS(468),
    [sym_color_value] = ACTIONS(466),
    [sym_comment] = ACTIONS(3),
  },
  [176] = {
    [anon_sym_LBRACE] = ACTIONS(470),
    [anon_sym_COMMA] = ACTIONS(470),
    [anon_sym_RBRACE] = ACTIONS(470),
    [anon_sym_SEMI] = ACTIONS(470),
    [anon_sym_LT] = ACTIONS(472),
    [anon_sym_GT] = ACTIONS(472),
    [anon_sym_return] = ACTIONS(472),
    [anon_sym_COLON] = ACTIONS(470),
    [anon_sym_LBRACK] = ACTIONS(470),
    [anon_sym_if] = ACTIONS(472),
    [anon_sym_LPAREN] = ACTIONS(470),
    [anon_sym_RPAREN] = ACTIONS(470),
    [anon_sym_ATtr] = ACTIONS(470),
    [anon_sym_DOT] = ACTIONS(472),
    [sym_logical_and] = ACTIONS(470),
    [sym_logical_or] = ACTIONS(470),
    [anon_sym_QMARK] = ACTIONS(470),
    [anon_sym_ATimage_DASHurl] = ACTIONS(470),
    [anon_sym_BANG] = ACTIONS(472),
    [anon_sym_DASH] = ACTIONS(472),
    [anon_sym_PLUS] = ACTIONS(472),
    [anon_sym_STAR] = ACTIONS(472),
    [anon_sym_SLASH] = ACTIONS(472),
    [anon_sym_GT_EQ] = ACTIONS(470),
    [anon_sym_LT_EQ] = ACTIONS(470),
    [anon_sym_EQ_EQ] = ACTIONS(470),
    [anon_sym_BANG_EQ] = ACTIONS(470),
    [anon_sym_EQ] = ACTIONS(472),
    [anon_sym_PLUS_EQ] = ACTIONS(470),
    [anon_sym_DASH_EQ] = ACTIONS(470),
    [anon_sym_STAR_EQ] = ACTIONS(470),
    [anon_sym_SLASH_EQ] = ACTIONS(470),
    [anon_sym_DQUOTE] = ACTIONS(470),
    [sym__identifier] = ACTIONS(472),
    [anon_sym_linear] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(472),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(472),
    [anon_sym_ease] = ACTIONS(472),
    [anon_sym_ease_DASHin] = ACTIONS(472),
    [anon_sym_ease_DASHout] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(472),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(472),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(472),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(472),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(472),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(472),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(472),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(472),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(472),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(472),
    [anon_sym_cubic_DASHbezier] = ACTIONS(472),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(470),
    [anon_sym_ATlinear_gradient] = ACTIONS(470),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(470),
    [anon_sym_ATradial_gradient] = ACTIONS(470),
    [anon_sym_parent] = ACTIONS(472),
    [anon_sym_root] = ACTIONS(472),
    [anon_sym_self] = ACTIONS(472),
    [sym__int_number] = ACTIONS(472),
    [sym__float_number] = ACTIONS(470),
    [anon_sym_true] = ACTIONS(472),
    [anon_sym_false] = ACTIONS(472),
    [sym_color_value] = ACTIONS(470),
    [sym_comment] = ACTIONS(3),
  },
  [177] = {
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_COMMA] = ACTIONS(474),
    [anon_sym_RBRACE] = ACTIONS(474),
    [anon_sym_SEMI] = ACTIONS(474),
    [anon_sym_LT] = ACTIONS(476),
    [anon_sym_GT] = ACTIONS(476),
    [anon_sym_return] = ACTIONS(476),
    [anon_sym_COLON] = ACTIONS(474),
    [anon_sym_LBRACK] = ACTIONS(474),
    [anon_sym_if] = ACTIONS(476),
    [anon_sym_LPAREN] = ACTIONS(474),
    [anon_sym_RPAREN] = ACTIONS(474),
    [anon_sym_ATtr] = ACTIONS(474),
    [anon_sym_DOT] = ACTIONS(476),
    [sym_logical_and] = ACTIONS(474),
    [sym_logical_or] = ACTIONS(474),
    [anon_sym_QMARK] = ACTIONS(474),
    [anon_sym_ATimage_DASHurl] = ACTIONS(474),
    [anon_sym_BANG] = ACTIONS(476),
    [anon_sym_DASH] = ACTIONS(476),
    [anon_sym_PLUS] = ACTIONS(476),
    [anon_sym_STAR] = ACTIONS(476),
    [anon_sym_SLASH] = ACTIONS(476),
    [anon_sym_GT_EQ] = ACTIONS(474),
    [anon_sym_LT_EQ] = ACTIONS(474),
    [anon_sym_EQ_EQ] = ACTIONS(474),
    [anon_sym_BANG_EQ] = ACTIONS(474),
    [anon_sym_EQ] = ACTIONS(476),
    [anon_sym_PLUS_EQ] = ACTIONS(474),
    [anon_sym_DASH_EQ] = ACTIONS(474),
    [anon_sym_STAR_EQ] = ACTIONS(474),
    [anon_sym_SLASH_EQ] = ACTIONS(474),
    [anon_sym_DQUOTE] = ACTIONS(474),
    [sym__identifier] = ACTIONS(476),
    [anon_sym_linear] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(476),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(476),
    [anon_sym_ease] = ACTIONS(476),
    [anon_sym_ease_DASHin] = ACTIONS(476),
    [anon_sym_ease_DASHout] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(476),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(476),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(476),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(476),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(476),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(476),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(476),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(476),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(476),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(476),
    [anon_sym_cubic_DASHbezier] = ACTIONS(476),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(474),
    [anon_sym_ATlinear_gradient] = ACTIONS(474),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(474),
    [anon_sym_ATradial_gradient] = ACTIONS(474),
    [anon_sym_parent] = ACTIONS(476),
    [anon_sym_root] = ACTIONS(476),
    [anon_sym_self] = ACTIONS(476),
    [sym__int_number] = ACTIONS(476),
    [sym__float_number] = ACTIONS(474),
    [anon_sym_true] = ACTIONS(476),
    [anon_sym_false] = ACTIONS(476),
    [sym_color_value] = ACTIONS(474),
    [sym_comment] = ACTIONS(3),
  },
  [178] = {
    [anon_sym_LBRACE] = ACTIONS(478),
    [anon_sym_COMMA] = ACTIONS(478),
    [anon_sym_RBRACE] = ACTIONS(478),
    [anon_sym_SEMI] = ACTIONS(478),
    [anon_sym_LT] = ACTIONS(480),
    [anon_sym_GT] = ACTIONS(480),
    [anon_sym_return] = ACTIONS(480),
    [anon_sym_COLON] = ACTIONS(478),
    [anon_sym_LBRACK] = ACTIONS(478),
    [anon_sym_if] = ACTIONS(480),
    [anon_sym_LPAREN] = ACTIONS(478),
    [anon_sym_RPAREN] = ACTIONS(478),
    [anon_sym_ATtr] = ACTIONS(478),
    [anon_sym_DOT] = ACTIONS(480),
    [sym_logical_and] = ACTIONS(478),
    [sym_logical_or] = ACTIONS(478),
    [anon_sym_QMARK] = ACTIONS(478),
    [anon_sym_ATimage_DASHurl] = ACTIONS(478),
    [anon_sym_BANG] = ACTIONS(480),
    [anon_sym_DASH] = ACTIONS(480),
    [anon_sym_PLUS] = ACTIONS(480),
    [anon_sym_STAR] = ACTIONS(480),
    [anon_sym_SLASH] = ACTIONS(480),
    [anon_sym_GT_EQ] = ACTIONS(478),
    [anon_sym_LT_EQ] = ACTIONS(478),
    [anon_sym_EQ_EQ] = ACTIONS(478),
    [anon_sym_BANG_EQ] = ACTIONS(478),
    [anon_sym_EQ] = ACTIONS(480),
    [anon_sym_PLUS_EQ] = ACTIONS(478),
    [anon_sym_DASH_EQ] = ACTIONS(478),
    [anon_sym_STAR_EQ] = ACTIONS(478),
    [anon_sym_SLASH_EQ] = ACTIONS(478),
    [anon_sym_DQUOTE] = ACTIONS(478),
    [sym__identifier] = ACTIONS(480),
    [anon_sym_linear] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(480),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(480),
    [anon_sym_ease] = ACTIONS(480),
    [anon_sym_ease_DASHin] = ACTIONS(480),
    [anon_sym_ease_DASHout] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(480),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(480),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(480),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(480),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(480),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(480),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(480),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(480),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(480),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(480),
    [anon_sym_cubic_DASHbezier] = ACTIONS(480),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(478),
    [anon_sym_ATlinear_gradient] = ACTIONS(478),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(478),
    [anon_sym_ATradial_gradient] = ACTIONS(478),
    [anon_sym_parent] = ACTIONS(480),
    [anon_sym_root] = ACTIONS(480),
    [anon_sym_self] = ACTIONS(480),
    [sym__int_number] = ACTIONS(480),
    [sym__float_number] = ACTIONS(478),
    [anon_sym_true] = ACTIONS(480),
    [anon_sym_false] = ACTIONS(480),
    [sym_color_value] = ACTIONS(478),
    [sym_comment] = ACTIONS(3),
  },
  [179] = {
    [anon_sym_LBRACE] = ACTIONS(482),
    [anon_sym_COMMA] = ACTIONS(482),
    [anon_sym_RBRACE] = ACTIONS(482),
    [anon_sym_SEMI] = ACTIONS(482),
    [anon_sym_LT] = ACTIONS(484),
    [anon_sym_GT] = ACTIONS(484),
    [anon_sym_return] = ACTIONS(484),
    [anon_sym_COLON] = ACTIONS(482),
    [anon_sym_LBRACK] = ACTIONS(482),
    [anon_sym_if] = ACTIONS(484),
    [anon_sym_LPAREN] = ACTIONS(482),
    [anon_sym_RPAREN] = ACTIONS(482),
    [anon_sym_ATtr] = ACTIONS(482),
    [anon_sym_DOT] = ACTIONS(484),
    [sym_logical_and] = ACTIONS(482),
    [sym_logical_or] = ACTIONS(482),
    [anon_sym_QMARK] = ACTIONS(482),
    [anon_sym_ATimage_DASHurl] = ACTIONS(482),
    [anon_sym_BANG] = ACTIONS(484),
    [anon_sym_DASH] = ACTIONS(484),
    [anon_sym_PLUS] = ACTIONS(484),
    [anon_sym_STAR] = ACTIONS(484),
    [anon_sym_SLASH] = ACTIONS(484),
    [anon_sym_GT_EQ] = ACTIONS(482),
    [anon_sym_LT_EQ] = ACTIONS(482),
    [anon_sym_EQ_EQ] = ACTIONS(482),
    [anon_sym_BANG_EQ] = ACTIONS(482),
    [anon_sym_EQ] = ACTIONS(484),
    [anon_sym_PLUS_EQ] = ACTIONS(482),
    [anon_sym_DASH_EQ] = ACTIONS(482),
    [anon_sym_STAR_EQ] = ACTIONS(482),
    [anon_sym_SLASH_EQ] = ACTIONS(482),
    [anon_sym_DQUOTE] = ACTIONS(482),
    [sym__identifier] = ACTIONS(484),
    [anon_sym_linear] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(484),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(484),
    [anon_sym_ease] = ACTIONS(484),
    [anon_sym_ease_DASHin] = ACTIONS(484),
    [anon_sym_ease_DASHout] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(484),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(484),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(484),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(484),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(484),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(484),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(484),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(484),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(484),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(484),
    [anon_sym_cubic_DASHbezier] = ACTIONS(484),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(482),
    [anon_sym_ATlinear_gradient] = ACTIONS(482),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(482),
    [anon_sym_ATradial_gradient] = ACTIONS(482),
    [anon_sym_parent] = ACTIONS(484),
    [anon_sym_root] = ACTIONS(484),
    [anon_sym_self] = ACTIONS(484),
    [sym__int_number] = ACTIONS(484),
    [sym__float_number] = ACTIONS(482),
    [anon_sym_true] = ACTIONS(484),
    [anon_sym_false] = ACTIONS(484),
    [sym_color_value] = ACTIONS(482),
    [sym_comment] = ACTIONS(3),
  },
  [180] = {
    [anon_sym_LBRACE] = ACTIONS(486),
    [anon_sym_COMMA] = ACTIONS(486),
    [anon_sym_RBRACE] = ACTIONS(486),
    [anon_sym_SEMI] = ACTIONS(486),
    [anon_sym_LT] = ACTIONS(488),
    [anon_sym_GT] = ACTIONS(488),
    [anon_sym_return] = ACTIONS(488),
    [anon_sym_COLON] = ACTIONS(486),
    [anon_sym_LBRACK] = ACTIONS(486),
    [anon_sym_if] = ACTIONS(488),
    [anon_sym_LPAREN] = ACTIONS(486),
    [anon_sym_RPAREN] = ACTIONS(486),
    [anon_sym_ATtr] = ACTIONS(486),
    [anon_sym_DOT] = ACTIONS(488),
    [sym_logical_and] = ACTIONS(486),
    [sym_logical_or] = ACTIONS(486),
    [anon_sym_QMARK] = ACTIONS(486),
    [anon_sym_ATimage_DASHurl] = ACTIONS(486),
    [anon_sym_BANG] = ACTIONS(488),
    [anon_sym_DASH] = ACTIONS(488),
    [anon_sym_PLUS] = ACTIONS(488),
    [anon_sym_STAR] = ACTIONS(488),
    [anon_sym_SLASH] = ACTIONS(488),
    [anon_sym_GT_EQ] = ACTIONS(486),
    [anon_sym_LT_EQ] = ACTIONS(486),
    [anon_sym_EQ_EQ] = ACTIONS(486),
    [anon_sym_BANG_EQ] = ACTIONS(486),
    [anon_sym_EQ] = ACTIONS(488),
    [anon_sym_PLUS_EQ] = ACTIONS(486),
    [anon_sym_DASH_EQ] = ACTIONS(486),
    [anon_sym_STAR_EQ] = ACTIONS(486),
    [anon_sym_SLASH_EQ] = ACTIONS(486),
    [anon_sym_DQUOTE] = ACTIONS(486),
    [sym__identifier] = ACTIONS(488),
    [anon_sym_linear] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(488),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(488),
    [anon_sym_ease] = ACTIONS(488),
    [anon_sym_ease_DASHin] = ACTIONS(488),
    [anon_sym_ease_DASHout] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(488),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(488),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(488),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(488),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(488),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(488),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(488),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(488),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(488),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(488),
    [anon_sym_cubic_DASHbezier] = ACTIONS(488),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(486),
    [anon_sym_ATlinear_gradient] = ACTIONS(486),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(486),
    [anon_sym_ATradial_gradient] = ACTIONS(486),
    [anon_sym_parent] = ACTIONS(488),
    [anon_sym_root] = ACTIONS(488),
    [anon_sym_self] = ACTIONS(488),
    [sym__int_number] = ACTIONS(488),
    [sym__float_number] = ACTIONS(486),
    [anon_sym_true] = ACTIONS(488),
    [anon_sym_false] = ACTIONS(488),
    [sym_color_value] = ACTIONS(486),
    [sym_comment] = ACTIONS(3),
  },
  [181] = {
    [anon_sym_LBRACE] = ACTIONS(490),
    [anon_sym_COMMA] = ACTIONS(490),
    [anon_sym_RBRACE] = ACTIONS(490),
    [anon_sym_SEMI] = ACTIONS(490),
    [anon_sym_LT] = ACTIONS(492),
    [anon_sym_GT] = ACTIONS(492),
    [anon_sym_return] = ACTIONS(492),
    [anon_sym_COLON] = ACTIONS(490),
    [anon_sym_LBRACK] = ACTIONS(490),
    [anon_sym_if] = ACTIONS(492),
    [anon_sym_LPAREN] = ACTIONS(490),
    [anon_sym_RPAREN] = ACTIONS(490),
    [anon_sym_ATtr] = ACTIONS(490),
    [anon_sym_DOT] = ACTIONS(492),
    [sym_logical_and] = ACTIONS(490),
    [sym_logical_or] = ACTIONS(490),
    [anon_sym_QMARK] = ACTIONS(490),
    [anon_sym_ATimage_DASHurl] = ACTIONS(490),
    [anon_sym_BANG] = ACTIONS(492),
    [anon_sym_DASH] = ACTIONS(492),
    [anon_sym_PLUS] = ACTIONS(492),
    [anon_sym_STAR] = ACTIONS(492),
    [anon_sym_SLASH] = ACTIONS(492),
    [anon_sym_GT_EQ] = ACTIONS(490),
    [anon_sym_LT_EQ] = ACTIONS(490),
    [anon_sym_EQ_EQ] = ACTIONS(490),
    [anon_sym_BANG_EQ] = ACTIONS(490),
    [anon_sym_EQ] = ACTIONS(492),
    [anon_sym_PLUS_EQ] = ACTIONS(490),
    [anon_sym_DASH_EQ] = ACTIONS(490),
    [anon_sym_STAR_EQ] = ACTIONS(490),
    [anon_sym_SLASH_EQ] = ACTIONS(490),
    [anon_sym_DQUOTE] = ACTIONS(490),
    [sym__identifier] = ACTIONS(492),
    [anon_sym_linear] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(492),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(492),
    [anon_sym_ease] = ACTIONS(492),
    [anon_sym_ease_DASHin] = ACTIONS(492),
    [anon_sym_ease_DASHout] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(492),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(492),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(492),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(492),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(492),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(492),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(492),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(492),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(492),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(492),
    [anon_sym_cubic_DASHbezier] = ACTIONS(492),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(490),
    [anon_sym_ATlinear_gradient] = ACTIONS(490),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(490),
    [anon_sym_ATradial_gradient] = ACTIONS(490),
    [anon_sym_parent] = ACTIONS(492),
    [anon_sym_root] = ACTIONS(492),
    [anon_sym_self] = ACTIONS(492),
    [sym__int_number] = ACTIONS(492),
    [sym__float_number] = ACTIONS(490),
    [anon_sym_true] = ACTIONS(492),
    [anon_sym_false] = ACTIONS(492),
    [sym_color_value] = ACTIONS(490),
    [sym_comment] = ACTIONS(3),
  },
  [182] = {
    [anon_sym_LBRACE] = ACTIONS(494),
    [anon_sym_COMMA] = ACTIONS(494),
    [anon_sym_RBRACE] = ACTIONS(494),
    [anon_sym_SEMI] = ACTIONS(494),
    [anon_sym_LT] = ACTIONS(496),
    [anon_sym_GT] = ACTIONS(496),
    [anon_sym_return] = ACTIONS(496),
    [anon_sym_COLON] = ACTIONS(494),
    [anon_sym_LBRACK] = ACTIONS(494),
    [anon_sym_if] = ACTIONS(496),
    [anon_sym_LPAREN] = ACTIONS(494),
    [anon_sym_RPAREN] = ACTIONS(494),
    [anon_sym_ATtr] = ACTIONS(494),
    [anon_sym_DOT] = ACTIONS(496),
    [sym_logical_and] = ACTIONS(494),
    [sym_logical_or] = ACTIONS(494),
    [anon_sym_QMARK] = ACTIONS(494),
    [anon_sym_ATimage_DASHurl] = ACTIONS(494),
    [anon_sym_BANG] = ACTIONS(496),
    [anon_sym_DASH] = ACTIONS(496),
    [anon_sym_PLUS] = ACTIONS(496),
    [anon_sym_STAR] = ACTIONS(496),
    [anon_sym_SLASH] = ACTIONS(496),
    [anon_sym_GT_EQ] = ACTIONS(494),
    [anon_sym_LT_EQ] = ACTIONS(494),
    [anon_sym_EQ_EQ] = ACTIONS(494),
    [anon_sym_BANG_EQ] = ACTIONS(494),
    [anon_sym_EQ] = ACTIONS(496),
    [anon_sym_PLUS_EQ] = ACTIONS(494),
    [anon_sym_DASH_EQ] = ACTIONS(494),
    [anon_sym_STAR_EQ] = ACTIONS(494),
    [anon_sym_SLASH_EQ] = ACTIONS(494),
    [anon_sym_DQUOTE] = ACTIONS(494),
    [sym__identifier] = ACTIONS(496),
    [anon_sym_linear] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(496),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(496),
    [anon_sym_ease] = ACTIONS(496),
    [anon_sym_ease_DASHin] = ACTIONS(496),
    [anon_sym_ease_DASHout] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(496),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(496),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(496),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(496),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(496),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(496),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(496),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(496),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(496),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(496),
    [anon_sym_cubic_DASHbezier] = ACTIONS(496),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(494),
    [anon_sym_ATlinear_gradient] = ACTIONS(494),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(494),
    [anon_sym_ATradial_gradient] = ACTIONS(494),
    [anon_sym_parent] = ACTIONS(496),
    [anon_sym_root] = ACTIONS(496),
    [anon_sym_self] = ACTIONS(496),
    [sym__int_number] = ACTIONS(496),
    [sym__float_number] = ACTIONS(494),
    [anon_sym_true] = ACTIONS(496),
    [anon_sym_false] = ACTIONS(496),
    [sym_color_value] = ACTIONS(494),
    [sym_comment] = ACTIONS(3),
  },
  [183] = {
    [anon_sym_LBRACE] = ACTIONS(498),
    [anon_sym_COMMA] = ACTIONS(498),
    [anon_sym_RBRACE] = ACTIONS(498),
    [anon_sym_SEMI] = ACTIONS(498),
    [anon_sym_LT] = ACTIONS(500),
    [anon_sym_GT] = ACTIONS(500),
    [anon_sym_return] = ACTIONS(500),
    [anon_sym_COLON] = ACTIONS(498),
    [anon_sym_LBRACK] = ACTIONS(498),
    [anon_sym_if] = ACTIONS(500),
    [anon_sym_LPAREN] = ACTIONS(498),
    [anon_sym_RPAREN] = ACTIONS(498),
    [anon_sym_ATtr] = ACTIONS(498),
    [anon_sym_DOT] = ACTIONS(500),
    [sym_logical_and] = ACTIONS(498),
    [sym_logical_or] = ACTIONS(498),
    [anon_sym_QMARK] = ACTIONS(498),
    [anon_sym_ATimage_DASHurl] = ACTIONS(498),
    [anon_sym_BANG] = ACTIONS(500),
    [anon_sym_DASH] = ACTIONS(500),
    [anon_sym_PLUS] = ACTIONS(500),
    [anon_sym_STAR] = ACTIONS(500),
    [anon_sym_SLASH] = ACTIONS(500),
    [anon_sym_GT_EQ] = ACTIONS(498),
    [anon_sym_LT_EQ] = ACTIONS(498),
    [anon_sym_EQ_EQ] = ACTIONS(498),
    [anon_sym_BANG_EQ] = ACTIONS(498),
    [anon_sym_EQ] = ACTIONS(500),
    [anon_sym_PLUS_EQ] = ACTIONS(498),
    [anon_sym_DASH_EQ] = ACTIONS(498),
    [anon_sym_STAR_EQ] = ACTIONS(498),
    [anon_sym_SLASH_EQ] = ACTIONS(498),
    [anon_sym_DQUOTE] = ACTIONS(498),
    [sym__identifier] = ACTIONS(500),
    [anon_sym_linear] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(500),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(500),
    [anon_sym_ease] = ACTIONS(500),
    [anon_sym_ease_DASHin] = ACTIONS(500),
    [anon_sym_ease_DASHout] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(500),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(500),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(500),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(500),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(500),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(500),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(500),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(500),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(500),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(500),
    [anon_sym_cubic_DASHbezier] = ACTIONS(500),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(498),
    [anon_sym_ATlinear_gradient] = ACTIONS(498),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(498),
    [anon_sym_ATradial_gradient] = ACTIONS(498),
    [anon_sym_parent] = ACTIONS(500),
    [anon_sym_root] = ACTIONS(500),
    [anon_sym_self] = ACTIONS(500),
    [sym__int_number] = ACTIONS(500),
    [sym__float_number] = ACTIONS(498),
    [anon_sym_true] = ACTIONS(500),
    [anon_sym_false] = ACTIONS(500),
    [sym_color_value] = ACTIONS(498),
    [sym_comment] = ACTIONS(3),
  },
  [184] = {
    [anon_sym_LBRACE] = ACTIONS(502),
    [anon_sym_COMMA] = ACTIONS(502),
    [anon_sym_RBRACE] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(502),
    [anon_sym_LT] = ACTIONS(504),
    [anon_sym_GT] = ACTIONS(504),
    [anon_sym_return] = ACTIONS(504),
    [anon_sym_COLON] = ACTIONS(502),
    [anon_sym_LBRACK] = ACTIONS(502),
    [anon_sym_if] = ACTIONS(504),
    [anon_sym_LPAREN] = ACTIONS(502),
    [anon_sym_RPAREN] = ACTIONS(502),
    [anon_sym_ATtr] = ACTIONS(502),
    [anon_sym_DOT] = ACTIONS(504),
    [sym_logical_and] = ACTIONS(502),
    [sym_logical_or] = ACTIONS(502),
    [anon_sym_QMARK] = ACTIONS(502),
    [anon_sym_ATimage_DASHurl] = ACTIONS(502),
    [anon_sym_BANG] = ACTIONS(504),
    [anon_sym_DASH] = ACTIONS(504),
    [anon_sym_PLUS] = ACTIONS(504),
    [anon_sym_STAR] = ACTIONS(504),
    [anon_sym_SLASH] = ACTIONS(504),
    [anon_sym_GT_EQ] = ACTIONS(502),
    [anon_sym_LT_EQ] = ACTIONS(502),
    [anon_sym_EQ_EQ] = ACTIONS(502),
    [anon_sym_BANG_EQ] = ACTIONS(502),
    [anon_sym_EQ] = ACTIONS(504),
    [anon_sym_PLUS_EQ] = ACTIONS(502),
    [anon_sym_DASH_EQ] = ACTIONS(502),
    [anon_sym_STAR_EQ] = ACTIONS(502),
    [anon_sym_SLASH_EQ] = ACTIONS(502),
    [anon_sym_DQUOTE] = ACTIONS(502),
    [sym__identifier] = ACTIONS(504),
    [anon_sym_linear] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(504),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(504),
    [anon_sym_ease] = ACTIONS(504),
    [anon_sym_ease_DASHin] = ACTIONS(504),
    [anon_sym_ease_DASHout] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(504),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(504),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(504),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(504),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(504),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(504),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(504),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(504),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(504),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(504),
    [anon_sym_cubic_DASHbezier] = ACTIONS(504),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(502),
    [anon_sym_ATlinear_gradient] = ACTIONS(502),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(502),
    [anon_sym_ATradial_gradient] = ACTIONS(502),
    [anon_sym_parent] = ACTIONS(504),
    [anon_sym_root] = ACTIONS(504),
    [anon_sym_self] = ACTIONS(504),
    [sym__int_number] = ACTIONS(504),
    [sym__float_number] = ACTIONS(502),
    [anon_sym_true] = ACTIONS(504),
    [anon_sym_false] = ACTIONS(504),
    [sym_color_value] = ACTIONS(502),
    [sym_comment] = ACTIONS(3),
  },
  [185] = {
    [anon_sym_LBRACE] = ACTIONS(506),
    [anon_sym_COMMA] = ACTIONS(506),
    [anon_sym_RBRACE] = ACTIONS(506),
    [anon_sym_SEMI] = ACTIONS(506),
    [anon_sym_LT] = ACTIONS(508),
    [anon_sym_GT] = ACTIONS(508),
    [anon_sym_return] = ACTIONS(508),
    [anon_sym_COLON] = ACTIONS(506),
    [anon_sym_LBRACK] = ACTIONS(506),
    [anon_sym_if] = ACTIONS(508),
    [anon_sym_LPAREN] = ACTIONS(506),
    [anon_sym_RPAREN] = ACTIONS(506),
    [anon_sym_ATtr] = ACTIONS(506),
    [anon_sym_DOT] = ACTIONS(508),
    [sym_logical_and] = ACTIONS(506),
    [sym_logical_or] = ACTIONS(506),
    [anon_sym_QMARK] = ACTIONS(506),
    [anon_sym_ATimage_DASHurl] = ACTIONS(506),
    [anon_sym_BANG] = ACTIONS(508),
    [anon_sym_DASH] = ACTIONS(508),
    [anon_sym_PLUS] = ACTIONS(508),
    [anon_sym_STAR] = ACTIONS(508),
    [anon_sym_SLASH] = ACTIONS(508),
    [anon_sym_GT_EQ] = ACTIONS(506),
    [anon_sym_LT_EQ] = ACTIONS(506),
    [anon_sym_EQ_EQ] = ACTIONS(506),
    [anon_sym_BANG_EQ] = ACTIONS(506),
    [anon_sym_EQ] = ACTIONS(508),
    [anon_sym_PLUS_EQ] = ACTIONS(506),
    [anon_sym_DASH_EQ] = ACTIONS(506),
    [anon_sym_STAR_EQ] = ACTIONS(506),
    [anon_sym_SLASH_EQ] = ACTIONS(506),
    [anon_sym_DQUOTE] = ACTIONS(506),
    [sym__identifier] = ACTIONS(508),
    [anon_sym_linear] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(508),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(508),
    [anon_sym_ease] = ACTIONS(508),
    [anon_sym_ease_DASHin] = ACTIONS(508),
    [anon_sym_ease_DASHout] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(508),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(508),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(508),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(508),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(508),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(508),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(508),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(508),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(508),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(508),
    [anon_sym_cubic_DASHbezier] = ACTIONS(508),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(506),
    [anon_sym_ATlinear_gradient] = ACTIONS(506),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(506),
    [anon_sym_ATradial_gradient] = ACTIONS(506),
    [anon_sym_parent] = ACTIONS(508),
    [anon_sym_root] = ACTIONS(508),
    [anon_sym_self] = ACTIONS(508),
    [sym__int_number] = ACTIONS(508),
    [sym__float_number] = ACTIONS(506),
    [anon_sym_true] = ACTIONS(508),
    [anon_sym_false] = ACTIONS(508),
    [sym_color_value] = ACTIONS(506),
    [sym_comment] = ACTIONS(3),
  },
  [186] = {
    [anon_sym_LBRACE] = ACTIONS(510),
    [anon_sym_COMMA] = ACTIONS(510),
    [anon_sym_RBRACE] = ACTIONS(510),
    [anon_sym_SEMI] = ACTIONS(510),
    [anon_sym_LT] = ACTIONS(512),
    [anon_sym_GT] = ACTIONS(512),
    [anon_sym_return] = ACTIONS(512),
    [anon_sym_COLON] = ACTIONS(510),
    [anon_sym_LBRACK] = ACTIONS(510),
    [anon_sym_if] = ACTIONS(512),
    [anon_sym_LPAREN] = ACTIONS(510),
    [anon_sym_RPAREN] = ACTIONS(510),
    [anon_sym_ATtr] = ACTIONS(510),
    [anon_sym_DOT] = ACTIONS(512),
    [sym_logical_and] = ACTIONS(510),
    [sym_logical_or] = ACTIONS(510),
    [anon_sym_QMARK] = ACTIONS(510),
    [anon_sym_ATimage_DASHurl] = ACTIONS(510),
    [anon_sym_BANG] = ACTIONS(512),
    [anon_sym_DASH] = ACTIONS(512),
    [anon_sym_PLUS] = ACTIONS(512),
    [anon_sym_STAR] = ACTIONS(512),
    [anon_sym_SLASH] = ACTIONS(512),
    [anon_sym_GT_EQ] = ACTIONS(510),
    [anon_sym_LT_EQ] = ACTIONS(510),
    [anon_sym_EQ_EQ] = ACTIONS(510),
    [anon_sym_BANG_EQ] = ACTIONS(510),
    [anon_sym_EQ] = ACTIONS(512),
    [anon_sym_PLUS_EQ] = ACTIONS(510),
    [anon_sym_DASH_EQ] = ACTIONS(510),
    [anon_sym_STAR_EQ] = ACTIONS(510),
    [anon_sym_SLASH_EQ] = ACTIONS(510),
    [anon_sym_DQUOTE] = ACTIONS(510),
    [sym__identifier] = ACTIONS(512),
    [anon_sym_linear] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(512),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(512),
    [anon_sym_ease] = ACTIONS(512),
    [anon_sym_ease_DASHin] = ACTIONS(512),
    [anon_sym_ease_DASHout] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(512),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(512),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(512),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(512),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(512),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(512),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(512),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(512),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(512),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(512),
    [anon_sym_cubic_DASHbezier] = ACTIONS(512),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(510),
    [anon_sym_ATlinear_gradient] = ACTIONS(510),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(510),
    [anon_sym_ATradial_gradient] = ACTIONS(510),
    [anon_sym_parent] = ACTIONS(512),
    [anon_sym_root] = ACTIONS(512),
    [anon_sym_self] = ACTIONS(512),
    [sym__int_number] = ACTIONS(512),
    [sym__float_number] = ACTIONS(510),
    [anon_sym_true] = ACTIONS(512),
    [anon_sym_false] = ACTIONS(512),
    [sym_color_value] = ACTIONS(510),
    [sym_comment] = ACTIONS(3),
  },
  [187] = {
    [anon_sym_LBRACE] = ACTIONS(514),
    [anon_sym_COMMA] = ACTIONS(514),
    [anon_sym_RBRACE] = ACTIONS(514),
    [anon_sym_SEMI] = ACTIONS(514),
    [anon_sym_LT] = ACTIONS(516),
    [anon_sym_GT] = ACTIONS(516),
    [anon_sym_return] = ACTIONS(516),
    [anon_sym_COLON] = ACTIONS(514),
    [anon_sym_LBRACK] = ACTIONS(514),
    [anon_sym_if] = ACTIONS(516),
    [anon_sym_LPAREN] = ACTIONS(514),
    [anon_sym_RPAREN] = ACTIONS(514),
    [anon_sym_ATtr] = ACTIONS(514),
    [anon_sym_DOT] = ACTIONS(516),
    [sym_logical_and] = ACTIONS(514),
    [sym_logical_or] = ACTIONS(514),
    [anon_sym_QMARK] = ACTIONS(514),
    [anon_sym_ATimage_DASHurl] = ACTIONS(514),
    [anon_sym_BANG] = ACTIONS(516),
    [anon_sym_DASH] = ACTIONS(516),
    [anon_sym_PLUS] = ACTIONS(516),
    [anon_sym_STAR] = ACTIONS(516),
    [anon_sym_SLASH] = ACTIONS(516),
    [anon_sym_GT_EQ] = ACTIONS(514),
    [anon_sym_LT_EQ] = ACTIONS(514),
    [anon_sym_EQ_EQ] = ACTIONS(514),
    [anon_sym_BANG_EQ] = ACTIONS(514),
    [anon_sym_EQ] = ACTIONS(516),
    [anon_sym_PLUS_EQ] = ACTIONS(514),
    [anon_sym_DASH_EQ] = ACTIONS(514),
    [anon_sym_STAR_EQ] = ACTIONS(514),
    [anon_sym_SLASH_EQ] = ACTIONS(514),
    [anon_sym_DQUOTE] = ACTIONS(514),
    [sym__identifier] = ACTIONS(516),
    [anon_sym_linear] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(516),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(516),
    [anon_sym_ease] = ACTIONS(516),
    [anon_sym_ease_DASHin] = ACTIONS(516),
    [anon_sym_ease_DASHout] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(516),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(516),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(516),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(516),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(516),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(516),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(516),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(516),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(516),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(516),
    [anon_sym_cubic_DASHbezier] = ACTIONS(516),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(514),
    [anon_sym_ATlinear_gradient] = ACTIONS(514),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(514),
    [anon_sym_ATradial_gradient] = ACTIONS(514),
    [anon_sym_parent] = ACTIONS(516),
    [anon_sym_root] = ACTIONS(516),
    [anon_sym_self] = ACTIONS(516),
    [sym__int_number] = ACTIONS(516),
    [sym__float_number] = ACTIONS(514),
    [anon_sym_true] = ACTIONS(516),
    [anon_sym_false] = ACTIONS(516),
    [sym_color_value] = ACTIONS(514),
    [sym_comment] = ACTIONS(3),
  },
  [188] = {
    [anon_sym_LBRACE] = ACTIONS(518),
    [anon_sym_COMMA] = ACTIONS(518),
    [anon_sym_RBRACE] = ACTIONS(518),
    [anon_sym_SEMI] = ACTIONS(518),
    [anon_sym_LT] = ACTIONS(520),
    [anon_sym_GT] = ACTIONS(520),
    [anon_sym_return] = ACTIONS(520),
    [anon_sym_COLON] = ACTIONS(518),
    [anon_sym_LBRACK] = ACTIONS(518),
    [anon_sym_if] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(518),
    [anon_sym_RPAREN] = ACTIONS(518),
    [anon_sym_ATtr] = ACTIONS(518),
    [anon_sym_DOT] = ACTIONS(520),
    [sym_logical_and] = ACTIONS(518),
    [sym_logical_or] = ACTIONS(518),
    [anon_sym_QMARK] = ACTIONS(518),
    [anon_sym_ATimage_DASHurl] = ACTIONS(518),
    [anon_sym_BANG] = ACTIONS(520),
    [anon_sym_DASH] = ACTIONS(520),
    [anon_sym_PLUS] = ACTIONS(520),
    [anon_sym_STAR] = ACTIONS(520),
    [anon_sym_SLASH] = ACTIONS(520),
    [anon_sym_GT_EQ] = ACTIONS(518),
    [anon_sym_LT_EQ] = ACTIONS(518),
    [anon_sym_EQ_EQ] = ACTIONS(518),
    [anon_sym_BANG_EQ] = ACTIONS(518),
    [anon_sym_EQ] = ACTIONS(520),
    [anon_sym_PLUS_EQ] = ACTIONS(518),
    [anon_sym_DASH_EQ] = ACTIONS(518),
    [anon_sym_STAR_EQ] = ACTIONS(518),
    [anon_sym_SLASH_EQ] = ACTIONS(518),
    [anon_sym_DQUOTE] = ACTIONS(518),
    [sym__identifier] = ACTIONS(520),
    [anon_sym_linear] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(520),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(520),
    [anon_sym_ease] = ACTIONS(520),
    [anon_sym_ease_DASHin] = ACTIONS(520),
    [anon_sym_ease_DASHout] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(520),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(520),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(520),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(520),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(520),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(520),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(520),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(520),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(520),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(520),
    [anon_sym_cubic_DASHbezier] = ACTIONS(520),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(518),
    [anon_sym_ATlinear_gradient] = ACTIONS(518),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(518),
    [anon_sym_ATradial_gradient] = ACTIONS(518),
    [anon_sym_parent] = ACTIONS(520),
    [anon_sym_root] = ACTIONS(520),
    [anon_sym_self] = ACTIONS(520),
    [sym__int_number] = ACTIONS(520),
    [sym__float_number] = ACTIONS(518),
    [anon_sym_true] = ACTIONS(520),
    [anon_sym_false] = ACTIONS(520),
    [sym_color_value] = ACTIONS(518),
    [sym_comment] = ACTIONS(3),
  },
  [189] = {
    [anon_sym_LBRACE] = ACTIONS(522),
    [anon_sym_COMMA] = ACTIONS(522),
    [anon_sym_RBRACE] = ACTIONS(522),
    [anon_sym_SEMI] = ACTIONS(522),
    [anon_sym_LT] = ACTIONS(524),
    [anon_sym_GT] = ACTIONS(524),
    [anon_sym_return] = ACTIONS(524),
    [anon_sym_COLON] = ACTIONS(522),
    [anon_sym_LBRACK] = ACTIONS(522),
    [anon_sym_if] = ACTIONS(524),
    [anon_sym_LPAREN] = ACTIONS(522),
    [anon_sym_RPAREN] = ACTIONS(522),
    [anon_sym_ATtr] = ACTIONS(522),
    [anon_sym_DOT] = ACTIONS(524),
    [sym_logical_and] = ACTIONS(522),
    [sym_logical_or] = ACTIONS(522),
    [anon_sym_QMARK] = ACTIONS(522),
    [anon_sym_ATimage_DASHurl] = ACTIONS(522),
    [anon_sym_BANG] = ACTIONS(524),
    [anon_sym_DASH] = ACTIONS(524),
    [anon_sym_PLUS] = ACTIONS(524),
    [anon_sym_STAR] = ACTIONS(524),
    [anon_sym_SLASH] = ACTIONS(524),
    [anon_sym_GT_EQ] = ACTIONS(522),
    [anon_sym_LT_EQ] = ACTIONS(522),
    [anon_sym_EQ_EQ] = ACTIONS(522),
    [anon_sym_BANG_EQ] = ACTIONS(522),
    [anon_sym_EQ] = ACTIONS(524),
    [anon_sym_PLUS_EQ] = ACTIONS(522),
    [anon_sym_DASH_EQ] = ACTIONS(522),
    [anon_sym_STAR_EQ] = ACTIONS(522),
    [anon_sym_SLASH_EQ] = ACTIONS(522),
    [anon_sym_DQUOTE] = ACTIONS(522),
    [sym__identifier] = ACTIONS(524),
    [anon_sym_linear] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(524),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(524),
    [anon_sym_ease] = ACTIONS(524),
    [anon_sym_ease_DASHin] = ACTIONS(524),
    [anon_sym_ease_DASHout] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(524),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(524),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(524),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(524),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(524),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(524),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(524),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(524),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(524),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(524),
    [anon_sym_cubic_DASHbezier] = ACTIONS(524),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(522),
    [anon_sym_ATlinear_gradient] = ACTIONS(522),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(522),
    [anon_sym_ATradial_gradient] = ACTIONS(522),
    [anon_sym_parent] = ACTIONS(524),
    [anon_sym_root] = ACTIONS(524),
    [anon_sym_self] = ACTIONS(524),
    [sym__int_number] = ACTIONS(524),
    [sym__float_number] = ACTIONS(522),
    [anon_sym_true] = ACTIONS(524),
    [anon_sym_false] = ACTIONS(524),
    [sym_color_value] = ACTIONS(522),
    [sym_comment] = ACTIONS(3),
  },
  [190] = {
    [anon_sym_LBRACE] = ACTIONS(526),
    [anon_sym_COMMA] = ACTIONS(526),
    [anon_sym_RBRACE] = ACTIONS(526),
    [anon_sym_SEMI] = ACTIONS(526),
    [anon_sym_LT] = ACTIONS(528),
    [anon_sym_GT] = ACTIONS(528),
    [anon_sym_return] = ACTIONS(528),
    [anon_sym_COLON] = ACTIONS(526),
    [anon_sym_LBRACK] = ACTIONS(526),
    [anon_sym_if] = ACTIONS(528),
    [anon_sym_LPAREN] = ACTIONS(526),
    [anon_sym_RPAREN] = ACTIONS(526),
    [anon_sym_ATtr] = ACTIONS(526),
    [anon_sym_DOT] = ACTIONS(528),
    [sym_logical_and] = ACTIONS(526),
    [sym_logical_or] = ACTIONS(526),
    [anon_sym_QMARK] = ACTIONS(526),
    [anon_sym_ATimage_DASHurl] = ACTIONS(526),
    [anon_sym_BANG] = ACTIONS(528),
    [anon_sym_DASH] = ACTIONS(528),
    [anon_sym_PLUS] = ACTIONS(528),
    [anon_sym_STAR] = ACTIONS(528),
    [anon_sym_SLASH] = ACTIONS(528),
    [anon_sym_GT_EQ] = ACTIONS(526),
    [anon_sym_LT_EQ] = ACTIONS(526),
    [anon_sym_EQ_EQ] = ACTIONS(526),
    [anon_sym_BANG_EQ] = ACTIONS(526),
    [anon_sym_EQ] = ACTIONS(528),
    [anon_sym_PLUS_EQ] = ACTIONS(526),
    [anon_sym_DASH_EQ] = ACTIONS(526),
    [anon_sym_STAR_EQ] = ACTIONS(526),
    [anon_sym_SLASH_EQ] = ACTIONS(526),
    [anon_sym_DQUOTE] = ACTIONS(526),
    [sym__identifier] = ACTIONS(528),
    [anon_sym_linear] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(528),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(528),
    [anon_sym_ease] = ACTIONS(528),
    [anon_sym_ease_DASHin] = ACTIONS(528),
    [anon_sym_ease_DASHout] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(528),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(528),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(528),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(528),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(528),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(528),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(528),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(528),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(528),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(528),
    [anon_sym_cubic_DASHbezier] = ACTIONS(528),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(526),
    [anon_sym_ATlinear_gradient] = ACTIONS(526),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(526),
    [anon_sym_ATradial_gradient] = ACTIONS(526),
    [anon_sym_parent] = ACTIONS(528),
    [anon_sym_root] = ACTIONS(528),
    [anon_sym_self] = ACTIONS(528),
    [sym__int_number] = ACTIONS(528),
    [sym__float_number] = ACTIONS(526),
    [anon_sym_true] = ACTIONS(528),
    [anon_sym_false] = ACTIONS(528),
    [sym_color_value] = ACTIONS(526),
    [sym_comment] = ACTIONS(3),
  },
  [191] = {
    [anon_sym_LBRACE] = ACTIONS(530),
    [anon_sym_COMMA] = ACTIONS(530),
    [anon_sym_RBRACE] = ACTIONS(530),
    [anon_sym_SEMI] = ACTIONS(530),
    [anon_sym_LT] = ACTIONS(532),
    [anon_sym_GT] = ACTIONS(532),
    [anon_sym_return] = ACTIONS(532),
    [anon_sym_COLON] = ACTIONS(530),
    [anon_sym_LBRACK] = ACTIONS(530),
    [anon_sym_if] = ACTIONS(532),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_RPAREN] = ACTIONS(530),
    [anon_sym_ATtr] = ACTIONS(530),
    [anon_sym_DOT] = ACTIONS(532),
    [sym_logical_and] = ACTIONS(530),
    [sym_logical_or] = ACTIONS(530),
    [anon_sym_QMARK] = ACTIONS(530),
    [anon_sym_ATimage_DASHurl] = ACTIONS(530),
    [anon_sym_BANG] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_STAR] = ACTIONS(532),
    [anon_sym_SLASH] = ACTIONS(532),
    [anon_sym_GT_EQ] = ACTIONS(530),
    [anon_sym_LT_EQ] = ACTIONS(530),
    [anon_sym_EQ_EQ] = ACTIONS(530),
    [anon_sym_BANG_EQ] = ACTIONS(530),
    [anon_sym_EQ] = ACTIONS(532),
    [anon_sym_PLUS_EQ] = ACTIONS(530),
    [anon_sym_DASH_EQ] = ACTIONS(530),
    [anon_sym_STAR_EQ] = ACTIONS(530),
    [anon_sym_SLASH_EQ] = ACTIONS(530),
    [anon_sym_DQUOTE] = ACTIONS(530),
    [sym__identifier] = ACTIONS(532),
    [anon_sym_linear] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(532),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(532),
    [anon_sym_ease] = ACTIONS(532),
    [anon_sym_ease_DASHin] = ACTIONS(532),
    [anon_sym_ease_DASHout] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(532),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(532),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(532),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(532),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(532),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(532),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(532),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(532),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(532),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(532),
    [anon_sym_cubic_DASHbezier] = ACTIONS(532),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(530),
    [anon_sym_ATlinear_gradient] = ACTIONS(530),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(530),
    [anon_sym_ATradial_gradient] = ACTIONS(530),
    [anon_sym_parent] = ACTIONS(532),
    [anon_sym_root] = ACTIONS(532),
    [anon_sym_self] = ACTIONS(532),
    [sym__int_number] = ACTIONS(532),
    [sym__float_number] = ACTIONS(530),
    [anon_sym_true] = ACTIONS(532),
    [anon_sym_false] = ACTIONS(532),
    [sym_color_value] = ACTIONS(530),
    [sym_comment] = ACTIONS(3),
  },
  [192] = {
    [anon_sym_LBRACE] = ACTIONS(534),
    [anon_sym_COMMA] = ACTIONS(534),
    [anon_sym_RBRACE] = ACTIONS(534),
    [anon_sym_SEMI] = ACTIONS(534),
    [anon_sym_LT] = ACTIONS(536),
    [anon_sym_GT] = ACTIONS(536),
    [anon_sym_return] = ACTIONS(536),
    [anon_sym_COLON] = ACTIONS(534),
    [anon_sym_LBRACK] = ACTIONS(534),
    [anon_sym_if] = ACTIONS(536),
    [anon_sym_LPAREN] = ACTIONS(534),
    [anon_sym_RPAREN] = ACTIONS(534),
    [anon_sym_ATtr] = ACTIONS(534),
    [anon_sym_DOT] = ACTIONS(536),
    [sym_logical_and] = ACTIONS(534),
    [sym_logical_or] = ACTIONS(534),
    [anon_sym_QMARK] = ACTIONS(534),
    [anon_sym_ATimage_DASHurl] = ACTIONS(534),
    [anon_sym_BANG] = ACTIONS(536),
    [anon_sym_DASH] = ACTIONS(536),
    [anon_sym_PLUS] = ACTIONS(536),
    [anon_sym_STAR] = ACTIONS(536),
    [anon_sym_SLASH] = ACTIONS(536),
    [anon_sym_GT_EQ] = ACTIONS(534),
    [anon_sym_LT_EQ] = ACTIONS(534),
    [anon_sym_EQ_EQ] = ACTIONS(534),
    [anon_sym_BANG_EQ] = ACTIONS(534),
    [anon_sym_EQ] = ACTIONS(536),
    [anon_sym_PLUS_EQ] = ACTIONS(534),
    [anon_sym_DASH_EQ] = ACTIONS(534),
    [anon_sym_STAR_EQ] = ACTIONS(534),
    [anon_sym_SLASH_EQ] = ACTIONS(534),
    [anon_sym_DQUOTE] = ACTIONS(534),
    [sym__identifier] = ACTIONS(536),
    [anon_sym_linear] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(536),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(536),
    [anon_sym_ease] = ACTIONS(536),
    [anon_sym_ease_DASHin] = ACTIONS(536),
    [anon_sym_ease_DASHout] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(536),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(536),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(536),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(536),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(536),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(536),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(536),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(536),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(536),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(536),
    [anon_sym_cubic_DASHbezier] = ACTIONS(536),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(534),
    [anon_sym_ATlinear_gradient] = ACTIONS(534),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(534),
    [anon_sym_ATradial_gradient] = ACTIONS(534),
    [anon_sym_parent] = ACTIONS(536),
    [anon_sym_root] = ACTIONS(536),
    [anon_sym_self] = ACTIONS(536),
    [sym__int_number] = ACTIONS(536),
    [sym__float_number] = ACTIONS(534),
    [anon_sym_true] = ACTIONS(536),
    [anon_sym_false] = ACTIONS(536),
    [sym_color_value] = ACTIONS(534),
    [sym_comment] = ACTIONS(3),
  },
  [193] = {
    [anon_sym_LBRACE] = ACTIONS(538),
    [anon_sym_COMMA] = ACTIONS(538),
    [anon_sym_RBRACE] = ACTIONS(538),
    [anon_sym_SEMI] = ACTIONS(538),
    [anon_sym_LT] = ACTIONS(540),
    [anon_sym_GT] = ACTIONS(540),
    [anon_sym_return] = ACTIONS(540),
    [anon_sym_COLON] = ACTIONS(538),
    [anon_sym_LBRACK] = ACTIONS(538),
    [anon_sym_if] = ACTIONS(540),
    [anon_sym_LPAREN] = ACTIONS(538),
    [anon_sym_RPAREN] = ACTIONS(538),
    [anon_sym_ATtr] = ACTIONS(538),
    [anon_sym_DOT] = ACTIONS(540),
    [sym_logical_and] = ACTIONS(538),
    [sym_logical_or] = ACTIONS(538),
    [anon_sym_QMARK] = ACTIONS(538),
    [anon_sym_ATimage_DASHurl] = ACTIONS(538),
    [anon_sym_BANG] = ACTIONS(540),
    [anon_sym_DASH] = ACTIONS(540),
    [anon_sym_PLUS] = ACTIONS(540),
    [anon_sym_STAR] = ACTIONS(540),
    [anon_sym_SLASH] = ACTIONS(540),
    [anon_sym_GT_EQ] = ACTIONS(538),
    [anon_sym_LT_EQ] = ACTIONS(538),
    [anon_sym_EQ_EQ] = ACTIONS(538),
    [anon_sym_BANG_EQ] = ACTIONS(538),
    [anon_sym_EQ] = ACTIONS(540),
    [anon_sym_PLUS_EQ] = ACTIONS(538),
    [anon_sym_DASH_EQ] = ACTIONS(538),
    [anon_sym_STAR_EQ] = ACTIONS(538),
    [anon_sym_SLASH_EQ] = ACTIONS(538),
    [anon_sym_DQUOTE] = ACTIONS(538),
    [sym__identifier] = ACTIONS(540),
    [anon_sym_linear] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(540),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(540),
    [anon_sym_ease] = ACTIONS(540),
    [anon_sym_ease_DASHin] = ACTIONS(540),
    [anon_sym_ease_DASHout] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(540),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(540),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(540),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(540),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(540),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(540),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(540),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(540),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(540),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(540),
    [anon_sym_cubic_DASHbezier] = ACTIONS(540),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(538),
    [anon_sym_ATlinear_gradient] = ACTIONS(538),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(538),
    [anon_sym_ATradial_gradient] = ACTIONS(538),
    [anon_sym_parent] = ACTIONS(540),
    [anon_sym_root] = ACTIONS(540),
    [anon_sym_self] = ACTIONS(540),
    [sym__int_number] = ACTIONS(540),
    [sym__float_number] = ACTIONS(538),
    [anon_sym_true] = ACTIONS(540),
    [anon_sym_false] = ACTIONS(540),
    [sym_color_value] = ACTIONS(538),
    [sym_comment] = ACTIONS(3),
  },
  [194] = {
    [anon_sym_LBRACE] = ACTIONS(542),
    [anon_sym_COMMA] = ACTIONS(542),
    [anon_sym_RBRACE] = ACTIONS(542),
    [anon_sym_SEMI] = ACTIONS(542),
    [anon_sym_LT] = ACTIONS(544),
    [anon_sym_GT] = ACTIONS(544),
    [anon_sym_return] = ACTIONS(544),
    [anon_sym_COLON] = ACTIONS(542),
    [anon_sym_LBRACK] = ACTIONS(542),
    [anon_sym_if] = ACTIONS(544),
    [anon_sym_LPAREN] = ACTIONS(542),
    [anon_sym_RPAREN] = ACTIONS(542),
    [anon_sym_ATtr] = ACTIONS(542),
    [anon_sym_DOT] = ACTIONS(544),
    [sym_logical_and] = ACTIONS(542),
    [sym_logical_or] = ACTIONS(542),
    [anon_sym_QMARK] = ACTIONS(542),
    [anon_sym_ATimage_DASHurl] = ACTIONS(542),
    [anon_sym_BANG] = ACTIONS(544),
    [anon_sym_DASH] = ACTIONS(544),
    [anon_sym_PLUS] = ACTIONS(544),
    [anon_sym_STAR] = ACTIONS(544),
    [anon_sym_SLASH] = ACTIONS(544),
    [anon_sym_GT_EQ] = ACTIONS(542),
    [anon_sym_LT_EQ] = ACTIONS(542),
    [anon_sym_EQ_EQ] = ACTIONS(542),
    [anon_sym_BANG_EQ] = ACTIONS(542),
    [anon_sym_EQ] = ACTIONS(544),
    [anon_sym_PLUS_EQ] = ACTIONS(542),
    [anon_sym_DASH_EQ] = ACTIONS(542),
    [anon_sym_STAR_EQ] = ACTIONS(542),
    [anon_sym_SLASH_EQ] = ACTIONS(542),
    [anon_sym_DQUOTE] = ACTIONS(542),
    [sym__identifier] = ACTIONS(544),
    [anon_sym_linear] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(544),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(544),
    [anon_sym_ease] = ACTIONS(544),
    [anon_sym_ease_DASHin] = ACTIONS(544),
    [anon_sym_ease_DASHout] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(544),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(544),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(544),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(544),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(544),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(544),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(544),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(544),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(544),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(544),
    [anon_sym_cubic_DASHbezier] = ACTIONS(544),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(542),
    [anon_sym_ATlinear_gradient] = ACTIONS(542),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(542),
    [anon_sym_ATradial_gradient] = ACTIONS(542),
    [anon_sym_parent] = ACTIONS(544),
    [anon_sym_root] = ACTIONS(544),
    [anon_sym_self] = ACTIONS(544),
    [sym__int_number] = ACTIONS(544),
    [sym__float_number] = ACTIONS(542),
    [anon_sym_true] = ACTIONS(544),
    [anon_sym_false] = ACTIONS(544),
    [sym_color_value] = ACTIONS(542),
    [sym_comment] = ACTIONS(3),
  },
  [195] = {
    [anon_sym_LBRACE] = ACTIONS(546),
    [anon_sym_COMMA] = ACTIONS(546),
    [anon_sym_RBRACE] = ACTIONS(546),
    [anon_sym_SEMI] = ACTIONS(546),
    [anon_sym_LT] = ACTIONS(548),
    [anon_sym_GT] = ACTIONS(548),
    [anon_sym_return] = ACTIONS(548),
    [anon_sym_COLON] = ACTIONS(546),
    [anon_sym_LBRACK] = ACTIONS(546),
    [anon_sym_if] = ACTIONS(548),
    [anon_sym_LPAREN] = ACTIONS(546),
    [anon_sym_RPAREN] = ACTIONS(546),
    [anon_sym_ATtr] = ACTIONS(546),
    [anon_sym_DOT] = ACTIONS(548),
    [sym_logical_and] = ACTIONS(546),
    [sym_logical_or] = ACTIONS(546),
    [anon_sym_QMARK] = ACTIONS(546),
    [anon_sym_ATimage_DASHurl] = ACTIONS(546),
    [anon_sym_BANG] = ACTIONS(548),
    [anon_sym_DASH] = ACTIONS(548),
    [anon_sym_PLUS] = ACTIONS(548),
    [anon_sym_STAR] = ACTIONS(548),
    [anon_sym_SLASH] = ACTIONS(548),
    [anon_sym_GT_EQ] = ACTIONS(546),
    [anon_sym_LT_EQ] = ACTIONS(546),
    [anon_sym_EQ_EQ] = ACTIONS(546),
    [anon_sym_BANG_EQ] = ACTIONS(546),
    [anon_sym_EQ] = ACTIONS(548),
    [anon_sym_PLUS_EQ] = ACTIONS(546),
    [anon_sym_DASH_EQ] = ACTIONS(546),
    [anon_sym_STAR_EQ] = ACTIONS(546),
    [anon_sym_SLASH_EQ] = ACTIONS(546),
    [anon_sym_DQUOTE] = ACTIONS(546),
    [sym__identifier] = ACTIONS(548),
    [anon_sym_linear] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(548),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(548),
    [anon_sym_ease] = ACTIONS(548),
    [anon_sym_ease_DASHin] = ACTIONS(548),
    [anon_sym_ease_DASHout] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(548),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(548),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(548),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(548),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(548),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(548),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(548),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(548),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(548),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(548),
    [anon_sym_cubic_DASHbezier] = ACTIONS(548),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(546),
    [anon_sym_ATlinear_gradient] = ACTIONS(546),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(546),
    [anon_sym_ATradial_gradient] = ACTIONS(546),
    [anon_sym_parent] = ACTIONS(548),
    [anon_sym_root] = ACTIONS(548),
    [anon_sym_self] = ACTIONS(548),
    [sym__int_number] = ACTIONS(548),
    [sym__float_number] = ACTIONS(546),
    [anon_sym_true] = ACTIONS(548),
    [anon_sym_false] = ACTIONS(548),
    [sym_color_value] = ACTIONS(546),
    [sym_comment] = ACTIONS(3),
  },
  [196] = {
    [anon_sym_LBRACE] = ACTIONS(550),
    [anon_sym_COMMA] = ACTIONS(550),
    [anon_sym_RBRACE] = ACTIONS(550),
    [anon_sym_SEMI] = ACTIONS(550),
    [anon_sym_LT] = ACTIONS(552),
    [anon_sym_GT] = ACTIONS(552),
    [anon_sym_return] = ACTIONS(552),
    [anon_sym_COLON] = ACTIONS(550),
    [anon_sym_LBRACK] = ACTIONS(550),
    [anon_sym_if] = ACTIONS(552),
    [anon_sym_LPAREN] = ACTIONS(550),
    [anon_sym_RPAREN] = ACTIONS(550),
    [anon_sym_ATtr] = ACTIONS(550),
    [anon_sym_DOT] = ACTIONS(552),
    [sym_logical_and] = ACTIONS(550),
    [sym_logical_or] = ACTIONS(550),
    [anon_sym_QMARK] = ACTIONS(550),
    [anon_sym_ATimage_DASHurl] = ACTIONS(550),
    [anon_sym_BANG] = ACTIONS(552),
    [anon_sym_DASH] = ACTIONS(552),
    [anon_sym_PLUS] = ACTIONS(552),
    [anon_sym_STAR] = ACTIONS(552),
    [anon_sym_SLASH] = ACTIONS(552),
    [anon_sym_GT_EQ] = ACTIONS(550),
    [anon_sym_LT_EQ] = ACTIONS(550),
    [anon_sym_EQ_EQ] = ACTIONS(550),
    [anon_sym_BANG_EQ] = ACTIONS(550),
    [anon_sym_EQ] = ACTIONS(552),
    [anon_sym_PLUS_EQ] = ACTIONS(550),
    [anon_sym_DASH_EQ] = ACTIONS(550),
    [anon_sym_STAR_EQ] = ACTIONS(550),
    [anon_sym_SLASH_EQ] = ACTIONS(550),
    [anon_sym_DQUOTE] = ACTIONS(550),
    [sym__identifier] = ACTIONS(552),
    [anon_sym_linear] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(552),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(552),
    [anon_sym_ease] = ACTIONS(552),
    [anon_sym_ease_DASHin] = ACTIONS(552),
    [anon_sym_ease_DASHout] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(552),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(552),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(552),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(552),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(552),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(552),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(552),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(552),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(552),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(552),
    [anon_sym_cubic_DASHbezier] = ACTIONS(552),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(550),
    [anon_sym_ATlinear_gradient] = ACTIONS(550),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(550),
    [anon_sym_ATradial_gradient] = ACTIONS(550),
    [anon_sym_parent] = ACTIONS(552),
    [anon_sym_root] = ACTIONS(552),
    [anon_sym_self] = ACTIONS(552),
    [sym__int_number] = ACTIONS(552),
    [sym__float_number] = ACTIONS(550),
    [anon_sym_true] = ACTIONS(552),
    [anon_sym_false] = ACTIONS(552),
    [sym_color_value] = ACTIONS(550),
    [sym_comment] = ACTIONS(3),
  },
  [197] = {
    [anon_sym_LBRACE] = ACTIONS(554),
    [anon_sym_COMMA] = ACTIONS(554),
    [anon_sym_RBRACE] = ACTIONS(554),
    [anon_sym_SEMI] = ACTIONS(554),
    [anon_sym_LT] = ACTIONS(556),
    [anon_sym_GT] = ACTIONS(556),
    [anon_sym_return] = ACTIONS(556),
    [anon_sym_COLON] = ACTIONS(554),
    [anon_sym_LBRACK] = ACTIONS(554),
    [anon_sym_if] = ACTIONS(556),
    [anon_sym_LPAREN] = ACTIONS(554),
    [anon_sym_RPAREN] = ACTIONS(554),
    [anon_sym_ATtr] = ACTIONS(554),
    [anon_sym_DOT] = ACTIONS(556),
    [sym_logical_and] = ACTIONS(554),
    [sym_logical_or] = ACTIONS(554),
    [anon_sym_QMARK] = ACTIONS(554),
    [anon_sym_ATimage_DASHurl] = ACTIONS(554),
    [anon_sym_BANG] = ACTIONS(556),
    [anon_sym_DASH] = ACTIONS(556),
    [anon_sym_PLUS] = ACTIONS(556),
    [anon_sym_STAR] = ACTIONS(556),
    [anon_sym_SLASH] = ACTIONS(556),
    [anon_sym_GT_EQ] = ACTIONS(554),
    [anon_sym_LT_EQ] = ACTIONS(554),
    [anon_sym_EQ_EQ] = ACTIONS(554),
    [anon_sym_BANG_EQ] = ACTIONS(554),
    [anon_sym_EQ] = ACTIONS(556),
    [anon_sym_PLUS_EQ] = ACTIONS(554),
    [anon_sym_DASH_EQ] = ACTIONS(554),
    [anon_sym_STAR_EQ] = ACTIONS(554),
    [anon_sym_SLASH_EQ] = ACTIONS(554),
    [anon_sym_DQUOTE] = ACTIONS(554),
    [sym__identifier] = ACTIONS(556),
    [anon_sym_linear] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(556),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(556),
    [anon_sym_ease] = ACTIONS(556),
    [anon_sym_ease_DASHin] = ACTIONS(556),
    [anon_sym_ease_DASHout] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(556),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(556),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(556),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(556),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(556),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(556),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(556),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(556),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(556),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(556),
    [anon_sym_cubic_DASHbezier] = ACTIONS(556),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(554),
    [anon_sym_ATlinear_gradient] = ACTIONS(554),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(554),
    [anon_sym_ATradial_gradient] = ACTIONS(554),
    [anon_sym_parent] = ACTIONS(556),
    [anon_sym_root] = ACTIONS(556),
    [anon_sym_self] = ACTIONS(556),
    [sym__int_number] = ACTIONS(556),
    [sym__float_number] = ACTIONS(554),
    [anon_sym_true] = ACTIONS(556),
    [anon_sym_false] = ACTIONS(556),
    [sym_color_value] = ACTIONS(554),
    [sym_comment] = ACTIONS(3),
  },
  [198] = {
    [anon_sym_LBRACE] = ACTIONS(558),
    [anon_sym_COMMA] = ACTIONS(558),
    [anon_sym_RBRACE] = ACTIONS(558),
    [anon_sym_SEMI] = ACTIONS(558),
    [anon_sym_LT] = ACTIONS(560),
    [anon_sym_GT] = ACTIONS(560),
    [anon_sym_return] = ACTIONS(560),
    [anon_sym_COLON] = ACTIONS(558),
    [anon_sym_LBRACK] = ACTIONS(558),
    [anon_sym_if] = ACTIONS(560),
    [anon_sym_LPAREN] = ACTIONS(558),
    [anon_sym_RPAREN] = ACTIONS(558),
    [anon_sym_ATtr] = ACTIONS(558),
    [anon_sym_DOT] = ACTIONS(560),
    [sym_logical_and] = ACTIONS(558),
    [sym_logical_or] = ACTIONS(558),
    [anon_sym_QMARK] = ACTIONS(558),
    [anon_sym_ATimage_DASHurl] = ACTIONS(558),
    [anon_sym_BANG] = ACTIONS(560),
    [anon_sym_DASH] = ACTIONS(560),
    [anon_sym_PLUS] = ACTIONS(560),
    [anon_sym_STAR] = ACTIONS(560),
    [anon_sym_SLASH] = ACTIONS(560),
    [anon_sym_GT_EQ] = ACTIONS(558),
    [anon_sym_LT_EQ] = ACTIONS(558),
    [anon_sym_EQ_EQ] = ACTIONS(558),
    [anon_sym_BANG_EQ] = ACTIONS(558),
    [anon_sym_EQ] = ACTIONS(560),
    [anon_sym_PLUS_EQ] = ACTIONS(558),
    [anon_sym_DASH_EQ] = ACTIONS(558),
    [anon_sym_STAR_EQ] = ACTIONS(558),
    [anon_sym_SLASH_EQ] = ACTIONS(558),
    [anon_sym_DQUOTE] = ACTIONS(558),
    [sym__identifier] = ACTIONS(560),
    [anon_sym_linear] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(560),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(560),
    [anon_sym_ease] = ACTIONS(560),
    [anon_sym_ease_DASHin] = ACTIONS(560),
    [anon_sym_ease_DASHout] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(560),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(560),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(560),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(560),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(560),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(560),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(560),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(560),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(560),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(560),
    [anon_sym_cubic_DASHbezier] = ACTIONS(560),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(558),
    [anon_sym_ATlinear_gradient] = ACTIONS(558),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(558),
    [anon_sym_ATradial_gradient] = ACTIONS(558),
    [anon_sym_parent] = ACTIONS(560),
    [anon_sym_root] = ACTIONS(560),
    [anon_sym_self] = ACTIONS(560),
    [sym__int_number] = ACTIONS(560),
    [sym__float_number] = ACTIONS(558),
    [anon_sym_true] = ACTIONS(560),
    [anon_sym_false] = ACTIONS(560),
    [sym_color_value] = ACTIONS(558),
    [sym_comment] = ACTIONS(3),
  },
  [199] = {
    [anon_sym_LBRACE] = ACTIONS(562),
    [anon_sym_COMMA] = ACTIONS(562),
    [anon_sym_RBRACE] = ACTIONS(562),
    [anon_sym_SEMI] = ACTIONS(562),
    [anon_sym_LT] = ACTIONS(564),
    [anon_sym_GT] = ACTIONS(564),
    [anon_sym_return] = ACTIONS(564),
    [anon_sym_COLON] = ACTIONS(562),
    [anon_sym_LBRACK] = ACTIONS(562),
    [anon_sym_if] = ACTIONS(564),
    [anon_sym_LPAREN] = ACTIONS(562),
    [anon_sym_RPAREN] = ACTIONS(562),
    [anon_sym_ATtr] = ACTIONS(562),
    [anon_sym_DOT] = ACTIONS(564),
    [sym_logical_and] = ACTIONS(562),
    [sym_logical_or] = ACTIONS(562),
    [anon_sym_QMARK] = ACTIONS(562),
    [anon_sym_ATimage_DASHurl] = ACTIONS(562),
    [anon_sym_BANG] = ACTIONS(564),
    [anon_sym_DASH] = ACTIONS(564),
    [anon_sym_PLUS] = ACTIONS(564),
    [anon_sym_STAR] = ACTIONS(564),
    [anon_sym_SLASH] = ACTIONS(564),
    [anon_sym_GT_EQ] = ACTIONS(562),
    [anon_sym_LT_EQ] = ACTIONS(562),
    [anon_sym_EQ_EQ] = ACTIONS(562),
    [anon_sym_BANG_EQ] = ACTIONS(562),
    [anon_sym_EQ] = ACTIONS(564),
    [anon_sym_PLUS_EQ] = ACTIONS(562),
    [anon_sym_DASH_EQ] = ACTIONS(562),
    [anon_sym_STAR_EQ] = ACTIONS(562),
    [anon_sym_SLASH_EQ] = ACTIONS(562),
    [anon_sym_DQUOTE] = ACTIONS(562),
    [sym__identifier] = ACTIONS(564),
    [anon_sym_linear] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(564),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(564),
    [anon_sym_ease] = ACTIONS(564),
    [anon_sym_ease_DASHin] = ACTIONS(564),
    [anon_sym_ease_DASHout] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(564),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(564),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(564),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(564),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(564),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(564),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(564),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(564),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(564),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(564),
    [anon_sym_cubic_DASHbezier] = ACTIONS(564),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(562),
    [anon_sym_ATlinear_gradient] = ACTIONS(562),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(562),
    [anon_sym_ATradial_gradient] = ACTIONS(562),
    [anon_sym_parent] = ACTIONS(564),
    [anon_sym_root] = ACTIONS(564),
    [anon_sym_self] = ACTIONS(564),
    [sym__int_number] = ACTIONS(564),
    [sym__float_number] = ACTIONS(562),
    [anon_sym_true] = ACTIONS(564),
    [anon_sym_false] = ACTIONS(564),
    [sym_color_value] = ACTIONS(562),
    [sym_comment] = ACTIONS(3),
  },
  [200] = {
    [anon_sym_LBRACE] = ACTIONS(566),
    [anon_sym_COMMA] = ACTIONS(566),
    [anon_sym_RBRACE] = ACTIONS(566),
    [anon_sym_SEMI] = ACTIONS(566),
    [anon_sym_LT] = ACTIONS(568),
    [anon_sym_GT] = ACTIONS(568),
    [anon_sym_return] = ACTIONS(568),
    [anon_sym_COLON] = ACTIONS(566),
    [anon_sym_LBRACK] = ACTIONS(566),
    [anon_sym_if] = ACTIONS(568),
    [anon_sym_LPAREN] = ACTIONS(566),
    [anon_sym_RPAREN] = ACTIONS(566),
    [anon_sym_ATtr] = ACTIONS(566),
    [anon_sym_DOT] = ACTIONS(568),
    [sym_logical_and] = ACTIONS(566),
    [sym_logical_or] = ACTIONS(566),
    [anon_sym_QMARK] = ACTIONS(566),
    [anon_sym_ATimage_DASHurl] = ACTIONS(566),
    [anon_sym_BANG] = ACTIONS(568),
    [anon_sym_DASH] = ACTIONS(568),
    [anon_sym_PLUS] = ACTIONS(568),
    [anon_sym_STAR] = ACTIONS(568),
    [anon_sym_SLASH] = ACTIONS(568),
    [anon_sym_GT_EQ] = ACTIONS(566),
    [anon_sym_LT_EQ] = ACTIONS(566),
    [anon_sym_EQ_EQ] = ACTIONS(566),
    [anon_sym_BANG_EQ] = ACTIONS(566),
    [anon_sym_EQ] = ACTIONS(568),
    [anon_sym_PLUS_EQ] = ACTIONS(566),
    [anon_sym_DASH_EQ] = ACTIONS(566),
    [anon_sym_STAR_EQ] = ACTIONS(566),
    [anon_sym_SLASH_EQ] = ACTIONS(566),
    [anon_sym_DQUOTE] = ACTIONS(566),
    [sym__identifier] = ACTIONS(568),
    [anon_sym_linear] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(568),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(568),
    [anon_sym_ease] = ACTIONS(568),
    [anon_sym_ease_DASHin] = ACTIONS(568),
    [anon_sym_ease_DASHout] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(568),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(568),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(568),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(568),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(568),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(568),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(568),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(568),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(568),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(568),
    [anon_sym_cubic_DASHbezier] = ACTIONS(568),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(566),
    [anon_sym_ATlinear_gradient] = ACTIONS(566),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(566),
    [anon_sym_ATradial_gradient] = ACTIONS(566),
    [anon_sym_parent] = ACTIONS(568),
    [anon_sym_root] = ACTIONS(568),
    [anon_sym_self] = ACTIONS(568),
    [sym__int_number] = ACTIONS(568),
    [sym__float_number] = ACTIONS(566),
    [anon_sym_true] = ACTIONS(568),
    [anon_sym_false] = ACTIONS(568),
    [sym_color_value] = ACTIONS(566),
    [sym_comment] = ACTIONS(3),
  },
  [201] = {
    [anon_sym_LBRACE] = ACTIONS(570),
    [anon_sym_COMMA] = ACTIONS(570),
    [anon_sym_RBRACE] = ACTIONS(570),
    [anon_sym_SEMI] = ACTIONS(570),
    [anon_sym_LT] = ACTIONS(572),
    [anon_sym_GT] = ACTIONS(572),
    [anon_sym_return] = ACTIONS(572),
    [anon_sym_COLON] = ACTIONS(570),
    [anon_sym_LBRACK] = ACTIONS(570),
    [anon_sym_if] = ACTIONS(572),
    [anon_sym_LPAREN] = ACTIONS(570),
    [anon_sym_RPAREN] = ACTIONS(570),
    [anon_sym_ATtr] = ACTIONS(570),
    [anon_sym_DOT] = ACTIONS(572),
    [sym_logical_and] = ACTIONS(570),
    [sym_logical_or] = ACTIONS(570),
    [anon_sym_QMARK] = ACTIONS(570),
    [anon_sym_ATimage_DASHurl] = ACTIONS(570),
    [anon_sym_BANG] = ACTIONS(572),
    [anon_sym_DASH] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(572),
    [anon_sym_STAR] = ACTIONS(572),
    [anon_sym_SLASH] = ACTIONS(572),
    [anon_sym_GT_EQ] = ACTIONS(570),
    [anon_sym_LT_EQ] = ACTIONS(570),
    [anon_sym_EQ_EQ] = ACTIONS(570),
    [anon_sym_BANG_EQ] = ACTIONS(570),
    [anon_sym_EQ] = ACTIONS(572),
    [anon_sym_PLUS_EQ] = ACTIONS(570),
    [anon_sym_DASH_EQ] = ACTIONS(570),
    [anon_sym_STAR_EQ] = ACTIONS(570),
    [anon_sym_SLASH_EQ] = ACTIONS(570),
    [anon_sym_DQUOTE] = ACTIONS(570),
    [sym__identifier] = ACTIONS(572),
    [anon_sym_linear] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(572),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(572),
    [anon_sym_ease] = ACTIONS(572),
    [anon_sym_ease_DASHin] = ACTIONS(572),
    [anon_sym_ease_DASHout] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(572),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(572),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(572),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(572),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(572),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(572),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(572),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(572),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(572),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(572),
    [anon_sym_cubic_DASHbezier] = ACTIONS(572),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(570),
    [anon_sym_ATlinear_gradient] = ACTIONS(570),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(570),
    [anon_sym_ATradial_gradient] = ACTIONS(570),
    [anon_sym_parent] = ACTIONS(572),
    [anon_sym_root] = ACTIONS(572),
    [anon_sym_self] = ACTIONS(572),
    [sym__int_number] = ACTIONS(572),
    [sym__float_number] = ACTIONS(570),
    [anon_sym_true] = ACTIONS(572),
    [anon_sym_false] = ACTIONS(572),
    [sym_color_value] = ACTIONS(570),
    [sym_comment] = ACTIONS(3),
  },
  [202] = {
    [anon_sym_LBRACE] = ACTIONS(574),
    [anon_sym_COMMA] = ACTIONS(574),
    [anon_sym_RBRACE] = ACTIONS(574),
    [anon_sym_SEMI] = ACTIONS(574),
    [anon_sym_LT] = ACTIONS(576),
    [anon_sym_GT] = ACTIONS(576),
    [anon_sym_return] = ACTIONS(576),
    [anon_sym_COLON] = ACTIONS(574),
    [anon_sym_LBRACK] = ACTIONS(574),
    [anon_sym_if] = ACTIONS(576),
    [anon_sym_LPAREN] = ACTIONS(574),
    [anon_sym_RPAREN] = ACTIONS(574),
    [anon_sym_ATtr] = ACTIONS(574),
    [anon_sym_DOT] = ACTIONS(576),
    [sym_logical_and] = ACTIONS(574),
    [sym_logical_or] = ACTIONS(574),
    [anon_sym_QMARK] = ACTIONS(574),
    [anon_sym_ATimage_DASHurl] = ACTIONS(574),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_DASH] = ACTIONS(576),
    [anon_sym_PLUS] = ACTIONS(576),
    [anon_sym_STAR] = ACTIONS(576),
    [anon_sym_SLASH] = ACTIONS(576),
    [anon_sym_GT_EQ] = ACTIONS(574),
    [anon_sym_LT_EQ] = ACTIONS(574),
    [anon_sym_EQ_EQ] = ACTIONS(574),
    [anon_sym_BANG_EQ] = ACTIONS(574),
    [anon_sym_EQ] = ACTIONS(576),
    [anon_sym_PLUS_EQ] = ACTIONS(574),
    [anon_sym_DASH_EQ] = ACTIONS(574),
    [anon_sym_STAR_EQ] = ACTIONS(574),
    [anon_sym_SLASH_EQ] = ACTIONS(574),
    [anon_sym_DQUOTE] = ACTIONS(574),
    [sym__identifier] = ACTIONS(576),
    [anon_sym_linear] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(576),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(576),
    [anon_sym_ease] = ACTIONS(576),
    [anon_sym_ease_DASHin] = ACTIONS(576),
    [anon_sym_ease_DASHout] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(576),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(576),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(576),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(576),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(576),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(576),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(576),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(576),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(576),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(576),
    [anon_sym_cubic_DASHbezier] = ACTIONS(576),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(574),
    [anon_sym_ATlinear_gradient] = ACTIONS(574),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(574),
    [anon_sym_ATradial_gradient] = ACTIONS(574),
    [anon_sym_parent] = ACTIONS(576),
    [anon_sym_root] = ACTIONS(576),
    [anon_sym_self] = ACTIONS(576),
    [sym__int_number] = ACTIONS(576),
    [sym__float_number] = ACTIONS(574),
    [anon_sym_true] = ACTIONS(576),
    [anon_sym_false] = ACTIONS(576),
    [sym_color_value] = ACTIONS(574),
    [sym_comment] = ACTIONS(3),
  },
  [203] = {
    [anon_sym_LBRACE] = ACTIONS(578),
    [anon_sym_COMMA] = ACTIONS(578),
    [anon_sym_RBRACE] = ACTIONS(578),
    [anon_sym_SEMI] = ACTIONS(578),
    [anon_sym_LT] = ACTIONS(580),
    [anon_sym_GT] = ACTIONS(580),
    [anon_sym_return] = ACTIONS(580),
    [anon_sym_COLON] = ACTIONS(578),
    [anon_sym_LBRACK] = ACTIONS(578),
    [anon_sym_if] = ACTIONS(580),
    [anon_sym_LPAREN] = ACTIONS(578),
    [anon_sym_RPAREN] = ACTIONS(578),
    [anon_sym_ATtr] = ACTIONS(578),
    [anon_sym_DOT] = ACTIONS(580),
    [sym_logical_and] = ACTIONS(578),
    [sym_logical_or] = ACTIONS(578),
    [anon_sym_QMARK] = ACTIONS(578),
    [anon_sym_ATimage_DASHurl] = ACTIONS(578),
    [anon_sym_BANG] = ACTIONS(580),
    [anon_sym_DASH] = ACTIONS(580),
    [anon_sym_PLUS] = ACTIONS(580),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_SLASH] = ACTIONS(580),
    [anon_sym_GT_EQ] = ACTIONS(578),
    [anon_sym_LT_EQ] = ACTIONS(578),
    [anon_sym_EQ_EQ] = ACTIONS(578),
    [anon_sym_BANG_EQ] = ACTIONS(578),
    [anon_sym_EQ] = ACTIONS(580),
    [anon_sym_PLUS_EQ] = ACTIONS(578),
    [anon_sym_DASH_EQ] = ACTIONS(578),
    [anon_sym_STAR_EQ] = ACTIONS(578),
    [anon_sym_SLASH_EQ] = ACTIONS(578),
    [anon_sym_DQUOTE] = ACTIONS(578),
    [sym__identifier] = ACTIONS(580),
    [anon_sym_linear] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(580),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(580),
    [anon_sym_ease] = ACTIONS(580),
    [anon_sym_ease_DASHin] = ACTIONS(580),
    [anon_sym_ease_DASHout] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(580),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(580),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(580),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(580),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(580),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(580),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(580),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(580),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(580),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(580),
    [anon_sym_cubic_DASHbezier] = ACTIONS(580),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(578),
    [anon_sym_ATlinear_gradient] = ACTIONS(578),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(578),
    [anon_sym_ATradial_gradient] = ACTIONS(578),
    [anon_sym_parent] = ACTIONS(580),
    [anon_sym_root] = ACTIONS(580),
    [anon_sym_self] = ACTIONS(580),
    [sym__int_number] = ACTIONS(580),
    [sym__float_number] = ACTIONS(578),
    [anon_sym_true] = ACTIONS(580),
    [anon_sym_false] = ACTIONS(580),
    [sym_color_value] = ACTIONS(578),
    [sym_comment] = ACTIONS(3),
  },
  [204] = {
    [anon_sym_LBRACE] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(582),
    [anon_sym_RBRACE] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_LT] = ACTIONS(584),
    [anon_sym_GT] = ACTIONS(584),
    [anon_sym_return] = ACTIONS(584),
    [anon_sym_COLON] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(584),
    [anon_sym_LPAREN] = ACTIONS(582),
    [anon_sym_RPAREN] = ACTIONS(582),
    [anon_sym_ATtr] = ACTIONS(582),
    [anon_sym_DOT] = ACTIONS(584),
    [sym_logical_and] = ACTIONS(582),
    [sym_logical_or] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_ATimage_DASHurl] = ACTIONS(582),
    [anon_sym_BANG] = ACTIONS(584),
    [anon_sym_DASH] = ACTIONS(584),
    [anon_sym_PLUS] = ACTIONS(584),
    [anon_sym_STAR] = ACTIONS(584),
    [anon_sym_SLASH] = ACTIONS(584),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_EQ_EQ] = ACTIONS(582),
    [anon_sym_BANG_EQ] = ACTIONS(582),
    [anon_sym_EQ] = ACTIONS(584),
    [anon_sym_PLUS_EQ] = ACTIONS(582),
    [anon_sym_DASH_EQ] = ACTIONS(582),
    [anon_sym_STAR_EQ] = ACTIONS(582),
    [anon_sym_SLASH_EQ] = ACTIONS(582),
    [anon_sym_DQUOTE] = ACTIONS(582),
    [sym__identifier] = ACTIONS(584),
    [anon_sym_linear] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(584),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(584),
    [anon_sym_ease] = ACTIONS(584),
    [anon_sym_ease_DASHin] = ACTIONS(584),
    [anon_sym_ease_DASHout] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(584),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(584),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(584),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(584),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(584),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(584),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(584),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(584),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(584),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(584),
    [anon_sym_cubic_DASHbezier] = ACTIONS(584),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(582),
    [anon_sym_ATlinear_gradient] = ACTIONS(582),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(582),
    [anon_sym_ATradial_gradient] = ACTIONS(582),
    [anon_sym_parent] = ACTIONS(584),
    [anon_sym_root] = ACTIONS(584),
    [anon_sym_self] = ACTIONS(584),
    [sym__int_number] = ACTIONS(584),
    [sym__float_number] = ACTIONS(582),
    [anon_sym_true] = ACTIONS(584),
    [anon_sym_false] = ACTIONS(584),
    [sym_color_value] = ACTIONS(582),
    [sym_comment] = ACTIONS(3),
  },
  [205] = {
    [anon_sym_LBRACE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(586),
    [anon_sym_RBRACE] = ACTIONS(586),
    [anon_sym_SEMI] = ACTIONS(586),
    [anon_sym_LT] = ACTIONS(588),
    [anon_sym_GT] = ACTIONS(588),
    [anon_sym_return] = ACTIONS(588),
    [anon_sym_COLON] = ACTIONS(586),
    [anon_sym_LBRACK] = ACTIONS(586),
    [anon_sym_if] = ACTIONS(588),
    [anon_sym_LPAREN] = ACTIONS(586),
    [anon_sym_RPAREN] = ACTIONS(586),
    [anon_sym_ATtr] = ACTIONS(586),
    [anon_sym_DOT] = ACTIONS(588),
    [sym_logical_and] = ACTIONS(586),
    [sym_logical_or] = ACTIONS(586),
    [anon_sym_QMARK] = ACTIONS(586),
    [anon_sym_ATimage_DASHurl] = ACTIONS(586),
    [anon_sym_BANG] = ACTIONS(588),
    [anon_sym_DASH] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(588),
    [anon_sym_STAR] = ACTIONS(588),
    [anon_sym_SLASH] = ACTIONS(588),
    [anon_sym_GT_EQ] = ACTIONS(586),
    [anon_sym_LT_EQ] = ACTIONS(586),
    [anon_sym_EQ_EQ] = ACTIONS(586),
    [anon_sym_BANG_EQ] = ACTIONS(586),
    [anon_sym_EQ] = ACTIONS(588),
    [anon_sym_PLUS_EQ] = ACTIONS(586),
    [anon_sym_DASH_EQ] = ACTIONS(586),
    [anon_sym_STAR_EQ] = ACTIONS(586),
    [anon_sym_SLASH_EQ] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [sym__identifier] = ACTIONS(588),
    [anon_sym_linear] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(588),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(588),
    [anon_sym_ease] = ACTIONS(588),
    [anon_sym_ease_DASHin] = ACTIONS(588),
    [anon_sym_ease_DASHout] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(588),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(588),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(588),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(588),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(588),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(588),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(588),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(588),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(588),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(588),
    [anon_sym_cubic_DASHbezier] = ACTIONS(588),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(586),
    [anon_sym_ATlinear_gradient] = ACTIONS(586),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(586),
    [anon_sym_ATradial_gradient] = ACTIONS(586),
    [anon_sym_parent] = ACTIONS(588),
    [anon_sym_root] = ACTIONS(588),
    [anon_sym_self] = ACTIONS(588),
    [sym__int_number] = ACTIONS(588),
    [sym__float_number] = ACTIONS(586),
    [anon_sym_true] = ACTIONS(588),
    [anon_sym_false] = ACTIONS(588),
    [sym_color_value] = ACTIONS(586),
    [sym_comment] = ACTIONS(3),
  },
  [206] = {
    [anon_sym_LBRACE] = ACTIONS(376),
    [anon_sym_COMMA] = ACTIONS(376),
    [anon_sym_RBRACE] = ACTIONS(376),
    [anon_sym_SEMI] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(378),
    [anon_sym_GT] = ACTIONS(378),
    [anon_sym_return] = ACTIONS(378),
    [anon_sym_COLON] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(376),
    [anon_sym_if] = ACTIONS(378),
    [anon_sym_LPAREN] = ACTIONS(376),
    [anon_sym_RPAREN] = ACTIONS(376),
    [anon_sym_ATtr] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(378),
    [sym_logical_and] = ACTIONS(376),
    [sym_logical_or] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(376),
    [anon_sym_ATimage_DASHurl] = ACTIONS(376),
    [anon_sym_BANG] = ACTIONS(378),
    [anon_sym_DASH] = ACTIONS(378),
    [anon_sym_PLUS] = ACTIONS(378),
    [anon_sym_STAR] = ACTIONS(378),
    [anon_sym_SLASH] = ACTIONS(378),
    [anon_sym_GT_EQ] = ACTIONS(376),
    [anon_sym_LT_EQ] = ACTIONS(376),
    [anon_sym_EQ_EQ] = ACTIONS(376),
    [anon_sym_BANG_EQ] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(378),
    [anon_sym_PLUS_EQ] = ACTIONS(376),
    [anon_sym_DASH_EQ] = ACTIONS(376),
    [anon_sym_STAR_EQ] = ACTIONS(376),
    [anon_sym_SLASH_EQ] = ACTIONS(376),
    [anon_sym_DQUOTE] = ACTIONS(376),
    [sym__identifier] = ACTIONS(378),
    [anon_sym_linear] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(378),
    [anon_sym_ease] = ACTIONS(378),
    [anon_sym_ease_DASHin] = ACTIONS(378),
    [anon_sym_ease_DASHout] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(378),
    [anon_sym_cubic_DASHbezier] = ACTIONS(378),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(376),
    [anon_sym_ATlinear_gradient] = ACTIONS(376),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(376),
    [anon_sym_ATradial_gradient] = ACTIONS(376),
    [anon_sym_parent] = ACTIONS(378),
    [anon_sym_root] = ACTIONS(378),
    [anon_sym_self] = ACTIONS(378),
    [sym__int_number] = ACTIONS(378),
    [sym__float_number] = ACTIONS(376),
    [anon_sym_true] = ACTIONS(378),
    [anon_sym_false] = ACTIONS(378),
    [sym_color_value] = ACTIONS(376),
    [sym_comment] = ACTIONS(3),
  },
  [207] = {
    [anon_sym_LBRACE] = ACTIONS(590),
    [anon_sym_COMMA] = ACTIONS(590),
    [anon_sym_RBRACE] = ACTIONS(590),
    [anon_sym_SEMI] = ACTIONS(590),
    [anon_sym_LT] = ACTIONS(592),
    [anon_sym_GT] = ACTIONS(592),
    [anon_sym_return] = ACTIONS(592),
    [anon_sym_COLON] = ACTIONS(590),
    [anon_sym_LBRACK] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(592),
    [anon_sym_LPAREN] = ACTIONS(590),
    [anon_sym_RPAREN] = ACTIONS(590),
    [anon_sym_ATtr] = ACTIONS(590),
    [anon_sym_DOT] = ACTIONS(592),
    [sym_logical_and] = ACTIONS(590),
    [sym_logical_or] = ACTIONS(590),
    [anon_sym_QMARK] = ACTIONS(590),
    [anon_sym_ATimage_DASHurl] = ACTIONS(590),
    [anon_sym_BANG] = ACTIONS(592),
    [anon_sym_DASH] = ACTIONS(592),
    [anon_sym_PLUS] = ACTIONS(592),
    [anon_sym_STAR] = ACTIONS(592),
    [anon_sym_SLASH] = ACTIONS(592),
    [anon_sym_GT_EQ] = ACTIONS(590),
    [anon_sym_LT_EQ] = ACTIONS(590),
    [anon_sym_EQ_EQ] = ACTIONS(590),
    [anon_sym_BANG_EQ] = ACTIONS(590),
    [anon_sym_EQ] = ACTIONS(592),
    [anon_sym_PLUS_EQ] = ACTIONS(590),
    [anon_sym_DASH_EQ] = ACTIONS(590),
    [anon_sym_STAR_EQ] = ACTIONS(590),
    [anon_sym_SLASH_EQ] = ACTIONS(590),
    [anon_sym_DQUOTE] = ACTIONS(590),
    [sym__identifier] = ACTIONS(592),
    [anon_sym_linear] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(592),
    [anon_sym_ease] = ACTIONS(592),
    [anon_sym_ease_DASHin] = ACTIONS(592),
    [anon_sym_ease_DASHout] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(592),
    [anon_sym_cubic_DASHbezier] = ACTIONS(592),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(590),
    [anon_sym_ATlinear_gradient] = ACTIONS(590),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(590),
    [anon_sym_ATradial_gradient] = ACTIONS(590),
    [anon_sym_parent] = ACTIONS(592),
    [anon_sym_root] = ACTIONS(592),
    [anon_sym_self] = ACTIONS(592),
    [sym__int_number] = ACTIONS(592),
    [sym__float_number] = ACTIONS(590),
    [anon_sym_true] = ACTIONS(592),
    [anon_sym_false] = ACTIONS(592),
    [sym_color_value] = ACTIONS(590),
    [sym_comment] = ACTIONS(3),
  },
  [208] = {
    [anon_sym_LBRACE] = ACTIONS(590),
    [anon_sym_COMMA] = ACTIONS(590),
    [anon_sym_RBRACE] = ACTIONS(590),
    [anon_sym_SEMI] = ACTIONS(590),
    [anon_sym_LT] = ACTIONS(592),
    [anon_sym_GT] = ACTIONS(592),
    [anon_sym_return] = ACTIONS(592),
    [anon_sym_COLON] = ACTIONS(590),
    [anon_sym_LBRACK] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(592),
    [anon_sym_LPAREN] = ACTIONS(590),
    [anon_sym_RPAREN] = ACTIONS(590),
    [anon_sym_ATtr] = ACTIONS(590),
    [anon_sym_DOT] = ACTIONS(592),
    [sym_logical_and] = ACTIONS(590),
    [sym_logical_or] = ACTIONS(590),
    [anon_sym_QMARK] = ACTIONS(590),
    [anon_sym_ATimage_DASHurl] = ACTIONS(590),
    [anon_sym_BANG] = ACTIONS(592),
    [anon_sym_DASH] = ACTIONS(592),
    [anon_sym_PLUS] = ACTIONS(592),
    [anon_sym_STAR] = ACTIONS(592),
    [anon_sym_SLASH] = ACTIONS(592),
    [anon_sym_GT_EQ] = ACTIONS(590),
    [anon_sym_LT_EQ] = ACTIONS(590),
    [anon_sym_EQ_EQ] = ACTIONS(590),
    [anon_sym_BANG_EQ] = ACTIONS(590),
    [anon_sym_EQ] = ACTIONS(592),
    [anon_sym_PLUS_EQ] = ACTIONS(590),
    [anon_sym_DASH_EQ] = ACTIONS(590),
    [anon_sym_STAR_EQ] = ACTIONS(590),
    [anon_sym_SLASH_EQ] = ACTIONS(590),
    [anon_sym_DQUOTE] = ACTIONS(590),
    [sym__identifier] = ACTIONS(592),
    [anon_sym_linear] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(592),
    [anon_sym_ease] = ACTIONS(592),
    [anon_sym_ease_DASHin] = ACTIONS(592),
    [anon_sym_ease_DASHout] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(592),
    [anon_sym_cubic_DASHbezier] = ACTIONS(592),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(590),
    [anon_sym_ATlinear_gradient] = ACTIONS(590),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(590),
    [anon_sym_ATradial_gradient] = ACTIONS(590),
    [anon_sym_parent] = ACTIONS(592),
    [anon_sym_root] = ACTIONS(592),
    [anon_sym_self] = ACTIONS(592),
    [sym__int_number] = ACTIONS(592),
    [sym__float_number] = ACTIONS(590),
    [anon_sym_true] = ACTIONS(592),
    [anon_sym_false] = ACTIONS(592),
    [sym_color_value] = ACTIONS(590),
    [sym_comment] = ACTIONS(3),
  },
  [209] = {
    [anon_sym_LBRACE] = ACTIONS(590),
    [anon_sym_COMMA] = ACTIONS(590),
    [anon_sym_RBRACE] = ACTIONS(590),
    [anon_sym_SEMI] = ACTIONS(590),
    [anon_sym_LT] = ACTIONS(592),
    [anon_sym_GT] = ACTIONS(592),
    [anon_sym_return] = ACTIONS(592),
    [anon_sym_COLON] = ACTIONS(590),
    [anon_sym_LBRACK] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(592),
    [anon_sym_LPAREN] = ACTIONS(590),
    [anon_sym_RPAREN] = ACTIONS(590),
    [anon_sym_ATtr] = ACTIONS(590),
    [anon_sym_DOT] = ACTIONS(592),
    [sym_logical_and] = ACTIONS(590),
    [sym_logical_or] = ACTIONS(590),
    [anon_sym_QMARK] = ACTIONS(590),
    [anon_sym_ATimage_DASHurl] = ACTIONS(590),
    [anon_sym_BANG] = ACTIONS(592),
    [anon_sym_DASH] = ACTIONS(592),
    [anon_sym_PLUS] = ACTIONS(592),
    [anon_sym_STAR] = ACTIONS(592),
    [anon_sym_SLASH] = ACTIONS(592),
    [anon_sym_GT_EQ] = ACTIONS(590),
    [anon_sym_LT_EQ] = ACTIONS(590),
    [anon_sym_EQ_EQ] = ACTIONS(590),
    [anon_sym_BANG_EQ] = ACTIONS(590),
    [anon_sym_EQ] = ACTIONS(592),
    [anon_sym_PLUS_EQ] = ACTIONS(590),
    [anon_sym_DASH_EQ] = ACTIONS(590),
    [anon_sym_STAR_EQ] = ACTIONS(590),
    [anon_sym_SLASH_EQ] = ACTIONS(590),
    [anon_sym_DQUOTE] = ACTIONS(590),
    [sym__identifier] = ACTIONS(592),
    [anon_sym_linear] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(592),
    [anon_sym_ease] = ACTIONS(592),
    [anon_sym_ease_DASHin] = ACTIONS(592),
    [anon_sym_ease_DASHout] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(592),
    [anon_sym_cubic_DASHbezier] = ACTIONS(592),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(590),
    [anon_sym_ATlinear_gradient] = ACTIONS(590),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(590),
    [anon_sym_ATradial_gradient] = ACTIONS(590),
    [anon_sym_parent] = ACTIONS(592),
    [anon_sym_root] = ACTIONS(592),
    [anon_sym_self] = ACTIONS(592),
    [sym__int_number] = ACTIONS(592),
    [sym__float_number] = ACTIONS(590),
    [anon_sym_true] = ACTIONS(592),
    [anon_sym_false] = ACTIONS(592),
    [sym_color_value] = ACTIONS(590),
    [sym_comment] = ACTIONS(3),
  },
  [210] = {
    [anon_sym_LBRACE] = ACTIONS(590),
    [anon_sym_COMMA] = ACTIONS(590),
    [anon_sym_RBRACE] = ACTIONS(590),
    [anon_sym_SEMI] = ACTIONS(590),
    [anon_sym_LT] = ACTIONS(592),
    [anon_sym_GT] = ACTIONS(592),
    [anon_sym_return] = ACTIONS(592),
    [anon_sym_COLON] = ACTIONS(590),
    [anon_sym_LBRACK] = ACTIONS(590),
    [anon_sym_if] = ACTIONS(592),
    [anon_sym_LPAREN] = ACTIONS(590),
    [anon_sym_RPAREN] = ACTIONS(590),
    [anon_sym_ATtr] = ACTIONS(590),
    [anon_sym_DOT] = ACTIONS(592),
    [sym_logical_and] = ACTIONS(590),
    [sym_logical_or] = ACTIONS(590),
    [anon_sym_QMARK] = ACTIONS(590),
    [anon_sym_ATimage_DASHurl] = ACTIONS(590),
    [anon_sym_BANG] = ACTIONS(592),
    [anon_sym_DASH] = ACTIONS(592),
    [anon_sym_PLUS] = ACTIONS(592),
    [anon_sym_STAR] = ACTIONS(592),
    [anon_sym_SLASH] = ACTIONS(592),
    [anon_sym_GT_EQ] = ACTIONS(590),
    [anon_sym_LT_EQ] = ACTIONS(590),
    [anon_sym_EQ_EQ] = ACTIONS(590),
    [anon_sym_BANG_EQ] = ACTIONS(590),
    [anon_sym_EQ] = ACTIONS(592),
    [anon_sym_PLUS_EQ] = ACTIONS(590),
    [anon_sym_DASH_EQ] = ACTIONS(590),
    [anon_sym_STAR_EQ] = ACTIONS(590),
    [anon_sym_SLASH_EQ] = ACTIONS(590),
    [anon_sym_DQUOTE] = ACTIONS(590),
    [sym__identifier] = ACTIONS(592),
    [anon_sym_linear] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(592),
    [anon_sym_ease] = ACTIONS(592),
    [anon_sym_ease_DASHin] = ACTIONS(592),
    [anon_sym_ease_DASHout] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(592),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(592),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(592),
    [anon_sym_cubic_DASHbezier] = ACTIONS(592),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(590),
    [anon_sym_ATlinear_gradient] = ACTIONS(590),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(590),
    [anon_sym_ATradial_gradient] = ACTIONS(590),
    [anon_sym_parent] = ACTIONS(592),
    [anon_sym_root] = ACTIONS(592),
    [anon_sym_self] = ACTIONS(592),
    [sym__int_number] = ACTIONS(592),
    [sym__float_number] = ACTIONS(590),
    [anon_sym_true] = ACTIONS(592),
    [anon_sym_false] = ACTIONS(592),
    [sym_color_value] = ACTIONS(590),
    [sym_comment] = ACTIONS(3),
  },
  [211] = {
    [sym_arguments] = STATE(153),
    [anon_sym_LBRACE] = ACTIONS(376),
    [anon_sym_RBRACE] = ACTIONS(376),
    [anon_sym_SEMI] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(378),
    [anon_sym_GT] = ACTIONS(378),
    [anon_sym_return] = ACTIONS(378),
    [anon_sym_COLON] = ACTIONS(594),
    [anon_sym_LBRACK] = ACTIONS(376),
    [anon_sym_if] = ACTIONS(378),
    [anon_sym_LPAREN] = ACTIONS(380),
    [anon_sym_ATtr] = ACTIONS(376),
    [anon_sym_EQ_GT] = ACTIONS(596),
    [anon_sym_DOT] = ACTIONS(378),
    [sym_logical_and] = ACTIONS(376),
    [sym_logical_or] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(376),
    [anon_sym_ATimage_DASHurl] = ACTIONS(376),
    [anon_sym_BANG] = ACTIONS(378),
    [anon_sym_DASH] = ACTIONS(378),
    [anon_sym_PLUS] = ACTIONS(378),
    [anon_sym_STAR] = ACTIONS(378),
    [anon_sym_SLASH] = ACTIONS(378),
    [anon_sym_GT_EQ] = ACTIONS(376),
    [anon_sym_LT_EQ] = ACTIONS(376),
    [anon_sym_EQ_EQ] = ACTIONS(376),
    [anon_sym_BANG_EQ] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(378),
    [anon_sym_PLUS_EQ] = ACTIONS(376),
    [anon_sym_DASH_EQ] = ACTIONS(376),
    [anon_sym_STAR_EQ] = ACTIONS(376),
    [anon_sym_SLASH_EQ] = ACTIONS(376),
    [anon_sym_DQUOTE] = ACTIONS(376),
    [sym__identifier] = ACTIONS(378),
    [anon_sym_linear] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(378),
    [anon_sym_ease] = ACTIONS(378),
    [anon_sym_ease_DASHin] = ACTIONS(378),
    [anon_sym_ease_DASHout] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(378),
    [anon_sym_cubic_DASHbezier] = ACTIONS(378),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(376),
    [anon_sym_ATlinear_gradient] = ACTIONS(376),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(376),
    [anon_sym_ATradial_gradient] = ACTIONS(376),
    [anon_sym_parent] = ACTIONS(378),
    [anon_sym_root] = ACTIONS(378),
    [anon_sym_self] = ACTIONS(378),
    [sym__int_number] = ACTIONS(378),
    [sym__float_number] = ACTIONS(376),
    [anon_sym_true] = ACTIONS(378),
    [anon_sym_false] = ACTIONS(378),
    [sym_color_value] = ACTIONS(376),
    [sym_comment] = ACTIONS(3),
  },
  [212] = {
    [anon_sym_LBRACE] = ACTIONS(598),
    [anon_sym_COMMA] = ACTIONS(598),
    [anon_sym_RBRACE] = ACTIONS(598),
    [anon_sym_SEMI] = ACTIONS(598),
    [anon_sym_LT] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(600),
    [anon_sym_return] = ACTIONS(600),
    [anon_sym_COLON] = ACTIONS(598),
    [anon_sym_LBRACK] = ACTIONS(598),
    [anon_sym_if] = ACTIONS(600),
    [anon_sym_LPAREN] = ACTIONS(598),
    [anon_sym_RPAREN] = ACTIONS(598),
    [anon_sym_ATtr] = ACTIONS(598),
    [anon_sym_DOT] = ACTIONS(600),
    [sym_logical_and] = ACTIONS(598),
    [sym_logical_or] = ACTIONS(598),
    [anon_sym_QMARK] = ACTIONS(598),
    [anon_sym_ATimage_DASHurl] = ACTIONS(598),
    [anon_sym_BANG] = ACTIONS(600),
    [anon_sym_DASH] = ACTIONS(600),
    [anon_sym_PLUS] = ACTIONS(600),
    [anon_sym_STAR] = ACTIONS(600),
    [anon_sym_SLASH] = ACTIONS(600),
    [anon_sym_GT_EQ] = ACTIONS(598),
    [anon_sym_LT_EQ] = ACTIONS(598),
    [anon_sym_EQ_EQ] = ACTIONS(598),
    [anon_sym_BANG_EQ] = ACTIONS(598),
    [anon_sym_EQ] = ACTIONS(600),
    [anon_sym_PLUS_EQ] = ACTIONS(598),
    [anon_sym_DASH_EQ] = ACTIONS(598),
    [anon_sym_STAR_EQ] = ACTIONS(598),
    [anon_sym_SLASH_EQ] = ACTIONS(598),
    [anon_sym_DQUOTE] = ACTIONS(598),
    [sym__identifier] = ACTIONS(600),
    [anon_sym_linear] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(600),
    [anon_sym_ease] = ACTIONS(600),
    [anon_sym_ease_DASHin] = ACTIONS(600),
    [anon_sym_ease_DASHout] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(600),
    [anon_sym_cubic_DASHbezier] = ACTIONS(600),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(598),
    [anon_sym_ATlinear_gradient] = ACTIONS(598),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(598),
    [anon_sym_ATradial_gradient] = ACTIONS(598),
    [anon_sym_parent] = ACTIONS(600),
    [anon_sym_root] = ACTIONS(600),
    [anon_sym_self] = ACTIONS(600),
    [sym__int_number] = ACTIONS(600),
    [sym__float_number] = ACTIONS(598),
    [anon_sym_true] = ACTIONS(600),
    [anon_sym_false] = ACTIONS(600),
    [sym_color_value] = ACTIONS(598),
    [sym_comment] = ACTIONS(3),
  },
  [213] = {
    [sym_arguments] = STATE(153),
    [anon_sym_LBRACE] = ACTIONS(376),
    [anon_sym_RBRACE] = ACTIONS(376),
    [anon_sym_SEMI] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(378),
    [anon_sym_GT] = ACTIONS(378),
    [anon_sym_return] = ACTIONS(378),
    [anon_sym_COLON] = ACTIONS(602),
    [anon_sym_LBRACK] = ACTIONS(376),
    [anon_sym_if] = ACTIONS(378),
    [anon_sym_LPAREN] = ACTIONS(380),
    [anon_sym_ATtr] = ACTIONS(376),
    [anon_sym_EQ_GT] = ACTIONS(596),
    [anon_sym_DOT] = ACTIONS(378),
    [sym_logical_and] = ACTIONS(376),
    [sym_logical_or] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(376),
    [anon_sym_ATimage_DASHurl] = ACTIONS(376),
    [anon_sym_BANG] = ACTIONS(378),
    [anon_sym_DASH] = ACTIONS(378),
    [anon_sym_PLUS] = ACTIONS(378),
    [anon_sym_STAR] = ACTIONS(378),
    [anon_sym_SLASH] = ACTIONS(378),
    [anon_sym_GT_EQ] = ACTIONS(376),
    [anon_sym_LT_EQ] = ACTIONS(376),
    [anon_sym_EQ_EQ] = ACTIONS(376),
    [anon_sym_BANG_EQ] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(378),
    [anon_sym_PLUS_EQ] = ACTIONS(376),
    [anon_sym_DASH_EQ] = ACTIONS(376),
    [anon_sym_STAR_EQ] = ACTIONS(376),
    [anon_sym_SLASH_EQ] = ACTIONS(376),
    [anon_sym_DQUOTE] = ACTIONS(376),
    [sym__identifier] = ACTIONS(378),
    [anon_sym_linear] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(378),
    [anon_sym_ease] = ACTIONS(378),
    [anon_sym_ease_DASHin] = ACTIONS(378),
    [anon_sym_ease_DASHout] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(378),
    [anon_sym_cubic_DASHbezier] = ACTIONS(378),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(376),
    [anon_sym_ATlinear_gradient] = ACTIONS(376),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(376),
    [anon_sym_ATradial_gradient] = ACTIONS(376),
    [anon_sym_parent] = ACTIONS(378),
    [anon_sym_root] = ACTIONS(378),
    [anon_sym_self] = ACTIONS(378),
    [sym__int_number] = ACTIONS(378),
    [sym__float_number] = ACTIONS(376),
    [anon_sym_true] = ACTIONS(378),
    [anon_sym_false] = ACTIONS(378),
    [sym_color_value] = ACTIONS(376),
    [sym_comment] = ACTIONS(3),
  },
  [214] = {
    [anon_sym_LBRACE] = ACTIONS(604),
    [anon_sym_COMMA] = ACTIONS(604),
    [anon_sym_RBRACE] = ACTIONS(604),
    [anon_sym_SEMI] = ACTIONS(604),
    [anon_sym_LT] = ACTIONS(606),
    [anon_sym_GT] = ACTIONS(606),
    [anon_sym_return] = ACTIONS(606),
    [anon_sym_COLON] = ACTIONS(604),
    [anon_sym_LBRACK] = ACTIONS(604),
    [anon_sym_if] = ACTIONS(606),
    [anon_sym_LPAREN] = ACTIONS(604),
    [anon_sym_RPAREN] = ACTIONS(604),
    [anon_sym_ATtr] = ACTIONS(604),
    [anon_sym_DOT] = ACTIONS(606),
    [sym_logical_and] = ACTIONS(604),
    [sym_logical_or] = ACTIONS(604),
    [anon_sym_QMARK] = ACTIONS(604),
    [anon_sym_ATimage_DASHurl] = ACTIONS(604),
    [anon_sym_BANG] = ACTIONS(606),
    [anon_sym_DASH] = ACTIONS(606),
    [anon_sym_PLUS] = ACTIONS(606),
    [anon_sym_STAR] = ACTIONS(606),
    [anon_sym_SLASH] = ACTIONS(606),
    [anon_sym_GT_EQ] = ACTIONS(604),
    [anon_sym_LT_EQ] = ACTIONS(604),
    [anon_sym_EQ_EQ] = ACTIONS(604),
    [anon_sym_BANG_EQ] = ACTIONS(604),
    [anon_sym_EQ] = ACTIONS(606),
    [anon_sym_PLUS_EQ] = ACTIONS(604),
    [anon_sym_DASH_EQ] = ACTIONS(604),
    [anon_sym_STAR_EQ] = ACTIONS(604),
    [anon_sym_SLASH_EQ] = ACTIONS(604),
    [anon_sym_DQUOTE] = ACTIONS(604),
    [sym__identifier] = ACTIONS(606),
    [anon_sym_linear] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(606),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(606),
    [anon_sym_ease] = ACTIONS(606),
    [anon_sym_ease_DASHin] = ACTIONS(606),
    [anon_sym_ease_DASHout] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(606),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(606),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(606),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(606),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(606),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(606),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(606),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(606),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(606),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(606),
    [anon_sym_cubic_DASHbezier] = ACTIONS(606),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(604),
    [anon_sym_ATlinear_gradient] = ACTIONS(604),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(604),
    [anon_sym_ATradial_gradient] = ACTIONS(604),
    [anon_sym_parent] = ACTIONS(606),
    [anon_sym_root] = ACTIONS(606),
    [anon_sym_self] = ACTIONS(606),
    [sym__int_number] = ACTIONS(606),
    [sym__float_number] = ACTIONS(604),
    [anon_sym_true] = ACTIONS(606),
    [anon_sym_false] = ACTIONS(606),
    [sym_color_value] = ACTIONS(604),
    [sym_comment] = ACTIONS(3),
  },
  [215] = {
    [anon_sym_LBRACE] = ACTIONS(608),
    [anon_sym_COMMA] = ACTIONS(608),
    [anon_sym_RBRACE] = ACTIONS(608),
    [anon_sym_SEMI] = ACTIONS(608),
    [anon_sym_LT] = ACTIONS(610),
    [anon_sym_GT] = ACTIONS(610),
    [anon_sym_return] = ACTIONS(610),
    [anon_sym_COLON] = ACTIONS(608),
    [anon_sym_LBRACK] = ACTIONS(608),
    [anon_sym_if] = ACTIONS(610),
    [anon_sym_LPAREN] = ACTIONS(608),
    [anon_sym_RPAREN] = ACTIONS(608),
    [anon_sym_ATtr] = ACTIONS(608),
    [anon_sym_DOT] = ACTIONS(610),
    [sym_logical_and] = ACTIONS(608),
    [sym_logical_or] = ACTIONS(608),
    [anon_sym_QMARK] = ACTIONS(608),
    [anon_sym_ATimage_DASHurl] = ACTIONS(608),
    [anon_sym_BANG] = ACTIONS(610),
    [anon_sym_DASH] = ACTIONS(610),
    [anon_sym_PLUS] = ACTIONS(610),
    [anon_sym_STAR] = ACTIONS(610),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_GT_EQ] = ACTIONS(608),
    [anon_sym_LT_EQ] = ACTIONS(608),
    [anon_sym_EQ_EQ] = ACTIONS(608),
    [anon_sym_BANG_EQ] = ACTIONS(608),
    [anon_sym_EQ] = ACTIONS(610),
    [anon_sym_PLUS_EQ] = ACTIONS(608),
    [anon_sym_DASH_EQ] = ACTIONS(608),
    [anon_sym_STAR_EQ] = ACTIONS(608),
    [anon_sym_SLASH_EQ] = ACTIONS(608),
    [anon_sym_DQUOTE] = ACTIONS(608),
    [sym__identifier] = ACTIONS(610),
    [anon_sym_linear] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(610),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(610),
    [anon_sym_ease] = ACTIONS(610),
    [anon_sym_ease_DASHin] = ACTIONS(610),
    [anon_sym_ease_DASHout] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(610),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(610),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(610),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(610),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(610),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(610),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(610),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(610),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(610),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(610),
    [anon_sym_cubic_DASHbezier] = ACTIONS(610),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(608),
    [anon_sym_ATlinear_gradient] = ACTIONS(608),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(608),
    [anon_sym_ATradial_gradient] = ACTIONS(608),
    [anon_sym_parent] = ACTIONS(610),
    [anon_sym_root] = ACTIONS(610),
    [anon_sym_self] = ACTIONS(610),
    [sym__int_number] = ACTIONS(610),
    [sym__float_number] = ACTIONS(608),
    [anon_sym_true] = ACTIONS(610),
    [anon_sym_false] = ACTIONS(610),
    [sym_color_value] = ACTIONS(608),
    [sym_comment] = ACTIONS(3),
  },
  [216] = {
    [anon_sym_LBRACE] = ACTIONS(612),
    [anon_sym_COMMA] = ACTIONS(612),
    [anon_sym_RBRACE] = ACTIONS(612),
    [anon_sym_SEMI] = ACTIONS(612),
    [anon_sym_LT] = ACTIONS(614),
    [anon_sym_GT] = ACTIONS(614),
    [anon_sym_return] = ACTIONS(614),
    [anon_sym_COLON] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(612),
    [anon_sym_if] = ACTIONS(614),
    [anon_sym_LPAREN] = ACTIONS(612),
    [anon_sym_RPAREN] = ACTIONS(612),
    [anon_sym_ATtr] = ACTIONS(612),
    [anon_sym_DOT] = ACTIONS(614),
    [sym_logical_and] = ACTIONS(612),
    [sym_logical_or] = ACTIONS(612),
    [anon_sym_QMARK] = ACTIONS(612),
    [anon_sym_ATimage_DASHurl] = ACTIONS(612),
    [anon_sym_BANG] = ACTIONS(614),
    [anon_sym_DASH] = ACTIONS(614),
    [anon_sym_PLUS] = ACTIONS(614),
    [anon_sym_STAR] = ACTIONS(614),
    [anon_sym_SLASH] = ACTIONS(614),
    [anon_sym_GT_EQ] = ACTIONS(612),
    [anon_sym_LT_EQ] = ACTIONS(612),
    [anon_sym_EQ_EQ] = ACTIONS(612),
    [anon_sym_BANG_EQ] = ACTIONS(612),
    [anon_sym_EQ] = ACTIONS(614),
    [anon_sym_PLUS_EQ] = ACTIONS(612),
    [anon_sym_DASH_EQ] = ACTIONS(612),
    [anon_sym_STAR_EQ] = ACTIONS(612),
    [anon_sym_SLASH_EQ] = ACTIONS(612),
    [anon_sym_DQUOTE] = ACTIONS(612),
    [sym__identifier] = ACTIONS(614),
    [anon_sym_linear] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(614),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(614),
    [anon_sym_ease] = ACTIONS(614),
    [anon_sym_ease_DASHin] = ACTIONS(614),
    [anon_sym_ease_DASHout] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(614),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(614),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(614),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(614),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(614),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(614),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(614),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(614),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(614),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(614),
    [anon_sym_cubic_DASHbezier] = ACTIONS(614),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(612),
    [anon_sym_ATlinear_gradient] = ACTIONS(612),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(612),
    [anon_sym_ATradial_gradient] = ACTIONS(612),
    [anon_sym_parent] = ACTIONS(614),
    [anon_sym_root] = ACTIONS(614),
    [anon_sym_self] = ACTIONS(614),
    [sym__int_number] = ACTIONS(614),
    [sym__float_number] = ACTIONS(612),
    [anon_sym_true] = ACTIONS(614),
    [anon_sym_false] = ACTIONS(614),
    [sym_color_value] = ACTIONS(612),
    [sym_comment] = ACTIONS(3),
  },
  [217] = {
    [anon_sym_LBRACE] = ACTIONS(616),
    [anon_sym_COMMA] = ACTIONS(616),
    [anon_sym_RBRACE] = ACTIONS(616),
    [anon_sym_SEMI] = ACTIONS(616),
    [anon_sym_LT] = ACTIONS(618),
    [anon_sym_GT] = ACTIONS(618),
    [anon_sym_return] = ACTIONS(618),
    [anon_sym_COLON] = ACTIONS(616),
    [anon_sym_LBRACK] = ACTIONS(616),
    [anon_sym_if] = ACTIONS(618),
    [anon_sym_LPAREN] = ACTIONS(616),
    [anon_sym_RPAREN] = ACTIONS(616),
    [anon_sym_ATtr] = ACTIONS(616),
    [anon_sym_DOT] = ACTIONS(618),
    [sym_logical_and] = ACTIONS(616),
    [sym_logical_or] = ACTIONS(616),
    [anon_sym_QMARK] = ACTIONS(616),
    [anon_sym_ATimage_DASHurl] = ACTIONS(616),
    [anon_sym_BANG] = ACTIONS(618),
    [anon_sym_DASH] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(618),
    [anon_sym_STAR] = ACTIONS(618),
    [anon_sym_SLASH] = ACTIONS(618),
    [anon_sym_GT_EQ] = ACTIONS(616),
    [anon_sym_LT_EQ] = ACTIONS(616),
    [anon_sym_EQ_EQ] = ACTIONS(616),
    [anon_sym_BANG_EQ] = ACTIONS(616),
    [anon_sym_EQ] = ACTIONS(618),
    [anon_sym_PLUS_EQ] = ACTIONS(616),
    [anon_sym_DASH_EQ] = ACTIONS(616),
    [anon_sym_STAR_EQ] = ACTIONS(616),
    [anon_sym_SLASH_EQ] = ACTIONS(616),
    [anon_sym_DQUOTE] = ACTIONS(616),
    [sym__identifier] = ACTIONS(618),
    [anon_sym_linear] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(618),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(618),
    [anon_sym_ease] = ACTIONS(618),
    [anon_sym_ease_DASHin] = ACTIONS(618),
    [anon_sym_ease_DASHout] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(618),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(618),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(618),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(618),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(618),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(618),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(618),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(618),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(618),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(618),
    [anon_sym_cubic_DASHbezier] = ACTIONS(618),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(616),
    [anon_sym_ATlinear_gradient] = ACTIONS(616),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(616),
    [anon_sym_ATradial_gradient] = ACTIONS(616),
    [anon_sym_parent] = ACTIONS(618),
    [anon_sym_root] = ACTIONS(618),
    [anon_sym_self] = ACTIONS(618),
    [sym__int_number] = ACTIONS(618),
    [sym__float_number] = ACTIONS(616),
    [anon_sym_true] = ACTIONS(618),
    [anon_sym_false] = ACTIONS(618),
    [sym_color_value] = ACTIONS(616),
    [sym_comment] = ACTIONS(3),
  },
  [218] = {
    [anon_sym_LBRACE] = ACTIONS(620),
    [anon_sym_COMMA] = ACTIONS(620),
    [anon_sym_RBRACE] = ACTIONS(620),
    [anon_sym_SEMI] = ACTIONS(620),
    [anon_sym_LT] = ACTIONS(622),
    [anon_sym_GT] = ACTIONS(622),
    [anon_sym_return] = ACTIONS(622),
    [anon_sym_COLON] = ACTIONS(620),
    [anon_sym_LBRACK] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(622),
    [anon_sym_LPAREN] = ACTIONS(620),
    [anon_sym_RPAREN] = ACTIONS(620),
    [anon_sym_ATtr] = ACTIONS(620),
    [anon_sym_DOT] = ACTIONS(622),
    [sym_logical_and] = ACTIONS(620),
    [sym_logical_or] = ACTIONS(620),
    [anon_sym_QMARK] = ACTIONS(620),
    [anon_sym_ATimage_DASHurl] = ACTIONS(620),
    [anon_sym_BANG] = ACTIONS(622),
    [anon_sym_DASH] = ACTIONS(622),
    [anon_sym_PLUS] = ACTIONS(622),
    [anon_sym_STAR] = ACTIONS(622),
    [anon_sym_SLASH] = ACTIONS(622),
    [anon_sym_GT_EQ] = ACTIONS(620),
    [anon_sym_LT_EQ] = ACTIONS(620),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_BANG_EQ] = ACTIONS(620),
    [anon_sym_EQ] = ACTIONS(622),
    [anon_sym_PLUS_EQ] = ACTIONS(620),
    [anon_sym_DASH_EQ] = ACTIONS(620),
    [anon_sym_STAR_EQ] = ACTIONS(620),
    [anon_sym_SLASH_EQ] = ACTIONS(620),
    [anon_sym_DQUOTE] = ACTIONS(620),
    [sym__identifier] = ACTIONS(622),
    [anon_sym_linear] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(622),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(622),
    [anon_sym_ease] = ACTIONS(622),
    [anon_sym_ease_DASHin] = ACTIONS(622),
    [anon_sym_ease_DASHout] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(622),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(622),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(622),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(622),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(622),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(622),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(622),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(622),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(622),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(622),
    [anon_sym_cubic_DASHbezier] = ACTIONS(622),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(620),
    [anon_sym_ATlinear_gradient] = ACTIONS(620),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(620),
    [anon_sym_ATradial_gradient] = ACTIONS(620),
    [anon_sym_parent] = ACTIONS(622),
    [anon_sym_root] = ACTIONS(622),
    [anon_sym_self] = ACTIONS(622),
    [sym__int_number] = ACTIONS(622),
    [sym__float_number] = ACTIONS(620),
    [anon_sym_true] = ACTIONS(622),
    [anon_sym_false] = ACTIONS(622),
    [sym_color_value] = ACTIONS(620),
    [sym_comment] = ACTIONS(3),
  },
  [219] = {
    [anon_sym_LBRACE] = ACTIONS(624),
    [anon_sym_COMMA] = ACTIONS(624),
    [anon_sym_RBRACE] = ACTIONS(624),
    [anon_sym_SEMI] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(626),
    [anon_sym_GT] = ACTIONS(626),
    [anon_sym_return] = ACTIONS(626),
    [anon_sym_COLON] = ACTIONS(624),
    [anon_sym_LBRACK] = ACTIONS(624),
    [anon_sym_if] = ACTIONS(626),
    [anon_sym_LPAREN] = ACTIONS(624),
    [anon_sym_RPAREN] = ACTIONS(624),
    [anon_sym_ATtr] = ACTIONS(624),
    [anon_sym_DOT] = ACTIONS(626),
    [sym_logical_and] = ACTIONS(624),
    [sym_logical_or] = ACTIONS(624),
    [anon_sym_QMARK] = ACTIONS(624),
    [anon_sym_ATimage_DASHurl] = ACTIONS(624),
    [anon_sym_BANG] = ACTIONS(626),
    [anon_sym_DASH] = ACTIONS(626),
    [anon_sym_PLUS] = ACTIONS(626),
    [anon_sym_STAR] = ACTIONS(626),
    [anon_sym_SLASH] = ACTIONS(626),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_EQ_EQ] = ACTIONS(624),
    [anon_sym_BANG_EQ] = ACTIONS(624),
    [anon_sym_EQ] = ACTIONS(626),
    [anon_sym_PLUS_EQ] = ACTIONS(624),
    [anon_sym_DASH_EQ] = ACTIONS(624),
    [anon_sym_STAR_EQ] = ACTIONS(624),
    [anon_sym_SLASH_EQ] = ACTIONS(624),
    [anon_sym_DQUOTE] = ACTIONS(624),
    [sym__identifier] = ACTIONS(626),
    [anon_sym_linear] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(626),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(626),
    [anon_sym_ease] = ACTIONS(626),
    [anon_sym_ease_DASHin] = ACTIONS(626),
    [anon_sym_ease_DASHout] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(626),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(626),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(626),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(626),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(626),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(626),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(626),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(626),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(626),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(626),
    [anon_sym_cubic_DASHbezier] = ACTIONS(626),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(624),
    [anon_sym_ATlinear_gradient] = ACTIONS(624),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(624),
    [anon_sym_ATradial_gradient] = ACTIONS(624),
    [anon_sym_parent] = ACTIONS(626),
    [anon_sym_root] = ACTIONS(626),
    [anon_sym_self] = ACTIONS(626),
    [sym__int_number] = ACTIONS(626),
    [sym__float_number] = ACTIONS(624),
    [anon_sym_true] = ACTIONS(626),
    [anon_sym_false] = ACTIONS(626),
    [sym_color_value] = ACTIONS(624),
    [sym_comment] = ACTIONS(3),
  },
  [220] = {
    [anon_sym_LBRACE] = ACTIONS(628),
    [anon_sym_COMMA] = ACTIONS(628),
    [anon_sym_RBRACE] = ACTIONS(628),
    [anon_sym_SEMI] = ACTIONS(628),
    [anon_sym_LT] = ACTIONS(630),
    [anon_sym_GT] = ACTIONS(630),
    [anon_sym_return] = ACTIONS(630),
    [anon_sym_COLON] = ACTIONS(628),
    [anon_sym_LBRACK] = ACTIONS(628),
    [anon_sym_if] = ACTIONS(630),
    [anon_sym_LPAREN] = ACTIONS(628),
    [anon_sym_RPAREN] = ACTIONS(628),
    [anon_sym_ATtr] = ACTIONS(628),
    [anon_sym_DOT] = ACTIONS(630),
    [sym_logical_and] = ACTIONS(628),
    [sym_logical_or] = ACTIONS(628),
    [anon_sym_QMARK] = ACTIONS(628),
    [anon_sym_ATimage_DASHurl] = ACTIONS(628),
    [anon_sym_BANG] = ACTIONS(630),
    [anon_sym_DASH] = ACTIONS(630),
    [anon_sym_PLUS] = ACTIONS(630),
    [anon_sym_STAR] = ACTIONS(630),
    [anon_sym_SLASH] = ACTIONS(630),
    [anon_sym_GT_EQ] = ACTIONS(628),
    [anon_sym_LT_EQ] = ACTIONS(628),
    [anon_sym_EQ_EQ] = ACTIONS(628),
    [anon_sym_BANG_EQ] = ACTIONS(628),
    [anon_sym_EQ] = ACTIONS(630),
    [anon_sym_PLUS_EQ] = ACTIONS(628),
    [anon_sym_DASH_EQ] = ACTIONS(628),
    [anon_sym_STAR_EQ] = ACTIONS(628),
    [anon_sym_SLASH_EQ] = ACTIONS(628),
    [anon_sym_DQUOTE] = ACTIONS(628),
    [sym__identifier] = ACTIONS(630),
    [anon_sym_linear] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(630),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(630),
    [anon_sym_ease] = ACTIONS(630),
    [anon_sym_ease_DASHin] = ACTIONS(630),
    [anon_sym_ease_DASHout] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(630),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(630),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(630),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(630),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(630),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(630),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(630),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(630),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(630),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(630),
    [anon_sym_cubic_DASHbezier] = ACTIONS(630),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(628),
    [anon_sym_ATlinear_gradient] = ACTIONS(628),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(628),
    [anon_sym_ATradial_gradient] = ACTIONS(628),
    [anon_sym_parent] = ACTIONS(630),
    [anon_sym_root] = ACTIONS(630),
    [anon_sym_self] = ACTIONS(630),
    [sym__int_number] = ACTIONS(630),
    [sym__float_number] = ACTIONS(628),
    [anon_sym_true] = ACTIONS(630),
    [anon_sym_false] = ACTIONS(630),
    [sym_color_value] = ACTIONS(628),
    [sym_comment] = ACTIONS(3),
  },
  [221] = {
    [anon_sym_LBRACE] = ACTIONS(632),
    [anon_sym_COMMA] = ACTIONS(632),
    [anon_sym_RBRACE] = ACTIONS(632),
    [anon_sym_SEMI] = ACTIONS(632),
    [anon_sym_LT] = ACTIONS(634),
    [anon_sym_GT] = ACTIONS(634),
    [anon_sym_return] = ACTIONS(634),
    [anon_sym_COLON] = ACTIONS(632),
    [anon_sym_LBRACK] = ACTIONS(632),
    [anon_sym_if] = ACTIONS(634),
    [anon_sym_LPAREN] = ACTIONS(632),
    [anon_sym_RPAREN] = ACTIONS(632),
    [anon_sym_ATtr] = ACTIONS(632),
    [anon_sym_DOT] = ACTIONS(634),
    [sym_logical_and] = ACTIONS(632),
    [sym_logical_or] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(632),
    [anon_sym_ATimage_DASHurl] = ACTIONS(632),
    [anon_sym_BANG] = ACTIONS(634),
    [anon_sym_DASH] = ACTIONS(634),
    [anon_sym_PLUS] = ACTIONS(634),
    [anon_sym_STAR] = ACTIONS(634),
    [anon_sym_SLASH] = ACTIONS(634),
    [anon_sym_GT_EQ] = ACTIONS(632),
    [anon_sym_LT_EQ] = ACTIONS(632),
    [anon_sym_EQ_EQ] = ACTIONS(632),
    [anon_sym_BANG_EQ] = ACTIONS(632),
    [anon_sym_EQ] = ACTIONS(634),
    [anon_sym_PLUS_EQ] = ACTIONS(632),
    [anon_sym_DASH_EQ] = ACTIONS(632),
    [anon_sym_STAR_EQ] = ACTIONS(632),
    [anon_sym_SLASH_EQ] = ACTIONS(632),
    [anon_sym_DQUOTE] = ACTIONS(632),
    [sym__identifier] = ACTIONS(634),
    [anon_sym_linear] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(634),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(634),
    [anon_sym_ease] = ACTIONS(634),
    [anon_sym_ease_DASHin] = ACTIONS(634),
    [anon_sym_ease_DASHout] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(634),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(634),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(634),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(634),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(634),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(634),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(634),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(634),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(634),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(634),
    [anon_sym_cubic_DASHbezier] = ACTIONS(634),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(632),
    [anon_sym_ATlinear_gradient] = ACTIONS(632),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(632),
    [anon_sym_ATradial_gradient] = ACTIONS(632),
    [anon_sym_parent] = ACTIONS(634),
    [anon_sym_root] = ACTIONS(634),
    [anon_sym_self] = ACTIONS(634),
    [sym__int_number] = ACTIONS(634),
    [sym__float_number] = ACTIONS(632),
    [anon_sym_true] = ACTIONS(634),
    [anon_sym_false] = ACTIONS(634),
    [sym_color_value] = ACTIONS(632),
    [sym_comment] = ACTIONS(3),
  },
  [222] = {
    [anon_sym_LBRACE] = ACTIONS(636),
    [anon_sym_COMMA] = ACTIONS(636),
    [anon_sym_RBRACE] = ACTIONS(636),
    [anon_sym_SEMI] = ACTIONS(636),
    [anon_sym_LT] = ACTIONS(638),
    [anon_sym_GT] = ACTIONS(638),
    [anon_sym_return] = ACTIONS(638),
    [anon_sym_COLON] = ACTIONS(636),
    [anon_sym_LBRACK] = ACTIONS(636),
    [anon_sym_if] = ACTIONS(638),
    [anon_sym_LPAREN] = ACTIONS(636),
    [anon_sym_RPAREN] = ACTIONS(636),
    [anon_sym_ATtr] = ACTIONS(636),
    [anon_sym_DOT] = ACTIONS(638),
    [sym_logical_and] = ACTIONS(636),
    [sym_logical_or] = ACTIONS(636),
    [anon_sym_QMARK] = ACTIONS(636),
    [anon_sym_ATimage_DASHurl] = ACTIONS(636),
    [anon_sym_BANG] = ACTIONS(638),
    [anon_sym_DASH] = ACTIONS(638),
    [anon_sym_PLUS] = ACTIONS(638),
    [anon_sym_STAR] = ACTIONS(638),
    [anon_sym_SLASH] = ACTIONS(638),
    [anon_sym_GT_EQ] = ACTIONS(636),
    [anon_sym_LT_EQ] = ACTIONS(636),
    [anon_sym_EQ_EQ] = ACTIONS(636),
    [anon_sym_BANG_EQ] = ACTIONS(636),
    [anon_sym_EQ] = ACTIONS(638),
    [anon_sym_PLUS_EQ] = ACTIONS(636),
    [anon_sym_DASH_EQ] = ACTIONS(636),
    [anon_sym_STAR_EQ] = ACTIONS(636),
    [anon_sym_SLASH_EQ] = ACTIONS(636),
    [anon_sym_DQUOTE] = ACTIONS(636),
    [sym__identifier] = ACTIONS(638),
    [anon_sym_linear] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(638),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(638),
    [anon_sym_ease] = ACTIONS(638),
    [anon_sym_ease_DASHin] = ACTIONS(638),
    [anon_sym_ease_DASHout] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(638),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(638),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(638),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(638),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(638),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(638),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(638),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(638),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(638),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(638),
    [anon_sym_cubic_DASHbezier] = ACTIONS(638),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(636),
    [anon_sym_ATlinear_gradient] = ACTIONS(636),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(636),
    [anon_sym_ATradial_gradient] = ACTIONS(636),
    [anon_sym_parent] = ACTIONS(638),
    [anon_sym_root] = ACTIONS(638),
    [anon_sym_self] = ACTIONS(638),
    [sym__int_number] = ACTIONS(638),
    [sym__float_number] = ACTIONS(636),
    [anon_sym_true] = ACTIONS(638),
    [anon_sym_false] = ACTIONS(638),
    [sym_color_value] = ACTIONS(636),
    [sym_comment] = ACTIONS(3),
  },
  [223] = {
    [anon_sym_LBRACE] = ACTIONS(640),
    [anon_sym_COMMA] = ACTIONS(640),
    [anon_sym_RBRACE] = ACTIONS(640),
    [anon_sym_SEMI] = ACTIONS(640),
    [anon_sym_LT] = ACTIONS(642),
    [anon_sym_GT] = ACTIONS(642),
    [anon_sym_return] = ACTIONS(642),
    [anon_sym_COLON] = ACTIONS(640),
    [anon_sym_LBRACK] = ACTIONS(640),
    [anon_sym_if] = ACTIONS(642),
    [anon_sym_LPAREN] = ACTIONS(640),
    [anon_sym_RPAREN] = ACTIONS(640),
    [anon_sym_ATtr] = ACTIONS(640),
    [anon_sym_DOT] = ACTIONS(642),
    [sym_logical_and] = ACTIONS(640),
    [sym_logical_or] = ACTIONS(640),
    [anon_sym_QMARK] = ACTIONS(640),
    [anon_sym_ATimage_DASHurl] = ACTIONS(640),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_DASH] = ACTIONS(642),
    [anon_sym_PLUS] = ACTIONS(642),
    [anon_sym_STAR] = ACTIONS(642),
    [anon_sym_SLASH] = ACTIONS(642),
    [anon_sym_GT_EQ] = ACTIONS(640),
    [anon_sym_LT_EQ] = ACTIONS(640),
    [anon_sym_EQ_EQ] = ACTIONS(640),
    [anon_sym_BANG_EQ] = ACTIONS(640),
    [anon_sym_EQ] = ACTIONS(642),
    [anon_sym_PLUS_EQ] = ACTIONS(640),
    [anon_sym_DASH_EQ] = ACTIONS(640),
    [anon_sym_STAR_EQ] = ACTIONS(640),
    [anon_sym_SLASH_EQ] = ACTIONS(640),
    [anon_sym_DQUOTE] = ACTIONS(640),
    [sym__identifier] = ACTIONS(642),
    [anon_sym_linear] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(642),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(642),
    [anon_sym_ease] = ACTIONS(642),
    [anon_sym_ease_DASHin] = ACTIONS(642),
    [anon_sym_ease_DASHout] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(642),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(642),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(642),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(642),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(642),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(642),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(642),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(642),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(642),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(642),
    [anon_sym_cubic_DASHbezier] = ACTIONS(642),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(640),
    [anon_sym_ATlinear_gradient] = ACTIONS(640),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(640),
    [anon_sym_ATradial_gradient] = ACTIONS(640),
    [anon_sym_parent] = ACTIONS(642),
    [anon_sym_root] = ACTIONS(642),
    [anon_sym_self] = ACTIONS(642),
    [sym__int_number] = ACTIONS(642),
    [sym__float_number] = ACTIONS(640),
    [anon_sym_true] = ACTIONS(642),
    [anon_sym_false] = ACTIONS(642),
    [sym_color_value] = ACTIONS(640),
    [sym_comment] = ACTIONS(3),
  },
  [224] = {
    [anon_sym_LBRACE] = ACTIONS(644),
    [anon_sym_COMMA] = ACTIONS(644),
    [anon_sym_RBRACE] = ACTIONS(644),
    [anon_sym_SEMI] = ACTIONS(644),
    [anon_sym_LT] = ACTIONS(646),
    [anon_sym_GT] = ACTIONS(646),
    [anon_sym_return] = ACTIONS(646),
    [anon_sym_COLON] = ACTIONS(644),
    [anon_sym_LBRACK] = ACTIONS(644),
    [anon_sym_if] = ACTIONS(646),
    [anon_sym_LPAREN] = ACTIONS(644),
    [anon_sym_RPAREN] = ACTIONS(644),
    [anon_sym_ATtr] = ACTIONS(644),
    [anon_sym_DOT] = ACTIONS(646),
    [sym_logical_and] = ACTIONS(644),
    [sym_logical_or] = ACTIONS(644),
    [anon_sym_QMARK] = ACTIONS(644),
    [anon_sym_ATimage_DASHurl] = ACTIONS(644),
    [anon_sym_BANG] = ACTIONS(646),
    [anon_sym_DASH] = ACTIONS(646),
    [anon_sym_PLUS] = ACTIONS(646),
    [anon_sym_STAR] = ACTIONS(646),
    [anon_sym_SLASH] = ACTIONS(646),
    [anon_sym_GT_EQ] = ACTIONS(644),
    [anon_sym_LT_EQ] = ACTIONS(644),
    [anon_sym_EQ_EQ] = ACTIONS(644),
    [anon_sym_BANG_EQ] = ACTIONS(644),
    [anon_sym_EQ] = ACTIONS(646),
    [anon_sym_PLUS_EQ] = ACTIONS(644),
    [anon_sym_DASH_EQ] = ACTIONS(644),
    [anon_sym_STAR_EQ] = ACTIONS(644),
    [anon_sym_SLASH_EQ] = ACTIONS(644),
    [anon_sym_DQUOTE] = ACTIONS(644),
    [sym__identifier] = ACTIONS(646),
    [anon_sym_linear] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(646),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(646),
    [anon_sym_ease] = ACTIONS(646),
    [anon_sym_ease_DASHin] = ACTIONS(646),
    [anon_sym_ease_DASHout] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(646),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(646),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(646),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(646),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(646),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(646),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(646),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(646),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(646),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(646),
    [anon_sym_cubic_DASHbezier] = ACTIONS(646),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(644),
    [anon_sym_ATlinear_gradient] = ACTIONS(644),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(644),
    [anon_sym_ATradial_gradient] = ACTIONS(644),
    [anon_sym_parent] = ACTIONS(646),
    [anon_sym_root] = ACTIONS(646),
    [anon_sym_self] = ACTIONS(646),
    [sym__int_number] = ACTIONS(646),
    [sym__float_number] = ACTIONS(644),
    [anon_sym_true] = ACTIONS(646),
    [anon_sym_false] = ACTIONS(646),
    [sym_color_value] = ACTIONS(644),
    [sym_comment] = ACTIONS(3),
  },
  [225] = {
    [anon_sym_LBRACE] = ACTIONS(648),
    [anon_sym_COMMA] = ACTIONS(648),
    [anon_sym_RBRACE] = ACTIONS(648),
    [anon_sym_SEMI] = ACTIONS(648),
    [anon_sym_LT] = ACTIONS(650),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_return] = ACTIONS(650),
    [anon_sym_COLON] = ACTIONS(648),
    [anon_sym_LBRACK] = ACTIONS(648),
    [anon_sym_if] = ACTIONS(650),
    [anon_sym_LPAREN] = ACTIONS(648),
    [anon_sym_RPAREN] = ACTIONS(648),
    [anon_sym_ATtr] = ACTIONS(648),
    [anon_sym_DOT] = ACTIONS(650),
    [sym_logical_and] = ACTIONS(648),
    [sym_logical_or] = ACTIONS(648),
    [anon_sym_QMARK] = ACTIONS(648),
    [anon_sym_ATimage_DASHurl] = ACTIONS(648),
    [anon_sym_BANG] = ACTIONS(650),
    [anon_sym_DASH] = ACTIONS(650),
    [anon_sym_PLUS] = ACTIONS(650),
    [anon_sym_STAR] = ACTIONS(650),
    [anon_sym_SLASH] = ACTIONS(650),
    [anon_sym_GT_EQ] = ACTIONS(648),
    [anon_sym_LT_EQ] = ACTIONS(648),
    [anon_sym_EQ_EQ] = ACTIONS(648),
    [anon_sym_BANG_EQ] = ACTIONS(648),
    [anon_sym_EQ] = ACTIONS(650),
    [anon_sym_PLUS_EQ] = ACTIONS(648),
    [anon_sym_DASH_EQ] = ACTIONS(648),
    [anon_sym_STAR_EQ] = ACTIONS(648),
    [anon_sym_SLASH_EQ] = ACTIONS(648),
    [anon_sym_DQUOTE] = ACTIONS(648),
    [sym__identifier] = ACTIONS(650),
    [anon_sym_linear] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(650),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(650),
    [anon_sym_ease] = ACTIONS(650),
    [anon_sym_ease_DASHin] = ACTIONS(650),
    [anon_sym_ease_DASHout] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(650),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(650),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(650),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(650),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(650),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(650),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(650),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(650),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(650),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(650),
    [anon_sym_cubic_DASHbezier] = ACTIONS(650),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(648),
    [anon_sym_ATlinear_gradient] = ACTIONS(648),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(648),
    [anon_sym_ATradial_gradient] = ACTIONS(648),
    [anon_sym_parent] = ACTIONS(650),
    [anon_sym_root] = ACTIONS(650),
    [anon_sym_self] = ACTIONS(650),
    [sym__int_number] = ACTIONS(650),
    [sym__float_number] = ACTIONS(648),
    [anon_sym_true] = ACTIONS(650),
    [anon_sym_false] = ACTIONS(650),
    [sym_color_value] = ACTIONS(648),
    [sym_comment] = ACTIONS(3),
  },
  [226] = {
    [anon_sym_LBRACE] = ACTIONS(376),
    [anon_sym_RBRACE] = ACTIONS(376),
    [anon_sym_SEMI] = ACTIONS(376),
    [anon_sym_LT] = ACTIONS(378),
    [anon_sym_GT] = ACTIONS(378),
    [anon_sym_return] = ACTIONS(378),
    [anon_sym_COLON] = ACTIONS(376),
    [anon_sym_LBRACK] = ACTIONS(376),
    [anon_sym_if] = ACTIONS(378),
    [anon_sym_LPAREN] = ACTIONS(376),
    [anon_sym_ATtr] = ACTIONS(376),
    [anon_sym_EQ_GT] = ACTIONS(596),
    [anon_sym_DOT] = ACTIONS(378),
    [sym_logical_and] = ACTIONS(376),
    [sym_logical_or] = ACTIONS(376),
    [anon_sym_QMARK] = ACTIONS(376),
    [anon_sym_ATimage_DASHurl] = ACTIONS(376),
    [anon_sym_BANG] = ACTIONS(378),
    [anon_sym_DASH] = ACTIONS(378),
    [anon_sym_PLUS] = ACTIONS(378),
    [anon_sym_STAR] = ACTIONS(378),
    [anon_sym_SLASH] = ACTIONS(378),
    [anon_sym_GT_EQ] = ACTIONS(376),
    [anon_sym_LT_EQ] = ACTIONS(376),
    [anon_sym_EQ_EQ] = ACTIONS(376),
    [anon_sym_BANG_EQ] = ACTIONS(376),
    [anon_sym_EQ] = ACTIONS(378),
    [anon_sym_PLUS_EQ] = ACTIONS(376),
    [anon_sym_DASH_EQ] = ACTIONS(376),
    [anon_sym_STAR_EQ] = ACTIONS(376),
    [anon_sym_SLASH_EQ] = ACTIONS(376),
    [anon_sym_DQUOTE] = ACTIONS(376),
    [sym__identifier] = ACTIONS(378),
    [anon_sym_linear] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(378),
    [anon_sym_ease] = ACTIONS(378),
    [anon_sym_ease_DASHin] = ACTIONS(378),
    [anon_sym_ease_DASHout] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(378),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(378),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(378),
    [anon_sym_cubic_DASHbezier] = ACTIONS(378),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(376),
    [anon_sym_ATlinear_gradient] = ACTIONS(376),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(376),
    [anon_sym_ATradial_gradient] = ACTIONS(376),
    [anon_sym_parent] = ACTIONS(378),
    [anon_sym_root] = ACTIONS(378),
    [anon_sym_self] = ACTIONS(378),
    [sym__int_number] = ACTIONS(378),
    [sym__float_number] = ACTIONS(376),
    [anon_sym_true] = ACTIONS(378),
    [anon_sym_false] = ACTIONS(378),
    [sym_color_value] = ACTIONS(376),
    [sym_comment] = ACTIONS(3),
  },
  [227] = {
    [sym_add_prec_operator] = STATE(107),
    [sym_mult_prec_operator] = STATE(108),
    [sym_comparison_operator] = STATE(109),
    [anon_sym_LBRACE] = ACTIONS(652),
    [anon_sym_RBRACE] = ACTIONS(652),
    [anon_sym_SEMI] = ACTIONS(652),
    [anon_sym_LT] = ACTIONS(352),
    [anon_sym_GT] = ACTIONS(352),
    [anon_sym_return] = ACTIONS(654),
    [anon_sym_LBRACK] = ACTIONS(358),
    [anon_sym_if] = ACTIONS(654),
    [anon_sym_LPAREN] = ACTIONS(652),
    [anon_sym_ATtr] = ACTIONS(652),
    [anon_sym_DOT] = ACTIONS(360),
    [sym_logical_and] = ACTIONS(362),
    [sym_logical_or] = ACTIONS(364),
    [anon_sym_QMARK] = ACTIONS(366),
    [anon_sym_ATimage_DASHurl] = ACTIONS(652),
    [anon_sym_BANG] = ACTIONS(654),
    [anon_sym_DASH] = ACTIONS(656),
    [anon_sym_PLUS] = ACTIONS(656),
    [anon_sym_STAR] = ACTIONS(658),
    [anon_sym_SLASH] = ACTIONS(370),
    [anon_sym_GT_EQ] = ACTIONS(372),
    [anon_sym_LT_EQ] = ACTIONS(372),
    [anon_sym_EQ_EQ] = ACTIONS(372),
    [anon_sym_BANG_EQ] = ACTIONS(372),
    [anon_sym_DQUOTE] = ACTIONS(652),
    [sym__identifier] = ACTIONS(654),
    [anon_sym_linear] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(654),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(654),
    [anon_sym_ease] = ACTIONS(654),
    [anon_sym_ease_DASHin] = ACTIONS(654),
    [anon_sym_ease_DASHout] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(654),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(654),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(654),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(654),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(654),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(654),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(654),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(654),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(654),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(654),
    [anon_sym_cubic_DASHbezier] = ACTIONS(654),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(652),
    [anon_sym_ATlinear_gradient] = ACTIONS(652),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(652),
    [anon_sym_ATradial_gradient] = ACTIONS(652),
    [anon_sym_parent] = ACTIONS(654),
    [anon_sym_root] = ACTIONS(654),
    [anon_sym_self] = ACTIONS(654),
    [sym__int_number] = ACTIONS(654),
    [sym__float_number] = ACTIONS(652),
    [anon_sym_true] = ACTIONS(654),
    [anon_sym_false] = ACTIONS(654),
    [sym_color_value] = ACTIONS(652),
    [sym_comment] = ACTIONS(3),
  },
  [228] = {
    [anon_sym_LBRACE] = ACTIONS(660),
    [anon_sym_COMMA] = ACTIONS(598),
    [anon_sym_RBRACE] = ACTIONS(598),
    [anon_sym_SEMI] = ACTIONS(598),
    [anon_sym_LT] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(600),
    [anon_sym_return] = ACTIONS(662),
    [anon_sym_LBRACK] = ACTIONS(598),
    [anon_sym_if] = ACTIONS(662),
    [anon_sym_LPAREN] = ACTIONS(660),
    [anon_sym_ATtr] = ACTIONS(660),
    [anon_sym_DOT] = ACTIONS(600),
    [sym_logical_and] = ACTIONS(598),
    [sym_logical_or] = ACTIONS(598),
    [anon_sym_QMARK] = ACTIONS(598),
    [anon_sym_ATimage_DASHurl] = ACTIONS(660),
    [anon_sym_BANG] = ACTIONS(662),
    [anon_sym_DASH] = ACTIONS(598),
    [anon_sym_PLUS] = ACTIONS(598),
    [anon_sym_STAR] = ACTIONS(598),
    [anon_sym_SLASH] = ACTIONS(600),
    [anon_sym_GT_EQ] = ACTIONS(598),
    [anon_sym_LT_EQ] = ACTIONS(598),
    [anon_sym_EQ_EQ] = ACTIONS(598),
    [anon_sym_BANG_EQ] = ACTIONS(598),
    [anon_sym_DQUOTE] = ACTIONS(660),
    [sym__identifier] = ACTIONS(662),
    [anon_sym_linear] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(662),
    [anon_sym_ease] = ACTIONS(662),
    [anon_sym_ease_DASHin] = ACTIONS(662),
    [anon_sym_ease_DASHout] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(662),
    [anon_sym_cubic_DASHbezier] = ACTIONS(662),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(660),
    [anon_sym_ATlinear_gradient] = ACTIONS(660),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(660),
    [anon_sym_ATradial_gradient] = ACTIONS(660),
    [anon_sym_parent] = ACTIONS(662),
    [anon_sym_root] = ACTIONS(662),
    [anon_sym_self] = ACTIONS(662),
    [sym__int_number] = ACTIONS(662),
    [sym__float_number] = ACTIONS(660),
    [anon_sym_true] = ACTIONS(662),
    [anon_sym_false] = ACTIONS(662),
    [sym_color_value] = ACTIONS(660),
    [sym_comment] = ACTIONS(3),
  },
  [229] = {
    [anon_sym_LBRACE] = ACTIONS(664),
    [anon_sym_RBRACE] = ACTIONS(664),
    [anon_sym_LT] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(600),
    [anon_sym_COLON] = ACTIONS(598),
    [anon_sym_in] = ACTIONS(666),
    [anon_sym_out] = ACTIONS(666),
    [anon_sym_LBRACK] = ACTIONS(598),
    [anon_sym_LPAREN] = ACTIONS(664),
    [anon_sym_ATtr] = ACTIONS(664),
    [anon_sym_DOT] = ACTIONS(600),
    [sym_logical_and] = ACTIONS(598),
    [sym_logical_or] = ACTIONS(598),
    [anon_sym_QMARK] = ACTIONS(598),
    [anon_sym_ATimage_DASHurl] = ACTIONS(664),
    [anon_sym_BANG] = ACTIONS(666),
    [anon_sym_DASH] = ACTIONS(598),
    [anon_sym_PLUS] = ACTIONS(598),
    [anon_sym_STAR] = ACTIONS(598),
    [anon_sym_SLASH] = ACTIONS(600),
    [anon_sym_GT_EQ] = ACTIONS(598),
    [anon_sym_LT_EQ] = ACTIONS(598),
    [anon_sym_EQ_EQ] = ACTIONS(598),
    [anon_sym_BANG_EQ] = ACTIONS(598),
    [anon_sym_DQUOTE] = ACTIONS(664),
    [sym__identifier] = ACTIONS(666),
    [anon_sym_linear] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(666),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(666),
    [anon_sym_ease] = ACTIONS(666),
    [anon_sym_ease_DASHin] = ACTIONS(666),
    [anon_sym_ease_DASHout] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(666),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(666),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(666),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(666),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(666),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(666),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(666),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(666),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(666),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(666),
    [anon_sym_cubic_DASHbezier] = ACTIONS(666),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(664),
    [anon_sym_ATlinear_gradient] = ACTIONS(664),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(664),
    [anon_sym_ATradial_gradient] = ACTIONS(664),
    [anon_sym_parent] = ACTIONS(666),
    [anon_sym_root] = ACTIONS(666),
    [anon_sym_self] = ACTIONS(666),
    [sym__int_number] = ACTIONS(666),
    [sym__float_number] = ACTIONS(664),
    [anon_sym_true] = ACTIONS(666),
    [anon_sym_false] = ACTIONS(666),
    [sym_color_value] = ACTIONS(664),
    [sym_comment] = ACTIONS(3),
  },
  [230] = {
    [anon_sym_LBRACE] = ACTIONS(668),
    [anon_sym_RBRACE] = ACTIONS(668),
    [anon_sym_SEMI] = ACTIONS(598),
    [anon_sym_LT] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(600),
    [anon_sym_in] = ACTIONS(670),
    [anon_sym_out] = ACTIONS(670),
    [anon_sym_LBRACK] = ACTIONS(598),
    [anon_sym_LPAREN] = ACTIONS(668),
    [anon_sym_ATtr] = ACTIONS(668),
    [anon_sym_DOT] = ACTIONS(600),
    [sym_logical_and] = ACTIONS(598),
    [sym_logical_or] = ACTIONS(598),
    [anon_sym_QMARK] = ACTIONS(598),
    [anon_sym_ATimage_DASHurl] = ACTIONS(668),
    [anon_sym_BANG] = ACTIONS(670),
    [anon_sym_DASH] = ACTIONS(598),
    [anon_sym_PLUS] = ACTIONS(598),
    [anon_sym_STAR] = ACTIONS(598),
    [anon_sym_SLASH] = ACTIONS(600),
    [anon_sym_GT_EQ] = ACTIONS(598),
    [anon_sym_LT_EQ] = ACTIONS(598),
    [anon_sym_EQ_EQ] = ACTIONS(598),
    [anon_sym_BANG_EQ] = ACTIONS(598),
    [anon_sym_DQUOTE] = ACTIONS(668),
    [sym__identifier] = ACTIONS(670),
    [anon_sym_linear] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(670),
    [anon_sym_ease] = ACTIONS(670),
    [anon_sym_ease_DASHin] = ACTIONS(670),
    [anon_sym_ease_DASHout] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(670),
    [anon_sym_cubic_DASHbezier] = ACTIONS(670),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(668),
    [anon_sym_ATlinear_gradient] = ACTIONS(668),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(668),
    [anon_sym_ATradial_gradient] = ACTIONS(668),
    [anon_sym_parent] = ACTIONS(670),
    [anon_sym_root] = ACTIONS(670),
    [anon_sym_self] = ACTIONS(670),
    [sym__int_number] = ACTIONS(670),
    [sym__float_number] = ACTIONS(668),
    [anon_sym_true] = ACTIONS(670),
    [anon_sym_false] = ACTIONS(670),
    [sym_color_value] = ACTIONS(668),
    [sym_comment] = ACTIONS(3),
  },
  [231] = {
    [anon_sym_LBRACE] = ACTIONS(668),
    [anon_sym_RBRACE] = ACTIONS(598),
    [anon_sym_SEMI] = ACTIONS(598),
    [anon_sym_LT] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(600),
    [anon_sym_in] = ACTIONS(670),
    [anon_sym_out] = ACTIONS(670),
    [anon_sym_LBRACK] = ACTIONS(598),
    [anon_sym_LPAREN] = ACTIONS(668),
    [anon_sym_ATtr] = ACTIONS(668),
    [anon_sym_DOT] = ACTIONS(600),
    [sym_logical_and] = ACTIONS(598),
    [sym_logical_or] = ACTIONS(598),
    [anon_sym_QMARK] = ACTIONS(598),
    [anon_sym_ATimage_DASHurl] = ACTIONS(668),
    [anon_sym_BANG] = ACTIONS(670),
    [anon_sym_DASH] = ACTIONS(598),
    [anon_sym_PLUS] = ACTIONS(598),
    [anon_sym_STAR] = ACTIONS(598),
    [anon_sym_SLASH] = ACTIONS(600),
    [anon_sym_GT_EQ] = ACTIONS(598),
    [anon_sym_LT_EQ] = ACTIONS(598),
    [anon_sym_EQ_EQ] = ACTIONS(598),
    [anon_sym_BANG_EQ] = ACTIONS(598),
    [anon_sym_DQUOTE] = ACTIONS(668),
    [sym__identifier] = ACTIONS(670),
    [anon_sym_linear] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(670),
    [anon_sym_ease] = ACTIONS(670),
    [anon_sym_ease_DASHin] = ACTIONS(670),
    [anon_sym_ease_DASHout] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(670),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(670),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(670),
    [anon_sym_cubic_DASHbezier] = ACTIONS(670),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(668),
    [anon_sym_ATlinear_gradient] = ACTIONS(668),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(668),
    [anon_sym_ATradial_gradient] = ACTIONS(668),
    [anon_sym_parent] = ACTIONS(670),
    [anon_sym_root] = ACTIONS(670),
    [anon_sym_self] = ACTIONS(670),
    [sym__int_number] = ACTIONS(670),
    [sym__float_number] = ACTIONS(668),
    [anon_sym_true] = ACTIONS(670),
    [anon_sym_false] = ACTIONS(670),
    [sym_color_value] = ACTIONS(668),
    [sym_comment] = ACTIONS(3),
  },
  [232] = {
    [anon_sym_LBRACE] = ACTIONS(598),
    [anon_sym_RBRACE] = ACTIONS(598),
    [anon_sym_SEMI] = ACTIONS(598),
    [anon_sym_LT] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(600),
    [anon_sym_return] = ACTIONS(600),
    [anon_sym_LBRACK] = ACTIONS(598),
    [anon_sym_if] = ACTIONS(600),
    [anon_sym_LPAREN] = ACTIONS(598),
    [anon_sym_ATtr] = ACTIONS(598),
    [anon_sym_DOT] = ACTIONS(600),
    [sym_logical_and] = ACTIONS(598),
    [sym_logical_or] = ACTIONS(598),
    [anon_sym_QMARK] = ACTIONS(598),
    [anon_sym_ATimage_DASHurl] = ACTIONS(598),
    [anon_sym_BANG] = ACTIONS(600),
    [anon_sym_DASH] = ACTIONS(598),
    [anon_sym_PLUS] = ACTIONS(598),
    [anon_sym_STAR] = ACTIONS(598),
    [anon_sym_SLASH] = ACTIONS(600),
    [anon_sym_GT_EQ] = ACTIONS(598),
    [anon_sym_LT_EQ] = ACTIONS(598),
    [anon_sym_EQ_EQ] = ACTIONS(598),
    [anon_sym_BANG_EQ] = ACTIONS(598),
    [anon_sym_DQUOTE] = ACTIONS(598),
    [sym__identifier] = ACTIONS(600),
    [anon_sym_linear] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(600),
    [anon_sym_ease] = ACTIONS(600),
    [anon_sym_ease_DASHin] = ACTIONS(600),
    [anon_sym_ease_DASHout] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(600),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(600),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(600),
    [anon_sym_cubic_DASHbezier] = ACTIONS(600),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(598),
    [anon_sym_ATlinear_gradient] = ACTIONS(598),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(598),
    [anon_sym_ATradial_gradient] = ACTIONS(598),
    [anon_sym_parent] = ACTIONS(600),
    [anon_sym_root] = ACTIONS(600),
    [anon_sym_self] = ACTIONS(600),
    [sym__int_number] = ACTIONS(600),
    [sym__float_number] = ACTIONS(598),
    [anon_sym_true] = ACTIONS(600),
    [anon_sym_false] = ACTIONS(600),
    [sym_color_value] = ACTIONS(598),
    [sym_comment] = ACTIONS(3),
  },
  [233] = {
    [anon_sym_LBRACE] = ACTIONS(660),
    [anon_sym_RBRACE] = ACTIONS(660),
    [anon_sym_SEMI] = ACTIONS(598),
    [anon_sym_LT] = ACTIONS(600),
    [anon_sym_GT] = ACTIONS(600),
    [anon_sym_return] = ACTIONS(662),
    [anon_sym_LBRACK] = ACTIONS(598),
    [anon_sym_if] = ACTIONS(662),
    [anon_sym_LPAREN] = ACTIONS(660),
    [anon_sym_ATtr] = ACTIONS(660),
    [anon_sym_DOT] = ACTIONS(600),
    [sym_logical_and] = ACTIONS(598),
    [sym_logical_or] = ACTIONS(598),
    [anon_sym_QMARK] = ACTIONS(598),
    [anon_sym_ATimage_DASHurl] = ACTIONS(660),
    [anon_sym_BANG] = ACTIONS(662),
    [anon_sym_DASH] = ACTIONS(598),
    [anon_sym_PLUS] = ACTIONS(598),
    [anon_sym_STAR] = ACTIONS(598),
    [anon_sym_SLASH] = ACTIONS(600),
    [anon_sym_GT_EQ] = ACTIONS(598),
    [anon_sym_LT_EQ] = ACTIONS(598),
    [anon_sym_EQ_EQ] = ACTIONS(598),
    [anon_sym_BANG_EQ] = ACTIONS(598),
    [anon_sym_DQUOTE] = ACTIONS(660),
    [sym__identifier] = ACTIONS(662),
    [anon_sym_linear] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHquad] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHquad] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHquad] = ACTIONS(662),
    [anon_sym_ease] = ACTIONS(662),
    [anon_sym_ease_DASHin] = ACTIONS(662),
    [anon_sym_ease_DASHout] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHquart] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHquart] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHquart] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHquint] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHquint] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHquint] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHexpo] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHexpo] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHexpo] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHsine] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHsine] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHsine] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHback] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHback] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHback] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHcirc] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHcirc] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHcirc] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHelastic] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHelastic] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHelastic] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHbounce] = ACTIONS(662),
    [anon_sym_ease_DASHout_DASHbounce] = ACTIONS(662),
    [anon_sym_ease_DASHin_DASHout_DASHbounce] = ACTIONS(662),
    [anon_sym_cubic_DASHbezier] = ACTIONS(662),
    [anon_sym_ATlinear_DASHgradient] = ACTIONS(660),
    [anon_sym_ATlinear_gradient] = ACTIONS(660),
    [anon_sym_ATradial_DASHgradient] = ACTIONS(660),
    [anon_sym_ATradial_gradient] = ACTIONS(660),
    [anon_sym_parent] = ACTIONS(662),
    [anon_sym_root] = ACTIONS(662),
    [anon_sym_self] = ACTIONS(662),
    [sym__int_number] = ACTIONS(662),
    [sym__float_number] = ACTIONS(660),
    [anon_sym_true] = ACTIONS(662),
    [anon_sym_false] = ACTIONS(662),
    [sym_color_value] = ACTIONS(660),
    [sym_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(676), 1,
      anon_sym_else,
    ACTIONS(672), 17,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(674), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [70] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(678), 17,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(680), 43,
      anon_sym_return,
      anon_sym_if,
      anon_sym_else,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [138] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(660), 17,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(662), 43,
      anon_sym_return,
      anon_sym_if,
      anon_sym_else,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [206] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(682), 17,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(684), 42,
      anon_sym_in,
      anon_sym_out,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [273] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(686), 17,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(688), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [340] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(690), 17,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(692), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [407] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(694), 17,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(696), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [474] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(700), 1,
      anon_sym_SEMI,
    ACTIONS(698), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(703), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [543] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(707), 1,
      anon_sym_SEMI,
    ACTIONS(705), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(710), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [612] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(712), 1,
      anon_sym_SEMI,
    ACTIONS(698), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(703), 42,
      anon_sym_in,
      anon_sym_out,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [681] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(304), 1,
      anon_sym_SEMI,
    ACTIONS(350), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(354), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [750] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(715), 1,
      anon_sym_SEMI,
    ACTIONS(705), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(710), 42,
      anon_sym_in,
      anon_sym_out,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [819] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(719), 1,
      anon_sym_SEMI,
    ACTIONS(717), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(721), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [888] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(678), 17,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(680), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [955] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(682), 17,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(684), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1022] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(686), 17,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(688), 42,
      anon_sym_in,
      anon_sym_out,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1089] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(660), 17,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(662), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1156] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(723), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(725), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1222] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(183), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(727), 42,
      anon_sym_in,
      anon_sym_out,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1288] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(729), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(731), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1354] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(690), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(692), 42,
      anon_sym_in,
      anon_sym_out,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1420] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(733), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(735), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(737), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(739), 42,
      anon_sym_in,
      anon_sym_out,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1552] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(741), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(743), 42,
      anon_sym_in,
      anon_sym_out,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1618] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(745), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(747), 42,
      anon_sym_in,
      anon_sym_out,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1684] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(751), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1750] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(753), 16,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(755), 42,
      anon_sym_return,
      anon_sym_if,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1816] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(757), 15,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(759), 40,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1879] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 15,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(763), 40,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [1942] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(765), 15,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(767), 40,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [2005] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(769), 15,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(771), 40,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [2068] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(773), 15,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(775), 40,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [2131] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(777), 15,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_ATtr,
      anon_sym_ATimage_DASHurl,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_DQUOTE,
      anon_sym_ATlinear_DASHgradient,
      anon_sym_ATlinear_gradient,
      anon_sym_ATradial_DASHgradient,
      anon_sym_ATradial_gradient,
      sym__float_number,
      sym_color_value,
    ACTIONS(779), 40,
      sym__identifier,
      anon_sym_linear,
      anon_sym_ease_DASHin_DASHquad,
      anon_sym_ease_DASHout_DASHquad,
      anon_sym_ease_DASHin_DASHout_DASHquad,
      anon_sym_ease,
      anon_sym_ease_DASHin,
      anon_sym_ease_DASHout,
      anon_sym_ease_DASHin_DASHout,
      anon_sym_ease_DASHin_DASHquart,
      anon_sym_ease_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHout_DASHquart,
      anon_sym_ease_DASHin_DASHquint,
      anon_sym_ease_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHout_DASHquint,
      anon_sym_ease_DASHin_DASHexpo,
      anon_sym_ease_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHout_DASHexpo,
      anon_sym_ease_DASHin_DASHsine,
      anon_sym_ease_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHout_DASHsine,
      anon_sym_ease_DASHin_DASHback,
      anon_sym_ease_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHout_DASHback,
      anon_sym_ease_DASHin_DASHcirc,
      anon_sym_ease_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHout_DASHcirc,
      anon_sym_ease_DASHin_DASHelastic,
      anon_sym_ease_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHout_DASHelastic,
      anon_sym_ease_DASHin_DASHbounce,
      anon_sym_ease_DASHout_DASHbounce,
      anon_sym_ease_DASHin_DASHout_DASHbounce,
      anon_sym_cubic_DASHbezier,
      anon_sym_parent,
      anon_sym_root,
      anon_sym_self,
      sym__int_number,
      anon_sym_true,
      anon_sym_false,
  [2194] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(781), 1,
      anon_sym_COMMA,
    ACTIONS(783), 1,
      anon_sym_RBRACE,
    ACTIONS(785), 1,
      anon_sym_property,
    ACTIONS(789), 1,
      anon_sym_transitions,
    ACTIONS(791), 1,
      anon_sym_states,
    ACTIONS(793), 1,
      anon_sym_animate,
    ACTIONS(795), 1,
      anon_sym_if,
    ACTIONS(797), 1,
      anon_sym_for,
    ACTIONS(799), 1,
      anon_sym_callback,
    ACTIONS(801), 1,
      anon_sym_pure,
    ACTIONS(803), 1,
      anon_sym_public,
    ACTIONS(805), 1,
      anon_sym_private,
    ACTIONS(807), 1,
      anon_sym_function,
    ACTIONS(809), 1,
      anon_sym_changed,
    ACTIONS(811), 1,
      sym__identifier,
    ACTIONS(813), 1,
      sym_children_identifier,
    STATE(588), 1,
      sym_simple_identifier,
    STATE(620), 1,
      sym_purity,
    STATE(740), 1,
      sym_property_visibility,
    STATE(790), 1,
      sym_user_type_identifier,
    STATE(857), 1,
      sym_function_call,
    STATE(584), 2,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
    ACTIONS(787), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_in_DASHout,
    STATE(275), 16,
      sym_component,
      sym_property,
      sym_binding_alias,
      sym__block_statement,
      sym_property_assignment,
      sym_transitions_definition,
      sym_states_definition,
      sym_animate_statement,
      sym_if_statement,
      sym_for_loop,
      sym_callback,
      sym_function_definition,
      sym_callback_alias,
      sym_callback_event,
      sym_changed_callback,
      aux_sym_block_repeat1,
  [2288] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_COMMA,
    ACTIONS(785), 1,
      anon_sym_property,
    ACTIONS(789), 1,
      anon_sym_transitions,
    ACTIONS(791), 1,
      anon_sym_states,
    ACTIONS(793), 1,
      anon_sym_animate,
    ACTIONS(795), 1,
      anon_sym_if,
    ACTIONS(797), 1,
      anon_sym_for,
    ACTIONS(799), 1,
      anon_sym_callback,
    ACTIONS(801), 1,
      anon_sym_pure,
    ACTIONS(803), 1,
      anon_sym_public,
    ACTIONS(805), 1,
      anon_sym_private,
    ACTIONS(807), 1,
      anon_sym_function,
    ACTIONS(809), 1,
      anon_sym_changed,
    ACTIONS(811), 1,
      sym__identifier,
    ACTIONS(815), 1,
      anon_sym_RBRACE,
    ACTIONS(817), 1,
      sym_children_identifier,
    STATE(600), 1,
      sym_simple_identifier,
    STATE(620), 1,
      sym_purity,
    STATE(740), 1,
      sym_property_visibility,
    STATE(790), 1,
      sym_user_type_identifier,
    STATE(857), 1,
      sym_function_call,
    STATE(584), 2,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
    ACTIONS(787), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_in_DASHout,
    STATE(270), 16,
      sym_component,
      sym_property,
      sym_binding_alias,
      sym__block_statement,
      sym_property_assignment,
      sym_transitions_definition,
      sym_states_definition,
      sym_animate_statement,
      sym_if_statement,
      sym_for_loop,
      sym_callback,
      sym_function_definition,
      sym_callback_alias,
      sym_callback_event,
      sym_changed_callback,
      aux_sym_block_repeat1,
  [2382] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_COMMA,
    ACTIONS(785), 1,
      anon_sym_property,
    ACTIONS(789), 1,
      anon_sym_transitions,
    ACTIONS(791), 1,
      anon_sym_states,
    ACTIONS(793), 1,
      anon_sym_animate,
    ACTIONS(795), 1,
      anon_sym_if,
    ACTIONS(797), 1,
      anon_sym_for,
    ACTIONS(799), 1,
      anon_sym_callback,
    ACTIONS(801), 1,
      anon_sym_pure,
    ACTIONS(803), 1,
      anon_sym_public,
    ACTIONS(805), 1,
      anon_sym_private,
    ACTIONS(807), 1,
      anon_sym_function,
    ACTIONS(809), 1,
      anon_sym_changed,
    ACTIONS(811), 1,
      sym__identifier,
    ACTIONS(817), 1,
      sym_children_identifier,
    ACTIONS(819), 1,
      anon_sym_RBRACE,
    STATE(600), 1,
      sym_simple_identifier,
    STATE(620), 1,
      sym_purity,
    STATE(740), 1,
      sym_property_visibility,
    STATE(790), 1,
      sym_user_type_identifier,
    STATE(857), 1,
      sym_function_call,
    STATE(584), 2,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
    ACTIONS(787), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_in_DASHout,
    STATE(270), 16,
      sym_component,
      sym_property,
      sym_binding_alias,
      sym__block_statement,
      sym_property_assignment,
      sym_transitions_definition,
      sym_states_definition,
      sym_animate_statement,
      sym_if_statement,
      sym_for_loop,
      sym_callback,
      sym_function_definition,
      sym_callback_alias,
      sym_callback_event,
      sym_changed_callback,
      aux_sym_block_repeat1,
  [2476] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(785), 1,
      anon_sym_property,
    ACTIONS(789), 1,
      anon_sym_transitions,
    ACTIONS(791), 1,
      anon_sym_states,
    ACTIONS(793), 1,
      anon_sym_animate,
    ACTIONS(795), 1,
      anon_sym_if,
    ACTIONS(797), 1,
      anon_sym_for,
    ACTIONS(799), 1,
      anon_sym_callback,
    ACTIONS(801), 1,
      anon_sym_pure,
    ACTIONS(803), 1,
      anon_sym_public,
    ACTIONS(805), 1,
      anon_sym_private,
    ACTIONS(807), 1,
      anon_sym_function,
    ACTIONS(809), 1,
      anon_sym_changed,
    ACTIONS(811), 1,
      sym__identifier,
    ACTIONS(821), 1,
      anon_sym_RBRACE,
    ACTIONS(823), 1,
      sym_children_identifier,
    STATE(591), 1,
      sym_simple_identifier,
    STATE(620), 1,
      sym_purity,
    STATE(740), 1,
      sym_property_visibility,
    STATE(790), 1,
      sym_user_type_identifier,
    STATE(857), 1,
      sym_function_call,
    STATE(584), 2,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
    ACTIONS(787), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_in_DASHout,
    STATE(272), 16,
      sym_component,
      sym_property,
      sym_binding_alias,
      sym__block_statement,
      sym_property_assignment,
      sym_transitions_definition,
      sym_states_definition,
      sym_animate_statement,
      sym_if_statement,
      sym_for_loop,
      sym_callback,
      sym_function_definition,
      sym_callback_alias,
      sym_callback_event,
      sym_changed_callback,
      aux_sym_block_repeat1,
  [2567] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(785), 1,
      anon_sym_property,
    ACTIONS(789), 1,
      anon_sym_transitions,
    ACTIONS(791), 1,
      anon_sym_states,
    ACTIONS(793), 1,
      anon_sym_animate,
    ACTIONS(795), 1,
      anon_sym_if,
    ACTIONS(797), 1,
      anon_sym_for,
    ACTIONS(799), 1,
      anon_sym_callback,
    ACTIONS(801), 1,
      anon_sym_pure,
    ACTIONS(803), 1,
      anon_sym_public,
    ACTIONS(805), 1,
      anon_sym_private,
    ACTIONS(807), 1,
      anon_sym_function,
    ACTIONS(809), 1,
      anon_sym_changed,
    ACTIONS(811), 1,
      sym__identifier,
    ACTIONS(825), 1,
      anon_sym_RBRACE,
    ACTIONS(827), 1,
      sym_children_identifier,
    STATE(591), 1,
      sym_simple_identifier,
    STATE(620), 1,
      sym_purity,
    STATE(740), 1,
      sym_property_visibility,
    STATE(790), 1,
      sym_user_type_identifier,
    STATE(857), 1,
      sym_function_call,
    STATE(584), 2,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
    ACTIONS(787), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_in_DASHout,
    STATE(273), 16,
      sym_component,
      sym_property,
      sym_binding_alias,
      sym__block_statement,
      sym_property_assignment,
      sym_transitions_definition,
      sym_states_definition,
      sym_animate_statement,
      sym_if_statement,
      sym_for_loop,
      sym_callback,
      sym_function_definition,
      sym_callback_alias,
      sym_callback_event,
      sym_changed_callback,
      aux_sym_block_repeat1,
  [2658] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(829), 1,
      anon_sym_RBRACE,
    ACTIONS(831), 1,
      anon_sym_property,
    ACTIONS(837), 1,
      anon_sym_transitions,
    ACTIONS(840), 1,
      anon_sym_states,
    ACTIONS(843), 1,
      anon_sym_animate,
    ACTIONS(846), 1,
      anon_sym_if,
    ACTIONS(849), 1,
      anon_sym_for,
    ACTIONS(852), 1,
      anon_sym_callback,
    ACTIONS(855), 1,
      anon_sym_pure,
    ACTIONS(858), 1,
      anon_sym_public,
    ACTIONS(861), 1,
      anon_sym_private,
    ACTIONS(864), 1,
      anon_sym_function,
    ACTIONS(867), 1,
      anon_sym_changed,
    ACTIONS(870), 1,
      sym__identifier,
    ACTIONS(873), 1,
      sym_children_identifier,
    STATE(591), 1,
      sym_simple_identifier,
    STATE(620), 1,
      sym_purity,
    STATE(740), 1,
      sym_property_visibility,
    STATE(790), 1,
      sym_user_type_identifier,
    STATE(857), 1,
      sym_function_call,
    STATE(584), 2,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
    ACTIONS(834), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_in_DASHout,
    STATE(272), 16,
      sym_component,
      sym_property,
      sym_binding_alias,
      sym__block_statement,
      sym_property_assignment,
      sym_transitions_definition,
      sym_states_definition,
      sym_animate_statement,
      sym_if_statement,
      sym_for_loop,
      sym_callback,
      sym_function_definition,
      sym_callback_alias,
      sym_callback_event,
      sym_changed_callback,
      aux_sym_block_repeat1,
  [2749] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(785), 1,
      anon_sym_property,
    ACTIONS(789), 1,
      anon_sym_transitions,
    ACTIONS(791), 1,
      anon_sym_states,
    ACTIONS(793), 1,
      anon_sym_animate,
    ACTIONS(795), 1,
      anon_sym_if,
    ACTIONS(797), 1,
      anon_sym_for,
    ACTIONS(799), 1,
      anon_sym_callback,
    ACTIONS(801), 1,
      anon_sym_pure,
    ACTIONS(803), 1,
      anon_sym_public,
    ACTIONS(805), 1,
      anon_sym_private,
    ACTIONS(807), 1,
      anon_sym_function,
    ACTIONS(809), 1,
      anon_sym_changed,
    ACTIONS(811), 1,
      sym__identifier,
    ACTIONS(823), 1,
      sym_children_identifier,
    ACTIONS(876), 1,
      anon_sym_RBRACE,
    STATE(591), 1,
      sym_simple_identifier,
    STATE(620), 1,
      sym_purity,
    STATE(740), 1,
      sym_property_visibility,
    STATE(790), 1,
      sym_user_type_identifier,
    STATE(857), 1,
      sym_function_call,
    STATE(584), 2,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
    ACTIONS(787), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_in_DASHout,
    STATE(272), 16,
      sym_component,
      sym_property,
      sym_binding_alias,
      sym__block_statement,
      sym_property_assignment,
      sym_transitions_definition,
      sym_states_definition,
      sym_animate_statement,
      sym_if_statement,
      sym_for_loop,
      sym_callback,
      sym_function_definition,
      sym_callback_alias,
      sym_callback_event,
      sym_changed_callback,
      aux_sym_block_repeat1,
  [2840] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(785), 1,
      anon_sym_property,
    ACTIONS(789), 1,
      anon_sym_transitions,
    ACTIONS(791), 1,
      anon_sym_states,
    ACTIONS(793), 1,
      anon_sym_animate,
    ACTIONS(795), 1,
      anon_sym_if,
    ACTIONS(797), 1,
      anon_sym_for,
    ACTIONS(799), 1,
      anon_sym_callback,
    ACTIONS(801), 1,
      anon_sym_pure,
    ACTIONS(803), 1,
      anon_sym_public,
    ACTIONS(805), 1,
      anon_sym_private,
    ACTIONS(807), 1,
      anon_sym_function,
    ACTIONS(809), 1,
      anon_sym_changed,
    ACTIONS(811), 1,
      sym__identifier,
    ACTIONS(823), 1,
      sym_children_identifier,
    ACTIONS(878), 1,
      anon_sym_RBRACE,
    STATE(591), 1,
      sym_simple_identifier,
    STATE(620), 1,
      sym_purity,
    STATE(740), 1,
      sym_property_visibility,
    STATE(790), 1,
      sym_user_type_identifier,
    STATE(857), 1,
      sym_function_call,
    STATE(584), 2,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
    ACTIONS(787), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_in_DASHout,
    STATE(272), 16,
      sym_component,
      sym_property,
      sym_binding_alias,
      sym__block_statement,
      sym_property_assignment,
      sym_transitions_definition,
      sym_states_definition,
      sym_animate_statement,
      sym_if_statement,
      sym_for_loop,
      sym_callback,
      sym_function_definition,
      sym_callback_alias,
      sym_callback_event,
      sym_changed_callback,
      aux_sym_block_repeat1,
  [2931] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(785), 1,
      anon_sym_property,
    ACTIONS(789), 1,
      anon_sym_transitions,
    ACTIONS(791), 1,
      anon_sym_states,
    ACTIONS(793), 1,
      anon_sym_animate,
    ACTIONS(795), 1,
      anon_sym_if,
    ACTIONS(797), 1,
      anon_sym_for,
    ACTIONS(799), 1,
      anon_sym_callback,
    ACTIONS(801), 1,
      anon_sym_pure,
    ACTIONS(803), 1,
      anon_sym_public,
    ACTIONS(805), 1,
      anon_sym_private,
    ACTIONS(807), 1,
      anon_sym_function,
    ACTIONS(809), 1,
      anon_sym_changed,
    ACTIONS(811), 1,
      sym__identifier,
    ACTIONS(823), 1,
      sym_children_identifier,
    ACTIONS(880), 1,
      anon_sym_RBRACE,
    STATE(591), 1,
      sym_simple_identifier,
    STATE(620), 1,
      sym_purity,
    STATE(740), 1,
      sym_property_visibility,
    STATE(790), 1,
      sym_user_type_identifier,
    STATE(857), 1,
      sym_function_call,
    STATE(584), 2,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
    ACTIONS(787), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_in_DASHout,
    STATE(272), 16,
      sym_component,
      sym_property,
      sym_binding_alias,
      sym__block_statement,
      sym_property_assignment,
      sym_transitions_definition,
      sym_states_definition,
      sym_animate_statement,
      sym_if_statement,
      sym_for_loop,
      sym_callback,
      sym_function_definition,
      sym_callback_alias,
      sym_callback_event,
      sym_changed_callback,
      aux_sym_block_repeat1,
  [3022] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(785), 1,
      anon_sym_property,
    ACTIONS(789), 1,
      anon_sym_transitions,
    ACTIONS(791), 1,
      anon_sym_states,
    ACTIONS(793), 1,
      anon_sym_animate,
    ACTIONS(795), 1,
      anon_sym_if,
    ACTIONS(797), 1,
      anon_sym_for,
    ACTIONS(799), 1,
      anon_sym_callback,
    ACTIONS(801), 1,
      anon_sym_pure,
    ACTIONS(803), 1,
      anon_sym_public,
    ACTIONS(805), 1,
      anon_sym_private,
    ACTIONS(807), 1,
      anon_sym_function,
    ACTIONS(809), 1,
      anon_sym_changed,
    ACTIONS(811), 1,
      sym__identifier,
    ACTIONS(882), 1,
      anon_sym_RBRACE,
    ACTIONS(884), 1,
      sym_children_identifier,
    STATE(591), 1,
      sym_simple_identifier,
    STATE(620), 1,
      sym_purity,
    STATE(740), 1,
      sym_property_visibility,
    STATE(790), 1,
      sym_user_type_identifier,
    STATE(857), 1,
      sym_function_call,
    STATE(584), 2,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
    ACTIONS(787), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_in_DASHout,
    STATE(274), 16,
      sym_component,
      sym_property,
      sym_binding_alias,
      sym__block_statement,
      sym_property_assignment,
      sym_transitions_definition,
      sym_states_definition,
      sym_animate_statement,
      sym_if_statement,
      sym_for_loop,
      sym_callback,
      sym_function_definition,
      sym_callback_alias,
      sym_callback_event,
      sym_changed_callback,
      aux_sym_block_repeat1,
  [3113] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(660), 1,
      sym_children_identifier,
    ACTIONS(600), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SLASH,
    ACTIONS(598), 15,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(662), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [3160] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(660), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(600), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SLASH,
    ACTIONS(598), 13,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(662), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [3206] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(432), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ,
    ACTIONS(430), 25,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LT_EQ_GT,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_EQ_GT,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3247] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(344), 6,
      anon_sym_phx,
      aux_sym_length_value_token1,
      aux_sym_duration_value_token1,
      aux_sym_angle_value_token1,
      anon_sym_PERCENT2,
      anon_sym_rem,
    ACTIONS(348), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(346), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3290] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(344), 6,
      anon_sym_phx,
      aux_sym_length_value_token1,
      aux_sym_duration_value_token1,
      aux_sym_angle_value_token1,
      anon_sym_PERCENT2,
      anon_sym_rem,
    ACTIONS(340), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(338), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3333] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(388), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(386), 18,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3381] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(472), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(470), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_EQ_GT,
      anon_sym_PERCENT,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3419] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(370), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(420), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
    ACTIONS(418), 18,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3471] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(408), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(406), 18,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3519] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(400), 1,
      anon_sym_EQ,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(370), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(398), 14,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(460), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(458), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_EQ_GT,
      anon_sym_PERCENT,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3613] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(428), 1,
      anon_sym_EQ,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(370), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(426), 13,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3671] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(456), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(454), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_EQ_GT,
      anon_sym_PERCENT,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3709] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(396), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(394), 19,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3755] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(400), 1,
      anon_sym_EQ,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(370), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(398), 13,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3813] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(370), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(404), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_EQ,
    ACTIONS(402), 18,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3863] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(892), 1,
      anon_sym_LPAREN,
    STATE(295), 1,
      sym_arguments,
    ACTIONS(378), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(376), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3904] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(424), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(422), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_EQ_GT,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(384), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(382), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_EQ_GT,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [3976] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(392), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(390), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_EQ_GT,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4012] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(416), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(414), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_EQ_GT,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4048] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(412), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(410), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_EQ_GT,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4084] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(568), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(566), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4119] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(584), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(582), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4154] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(378), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(376), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4189] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(592), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(590), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4224] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(592), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(590), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4259] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(592), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(590), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4294] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(592), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(590), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4329] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(464), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(462), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4364] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(468), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(466), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4399] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(476), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(474), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4434] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(480), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(478), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4469] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(484), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(482), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4504] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(488), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(486), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4539] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(492), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(490), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4574] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(496), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(494), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4609] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(500), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(498), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4644] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(504), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(502), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4679] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(508), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(506), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4714] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(512), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(510), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4749] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(516), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(514), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4784] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(520), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(518), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4819] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(524), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(522), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4854] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(528), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(526), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4889] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(532), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(530), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4924] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(536), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(534), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4959] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(600), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(598), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [4994] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(540), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(538), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5029] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(544), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(542), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5064] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(606), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(604), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5099] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(436), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(434), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5134] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(548), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(546), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(552), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(550), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5204] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(556), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(554), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5239] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(560), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(558), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5274] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(564), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(562), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5309] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(610), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(608), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5344] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(650), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(648), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5379] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(588), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(586), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5414] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(614), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(612), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5449] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(618), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(616), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5484] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(622), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(620), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5519] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(626), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(624), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5554] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(630), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(628), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(634), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(632), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5624] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(660), 1,
      anon_sym_RBRACE,
    ACTIONS(600), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SLASH,
    ACTIONS(662), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
    ACTIONS(598), 13,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [5663] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(638), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(636), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5698] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(642), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(640), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5733] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(646), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(644), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5768] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(440), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(438), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5803] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(444), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(442), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5838] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(448), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(446), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5873] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(452), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(450), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5908] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(576), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(574), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5943] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(580), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(578), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [5978] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(572), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_EQ,
    ACTIONS(570), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [6013] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(374), 1,
      anon_sym_EQ,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(265), 1,
      sym_assignment_prec_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(370), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(356), 5,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
  [6072] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(900), 1,
      anon_sym_COMMA,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    ACTIONS(904), 1,
      anon_sym_RBRACK,
    STATE(697), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6117] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(348), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym__int_number,
    ACTIONS(344), 6,
      anon_sym_phx,
      aux_sym_length_value_token1,
      aux_sym_duration_value_token1,
      aux_sym_angle_value_token1,
      anon_sym_PERCENT2,
      anon_sym_rem,
    ACTIONS(346), 14,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym__float_number,
  [6152] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(340), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym__int_number,
    ACTIONS(344), 6,
      anon_sym_phx,
      aux_sym_length_value_token1,
      aux_sym_duration_value_token1,
      aux_sym_angle_value_token1,
      anon_sym_PERCENT2,
      anon_sym_rem,
    ACTIONS(338), 14,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym__float_number,
  [6187] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    ACTIONS(908), 1,
      anon_sym_RPAREN,
    STATE(657), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6229] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    ACTIONS(910), 1,
      anon_sym_RBRACK,
    STATE(708), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6271] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    ACTIONS(912), 1,
      anon_sym_RPAREN,
    STATE(708), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6313] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    ACTIONS(914), 1,
      anon_sym_RBRACK,
    STATE(708), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6355] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    ACTIONS(916), 1,
      anon_sym_RPAREN,
    STATE(708), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6397] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    STATE(819), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6436] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    STATE(786), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6475] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    STATE(784), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6514] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    STATE(774), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6553] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(162), 1,
      sym__identifier,
    ACTIONS(801), 1,
      anon_sym_pure,
    ACTIONS(803), 1,
      anon_sym_public,
    ACTIONS(805), 1,
      anon_sym_private,
    ACTIONS(918), 1,
      anon_sym_RBRACE,
    ACTIONS(920), 1,
      anon_sym_property,
    ACTIONS(922), 1,
      anon_sym_callback,
    ACTIONS(924), 1,
      anon_sym_function,
    STATE(612), 1,
      sym_purity,
    STATE(641), 1,
      sym_simple_identifier,
    STATE(746), 1,
      sym_property_visibility,
    STATE(856), 1,
      sym_function_call,
    STATE(586), 2,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
    ACTIONS(787), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_in_DASHout,
    STATE(373), 6,
      sym_property,
      sym_binding_alias,
      sym_callback,
      sym_function_definition,
      sym_callback_event,
      aux_sym_global_block_repeat1,
  [6610] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    STATE(655), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6649] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(162), 1,
      sym__identifier,
    ACTIONS(801), 1,
      anon_sym_pure,
    ACTIONS(803), 1,
      anon_sym_public,
    ACTIONS(805), 1,
      anon_sym_private,
    ACTIONS(920), 1,
      anon_sym_property,
    ACTIONS(922), 1,
      anon_sym_callback,
    ACTIONS(924), 1,
      anon_sym_function,
    ACTIONS(926), 1,
      anon_sym_RBRACE,
    STATE(612), 1,
      sym_purity,
    STATE(641), 1,
      sym_simple_identifier,
    STATE(746), 1,
      sym_property_visibility,
    STATE(856), 1,
      sym_function_call,
    STATE(586), 2,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
    ACTIONS(787), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_in_DASHout,
    STATE(367), 6,
      sym_property,
      sym_binding_alias,
      sym_callback,
      sym_function_definition,
      sym_callback_event,
      aux_sym_global_block_repeat1,
  [6706] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    STATE(823), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6745] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    STATE(780), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6784] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    STATE(764), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6823] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(928), 1,
      anon_sym_RBRACE,
    ACTIONS(930), 1,
      anon_sym_property,
    ACTIONS(936), 1,
      anon_sym_callback,
    ACTIONS(939), 1,
      anon_sym_pure,
    ACTIONS(942), 1,
      anon_sym_public,
    ACTIONS(945), 1,
      anon_sym_private,
    ACTIONS(948), 1,
      anon_sym_function,
    ACTIONS(951), 1,
      sym__identifier,
    STATE(612), 1,
      sym_purity,
    STATE(641), 1,
      sym_simple_identifier,
    STATE(746), 1,
      sym_property_visibility,
    STATE(856), 1,
      sym_function_call,
    STATE(586), 2,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
    ACTIONS(933), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_in_DASHout,
    STATE(373), 6,
      sym_property,
      sym_binding_alias,
      sym_callback,
      sym_function_definition,
      sym_callback_event,
      aux_sym_global_block_repeat1,
  [6880] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    STATE(771), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6919] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    STATE(782), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6958] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    STATE(708), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [6997] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    STATE(787), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [7036] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(902), 1,
      anon_sym_LBRACK,
    STATE(888), 1,
      sym_type,
    STATE(592), 5,
      sym_struct_block,
      sym_type_list,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [7075] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(358), 1,
      anon_sym_LBRACK,
    ACTIONS(954), 1,
      anon_sym_DOT,
    STATE(115), 1,
      sym_add_prec_operator,
    STATE(116), 1,
      sym_mult_prec_operator,
    STATE(117), 1,
      sym_comparison_operator,
    ACTIONS(388), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SLASH,
      sym__int_number,
    ACTIONS(386), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym__float_number,
  [7115] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(358), 1,
      anon_sym_LBRACK,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(954), 1,
      anon_sym_DOT,
    ACTIONS(958), 1,
      sym_logical_and,
    ACTIONS(960), 1,
      sym_logical_or,
    ACTIONS(962), 1,
      anon_sym_QMARK,
    ACTIONS(964), 1,
      sym__int_number,
    STATE(115), 1,
      sym_add_prec_operator,
    STATE(116), 1,
      sym_mult_prec_operator,
    STATE(117), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(956), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__float_number,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [7171] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(358), 1,
      anon_sym_LBRACK,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(954), 1,
      anon_sym_DOT,
    STATE(115), 1,
      sym_add_prec_operator,
    STATE(116), 1,
      sym_mult_prec_operator,
    STATE(117), 1,
      sym_comparison_operator,
    ACTIONS(404), 3,
      anon_sym_LT,
      anon_sym_GT,
      sym__int_number,
    ACTIONS(402), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym__float_number,
  [7215] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(358), 1,
      anon_sym_LBRACK,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(400), 1,
      sym__int_number,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(954), 1,
      anon_sym_DOT,
    STATE(115), 1,
      sym_add_prec_operator,
    STATE(116), 1,
      sym_mult_prec_operator,
    STATE(117), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(398), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      sym__float_number,
  [7265] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(358), 1,
      anon_sym_LBRACK,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(954), 1,
      anon_sym_DOT,
    STATE(115), 1,
      sym_add_prec_operator,
    STATE(116), 1,
      sym_mult_prec_operator,
    STATE(117), 1,
      sym_comparison_operator,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(420), 3,
      anon_sym_LT,
      anon_sym_GT,
      sym__int_number,
    ACTIONS(418), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym__float_number,
  [7311] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(358), 1,
      anon_sym_LBRACK,
    ACTIONS(954), 1,
      anon_sym_DOT,
    STATE(115), 1,
      sym_add_prec_operator,
    STATE(116), 1,
      sym_mult_prec_operator,
    STATE(117), 1,
      sym_comparison_operator,
    ACTIONS(408), 4,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SLASH,
      sym__int_number,
    ACTIONS(406), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym__float_number,
  [7351] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(358), 1,
      anon_sym_LBRACK,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(428), 1,
      sym__int_number,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(954), 1,
      anon_sym_DOT,
    ACTIONS(958), 1,
      sym_logical_and,
    STATE(115), 1,
      sym_add_prec_operator,
    STATE(116), 1,
      sym_mult_prec_operator,
    STATE(117), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(426), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym_logical_or,
      anon_sym_QMARK,
      sym__float_number,
  [7403] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(358), 1,
      anon_sym_LBRACK,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(400), 1,
      sym__int_number,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(954), 1,
      anon_sym_DOT,
    ACTIONS(958), 1,
      sym_logical_and,
    STATE(115), 1,
      sym_add_prec_operator,
    STATE(116), 1,
      sym_mult_prec_operator,
    STATE(117), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(398), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym_logical_or,
      anon_sym_QMARK,
      sym__float_number,
  [7455] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(966), 1,
      anon_sym_COMMA,
    ACTIONS(968), 1,
      anon_sym_RBRACE,
    ACTIONS(970), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(741), 1,
      aux_sym_anon_struct_block_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [7515] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(970), 1,
      anon_sym_SEMI,
    ACTIONS(972), 1,
      anon_sym_COMMA,
    ACTIONS(974), 1,
      anon_sym_RBRACE,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(660), 1,
      aux_sym_anon_struct_block_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [7575] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(358), 1,
      anon_sym_LBRACK,
    STATE(115), 1,
      sym_add_prec_operator,
    STATE(116), 1,
      sym_mult_prec_operator,
    STATE(117), 1,
      sym_comparison_operator,
    ACTIONS(396), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym__int_number,
    ACTIONS(394), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym__float_number,
  [7613] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(719), 1,
      anon_sym_SEMI,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(966), 1,
      anon_sym_COMMA,
    ACTIONS(968), 1,
      anon_sym_RBRACE,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(741), 1,
      aux_sym_anon_struct_block_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [7673] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(976), 1,
      anon_sym_COMMA,
    ACTIONS(978), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(706), 1,
      aux_sym_tr_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [7730] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(980), 1,
      anon_sym_COMMA,
    ACTIONS(982), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(716), 1,
      aux_sym_tr_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [7787] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(984), 1,
      anon_sym_COMMA,
    ACTIONS(986), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(693), 1,
      aux_sym_tr_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [7844] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(988), 1,
      anon_sym_COMMA,
    ACTIONS(990), 1,
      anon_sym_RBRACK,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(685), 1,
      aux_sym_tr_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [7901] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(972), 1,
      anon_sym_COMMA,
    ACTIONS(974), 1,
      anon_sym_RBRACE,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(660), 1,
      aux_sym_anon_struct_block_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [7958] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(992), 1,
      anon_sym_COMMA,
    ACTIONS(994), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(667), 1,
      aux_sym_tr_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8015] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(996), 1,
      anon_sym_COMMA,
    ACTIONS(998), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(676), 1,
      aux_sym_tr_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8072] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(966), 1,
      anon_sym_COMMA,
    ACTIONS(968), 1,
      anon_sym_RBRACE,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(741), 1,
      aux_sym_anon_struct_block_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8129] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1000), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8182] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1002), 1,
      anon_sym_COMMA,
    ACTIONS(1004), 1,
      anon_sym_RBRACK,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(729), 1,
      aux_sym_tr_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8239] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1006), 1,
      anon_sym_COMMA,
    ACTIONS(1008), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(687), 1,
      aux_sym_tr_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8296] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1010), 1,
      anon_sym_COMMA,
    ACTIONS(1012), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(691), 1,
      aux_sym_tr_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8353] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1014), 1,
      anon_sym_COMMA,
    ACTIONS(1016), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(752), 1,
      aux_sym_tr_repeat1,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8410] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1018), 1,
      anon_sym_LBRACE,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(234), 1,
      sym_imperative_block,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8464] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1020), 1,
      anon_sym_COMMA,
    ACTIONS(1022), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8518] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(1024), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8570] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(1026), 1,
      anon_sym_RBRACE,
    STATE(670), 1,
      sym_export_type,
    STATE(707), 3,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [8604] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(956), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8656] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(652), 2,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8708] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1028), 1,
      anon_sym_LBRACE,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(458), 1,
      sym_animate_body,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8762] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1030), 1,
      anon_sym_COMMA,
    ACTIONS(1032), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8816] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1034), 1,
      anon_sym_LBRACE,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    STATE(833), 1,
      sym_animate_body,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8870] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1036), 1,
      anon_sym_COMMA,
    ACTIONS(1038), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8924] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1040), 1,
      anon_sym_COMMA,
    ACTIONS(1042), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [8978] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1044), 1,
      anon_sym_RBRACE,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9029] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1046), 1,
      anon_sym_RBRACK,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9080] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1048), 1,
      anon_sym_COLON,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9131] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1050), 1,
      anon_sym_COLON,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9182] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1052), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9233] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1054), 1,
      anon_sym_COLON,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9284] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1056), 1,
      anon_sym_COLON,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9335] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1058), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9386] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1060), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9437] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1062), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9488] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1064), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9539] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1066), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9590] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1068), 1,
      anon_sym_RBRACK,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9641] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1070), 1,
      anon_sym_COLON,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9692] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1072), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9743] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1074), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9794] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    STATE(822), 1,
      sym_export_type,
    STATE(707), 3,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [9825] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1076), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9876] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1078), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9927] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1080), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [9978] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1082), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10029] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(970), 1,
      anon_sym_SEMI,
    ACTIONS(1084), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1086), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [10058] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1088), 1,
      anon_sym_RPAREN,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10109] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1090), 1,
      anon_sym_COLON,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10160] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(719), 1,
      anon_sym_SEMI,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10211] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(970), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10262] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1092), 1,
      anon_sym_SEMI,
    ACTIONS(717), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(721), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [10291] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1092), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10342] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1094), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10393] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(600), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SLASH,
    ACTIONS(664), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_RBRACK,
    ACTIONS(598), 13,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10422] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1096), 1,
      anon_sym_COLON,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10473] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1098), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10524] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(678), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_children_identifier,
    ACTIONS(680), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [10551] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1100), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10602] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1102), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10653] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1104), 1,
      anon_sym_COLON,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10704] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1106), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10755] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_SLASH,
    ACTIONS(658), 1,
      anon_sym_STAR,
    ACTIONS(886), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_DOT,
    ACTIONS(890), 1,
      sym_logical_and,
    ACTIONS(894), 1,
      sym_logical_or,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(1108), 1,
      anon_sym_SEMI,
    STATE(91), 1,
      sym_add_prec_operator,
    STATE(92), 1,
      sym_mult_prec_operator,
    STATE(95), 1,
      sym_comparison_operator,
    ACTIONS(352), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(656), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(372), 4,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [10806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1110), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1112), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [10832] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    STATE(842), 3,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [10860] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1116), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [10886] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1118), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1120), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [10912] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1122), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1124), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [10938] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1126), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1128), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [10964] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1130), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1132), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [10990] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1134), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1136), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11016] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1138), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1140), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11042] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1142), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1144), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11068] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    STATE(873), 3,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [11096] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1146), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1148), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11122] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1150), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1152), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11148] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1154), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1156), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11174] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1158), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1160), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11200] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1162), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1164), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11226] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1166), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1168), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11252] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1170), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1172), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11278] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1174), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1176), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11304] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    STATE(896), 3,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [11332] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(723), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(725), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11358] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1178), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1180), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11384] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(733), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(735), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11410] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1182), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1184), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11436] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    STATE(829), 3,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [11464] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1186), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1188), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11490] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1190), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1192), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11516] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(686), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(688), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11542] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    STATE(919), 3,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [11570] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(660), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(662), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11596] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1194), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1196), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1198), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1200), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11648] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1202), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1204), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11674] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1206), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1208), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11700] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1210), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1212), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11726] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1214), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1216), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11752] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    STATE(883), 3,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [11780] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1218), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1220), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1222), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1224), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11832] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    STATE(869), 3,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [11860] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1226), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1228), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11886] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    STATE(885), 3,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [11914] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1230), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1232), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1234), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1236), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11966] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1238), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1240), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [11992] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym__identifier,
    STATE(848), 3,
      sym_builtin_type_identifier,
      sym_user_type_identifier,
      sym__type_identifier,
    ACTIONS(906), 14,
      anon_sym_duration,
      anon_sym_easing,
      anon_sym_int,
      anon_sym_float,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_color,
      anon_sym_brush,
      anon_sym_physical_DASHlength,
      anon_sym_length,
      anon_sym_angle,
      anon_sym_percent,
      anon_sym_image,
      anon_sym_relative_DASHfont_DASHsize,
  [12020] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1242), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1244), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [12046] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1246), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1248), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [12072] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1252), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [12098] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1256), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [12124] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 1,
      ts_builtin_sym_end,
    ACTIONS(1260), 1,
      sym_export,
    ACTIONS(1263), 1,
      anon_sym_import,
    ACTIONS(1266), 1,
      anon_sym_component,
    ACTIONS(1269), 1,
      anon_sym_global,
    ACTIONS(1272), 1,
      anon_sym_struct,
    ACTIONS(1275), 1,
      anon_sym_enum,
    ACTIONS(1278), 1,
      sym__identifier,
    STATE(886), 1,
      sym_user_type_identifier,
    STATE(503), 9,
      sym__definition,
      sym__local_type,
      sym__exported_type,
      sym_import_statement,
      sym_component_definition,
      sym_global_definition,
      sym_struct_definition,
      sym_enum_definition,
      aux_sym_sourcefile_repeat1,
  [12166] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_export,
    ACTIONS(9), 1,
      anon_sym_import,
    ACTIONS(11), 1,
      anon_sym_component,
    ACTIONS(13), 1,
      anon_sym_global,
    ACTIONS(15), 1,
      anon_sym_struct,
    ACTIONS(17), 1,
      anon_sym_enum,
    ACTIONS(19), 1,
      sym__identifier,
    ACTIONS(1281), 1,
      ts_builtin_sym_end,
    STATE(886), 1,
      sym_user_type_identifier,
    STATE(503), 9,
      sym__definition,
      sym__local_type,
      sym__exported_type,
      sym_import_statement,
      sym_component_definition,
      sym_global_definition,
      sym_struct_definition,
      sym_enum_definition,
      aux_sym_sourcefile_repeat1,
  [12208] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(668), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(670), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [12234] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1283), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1285), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [12260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1287), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1289), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [12286] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1291), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1293), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [12312] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1295), 2,
      anon_sym_RBRACE,
      sym_children_identifier,
    ACTIONS(1297), 16,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_transitions,
      anon_sym_states,
      anon_sym_animate,
      anon_sym_if,
      anon_sym_for,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_changed,
      anon_sym_in_DASHout,
      sym__identifier,
  [12338] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(588), 3,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SLASH,
    ACTIONS(586), 13,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_DOT,
      sym_logical_and,
      sym_logical_or,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [12362] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1299), 1,
      ts_builtin_sym_end,
    ACTIONS(1303), 1,
      anon_sym_LBRACE,
    STATE(886), 1,
      sym_user_type_identifier,
    STATE(578), 5,
      sym__local_type,
      sym_component_definition,
      sym_global_definition,
      sym_struct_definition,
      sym_enum_definition,
    ACTIONS(1301), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [12391] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1305), 7,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(1307), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [12413] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1309), 7,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(1311), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [12435] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1313), 7,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(1315), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [12457] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1317), 7,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(1319), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [12479] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1321), 7,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(1323), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [12501] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1325), 7,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(1327), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [12523] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(678), 2,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(680), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12543] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(717), 1,
      anon_sym_RBRACE,
    ACTIONS(1108), 1,
      anon_sym_SEMI,
    ACTIONS(721), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12565] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 1,
      anon_sym_RBRACE,
    ACTIONS(1252), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12584] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1198), 1,
      anon_sym_RBRACE,
    ACTIONS(1200), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12603] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1210), 1,
      anon_sym_RBRACE,
    ACTIONS(1212), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1110), 1,
      anon_sym_RBRACE,
    ACTIONS(1112), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12641] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 1,
      anon_sym_RBRACE,
    ACTIONS(1256), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12660] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1182), 1,
      anon_sym_RBRACE,
    ACTIONS(1184), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12679] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1246), 1,
      anon_sym_RBRACE,
    ACTIONS(1248), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12698] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 1,
      anon_sym_RBRACE,
    ACTIONS(1116), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12717] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1186), 1,
      anon_sym_RBRACE,
    ACTIONS(1188), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12736] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(723), 1,
      anon_sym_RBRACE,
    ACTIONS(725), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12755] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1190), 1,
      anon_sym_RBRACE,
    ACTIONS(1192), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12774] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1142), 1,
      anon_sym_RBRACE,
    ACTIONS(1144), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12793] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1170), 1,
      anon_sym_RBRACE,
    ACTIONS(1172), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12812] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1206), 1,
      anon_sym_RBRACE,
    ACTIONS(1208), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12831] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1214), 1,
      anon_sym_RBRACE,
    ACTIONS(1216), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12850] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1218), 1,
      anon_sym_RBRACE,
    ACTIONS(1220), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12869] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1166), 1,
      anon_sym_RBRACE,
    ACTIONS(1168), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12888] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1238), 1,
      anon_sym_RBRACE,
    ACTIONS(1240), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12907] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1242), 1,
      anon_sym_RBRACE,
    ACTIONS(1244), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12926] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1154), 1,
      anon_sym_RBRACE,
    ACTIONS(1156), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12945] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1178), 1,
      anon_sym_RBRACE,
    ACTIONS(1180), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12964] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(733), 1,
      anon_sym_RBRACE,
    ACTIONS(735), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [12983] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1134), 1,
      anon_sym_RBRACE,
    ACTIONS(1136), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [13002] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1295), 1,
      anon_sym_RBRACE,
    ACTIONS(1297), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [13021] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(660), 1,
      anon_sym_RBRACE,
    ACTIONS(662), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [13040] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1283), 1,
      anon_sym_RBRACE,
    ACTIONS(1285), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [13059] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1291), 1,
      anon_sym_RBRACE,
    ACTIONS(1293), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [13078] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1138), 1,
      anon_sym_RBRACE,
    ACTIONS(1140), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [13097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1234), 1,
      anon_sym_RBRACE,
    ACTIONS(1236), 10,
      anon_sym_property,
      anon_sym_in,
      anon_sym_out,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
      anon_sym_in_DASHout,
      sym__identifier,
  [13116] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1329), 10,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_COLON_EQ,
      anon_sym_inherits,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [13132] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1331), 1,
      anon_sym_RBRACE,
    STATE(851), 1,
      sym_animate_option_identifier,
    STATE(554), 2,
      sym_animate_option,
      aux_sym_animate_body_repeat1,
    ACTIONS(1333), 5,
      anon_sym_delay,
      anon_sym_duration,
      anon_sym_iteration_DASHcount,
      anon_sym_direction,
      anon_sym_easing,
  [13153] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1335), 1,
      anon_sym_RBRACE,
    STATE(851), 1,
      sym_animate_option_identifier,
    STATE(552), 2,
      sym_animate_option,
      aux_sym_animate_body_repeat1,
    ACTIONS(1333), 5,
      anon_sym_delay,
      anon_sym_duration,
      anon_sym_iteration_DASHcount,
      anon_sym_direction,
      anon_sym_easing,
  [13174] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1337), 1,
      anon_sym_RBRACE,
    STATE(851), 1,
      sym_animate_option_identifier,
    STATE(554), 2,
      sym_animate_option,
      aux_sym_animate_body_repeat1,
    ACTIONS(1333), 5,
      anon_sym_delay,
      anon_sym_duration,
      anon_sym_iteration_DASHcount,
      anon_sym_direction,
      anon_sym_easing,
  [13195] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1339), 1,
      anon_sym_RBRACE,
    STATE(851), 1,
      sym_animate_option_identifier,
    STATE(550), 2,
      sym_animate_option,
      aux_sym_animate_body_repeat1,
    ACTIONS(1333), 5,
      anon_sym_delay,
      anon_sym_duration,
      anon_sym_iteration_DASHcount,
      anon_sym_direction,
      anon_sym_easing,
  [13216] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1341), 1,
      anon_sym_RBRACE,
    STATE(851), 1,
      sym_animate_option_identifier,
    STATE(554), 2,
      sym_animate_option,
      aux_sym_animate_body_repeat1,
    ACTIONS(1343), 5,
      anon_sym_delay,
      anon_sym_duration,
      anon_sym_iteration_DASHcount,
      anon_sym_direction,
      anon_sym_easing,
  [13237] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1346), 1,
      ts_builtin_sym_end,
    ACTIONS(1348), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13253] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      ts_builtin_sym_end,
    ACTIONS(1352), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13269] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1354), 1,
      ts_builtin_sym_end,
    ACTIONS(1356), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13285] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1358), 1,
      ts_builtin_sym_end,
    ACTIONS(1360), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(686), 1,
      ts_builtin_sym_end,
    ACTIONS(688), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1362), 1,
      ts_builtin_sym_end,
    ACTIONS(1364), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13333] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1366), 1,
      ts_builtin_sym_end,
    ACTIONS(1368), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13349] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1370), 1,
      ts_builtin_sym_end,
    ACTIONS(1372), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13365] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1374), 1,
      ts_builtin_sym_end,
    ACTIONS(1376), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13381] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1378), 1,
      ts_builtin_sym_end,
    ACTIONS(1380), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13397] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1382), 1,
      ts_builtin_sym_end,
    ACTIONS(1384), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13413] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1386), 1,
      ts_builtin_sym_end,
    ACTIONS(1388), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13429] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1390), 1,
      ts_builtin_sym_end,
    ACTIONS(1392), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13445] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1394), 1,
      ts_builtin_sym_end,
    ACTIONS(1396), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13461] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1398), 1,
      ts_builtin_sym_end,
    ACTIONS(1400), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13477] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1402), 1,
      ts_builtin_sym_end,
    ACTIONS(1404), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13493] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1406), 1,
      ts_builtin_sym_end,
    ACTIONS(1408), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13509] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1410), 1,
      ts_builtin_sym_end,
    ACTIONS(1412), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13525] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1414), 1,
      ts_builtin_sym_end,
    ACTIONS(1416), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13541] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(668), 1,
      ts_builtin_sym_end,
    ACTIONS(670), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13557] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1418), 1,
      ts_builtin_sym_end,
    ACTIONS(1420), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13573] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1422), 1,
      ts_builtin_sym_end,
    ACTIONS(1424), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1426), 1,
      ts_builtin_sym_end,
    ACTIONS(1428), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13605] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1430), 1,
      ts_builtin_sym_end,
    ACTIONS(1432), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13621] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1434), 1,
      ts_builtin_sym_end,
    ACTIONS(1436), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13637] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1438), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_as,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [13651] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1440), 1,
      ts_builtin_sym_end,
    ACTIONS(1442), 7,
      sym_export,
      anon_sym_import,
      anon_sym_component,
      anon_sym_global,
      anon_sym_struct,
      anon_sym_enum,
      sym__identifier,
  [13667] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_COMMA,
    ACTIONS(162), 1,
      sym__identifier,
    ACTIONS(1444), 1,
      anon_sym_RBRACE,
    ACTIONS(1446), 1,
      anon_sym_animate,
    STATE(871), 1,
      sym_simple_identifier,
    STATE(644), 2,
      sym_animate_statement,
      aux_sym_in_out_transition_repeat1,
  [13690] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1448), 1,
      anon_sym_pure,
    ACTIONS(1454), 1,
      anon_sym_function,
    ACTIONS(1451), 2,
      anon_sym_public,
      anon_sym_private,
    STATE(583), 3,
      sym_purity,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
  [13709] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1456), 1,
      anon_sym_pure,
    ACTIONS(1460), 1,
      anon_sym_function,
    ACTIONS(1458), 2,
      anon_sym_public,
      anon_sym_private,
    STATE(583), 3,
      sym_purity,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
  [13728] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_COMMA,
    ACTIONS(162), 1,
      sym__identifier,
    ACTIONS(1446), 1,
      anon_sym_animate,
    ACTIONS(1462), 1,
      anon_sym_RBRACE,
    STATE(871), 1,
      sym_simple_identifier,
    STATE(631), 2,
      sym_animate_statement,
      aux_sym_in_out_transition_repeat1,
  [13751] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1456), 1,
      anon_sym_pure,
    ACTIONS(1464), 1,
      anon_sym_function,
    ACTIONS(1458), 2,
      anon_sym_public,
      anon_sym_private,
    STATE(583), 3,
      sym_purity,
      sym_function_visibility,
      aux_sym_function_definition_repeat1,
  [13770] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(170), 1,
      sym__int_number,
    ACTIONS(172), 1,
      sym__float_number,
    STATE(872), 1,
      sym__number,
    STATE(917), 3,
      sym_int_value,
      sym_float_value,
      sym_angle_value,
  [13788] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(892), 1,
      anon_sym_LPAREN,
    ACTIONS(1466), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1468), 1,
      anon_sym_COLON,
    ACTIONS(1470), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(1472), 1,
      anon_sym_EQ_GT,
    STATE(295), 1,
      sym_arguments,
  [13810] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1474), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [13822] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(170), 1,
      sym__int_number,
    ACTIONS(172), 1,
      sym__float_number,
    STATE(872), 1,
      sym__number,
    STATE(874), 3,
      sym_int_value,
      sym_float_value,
      sym_angle_value,
  [13840] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(892), 1,
      anon_sym_LPAREN,
    ACTIONS(1466), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1470), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(1472), 1,
      anon_sym_EQ_GT,
    ACTIONS(1476), 1,
      anon_sym_COLON,
    STATE(295), 1,
      sym_arguments,
  [13862] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1478), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [13874] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1480), 1,
      anon_sym_phx,
    ACTIONS(1482), 1,
      aux_sym_length_value_token1,
    ACTIONS(1484), 1,
      aux_sym_duration_value_token1,
    ACTIONS(1486), 1,
      aux_sym_angle_value_token1,
    ACTIONS(1488), 1,
      anon_sym_PERCENT2,
    ACTIONS(1490), 1,
      anon_sym_rem,
  [13896] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1492), 6,
      anon_sym_RBRACE,
      anon_sym_delay,
      anon_sym_duration,
      anon_sym_iteration_DASHcount,
      anon_sym_direction,
      anon_sym_easing,
  [13908] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1494), 2,
      anon_sym_property,
      sym__identifier,
    ACTIONS(1496), 4,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
  [13922] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1498), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [13934] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1502), 1,
      sym__int_number,
    ACTIONS(1504), 1,
      sym__float_number,
    STATE(832), 1,
      sym_percent_value,
    STATE(905), 1,
      sym__number,
    ACTIONS(1500), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13954] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1506), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [13966] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1508), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [13978] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(892), 1,
      anon_sym_LPAREN,
    ACTIONS(1466), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1470), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(1472), 1,
      anon_sym_EQ_GT,
    ACTIONS(1510), 1,
      anon_sym_COLON,
    STATE(295), 1,
      sym_arguments,
  [14000] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(432), 1,
      anon_sym_COLON,
    ACTIONS(1329), 1,
      anon_sym_LBRACE,
    ACTIONS(430), 4,
      anon_sym_COLON_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_EQ_GT,
  [14016] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1512), 1,
      anon_sym_phx,
    ACTIONS(1514), 1,
      aux_sym_length_value_token1,
    ACTIONS(1516), 1,
      aux_sym_duration_value_token1,
    ACTIONS(1518), 1,
      aux_sym_angle_value_token1,
    ACTIONS(1520), 1,
      anon_sym_PERCENT2,
    ACTIONS(1522), 1,
      anon_sym_rem,
  [14038] = 5,
    ACTIONS(1524), 1,
      anon_sym_DQUOTE,
    ACTIONS(1526), 1,
      sym__unescaped_string_fragment,
    ACTIONS(1528), 1,
      anon_sym_BSLASH,
    ACTIONS(1530), 1,
      sym_comment,
    STATE(618), 2,
      sym_escape_sequence,
      aux_sym__string_repeat1,
  [14055] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1532), 1,
      anon_sym_LBRACE,
    ACTIONS(1534), 1,
      anon_sym_LPAREN,
    ACTIONS(1536), 1,
      anon_sym_DASH_GT,
    STATE(540), 1,
      sym_imperative_block,
    STATE(742), 1,
      sym__function_signature,
  [14074] = 5,
    ACTIONS(1526), 1,
      sym__unescaped_string_fragment,
    ACTIONS(1528), 1,
      anon_sym_BSLASH,
    ACTIONS(1530), 1,
      sym_comment,
    ACTIONS(1538), 1,
      anon_sym_DQUOTE,
    STATE(618), 2,
      sym_escape_sequence,
      aux_sym__string_repeat1,
  [14091] = 5,
    ACTIONS(1528), 1,
      anon_sym_BSLASH,
    ACTIONS(1530), 1,
      sym_comment,
    ACTIONS(1540), 1,
      anon_sym_DQUOTE,
    ACTIONS(1542), 1,
      sym__unescaped_string_fragment,
    STATE(603), 2,
      sym_escape_sequence,
      aux_sym__string_repeat1,
  [14108] = 5,
    ACTIONS(1528), 1,
      anon_sym_BSLASH,
    ACTIONS(1530), 1,
      sym_comment,
    ACTIONS(1544), 1,
      anon_sym_DQUOTE,
    ACTIONS(1546), 1,
      sym__unescaped_string_fragment,
    STATE(605), 2,
      sym_escape_sequence,
      aux_sym__string_repeat1,
  [14125] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1551), 1,
      anon_sym_RBRACK,
    ACTIONS(1548), 2,
      anon_sym_in,
      anon_sym_out,
    STATE(608), 2,
      sym_in_out_transition,
      aux_sym_transitions_definition_repeat1,
  [14140] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1553), 1,
      anon_sym_SEMI,
    ACTIONS(1555), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(1557), 1,
      anon_sym_LPAREN,
    ACTIONS(1559), 1,
      anon_sym_DASH_GT,
    STATE(791), 1,
      sym__callback_signature,
  [14159] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1534), 1,
      anon_sym_LPAREN,
    ACTIONS(1561), 1,
      anon_sym_LBRACE,
    ACTIONS(1563), 1,
      anon_sym_DASH_GT,
    STATE(469), 1,
      sym_imperative_block,
    STATE(656), 1,
      sym__function_signature,
  [14178] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1565), 1,
      anon_sym_LBRACE,
    ACTIONS(1567), 4,
      anon_sym_DQUOTE,
      anon_sym_BSLASH,
      aux_sym_escape_sequence_token1,
      anon_sym_n,
  [14191] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1569), 1,
      anon_sym_callback,
    ACTIONS(1571), 4,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
  [14204] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      anon_sym_LPAREN,
    ACTIONS(1573), 1,
      anon_sym_SEMI,
    ACTIONS(1575), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(1577), 1,
      anon_sym_DASH_GT,
    STATE(773), 1,
      sym__callback_signature,
  [14223] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1534), 1,
      anon_sym_LPAREN,
    ACTIONS(1561), 1,
      anon_sym_LBRACE,
    ACTIONS(1579), 1,
      anon_sym_DASH_GT,
    STATE(474), 1,
      sym_imperative_block,
    STATE(717), 1,
      sym__function_signature,
  [14242] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1583), 1,
      anon_sym_RBRACK,
    ACTIONS(1581), 2,
      anon_sym_in,
      anon_sym_out,
    STATE(608), 2,
      sym_in_out_transition,
      aux_sym_transitions_definition_repeat1,
  [14257] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1532), 1,
      anon_sym_LBRACE,
    ACTIONS(1534), 1,
      anon_sym_LPAREN,
    ACTIONS(1585), 1,
      anon_sym_DASH_GT,
    STATE(536), 1,
      sym_imperative_block,
    STATE(724), 1,
      sym__function_signature,
  [14276] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1587), 5,
      anon_sym_callback,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
  [14287] = 5,
    ACTIONS(1530), 1,
      sym_comment,
    ACTIONS(1589), 1,
      anon_sym_DQUOTE,
    ACTIONS(1591), 1,
      sym__unescaped_string_fragment,
    ACTIONS(1594), 1,
      anon_sym_BSLASH,
    STATE(618), 2,
      sym_escape_sequence,
      aux_sym__string_repeat1,
  [14304] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1597), 1,
      anon_sym_RBRACK,
    ACTIONS(1581), 2,
      anon_sym_in,
      anon_sym_out,
    STATE(615), 2,
      sym_in_out_transition,
      aux_sym_transitions_definition_repeat1,
  [14319] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1599), 1,
      anon_sym_callback,
    ACTIONS(1571), 4,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
  [14332] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1601), 1,
      anon_sym_COMMA,
    ACTIONS(1603), 1,
      anon_sym_RPAREN,
    ACTIONS(1605), 1,
      anon_sym_EQ_GT,
    ACTIONS(1607), 1,
      anon_sym_PIPE,
  [14348] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(781), 1,
      anon_sym_COMMA,
    ACTIONS(1609), 1,
      anon_sym_RBRACE,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(903), 1,
      sym_simple_identifier,
  [14364] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1613), 1,
      anon_sym_COMMA,
    ACTIONS(1615), 1,
      anon_sym_RBRACE,
    STATE(836), 1,
      sym_simple_identifier,
  [14380] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1617), 1,
      anon_sym_COMMA,
    ACTIONS(1619), 1,
      anon_sym_RBRACE,
    ACTIONS(1621), 1,
      sym__identifier,
    STATE(694), 1,
      sym_user_type_identifier,
  [14396] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1623), 1,
      anon_sym_COMMA,
    ACTIONS(1625), 1,
      anon_sym_RPAREN,
    ACTIONS(1627), 1,
      anon_sym_EQ_GT,
    ACTIONS(1629), 1,
      anon_sym_PIPE,
  [14412] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      sym__identifier,
    ACTIONS(1631), 1,
      anon_sym_RBRACE,
    STATE(689), 1,
      sym_user_type_identifier,
    STATE(749), 1,
      sym_import_type,
  [14428] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    ACTIONS(1633), 1,
      anon_sym_LBRACE,
    STATE(289), 1,
      sym__string,
    STATE(914), 1,
      sym_string_value,
  [14444] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1635), 1,
      anon_sym_RBRACE,
    ACTIONS(1637), 1,
      anon_sym_animate,
    STATE(628), 2,
      sym_animate_statement,
      aux_sym_in_out_transition_repeat1,
  [14458] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1640), 1,
      anon_sym_RPAREN,
    STATE(817), 1,
      sym_typed_identifier,
    STATE(920), 1,
      sym_simple_identifier,
  [14474] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1642), 1,
      anon_sym_RBRACK,
    STATE(637), 1,
      aux_sym_states_definition_repeat2,
    STATE(897), 1,
      sym_simple_identifier,
  [14490] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1644), 1,
      anon_sym_RBRACE,
    ACTIONS(1646), 1,
      anon_sym_animate,
    STATE(628), 2,
      sym_animate_statement,
      aux_sym_in_out_transition_repeat1,
  [14504] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1648), 1,
      anon_sym_RPAREN,
    STATE(817), 1,
      sym_typed_identifier,
    STATE(920), 1,
      sym_simple_identifier,
  [14520] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1646), 1,
      anon_sym_animate,
    ACTIONS(1650), 1,
      anon_sym_RBRACE,
    STATE(634), 2,
      sym_animate_statement,
      aux_sym_in_out_transition_repeat1,
  [14534] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1646), 1,
      anon_sym_animate,
    ACTIONS(1652), 1,
      anon_sym_RBRACE,
    STATE(628), 2,
      sym_animate_statement,
      aux_sym_in_out_transition_repeat1,
  [14548] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1646), 1,
      anon_sym_animate,
    ACTIONS(1654), 1,
      anon_sym_RBRACE,
    STATE(628), 2,
      sym_animate_statement,
      aux_sym_in_out_transition_repeat1,
  [14562] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1656), 1,
      anon_sym_COMMA,
    STATE(636), 1,
      aux_sym_tr_repeat1,
    ACTIONS(1000), 2,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [14576] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1659), 1,
      anon_sym_RBRACK,
    STATE(652), 1,
      aux_sym_states_definition_repeat2,
    STATE(897), 1,
      sym_simple_identifier,
  [14592] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1661), 4,
      anon_sym_pure,
      anon_sym_public,
      anon_sym_private,
      anon_sym_function,
  [14602] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      anon_sym_LPAREN,
    ACTIONS(1663), 1,
      anon_sym_SEMI,
    ACTIONS(1665), 1,
      anon_sym_DASH_GT,
    STATE(757), 1,
      sym__callback_signature,
  [14618] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1667), 1,
      sym__identifier,
    STATE(468), 1,
      sym_component,
    STATE(790), 1,
      sym_user_type_identifier,
    STATE(839), 1,
      sym_simple_identifier,
  [14634] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(892), 1,
      anon_sym_LPAREN,
    ACTIONS(1669), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(1671), 1,
      anon_sym_EQ_GT,
    STATE(295), 1,
      sym_arguments,
  [14650] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_COMMA,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1673), 1,
      anon_sym_RBRACE,
    STATE(871), 1,
      sym_simple_identifier,
  [14666] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1675), 1,
      anon_sym_LT,
    STATE(785), 1,
      sym__property_type,
    STATE(850), 1,
      sym_simple_identifier,
  [14682] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1646), 1,
      anon_sym_animate,
    ACTIONS(1677), 1,
      anon_sym_RBRACE,
    STATE(628), 2,
      sym_animate_statement,
      aux_sym_in_out_transition_repeat1,
  [14696] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1679), 1,
      anon_sym_RPAREN,
    STATE(705), 1,
      sym_typed_identifier,
    STATE(920), 1,
      sym_simple_identifier,
  [14712] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1681), 1,
      anon_sym_COMMA,
    STATE(646), 1,
      aux_sym_type_list_repeat1,
    ACTIONS(1684), 2,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [14726] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1667), 1,
      sym__identifier,
    STATE(471), 1,
      sym_component,
    STATE(790), 1,
      sym_user_type_identifier,
    STATE(839), 1,
      sym_simple_identifier,
  [14742] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1686), 1,
      anon_sym_LBRACE,
    ACTIONS(1688), 1,
      anon_sym_if,
    STATE(240), 2,
      sym_imperative_block,
      sym_if_expr,
  [14756] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1675), 1,
      anon_sym_LT,
    STATE(808), 1,
      sym__property_type,
    STATE(853), 1,
      sym_simple_identifier,
  [14772] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1646), 1,
      anon_sym_animate,
    ACTIONS(1690), 1,
      anon_sym_RBRACE,
    STATE(635), 2,
      sym_animate_statement,
      aux_sym_in_out_transition_repeat1,
  [14786] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1675), 1,
      anon_sym_LT,
    STATE(812), 1,
      sym__property_type,
    STATE(900), 1,
      sym_simple_identifier,
  [14802] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1692), 1,
      anon_sym_RBRACK,
    ACTIONS(1694), 1,
      sym__identifier,
    STATE(652), 1,
      aux_sym_states_definition_repeat2,
    STATE(897), 1,
      sym_simple_identifier,
  [14818] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1675), 1,
      anon_sym_LT,
    STATE(820), 1,
      sym__property_type,
    STATE(904), 1,
      sym_simple_identifier,
  [14834] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      anon_sym_LPAREN,
    ACTIONS(1697), 1,
      anon_sym_SEMI,
    ACTIONS(1699), 1,
      anon_sym_DASH_GT,
    STATE(772), 1,
      sym__callback_signature,
  [14850] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1701), 1,
      anon_sym_COMMA,
    ACTIONS(1703), 1,
      anon_sym_RBRACE,
    STATE(669), 1,
      aux_sym_struct_block_repeat1,
  [14863] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1561), 1,
      anon_sym_LBRACE,
    ACTIONS(1705), 1,
      anon_sym_DASH_GT,
    STATE(478), 1,
      sym_imperative_block,
  [14876] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1707), 1,
      anon_sym_COMMA,
    ACTIONS(1709), 1,
      anon_sym_RPAREN,
    STATE(728), 1,
      aux_sym_type_list_repeat1,
  [14889] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1711), 1,
      anon_sym_RBRACE,
    STATE(858), 1,
      sym_simple_identifier,
  [14902] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1713), 1,
      anon_sym_RBRACE,
    STATE(887), 1,
      sym_simple_identifier,
  [14915] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1713), 1,
      anon_sym_RBRACE,
    ACTIONS(1715), 1,
      anon_sym_COMMA,
    STATE(681), 1,
      aux_sym_anon_struct_block_repeat1,
  [14928] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1717), 1,
      anon_sym_RPAREN,
    ACTIONS(1719), 1,
      sym__int_number,
    STATE(745), 1,
      aux_sym_image_call_repeat1,
  [14941] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1721), 1,
      anon_sym_COMMA,
    ACTIONS(1723), 1,
      anon_sym_RPAREN,
    ACTIONS(1725), 1,
      anon_sym_PIPE,
  [14954] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1727), 1,
      anon_sym_COMMA,
    ACTIONS(1729), 1,
      anon_sym_RPAREN,
    STATE(720), 1,
      aux_sym_arguments_repeat1,
  [14967] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1731), 1,
      anon_sym_COMMA,
    ACTIONS(1733), 1,
      anon_sym_RPAREN,
    STATE(704), 1,
      aux_sym_gradient_call_repeat1,
  [14980] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1735), 1,
      anon_sym_RBRACE,
    STATE(887), 1,
      sym_simple_identifier,
  [14993] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1737), 1,
      anon_sym_COMMA,
    ACTIONS(1739), 1,
      anon_sym_RPAREN,
    STATE(702), 1,
      aux_sym_gradient_call_repeat1,
  [15006] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(296), 1,
      anon_sym_RPAREN,
    ACTIONS(1741), 1,
      anon_sym_COMMA,
    STATE(636), 1,
      aux_sym_tr_repeat1,
  [15019] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1743), 1,
      anon_sym_COMMA,
    ACTIONS(1745), 1,
      anon_sym_RPAREN,
    STATE(719), 1,
      aux_sym_arguments_repeat1,
  [15032] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1747), 1,
      anon_sym_COMMA,
    ACTIONS(1749), 1,
      anon_sym_RBRACE,
    STATE(721), 1,
      aux_sym_struct_block_repeat1,
  [15045] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1751), 1,
      anon_sym_COMMA,
    ACTIONS(1753), 1,
      anon_sym_RBRACE,
    STATE(715), 1,
      aux_sym__exported_type_repeat1,
  [15058] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(737), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_RBRACK,
  [15067] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1755), 1,
      anon_sym_SEMI,
    ACTIONS(1757), 1,
      anon_sym_COLON,
    ACTIONS(1759), 1,
      anon_sym_LT_EQ_GT,
  [15080] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1761), 1,
      anon_sym_COMMA,
    ACTIONS(1763), 1,
      anon_sym_RPAREN,
    STATE(678), 1,
      aux_sym_gradient_call_repeat1,
  [15093] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1765), 1,
      anon_sym_COMMA,
    ACTIONS(1767), 1,
      anon_sym_RPAREN,
    STATE(680), 1,
      aux_sym_gradient_call_repeat1,
  [15106] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1769), 1,
      anon_sym_COMMA,
    ACTIONS(1772), 1,
      anon_sym_RPAREN,
    STATE(675), 1,
      aux_sym_arguments_repeat1,
  [15119] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(302), 1,
      anon_sym_RPAREN,
    ACTIONS(1774), 1,
      anon_sym_COMMA,
    STATE(636), 1,
      aux_sym_tr_repeat1,
  [15132] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(745), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_RBRACK,
  [15141] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1776), 1,
      anon_sym_COMMA,
    ACTIONS(1778), 1,
      anon_sym_RPAREN,
    STATE(751), 1,
      aux_sym_gradient_call_repeat1,
  [15154] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    STATE(289), 1,
      sym__string,
    STATE(895), 1,
      sym_string_value,
  [15167] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1780), 1,
      anon_sym_COMMA,
    ACTIONS(1782), 1,
      anon_sym_RPAREN,
    STATE(751), 1,
      aux_sym_gradient_call_repeat1,
  [15180] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1784), 1,
      anon_sym_COMMA,
    ACTIONS(1787), 1,
      anon_sym_RBRACE,
    STATE(681), 1,
      aux_sym_anon_struct_block_repeat1,
  [15193] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    STATE(289), 1,
      sym__string,
    STATE(621), 1,
      sym_string_value,
  [15206] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1789), 1,
      anon_sym_COMMA,
    ACTIONS(1792), 1,
      anon_sym_RPAREN,
    STATE(683), 1,
      aux_sym__function_signature_repeat1,
  [15219] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1794), 1,
      anon_sym_LBRACE,
    ACTIONS(1796), 1,
      anon_sym_inherits,
    STATE(562), 1,
      sym_block,
  [15232] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(326), 1,
      anon_sym_RBRACK,
    ACTIONS(1798), 1,
      anon_sym_COMMA,
    STATE(636), 1,
      aux_sym_tr_repeat1,
  [15245] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1800), 1,
      anon_sym_COMMA,
    ACTIONS(1803), 1,
      anon_sym_RBRACE,
    STATE(686), 1,
      aux_sym__exported_type_repeat1,
  [15258] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(312), 1,
      anon_sym_RPAREN,
    ACTIONS(1805), 1,
      anon_sym_COMMA,
    STATE(636), 1,
      aux_sym_tr_repeat1,
  [15271] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    STATE(289), 1,
      sym__string,
    STATE(863), 1,
      sym_string_value,
  [15284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1809), 1,
      anon_sym_as,
    ACTIONS(1807), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15295] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    STATE(289), 1,
      sym__string,
    STATE(743), 1,
      sym_string_value,
  [15308] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(316), 1,
      anon_sym_RPAREN,
    ACTIONS(1811), 1,
      anon_sym_COMMA,
    STATE(636), 1,
      aux_sym_tr_repeat1,
  [15321] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    STATE(289), 1,
      sym__string,
    STATE(891), 1,
      sym_string_value,
  [15334] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(310), 1,
      anon_sym_RPAREN,
    ACTIONS(1813), 1,
      anon_sym_COMMA,
    STATE(636), 1,
      aux_sym_tr_repeat1,
  [15347] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1815), 1,
      anon_sym_COMMA,
    ACTIONS(1817), 1,
      anon_sym_RBRACE,
    STATE(731), 1,
      aux_sym_enum_block_repeat1,
  [15360] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      sym__identifier,
    STATE(689), 1,
      sym_user_type_identifier,
    STATE(830), 1,
      sym_import_type,
  [15373] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    STATE(289), 1,
      sym__string,
    STATE(860), 1,
      sym_string_value,
  [15386] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1819), 1,
      anon_sym_COMMA,
    ACTIONS(1821), 1,
      anon_sym_RBRACK,
    STATE(703), 1,
      aux_sym_type_list_repeat1,
  [15399] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1823), 1,
      anon_sym_COMMA,
    ACTIONS(1826), 1,
      anon_sym_RBRACE,
    STATE(698), 1,
      aux_sym_import_statement_repeat1,
  [15412] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1828), 1,
      anon_sym_COMMA,
    ACTIONS(1830), 1,
      anon_sym_RBRACE,
    STATE(698), 1,
      aux_sym_import_statement_repeat1,
  [15425] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1832), 1,
      anon_sym_SEMI,
    ACTIONS(1834), 1,
      anon_sym_COLON,
    ACTIONS(1836), 1,
      anon_sym_LT_EQ_GT,
  [15438] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    STATE(289), 1,
      sym__string,
    STATE(809), 1,
      sym_string_value,
  [15451] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1838), 1,
      anon_sym_COMMA,
    ACTIONS(1840), 1,
      anon_sym_RPAREN,
    STATE(751), 1,
      aux_sym_gradient_call_repeat1,
  [15464] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(914), 1,
      anon_sym_RBRACK,
    ACTIONS(1842), 1,
      anon_sym_COMMA,
    STATE(646), 1,
      aux_sym_type_list_repeat1,
  [15477] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1844), 1,
      anon_sym_COMMA,
    ACTIONS(1846), 1,
      anon_sym_RPAREN,
    STATE(751), 1,
      aux_sym_gradient_call_repeat1,
  [15490] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1848), 1,
      anon_sym_COMMA,
    ACTIONS(1850), 1,
      anon_sym_RPAREN,
    STATE(711), 1,
      aux_sym__function_signature_repeat1,
  [15503] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(320), 1,
      anon_sym_RPAREN,
    ACTIONS(1852), 1,
      anon_sym_COMMA,
    STATE(636), 1,
      aux_sym_tr_repeat1,
  [15516] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1856), 1,
      anon_sym_as,
    ACTIONS(1854), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [15527] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1684), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [15536] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    STATE(289), 1,
      sym__string,
    STATE(625), 1,
      sym_string_value,
  [15549] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    STATE(289), 1,
      sym__string,
    STATE(766), 1,
      sym_string_value,
  [15562] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1640), 1,
      anon_sym_RPAREN,
    ACTIONS(1858), 1,
      anon_sym_COMMA,
    STATE(683), 1,
      aux_sym__function_signature_repeat1,
  [15575] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1860), 1,
      anon_sym_RBRACE,
    STATE(887), 1,
      sym_simple_identifier,
  [15588] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1862), 1,
      anon_sym_SEMI,
    ACTIONS(1864), 1,
      anon_sym_COLON,
    ACTIONS(1866), 1,
      anon_sym_LT_EQ_GT,
  [15601] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1868), 1,
      anon_sym_LBRACE,
    ACTIONS(1870), 1,
      anon_sym_COLON_EQ,
    STATE(564), 1,
      sym_global_block,
  [15614] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1751), 1,
      anon_sym_COMMA,
    ACTIONS(1872), 1,
      anon_sym_RBRACE,
    STATE(686), 1,
      aux_sym__exported_type_repeat1,
  [15627] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_RPAREN,
    ACTIONS(1874), 1,
      anon_sym_COMMA,
    STATE(636), 1,
      aux_sym_tr_repeat1,
  [15640] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1561), 1,
      anon_sym_LBRACE,
    ACTIONS(1876), 1,
      anon_sym_DASH_GT,
    STATE(506), 1,
      sym_imperative_block,
  [15653] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      sym__identifier,
    ACTIONS(1878), 1,
      anon_sym_RBRACE,
    STATE(800), 1,
      sym_user_type_identifier,
  [15666] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(260), 1,
      anon_sym_RPAREN,
    ACTIONS(1880), 1,
      anon_sym_COMMA,
    STATE(675), 1,
      aux_sym_arguments_repeat1,
  [15679] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(288), 1,
      anon_sym_RPAREN,
    ACTIONS(1882), 1,
      anon_sym_COMMA,
    STATE(675), 1,
      aux_sym_arguments_repeat1,
  [15692] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1884), 1,
      anon_sym_COMMA,
    ACTIONS(1887), 1,
      anon_sym_RBRACE,
    STATE(721), 1,
      aux_sym_struct_block_repeat1,
  [15705] = 3,
    ACTIONS(1530), 1,
      sym_comment,
    ACTIONS(1891), 1,
      sym__unescaped_string_fragment,
    ACTIONS(1889), 2,
      anon_sym_DQUOTE,
      anon_sym_BSLASH,
  [15716] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      sym__identifier,
    ACTIONS(1893), 1,
      anon_sym_RBRACE,
    STATE(800), 1,
      sym_user_type_identifier,
  [15729] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1532), 1,
      anon_sym_LBRACE,
    ACTIONS(1895), 1,
      anon_sym_DASH_GT,
    STATE(528), 1,
      sym_imperative_block,
  [15742] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    STATE(289), 1,
      sym__string,
    STATE(843), 1,
      sym_string_value,
  [15755] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    STATE(289), 1,
      sym__string,
    STATE(662), 1,
      sym_string_value,
  [15768] = 3,
    ACTIONS(1530), 1,
      sym_comment,
    ACTIONS(1899), 1,
      sym__unescaped_string_fragment,
    ACTIONS(1897), 2,
      anon_sym_DQUOTE,
      anon_sym_BSLASH,
  [15779] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(916), 1,
      anon_sym_RPAREN,
    ACTIONS(1901), 1,
      anon_sym_COMMA,
    STATE(646), 1,
      aux_sym_type_list_repeat1,
  [15792] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(330), 1,
      anon_sym_RBRACK,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    STATE(636), 1,
      aux_sym_tr_repeat1,
  [15805] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(818), 1,
      sym_simple_identifier,
    STATE(870), 1,
      sym_simple_indexed_identifier,
  [15818] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1905), 1,
      anon_sym_COMMA,
    ACTIONS(1907), 1,
      anon_sym_RBRACE,
    STATE(744), 1,
      aux_sym_enum_block_repeat1,
  [15831] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    ACTIONS(1909), 1,
      anon_sym_COLON_EQ,
    STATE(581), 1,
      sym_struct_block,
  [15844] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1911), 1,
      anon_sym_RPAREN,
    ACTIONS(1913), 1,
      sym__int_number,
    STATE(736), 1,
      aux_sym_image_call_repeat1,
  [15857] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1915), 1,
      anon_sym_RBRACE,
    STATE(887), 1,
      sym_simple_identifier,
  [15870] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(741), 3,
      anon_sym_in,
      anon_sym_out,
      anon_sym_RBRACK,
  [15879] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1719), 1,
      sym__int_number,
    ACTIONS(1917), 1,
      anon_sym_RPAREN,
    STATE(745), 1,
      aux_sym_image_call_repeat1,
  [15892] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(817), 1,
      sym_typed_identifier,
    STATE(920), 1,
      sym_simple_identifier,
  [15905] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1919), 1,
      anon_sym_RPAREN,
    ACTIONS(1921), 1,
      sym__int_number,
    STATE(661), 1,
      aux_sym_image_call_repeat1,
  [15918] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1923), 1,
      anon_sym_SEMI,
    ACTIONS(1925), 1,
      anon_sym_COLON,
    ACTIONS(1927), 1,
      anon_sym_LT_EQ_GT,
  [15931] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(162), 1,
      sym__identifier,
    ACTIONS(1929), 1,
      anon_sym_property,
    STATE(890), 1,
      sym_simple_identifier,
  [15944] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1915), 1,
      anon_sym_RBRACE,
    ACTIONS(1931), 1,
      anon_sym_COMMA,
    STATE(681), 1,
      aux_sym_anon_struct_block_repeat1,
  [15957] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1532), 1,
      anon_sym_LBRACE,
    ACTIONS(1933), 1,
      anon_sym_DASH_GT,
    STATE(545), 1,
      sym_imperative_block,
  [15970] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1935), 1,
      anon_sym_COMMA,
    ACTIONS(1937), 1,
      anon_sym_RPAREN,
    ACTIONS(1939), 1,
      anon_sym_PIPE,
  [15983] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1941), 1,
      anon_sym_COMMA,
    ACTIONS(1944), 1,
      anon_sym_RBRACE,
    STATE(744), 1,
      aux_sym_enum_block_repeat1,
  [15996] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1946), 1,
      anon_sym_RPAREN,
    ACTIONS(1948), 1,
      sym__int_number,
    STATE(745), 1,
      aux_sym_image_call_repeat1,
  [16009] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(162), 1,
      sym__identifier,
    ACTIONS(1951), 1,
      anon_sym_property,
    STATE(902), 1,
      sym_simple_identifier,
  [16022] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    STATE(289), 1,
      sym__string,
    STATE(906), 1,
      sym_string_value,
  [16035] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    ACTIONS(1953), 1,
      anon_sym_RBRACE,
    STATE(858), 1,
      sym_simple_identifier,
  [16048] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1828), 1,
      anon_sym_COMMA,
    ACTIONS(1955), 1,
      anon_sym_RBRACE,
    STATE(699), 1,
      aux_sym_import_statement_repeat1,
  [16061] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DQUOTE,
    STATE(289), 1,
      sym__string,
    STATE(910), 1,
      sym_string_value,
  [16074] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COMMA,
    ACTIONS(1960), 1,
      anon_sym_RPAREN,
    STATE(751), 1,
      aux_sym_gradient_call_repeat1,
  [16087] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(332), 1,
      anon_sym_RPAREN,
    ACTIONS(1962), 1,
      anon_sym_COMMA,
    STATE(636), 1,
      aux_sym_tr_repeat1,
  [16100] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1964), 2,
      anon_sym_RBRACK,
      sym__identifier,
  [16108] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1532), 1,
      anon_sym_LBRACE,
    STATE(541), 1,
      sym_imperative_block,
  [16118] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(614), 1,
      sym_simple_identifier,
  [16128] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1966), 2,
      anon_sym_SEMI,
      anon_sym_DASH_GT,
  [16136] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1968), 1,
      anon_sym_SEMI,
    ACTIONS(1970), 1,
      anon_sym_DASH_GT,
  [16146] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1972), 2,
      anon_sym_LBRACE,
      anon_sym_DASH_GT,
  [16154] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(610), 1,
      sym_simple_identifier,
  [16164] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(861), 1,
      sym_simple_identifier,
  [16174] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1974), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [16182] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1976), 2,
      anon_sym_SEMI,
      anon_sym_DASH_GT,
  [16190] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1158), 2,
      anon_sym_RBRACE,
      anon_sym_animate,
  [16198] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1978), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [16206] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(879), 1,
      sym_simple_identifier,
  [16216] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      anon_sym_COMMA,
    ACTIONS(1982), 1,
      anon_sym_RPAREN,
  [16226] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(887), 1,
      sym_simple_identifier,
  [16236] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      sym__identifier,
    STATE(714), 1,
      sym_user_type_identifier,
  [16246] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1984), 2,
      anon_sym_LBRACE,
      anon_sym_DASH_GT,
  [16254] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(654), 1,
      sym_simple_identifier,
  [16264] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1532), 1,
      anon_sym_LBRACE,
    STATE(524), 1,
      sym_imperative_block,
  [16274] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1986), 1,
      anon_sym_SEMI,
    ACTIONS(1988), 1,
      anon_sym_DASH_GT,
  [16284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1990), 1,
      anon_sym_SEMI,
    ACTIONS(1992), 1,
      anon_sym_DASH_GT,
  [16294] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1561), 1,
      anon_sym_LBRACE,
    STATE(470), 1,
      sym_imperative_block,
  [16304] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(178), 1,
      anon_sym_RBRACE,
    ACTIONS(1994), 1,
      anon_sym_SEMI,
  [16314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1868), 1,
      anon_sym_LBRACE,
    STATE(560), 1,
      sym_global_block,
  [16324] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1222), 2,
      anon_sym_RBRACE,
      anon_sym_animate,
  [16332] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(892), 1,
      anon_sym_LPAREN,
    STATE(334), 1,
      sym_arguments,
  [16342] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1561), 1,
      anon_sym_LBRACE,
    STATE(507), 1,
      sym_imperative_block,
  [16352] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1532), 1,
      anon_sym_LBRACE,
    STATE(532), 1,
      sym_imperative_block,
  [16362] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1996), 2,
      anon_sym_LBRACE,
      anon_sym_DASH_GT,
  [16370] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1532), 1,
      anon_sym_LBRACE,
    STATE(520), 1,
      sym_imperative_block,
  [16380] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1772), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [16388] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1561), 1,
      anon_sym_LBRACE,
    STATE(502), 1,
      sym_imperative_block,
  [16398] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(739), 1,
      sym_simple_identifier,
  [16408] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1561), 1,
      anon_sym_LBRACE,
    STATE(501), 1,
      sym_imperative_block,
  [16418] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1532), 1,
      anon_sym_LBRACE,
    STATE(538), 1,
      sym_imperative_block,
  [16428] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      sym__identifier,
    STATE(761), 1,
      sym_user_type_identifier,
  [16438] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1998), 1,
      anon_sym_LBRACE,
    STATE(456), 1,
      sym_block,
  [16448] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1998), 1,
      anon_sym_LBRACE,
    STATE(493), 1,
      sym_block,
  [16458] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2000), 1,
      anon_sym_SEMI,
    ACTIONS(2002), 1,
      anon_sym_DASH_GT,
  [16468] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2004), 2,
      anon_sym_RBRACK,
      sym__identifier,
  [16476] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1994), 1,
      anon_sym_SEMI,
    ACTIONS(2006), 1,
      anon_sym_RBRACE,
  [16486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      sym__identifier,
    STATE(732), 1,
      sym_user_type_identifier,
  [16496] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1794), 1,
      anon_sym_LBRACE,
    STATE(572), 1,
      sym_block,
  [16506] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(898), 1,
      anon_sym_LBRACE,
    STATE(563), 1,
      sym_struct_block,
  [16516] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2008), 1,
      anon_sym_circle,
    STATE(918), 1,
      sym_radial_gradient_kind,
  [16526] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(639), 1,
      sym_simple_identifier,
  [16536] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      sym__identifier,
    STATE(801), 1,
      sym_user_type_identifier,
  [16546] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2010), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [16554] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2012), 1,
      anon_sym_LBRACE,
    STATE(567), 1,
      sym_enum_block,
  [16564] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2014), 2,
      anon_sym_RBRACK,
      sym__identifier,
  [16572] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      sym__identifier,
    STATE(811), 1,
      sym_user_type_identifier,
  [16582] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1494), 2,
      anon_sym_property,
      sym__identifier,
  [16590] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1686), 1,
      anon_sym_LBRACE,
    STATE(255), 1,
      sym_imperative_block,
  [16600] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      sym__identifier,
    STATE(800), 1,
      sym_user_type_identifier,
  [16610] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2016), 2,
      anon_sym_SEMI,
      anon_sym_DASH_GT,
  [16618] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(672), 1,
      sym_simple_identifier,
  [16628] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2018), 1,
      anon_sym_COMMA,
    ACTIONS(2020), 1,
      anon_sym_RPAREN,
  [16638] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(604), 1,
      sym_simple_identifier,
  [16648] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1794), 1,
      anon_sym_LBRACE,
    STATE(569), 1,
      sym_block,
  [16658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(700), 1,
      sym_simple_identifier,
  [16668] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(616), 1,
      sym_simple_identifier,
  [16678] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      sym__identifier,
    STATE(684), 1,
      sym_user_type_identifier,
  [16688] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2008), 1,
      anon_sym_circle,
    STATE(876), 1,
      sym_radial_gradient_kind,
  [16698] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2022), 2,
      anon_sym_LBRACE,
      anon_sym_DASH_GT,
  [16706] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1792), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [16714] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2024), 1,
      anon_sym_in,
    ACTIONS(2026), 1,
      anon_sym_LBRACK,
  [16724] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2028), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [16732] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(713), 1,
      sym_simple_identifier,
  [16742] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(613), 1,
      sym_simple_identifier,
  [16752] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1803), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [16760] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1561), 1,
      anon_sym_LBRACE,
    STATE(499), 1,
      sym_imperative_block,
  [16770] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(609), 1,
      sym_simple_identifier,
  [16780] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1561), 1,
      anon_sym_LBRACE,
    STATE(475), 1,
      sym_imperative_block,
  [16790] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 1,
      sym__identifier,
    STATE(858), 1,
      sym_simple_identifier,
  [16800] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      sym__identifier,
    STATE(789), 1,
      sym_user_type_identifier,
  [16810] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 1,
      sym__identifier,
    STATE(795), 1,
      sym_user_type_identifier,
  [16820] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2030), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [16828] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1826), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [16836] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2032), 2,
      anon_sym_SEMI,
      anon_sym_DASH_GT,
  [16844] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2034), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [16852] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1126), 2,
      anon_sym_RBRACE,
      anon_sym_animate,
  [16860] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(380), 1,
      anon_sym_LPAREN,
    STATE(215), 1,
      sym_arguments,
  [16870] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1960), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [16878] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2036), 1,
      anon_sym_COLON,
  [16885] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(990), 1,
      anon_sym_RBRACK,
  [16892] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1994), 1,
      anon_sym_SEMI,
  [16899] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1466), 1,
      anon_sym_COLON_EQ,
  [16906] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2038), 1,
      anon_sym_LPAREN,
  [16913] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2040), 1,
      anon_sym_LBRACK,
  [16920] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2042), 1,
      anon_sym_SEMI,
  [16927] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2044), 1,
      anon_sym_SEMI,
  [16934] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2046), 1,
      anon_sym_RBRACE,
  [16941] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2048), 1,
      anon_sym_LPAREN,
  [16948] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2050), 1,
      anon_sym_LPAREN,
  [16955] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2052), 1,
      anon_sym_LBRACE,
  [16962] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2054), 1,
      anon_sym_SEMI,
  [16969] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2056), 1,
      anon_sym_LBRACK,
  [16976] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2058), 1,
      anon_sym_LT_EQ_GT,
  [16983] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2060), 1,
      anon_sym_COLON,
  [16990] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2062), 1,
      anon_sym_LPAREN,
  [16997] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2064), 1,
      anon_sym_LT_EQ_GT,
  [17004] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2066), 1,
      anon_sym_RPAREN,
  [17011] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2068), 1,
      anon_sym_RBRACE,
  [17018] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1671), 1,
      anon_sym_EQ_GT,
  [17025] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1472), 1,
      anon_sym_EQ_GT,
  [17032] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2070), 1,
      anon_sym_COLON,
  [17039] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2072), 1,
      anon_sym_RBRACE,
  [17046] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2074), 1,
      anon_sym_SEMI,
  [17053] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2076), 1,
      anon_sym_RBRACK,
  [17060] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      ts_builtin_sym_end,
  [17067] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2080), 1,
      anon_sym_PERCENT,
  [17074] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2082), 1,
      anon_sym_RBRACE,
  [17081] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2084), 1,
      anon_sym_RPAREN,
  [17088] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2086), 1,
      anon_sym_nine_DASHslice,
  [17095] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2088), 1,
      anon_sym_from,
  [17102] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2090), 1,
      anon_sym_from,
  [17109] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2092), 1,
      anon_sym_SEMI,
  [17116] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2094), 1,
      anon_sym_in,
  [17123] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2096), 1,
      anon_sym_COLON,
  [17130] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1486), 1,
      aux_sym_angle_value_token1,
  [17137] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2098), 1,
      anon_sym_SEMI,
  [17144] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2100), 1,
      anon_sym_COMMA,
  [17151] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2102), 1,
      anon_sym_COMMA,
  [17158] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2104), 1,
      anon_sym_COMMA,
  [17165] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_RBRACK,
  [17172] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2106), 1,
      anon_sym_RPAREN,
  [17179] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2108), 1,
      anon_sym_EQ_GT,
  [17186] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2110), 1,
      anon_sym_from,
  [17193] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2112), 1,
      sym__identifier,
  [17200] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1004), 1,
      anon_sym_RBRACK,
  [17207] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2114), 1,
      anon_sym_SEMI,
  [17214] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2116), 1,
      anon_sym_RPAREN,
  [17221] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2118), 1,
      anon_sym_SEMI,
  [17228] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2120), 1,
      anon_sym_COLON_EQ,
  [17235] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2122), 1,
      anon_sym_COLON,
  [17242] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2124), 1,
      anon_sym_GT,
  [17249] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2126), 1,
      anon_sym_LBRACE,
  [17256] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2128), 1,
      anon_sym_LT_EQ_GT,
  [17263] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2130), 1,
      anon_sym_PERCENT,
  [17270] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2132), 1,
      anon_sym_LPAREN,
  [17277] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2134), 1,
      anon_sym_LPAREN,
  [17284] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2136), 1,
      anon_sym_in,
  [17291] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2138), 1,
      anon_sym_SEMI,
  [17298] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2140), 1,
      anon_sym_SEMI,
  [17305] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2142), 1,
      anon_sym_when,
  [17312] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2144), 1,
      anon_sym_LPAREN,
  [17319] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2146), 1,
      anon_sym_LPAREN,
  [17326] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2148), 1,
      anon_sym_LT_EQ_GT,
  [17333] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2150), 1,
      anon_sym_COMMA,
  [17340] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2152), 1,
      anon_sym_LT_EQ_GT,
  [17347] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2154), 1,
      anon_sym_COLON,
  [17354] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2156), 1,
      anon_sym_LT_EQ_GT,
  [17361] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1488), 1,
      anon_sym_PERCENT2,
  [17368] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2158), 1,
      anon_sym_PERCENT,
  [17375] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2160), 1,
      anon_sym_LPAREN,
  [17382] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2162), 1,
      anon_sym_COMMA,
  [17389] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2164), 1,
      anon_sym_COMMA,
  [17396] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2166), 1,
      anon_sym_PERCENT,
  [17403] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2168), 1,
      anon_sym_LPAREN,
  [17410] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2170), 1,
      anon_sym_COMMA,
  [17417] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2172), 1,
      anon_sym_nine_DASHslice,
  [17424] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2174), 1,
      anon_sym_SEMI,
  [17431] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2176), 1,
      anon_sym_COLON,
  [17438] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2178), 1,
      anon_sym_COLON,
  [17445] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2180), 1,
      anon_sym_COMMA,
  [17452] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2182), 1,
      anon_sym_COMMA,
  [17459] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2184), 1,
      anon_sym_SEMI,
  [17466] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2186), 1,
      anon_sym_COLON,
  [17473] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2188), 1,
      anon_sym_LPAREN,
  [17480] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2190), 1,
      anon_sym_LPAREN,
  [17487] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2192), 1,
      anon_sym_LBRACE,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(234)] = 0,
  [SMALL_STATE(235)] = 70,
  [SMALL_STATE(236)] = 138,
  [SMALL_STATE(237)] = 206,
  [SMALL_STATE(238)] = 273,
  [SMALL_STATE(239)] = 340,
  [SMALL_STATE(240)] = 407,
  [SMALL_STATE(241)] = 474,
  [SMALL_STATE(242)] = 543,
  [SMALL_STATE(243)] = 612,
  [SMALL_STATE(244)] = 681,
  [SMALL_STATE(245)] = 750,
  [SMALL_STATE(246)] = 819,
  [SMALL_STATE(247)] = 888,
  [SMALL_STATE(248)] = 955,
  [SMALL_STATE(249)] = 1022,
  [SMALL_STATE(250)] = 1089,
  [SMALL_STATE(251)] = 1156,
  [SMALL_STATE(252)] = 1222,
  [SMALL_STATE(253)] = 1288,
  [SMALL_STATE(254)] = 1354,
  [SMALL_STATE(255)] = 1420,
  [SMALL_STATE(256)] = 1486,
  [SMALL_STATE(257)] = 1552,
  [SMALL_STATE(258)] = 1618,
  [SMALL_STATE(259)] = 1684,
  [SMALL_STATE(260)] = 1750,
  [SMALL_STATE(261)] = 1816,
  [SMALL_STATE(262)] = 1879,
  [SMALL_STATE(263)] = 1942,
  [SMALL_STATE(264)] = 2005,
  [SMALL_STATE(265)] = 2068,
  [SMALL_STATE(266)] = 2131,
  [SMALL_STATE(267)] = 2194,
  [SMALL_STATE(268)] = 2288,
  [SMALL_STATE(269)] = 2382,
  [SMALL_STATE(270)] = 2476,
  [SMALL_STATE(271)] = 2567,
  [SMALL_STATE(272)] = 2658,
  [SMALL_STATE(273)] = 2749,
  [SMALL_STATE(274)] = 2840,
  [SMALL_STATE(275)] = 2931,
  [SMALL_STATE(276)] = 3022,
  [SMALL_STATE(277)] = 3113,
  [SMALL_STATE(278)] = 3160,
  [SMALL_STATE(279)] = 3206,
  [SMALL_STATE(280)] = 3247,
  [SMALL_STATE(281)] = 3290,
  [SMALL_STATE(282)] = 3333,
  [SMALL_STATE(283)] = 3381,
  [SMALL_STATE(284)] = 3419,
  [SMALL_STATE(285)] = 3471,
  [SMALL_STATE(286)] = 3519,
  [SMALL_STATE(287)] = 3575,
  [SMALL_STATE(288)] = 3613,
  [SMALL_STATE(289)] = 3671,
  [SMALL_STATE(290)] = 3709,
  [SMALL_STATE(291)] = 3755,
  [SMALL_STATE(292)] = 3813,
  [SMALL_STATE(293)] = 3863,
  [SMALL_STATE(294)] = 3904,
  [SMALL_STATE(295)] = 3940,
  [SMALL_STATE(296)] = 3976,
  [SMALL_STATE(297)] = 4012,
  [SMALL_STATE(298)] = 4048,
  [SMALL_STATE(299)] = 4084,
  [SMALL_STATE(300)] = 4119,
  [SMALL_STATE(301)] = 4154,
  [SMALL_STATE(302)] = 4189,
  [SMALL_STATE(303)] = 4224,
  [SMALL_STATE(304)] = 4259,
  [SMALL_STATE(305)] = 4294,
  [SMALL_STATE(306)] = 4329,
  [SMALL_STATE(307)] = 4364,
  [SMALL_STATE(308)] = 4399,
  [SMALL_STATE(309)] = 4434,
  [SMALL_STATE(310)] = 4469,
  [SMALL_STATE(311)] = 4504,
  [SMALL_STATE(312)] = 4539,
  [SMALL_STATE(313)] = 4574,
  [SMALL_STATE(314)] = 4609,
  [SMALL_STATE(315)] = 4644,
  [SMALL_STATE(316)] = 4679,
  [SMALL_STATE(317)] = 4714,
  [SMALL_STATE(318)] = 4749,
  [SMALL_STATE(319)] = 4784,
  [SMALL_STATE(320)] = 4819,
  [SMALL_STATE(321)] = 4854,
  [SMALL_STATE(322)] = 4889,
  [SMALL_STATE(323)] = 4924,
  [SMALL_STATE(324)] = 4959,
  [SMALL_STATE(325)] = 4994,
  [SMALL_STATE(326)] = 5029,
  [SMALL_STATE(327)] = 5064,
  [SMALL_STATE(328)] = 5099,
  [SMALL_STATE(329)] = 5134,
  [SMALL_STATE(330)] = 5169,
  [SMALL_STATE(331)] = 5204,
  [SMALL_STATE(332)] = 5239,
  [SMALL_STATE(333)] = 5274,
  [SMALL_STATE(334)] = 5309,
  [SMALL_STATE(335)] = 5344,
  [SMALL_STATE(336)] = 5379,
  [SMALL_STATE(337)] = 5414,
  [SMALL_STATE(338)] = 5449,
  [SMALL_STATE(339)] = 5484,
  [SMALL_STATE(340)] = 5519,
  [SMALL_STATE(341)] = 5554,
  [SMALL_STATE(342)] = 5589,
  [SMALL_STATE(343)] = 5624,
  [SMALL_STATE(344)] = 5663,
  [SMALL_STATE(345)] = 5698,
  [SMALL_STATE(346)] = 5733,
  [SMALL_STATE(347)] = 5768,
  [SMALL_STATE(348)] = 5803,
  [SMALL_STATE(349)] = 5838,
  [SMALL_STATE(350)] = 5873,
  [SMALL_STATE(351)] = 5908,
  [SMALL_STATE(352)] = 5943,
  [SMALL_STATE(353)] = 5978,
  [SMALL_STATE(354)] = 6013,
  [SMALL_STATE(355)] = 6072,
  [SMALL_STATE(356)] = 6117,
  [SMALL_STATE(357)] = 6152,
  [SMALL_STATE(358)] = 6187,
  [SMALL_STATE(359)] = 6229,
  [SMALL_STATE(360)] = 6271,
  [SMALL_STATE(361)] = 6313,
  [SMALL_STATE(362)] = 6355,
  [SMALL_STATE(363)] = 6397,
  [SMALL_STATE(364)] = 6436,
  [SMALL_STATE(365)] = 6475,
  [SMALL_STATE(366)] = 6514,
  [SMALL_STATE(367)] = 6553,
  [SMALL_STATE(368)] = 6610,
  [SMALL_STATE(369)] = 6649,
  [SMALL_STATE(370)] = 6706,
  [SMALL_STATE(371)] = 6745,
  [SMALL_STATE(372)] = 6784,
  [SMALL_STATE(373)] = 6823,
  [SMALL_STATE(374)] = 6880,
  [SMALL_STATE(375)] = 6919,
  [SMALL_STATE(376)] = 6958,
  [SMALL_STATE(377)] = 6997,
  [SMALL_STATE(378)] = 7036,
  [SMALL_STATE(379)] = 7075,
  [SMALL_STATE(380)] = 7115,
  [SMALL_STATE(381)] = 7171,
  [SMALL_STATE(382)] = 7215,
  [SMALL_STATE(383)] = 7265,
  [SMALL_STATE(384)] = 7311,
  [SMALL_STATE(385)] = 7351,
  [SMALL_STATE(386)] = 7403,
  [SMALL_STATE(387)] = 7455,
  [SMALL_STATE(388)] = 7515,
  [SMALL_STATE(389)] = 7575,
  [SMALL_STATE(390)] = 7613,
  [SMALL_STATE(391)] = 7673,
  [SMALL_STATE(392)] = 7730,
  [SMALL_STATE(393)] = 7787,
  [SMALL_STATE(394)] = 7844,
  [SMALL_STATE(395)] = 7901,
  [SMALL_STATE(396)] = 7958,
  [SMALL_STATE(397)] = 8015,
  [SMALL_STATE(398)] = 8072,
  [SMALL_STATE(399)] = 8129,
  [SMALL_STATE(400)] = 8182,
  [SMALL_STATE(401)] = 8239,
  [SMALL_STATE(402)] = 8296,
  [SMALL_STATE(403)] = 8353,
  [SMALL_STATE(404)] = 8410,
  [SMALL_STATE(405)] = 8464,
  [SMALL_STATE(406)] = 8518,
  [SMALL_STATE(407)] = 8570,
  [SMALL_STATE(408)] = 8604,
  [SMALL_STATE(409)] = 8656,
  [SMALL_STATE(410)] = 8708,
  [SMALL_STATE(411)] = 8762,
  [SMALL_STATE(412)] = 8816,
  [SMALL_STATE(413)] = 8870,
  [SMALL_STATE(414)] = 8924,
  [SMALL_STATE(415)] = 8978,
  [SMALL_STATE(416)] = 9029,
  [SMALL_STATE(417)] = 9080,
  [SMALL_STATE(418)] = 9131,
  [SMALL_STATE(419)] = 9182,
  [SMALL_STATE(420)] = 9233,
  [SMALL_STATE(421)] = 9284,
  [SMALL_STATE(422)] = 9335,
  [SMALL_STATE(423)] = 9386,
  [SMALL_STATE(424)] = 9437,
  [SMALL_STATE(425)] = 9488,
  [SMALL_STATE(426)] = 9539,
  [SMALL_STATE(427)] = 9590,
  [SMALL_STATE(428)] = 9641,
  [SMALL_STATE(429)] = 9692,
  [SMALL_STATE(430)] = 9743,
  [SMALL_STATE(431)] = 9794,
  [SMALL_STATE(432)] = 9825,
  [SMALL_STATE(433)] = 9876,
  [SMALL_STATE(434)] = 9927,
  [SMALL_STATE(435)] = 9978,
  [SMALL_STATE(436)] = 10029,
  [SMALL_STATE(437)] = 10058,
  [SMALL_STATE(438)] = 10109,
  [SMALL_STATE(439)] = 10160,
  [SMALL_STATE(440)] = 10211,
  [SMALL_STATE(441)] = 10262,
  [SMALL_STATE(442)] = 10291,
  [SMALL_STATE(443)] = 10342,
  [SMALL_STATE(444)] = 10393,
  [SMALL_STATE(445)] = 10422,
  [SMALL_STATE(446)] = 10473,
  [SMALL_STATE(447)] = 10524,
  [SMALL_STATE(448)] = 10551,
  [SMALL_STATE(449)] = 10602,
  [SMALL_STATE(450)] = 10653,
  [SMALL_STATE(451)] = 10704,
  [SMALL_STATE(452)] = 10755,
  [SMALL_STATE(453)] = 10806,
  [SMALL_STATE(454)] = 10832,
  [SMALL_STATE(455)] = 10860,
  [SMALL_STATE(456)] = 10886,
  [SMALL_STATE(457)] = 10912,
  [SMALL_STATE(458)] = 10938,
  [SMALL_STATE(459)] = 10964,
  [SMALL_STATE(460)] = 10990,
  [SMALL_STATE(461)] = 11016,
  [SMALL_STATE(462)] = 11042,
  [SMALL_STATE(463)] = 11068,
  [SMALL_STATE(464)] = 11096,
  [SMALL_STATE(465)] = 11122,
  [SMALL_STATE(466)] = 11148,
  [SMALL_STATE(467)] = 11174,
  [SMALL_STATE(468)] = 11200,
  [SMALL_STATE(469)] = 11226,
  [SMALL_STATE(470)] = 11252,
  [SMALL_STATE(471)] = 11278,
  [SMALL_STATE(472)] = 11304,
  [SMALL_STATE(473)] = 11332,
  [SMALL_STATE(474)] = 11358,
  [SMALL_STATE(475)] = 11384,
  [SMALL_STATE(476)] = 11410,
  [SMALL_STATE(477)] = 11436,
  [SMALL_STATE(478)] = 11464,
  [SMALL_STATE(479)] = 11490,
  [SMALL_STATE(480)] = 11516,
  [SMALL_STATE(481)] = 11542,
  [SMALL_STATE(482)] = 11570,
  [SMALL_STATE(483)] = 11596,
  [SMALL_STATE(484)] = 11622,
  [SMALL_STATE(485)] = 11648,
  [SMALL_STATE(486)] = 11674,
  [SMALL_STATE(487)] = 11700,
  [SMALL_STATE(488)] = 11726,
  [SMALL_STATE(489)] = 11752,
  [SMALL_STATE(490)] = 11780,
  [SMALL_STATE(491)] = 11806,
  [SMALL_STATE(492)] = 11832,
  [SMALL_STATE(493)] = 11860,
  [SMALL_STATE(494)] = 11886,
  [SMALL_STATE(495)] = 11914,
  [SMALL_STATE(496)] = 11940,
  [SMALL_STATE(497)] = 11966,
  [SMALL_STATE(498)] = 11992,
  [SMALL_STATE(499)] = 12020,
  [SMALL_STATE(500)] = 12046,
  [SMALL_STATE(501)] = 12072,
  [SMALL_STATE(502)] = 12098,
  [SMALL_STATE(503)] = 12124,
  [SMALL_STATE(504)] = 12166,
  [SMALL_STATE(505)] = 12208,
  [SMALL_STATE(506)] = 12234,
  [SMALL_STATE(507)] = 12260,
  [SMALL_STATE(508)] = 12286,
  [SMALL_STATE(509)] = 12312,
  [SMALL_STATE(510)] = 12338,
  [SMALL_STATE(511)] = 12362,
  [SMALL_STATE(512)] = 12391,
  [SMALL_STATE(513)] = 12413,
  [SMALL_STATE(514)] = 12435,
  [SMALL_STATE(515)] = 12457,
  [SMALL_STATE(516)] = 12479,
  [SMALL_STATE(517)] = 12501,
  [SMALL_STATE(518)] = 12523,
  [SMALL_STATE(519)] = 12543,
  [SMALL_STATE(520)] = 12565,
  [SMALL_STATE(521)] = 12584,
  [SMALL_STATE(522)] = 12603,
  [SMALL_STATE(523)] = 12622,
  [SMALL_STATE(524)] = 12641,
  [SMALL_STATE(525)] = 12660,
  [SMALL_STATE(526)] = 12679,
  [SMALL_STATE(527)] = 12698,
  [SMALL_STATE(528)] = 12717,
  [SMALL_STATE(529)] = 12736,
  [SMALL_STATE(530)] = 12755,
  [SMALL_STATE(531)] = 12774,
  [SMALL_STATE(532)] = 12793,
  [SMALL_STATE(533)] = 12812,
  [SMALL_STATE(534)] = 12831,
  [SMALL_STATE(535)] = 12850,
  [SMALL_STATE(536)] = 12869,
  [SMALL_STATE(537)] = 12888,
  [SMALL_STATE(538)] = 12907,
  [SMALL_STATE(539)] = 12926,
  [SMALL_STATE(540)] = 12945,
  [SMALL_STATE(541)] = 12964,
  [SMALL_STATE(542)] = 12983,
  [SMALL_STATE(543)] = 13002,
  [SMALL_STATE(544)] = 13021,
  [SMALL_STATE(545)] = 13040,
  [SMALL_STATE(546)] = 13059,
  [SMALL_STATE(547)] = 13078,
  [SMALL_STATE(548)] = 13097,
  [SMALL_STATE(549)] = 13116,
  [SMALL_STATE(550)] = 13132,
  [SMALL_STATE(551)] = 13153,
  [SMALL_STATE(552)] = 13174,
  [SMALL_STATE(553)] = 13195,
  [SMALL_STATE(554)] = 13216,
  [SMALL_STATE(555)] = 13237,
  [SMALL_STATE(556)] = 13253,
  [SMALL_STATE(557)] = 13269,
  [SMALL_STATE(558)] = 13285,
  [SMALL_STATE(559)] = 13301,
  [SMALL_STATE(560)] = 13317,
  [SMALL_STATE(561)] = 13333,
  [SMALL_STATE(562)] = 13349,
  [SMALL_STATE(563)] = 13365,
  [SMALL_STATE(564)] = 13381,
  [SMALL_STATE(565)] = 13397,
  [SMALL_STATE(566)] = 13413,
  [SMALL_STATE(567)] = 13429,
  [SMALL_STATE(568)] = 13445,
  [SMALL_STATE(569)] = 13461,
  [SMALL_STATE(570)] = 13477,
  [SMALL_STATE(571)] = 13493,
  [SMALL_STATE(572)] = 13509,
  [SMALL_STATE(573)] = 13525,
  [SMALL_STATE(574)] = 13541,
  [SMALL_STATE(575)] = 13557,
  [SMALL_STATE(576)] = 13573,
  [SMALL_STATE(577)] = 13589,
  [SMALL_STATE(578)] = 13605,
  [SMALL_STATE(579)] = 13621,
  [SMALL_STATE(580)] = 13637,
  [SMALL_STATE(581)] = 13651,
  [SMALL_STATE(582)] = 13667,
  [SMALL_STATE(583)] = 13690,
  [SMALL_STATE(584)] = 13709,
  [SMALL_STATE(585)] = 13728,
  [SMALL_STATE(586)] = 13751,
  [SMALL_STATE(587)] = 13770,
  [SMALL_STATE(588)] = 13788,
  [SMALL_STATE(589)] = 13810,
  [SMALL_STATE(590)] = 13822,
  [SMALL_STATE(591)] = 13840,
  [SMALL_STATE(592)] = 13862,
  [SMALL_STATE(593)] = 13874,
  [SMALL_STATE(594)] = 13896,
  [SMALL_STATE(595)] = 13908,
  [SMALL_STATE(596)] = 13922,
  [SMALL_STATE(597)] = 13934,
  [SMALL_STATE(598)] = 13954,
  [SMALL_STATE(599)] = 13966,
  [SMALL_STATE(600)] = 13978,
  [SMALL_STATE(601)] = 14000,
  [SMALL_STATE(602)] = 14016,
  [SMALL_STATE(603)] = 14038,
  [SMALL_STATE(604)] = 14055,
  [SMALL_STATE(605)] = 14074,
  [SMALL_STATE(606)] = 14091,
  [SMALL_STATE(607)] = 14108,
  [SMALL_STATE(608)] = 14125,
  [SMALL_STATE(609)] = 14140,
  [SMALL_STATE(610)] = 14159,
  [SMALL_STATE(611)] = 14178,
  [SMALL_STATE(612)] = 14191,
  [SMALL_STATE(613)] = 14204,
  [SMALL_STATE(614)] = 14223,
  [SMALL_STATE(615)] = 14242,
  [SMALL_STATE(616)] = 14257,
  [SMALL_STATE(617)] = 14276,
  [SMALL_STATE(618)] = 14287,
  [SMALL_STATE(619)] = 14304,
  [SMALL_STATE(620)] = 14319,
  [SMALL_STATE(621)] = 14332,
  [SMALL_STATE(622)] = 14348,
  [SMALL_STATE(623)] = 14364,
  [SMALL_STATE(624)] = 14380,
  [SMALL_STATE(625)] = 14396,
  [SMALL_STATE(626)] = 14412,
  [SMALL_STATE(627)] = 14428,
  [SMALL_STATE(628)] = 14444,
  [SMALL_STATE(629)] = 14458,
  [SMALL_STATE(630)] = 14474,
  [SMALL_STATE(631)] = 14490,
  [SMALL_STATE(632)] = 14504,
  [SMALL_STATE(633)] = 14520,
  [SMALL_STATE(634)] = 14534,
  [SMALL_STATE(635)] = 14548,
  [SMALL_STATE(636)] = 14562,
  [SMALL_STATE(637)] = 14576,
  [SMALL_STATE(638)] = 14592,
  [SMALL_STATE(639)] = 14602,
  [SMALL_STATE(640)] = 14618,
  [SMALL_STATE(641)] = 14634,
  [SMALL_STATE(642)] = 14650,
  [SMALL_STATE(643)] = 14666,
  [SMALL_STATE(644)] = 14682,
  [SMALL_STATE(645)] = 14696,
  [SMALL_STATE(646)] = 14712,
  [SMALL_STATE(647)] = 14726,
  [SMALL_STATE(648)] = 14742,
  [SMALL_STATE(649)] = 14756,
  [SMALL_STATE(650)] = 14772,
  [SMALL_STATE(651)] = 14786,
  [SMALL_STATE(652)] = 14802,
  [SMALL_STATE(653)] = 14818,
  [SMALL_STATE(654)] = 14834,
  [SMALL_STATE(655)] = 14850,
  [SMALL_STATE(656)] = 14863,
  [SMALL_STATE(657)] = 14876,
  [SMALL_STATE(658)] = 14889,
  [SMALL_STATE(659)] = 14902,
  [SMALL_STATE(660)] = 14915,
  [SMALL_STATE(661)] = 14928,
  [SMALL_STATE(662)] = 14941,
  [SMALL_STATE(663)] = 14954,
  [SMALL_STATE(664)] = 14967,
  [SMALL_STATE(665)] = 14980,
  [SMALL_STATE(666)] = 14993,
  [SMALL_STATE(667)] = 15006,
  [SMALL_STATE(668)] = 15019,
  [SMALL_STATE(669)] = 15032,
  [SMALL_STATE(670)] = 15045,
  [SMALL_STATE(671)] = 15058,
  [SMALL_STATE(672)] = 15067,
  [SMALL_STATE(673)] = 15080,
  [SMALL_STATE(674)] = 15093,
  [SMALL_STATE(675)] = 15106,
  [SMALL_STATE(676)] = 15119,
  [SMALL_STATE(677)] = 15132,
  [SMALL_STATE(678)] = 15141,
  [SMALL_STATE(679)] = 15154,
  [SMALL_STATE(680)] = 15167,
  [SMALL_STATE(681)] = 15180,
  [SMALL_STATE(682)] = 15193,
  [SMALL_STATE(683)] = 15206,
  [SMALL_STATE(684)] = 15219,
  [SMALL_STATE(685)] = 15232,
  [SMALL_STATE(686)] = 15245,
  [SMALL_STATE(687)] = 15258,
  [SMALL_STATE(688)] = 15271,
  [SMALL_STATE(689)] = 15284,
  [SMALL_STATE(690)] = 15295,
  [SMALL_STATE(691)] = 15308,
  [SMALL_STATE(692)] = 15321,
  [SMALL_STATE(693)] = 15334,
  [SMALL_STATE(694)] = 15347,
  [SMALL_STATE(695)] = 15360,
  [SMALL_STATE(696)] = 15373,
  [SMALL_STATE(697)] = 15386,
  [SMALL_STATE(698)] = 15399,
  [SMALL_STATE(699)] = 15412,
  [SMALL_STATE(700)] = 15425,
  [SMALL_STATE(701)] = 15438,
  [SMALL_STATE(702)] = 15451,
  [SMALL_STATE(703)] = 15464,
  [SMALL_STATE(704)] = 15477,
  [SMALL_STATE(705)] = 15490,
  [SMALL_STATE(706)] = 15503,
  [SMALL_STATE(707)] = 15516,
  [SMALL_STATE(708)] = 15527,
  [SMALL_STATE(709)] = 15536,
  [SMALL_STATE(710)] = 15549,
  [SMALL_STATE(711)] = 15562,
  [SMALL_STATE(712)] = 15575,
  [SMALL_STATE(713)] = 15588,
  [SMALL_STATE(714)] = 15601,
  [SMALL_STATE(715)] = 15614,
  [SMALL_STATE(716)] = 15627,
  [SMALL_STATE(717)] = 15640,
  [SMALL_STATE(718)] = 15653,
  [SMALL_STATE(719)] = 15666,
  [SMALL_STATE(720)] = 15679,
  [SMALL_STATE(721)] = 15692,
  [SMALL_STATE(722)] = 15705,
  [SMALL_STATE(723)] = 15716,
  [SMALL_STATE(724)] = 15729,
  [SMALL_STATE(725)] = 15742,
  [SMALL_STATE(726)] = 15755,
  [SMALL_STATE(727)] = 15768,
  [SMALL_STATE(728)] = 15779,
  [SMALL_STATE(729)] = 15792,
  [SMALL_STATE(730)] = 15805,
  [SMALL_STATE(731)] = 15818,
  [SMALL_STATE(732)] = 15831,
  [SMALL_STATE(733)] = 15844,
  [SMALL_STATE(734)] = 15857,
  [SMALL_STATE(735)] = 15870,
  [SMALL_STATE(736)] = 15879,
  [SMALL_STATE(737)] = 15892,
  [SMALL_STATE(738)] = 15905,
  [SMALL_STATE(739)] = 15918,
  [SMALL_STATE(740)] = 15931,
  [SMALL_STATE(741)] = 15944,
  [SMALL_STATE(742)] = 15957,
  [SMALL_STATE(743)] = 15970,
  [SMALL_STATE(744)] = 15983,
  [SMALL_STATE(745)] = 15996,
  [SMALL_STATE(746)] = 16009,
  [SMALL_STATE(747)] = 16022,
  [SMALL_STATE(748)] = 16035,
  [SMALL_STATE(749)] = 16048,
  [SMALL_STATE(750)] = 16061,
  [SMALL_STATE(751)] = 16074,
  [SMALL_STATE(752)] = 16087,
  [SMALL_STATE(753)] = 16100,
  [SMALL_STATE(754)] = 16108,
  [SMALL_STATE(755)] = 16118,
  [SMALL_STATE(756)] = 16128,
  [SMALL_STATE(757)] = 16136,
  [SMALL_STATE(758)] = 16146,
  [SMALL_STATE(759)] = 16154,
  [SMALL_STATE(760)] = 16164,
  [SMALL_STATE(761)] = 16174,
  [SMALL_STATE(762)] = 16182,
  [SMALL_STATE(763)] = 16190,
  [SMALL_STATE(764)] = 16198,
  [SMALL_STATE(765)] = 16206,
  [SMALL_STATE(766)] = 16216,
  [SMALL_STATE(767)] = 16226,
  [SMALL_STATE(768)] = 16236,
  [SMALL_STATE(769)] = 16246,
  [SMALL_STATE(770)] = 16254,
  [SMALL_STATE(771)] = 16264,
  [SMALL_STATE(772)] = 16274,
  [SMALL_STATE(773)] = 16284,
  [SMALL_STATE(774)] = 16294,
  [SMALL_STATE(775)] = 16304,
  [SMALL_STATE(776)] = 16314,
  [SMALL_STATE(777)] = 16324,
  [SMALL_STATE(778)] = 16332,
  [SMALL_STATE(779)] = 16342,
  [SMALL_STATE(780)] = 16352,
  [SMALL_STATE(781)] = 16362,
  [SMALL_STATE(782)] = 16370,
  [SMALL_STATE(783)] = 16380,
  [SMALL_STATE(784)] = 16388,
  [SMALL_STATE(785)] = 16398,
  [SMALL_STATE(786)] = 16408,
  [SMALL_STATE(787)] = 16418,
  [SMALL_STATE(788)] = 16428,
  [SMALL_STATE(789)] = 16438,
  [SMALL_STATE(790)] = 16448,
  [SMALL_STATE(791)] = 16458,
  [SMALL_STATE(792)] = 16468,
  [SMALL_STATE(793)] = 16476,
  [SMALL_STATE(794)] = 16486,
  [SMALL_STATE(795)] = 16496,
  [SMALL_STATE(796)] = 16506,
  [SMALL_STATE(797)] = 16516,
  [SMALL_STATE(798)] = 16526,
  [SMALL_STATE(799)] = 16536,
  [SMALL_STATE(800)] = 16546,
  [SMALL_STATE(801)] = 16554,
  [SMALL_STATE(802)] = 16564,
  [SMALL_STATE(803)] = 16572,
  [SMALL_STATE(804)] = 16582,
  [SMALL_STATE(805)] = 16590,
  [SMALL_STATE(806)] = 16600,
  [SMALL_STATE(807)] = 16610,
  [SMALL_STATE(808)] = 16618,
  [SMALL_STATE(809)] = 16628,
  [SMALL_STATE(810)] = 16638,
  [SMALL_STATE(811)] = 16648,
  [SMALL_STATE(812)] = 16658,
  [SMALL_STATE(813)] = 16668,
  [SMALL_STATE(814)] = 16678,
  [SMALL_STATE(815)] = 16688,
  [SMALL_STATE(816)] = 16698,
  [SMALL_STATE(817)] = 16706,
  [SMALL_STATE(818)] = 16714,
  [SMALL_STATE(819)] = 16724,
  [SMALL_STATE(820)] = 16732,
  [SMALL_STATE(821)] = 16742,
  [SMALL_STATE(822)] = 16752,
  [SMALL_STATE(823)] = 16760,
  [SMALL_STATE(824)] = 16770,
  [SMALL_STATE(825)] = 16780,
  [SMALL_STATE(826)] = 16790,
  [SMALL_STATE(827)] = 16800,
  [SMALL_STATE(828)] = 16810,
  [SMALL_STATE(829)] = 16820,
  [SMALL_STATE(830)] = 16828,
  [SMALL_STATE(831)] = 16836,
  [SMALL_STATE(832)] = 16844,
  [SMALL_STATE(833)] = 16852,
  [SMALL_STATE(834)] = 16860,
  [SMALL_STATE(835)] = 16870,
  [SMALL_STATE(836)] = 16878,
  [SMALL_STATE(837)] = 16885,
  [SMALL_STATE(838)] = 16892,
  [SMALL_STATE(839)] = 16899,
  [SMALL_STATE(840)] = 16906,
  [SMALL_STATE(841)] = 16913,
  [SMALL_STATE(842)] = 16920,
  [SMALL_STATE(843)] = 16927,
  [SMALL_STATE(844)] = 16934,
  [SMALL_STATE(845)] = 16941,
  [SMALL_STATE(846)] = 16948,
  [SMALL_STATE(847)] = 16955,
  [SMALL_STATE(848)] = 16962,
  [SMALL_STATE(849)] = 16969,
  [SMALL_STATE(850)] = 16976,
  [SMALL_STATE(851)] = 16983,
  [SMALL_STATE(852)] = 16990,
  [SMALL_STATE(853)] = 16997,
  [SMALL_STATE(854)] = 17004,
  [SMALL_STATE(855)] = 17011,
  [SMALL_STATE(856)] = 17018,
  [SMALL_STATE(857)] = 17025,
  [SMALL_STATE(858)] = 17032,
  [SMALL_STATE(859)] = 17039,
  [SMALL_STATE(860)] = 17046,
  [SMALL_STATE(861)] = 17053,
  [SMALL_STATE(862)] = 17060,
  [SMALL_STATE(863)] = 17067,
  [SMALL_STATE(864)] = 17074,
  [SMALL_STATE(865)] = 17081,
  [SMALL_STATE(866)] = 17088,
  [SMALL_STATE(867)] = 17095,
  [SMALL_STATE(868)] = 17102,
  [SMALL_STATE(869)] = 17109,
  [SMALL_STATE(870)] = 17116,
  [SMALL_STATE(871)] = 17123,
  [SMALL_STATE(872)] = 17130,
  [SMALL_STATE(873)] = 17137,
  [SMALL_STATE(874)] = 17144,
  [SMALL_STATE(875)] = 17151,
  [SMALL_STATE(876)] = 17158,
  [SMALL_STATE(877)] = 17165,
  [SMALL_STATE(878)] = 17172,
  [SMALL_STATE(879)] = 17179,
  [SMALL_STATE(880)] = 17186,
  [SMALL_STATE(881)] = 17193,
  [SMALL_STATE(882)] = 17200,
  [SMALL_STATE(883)] = 17207,
  [SMALL_STATE(884)] = 17214,
  [SMALL_STATE(885)] = 17221,
  [SMALL_STATE(886)] = 17228,
  [SMALL_STATE(887)] = 17235,
  [SMALL_STATE(888)] = 17242,
  [SMALL_STATE(889)] = 17249,
  [SMALL_STATE(890)] = 17256,
  [SMALL_STATE(891)] = 17263,
  [SMALL_STATE(892)] = 17270,
  [SMALL_STATE(893)] = 17277,
  [SMALL_STATE(894)] = 17284,
  [SMALL_STATE(895)] = 17291,
  [SMALL_STATE(896)] = 17298,
  [SMALL_STATE(897)] = 17305,
  [SMALL_STATE(898)] = 17312,
  [SMALL_STATE(899)] = 17319,
  [SMALL_STATE(900)] = 17326,
  [SMALL_STATE(901)] = 17333,
  [SMALL_STATE(902)] = 17340,
  [SMALL_STATE(903)] = 17347,
  [SMALL_STATE(904)] = 17354,
  [SMALL_STATE(905)] = 17361,
  [SMALL_STATE(906)] = 17368,
  [SMALL_STATE(907)] = 17375,
  [SMALL_STATE(908)] = 17382,
  [SMALL_STATE(909)] = 17389,
  [SMALL_STATE(910)] = 17396,
  [SMALL_STATE(911)] = 17403,
  [SMALL_STATE(912)] = 17410,
  [SMALL_STATE(913)] = 17417,
  [SMALL_STATE(914)] = 17424,
  [SMALL_STATE(915)] = 17431,
  [SMALL_STATE(916)] = 17438,
  [SMALL_STATE(917)] = 17445,
  [SMALL_STATE(918)] = 17452,
  [SMALL_STATE(919)] = 17459,
  [SMALL_STATE(920)] = 17466,
  [SMALL_STATE(921)] = 17473,
  [SMALL_STATE(922)] = 17480,
  [SMALL_STATE(923)] = 17487,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sourcefile, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(511),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(627),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(814),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(768),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(794),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(799),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(549),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(60),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(121),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(202),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(834),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(203),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(149),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(204),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [73] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(622),
  [76] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0),
  [78] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(60),
  [81] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(35),
  [84] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(121),
  [87] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(130),
  [90] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [93] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(899),
  [96] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(262),
  [99] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(606),
  [102] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(166),
  [105] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(202),
  [108] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(834),
  [111] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(893),
  [114] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(911),
  [117] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(203),
  [120] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(149),
  [123] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(150),
  [126] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(204),
  [129] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_imperative_block_repeat1, 2, 0, 0), SHIFT_REPEAT(205),
  [132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(135),
  [152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(279),
  [164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(351),
  [166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(352),
  [170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(281),
  [172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [180] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(642),
  [183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0),
  [185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(135),
  [188] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(40),
  [191] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(122),
  [194] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(840),
  [197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(852),
  [200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(262),
  [203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(607),
  [206] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(279),
  [209] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(351),
  [212] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(778),
  [215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(893),
  [218] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(911),
  [221] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(352),
  [224] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(281),
  [227] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(280),
  [230] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(300),
  [233] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(336),
  [236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(357),
  [240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_int_value, 1, 0, 0),
  [340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_int_value, 1, 0, 0),
  [342] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__number, 1, 0, 0),
  [344] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__number, 1, 0, 0),
  [346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_float_value, 1, 0, 0),
  [348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_float_value, 1, 0, 0),
  [350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__imperative_block_statement, 1, 0, 0),
  [352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(263),
  [354] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__imperative_block_statement, 1, 0, 0),
  [356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(105),
  [362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(266),
  [370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(264),
  [376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [378] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0),
  [380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 10),
  [384] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 10),
  [386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 13),
  [388] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 13),
  [390] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 2, 0, 0),
  [392] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 2, 0, 0),
  [394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_access, 3, 0, 19),
  [396] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_access, 3, 0, 19),
  [398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__logic_binary_expression, 3, 0, 20),
  [400] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__logic_binary_expression, 3, 0, 20),
  [402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__add_binary_expression, 3, 0, 20),
  [404] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__add_binary_expression, 3, 0, 20),
  [406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__mult_binary_expression, 3, 0, 20),
  [408] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__mult_binary_expression, 3, 0, 20),
  [410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [412] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 3, 0, 0),
  [414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0),
  [416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 4, 0, 0),
  [418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__comparison_binary_expression, 3, 0, 20),
  [420] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__comparison_binary_expression, 3, 0, 20),
  [422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 5, 0, 0),
  [424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 5, 0, 0),
  [426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ternary_expression, 5, 0, 49),
  [428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ternary_expression, 5, 0, 49),
  [430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_identifier, 1, 0, 0),
  [432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_simple_identifier, 1, 0, 0),
  [434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 10, 0, 80),
  [436] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 10, 0, 80),
  [438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_list, 4, 0, 0),
  [440] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_list, 4, 0, 0),
  [442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 4, 0, 32),
  [444] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 4, 0, 32),
  [446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_image_call, 4, 0, 33),
  [448] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_image_call, 4, 0, 33),
  [450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_op, 4, 0, 34),
  [452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_index_op, 4, 0, 34),
  [454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_value, 1, 0, 0),
  [456] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_value, 1, 0, 0),
  [458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string, 2, 0, 0),
  [460] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string, 2, 0, 0),
  [462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_anon_struct_block, 5, 0, 0),
  [464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_anon_struct_block, 5, 0, 0),
  [466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_list, 5, 0, 0),
  [468] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_list, 5, 0, 0),
  [470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string, 3, 0, 0),
  [472] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string, 3, 0, 0),
  [474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_anon_struct_block, 6, 0, 0),
  [476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_anon_struct_block, 6, 0, 0),
  [478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 6, 0, 62),
  [480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 6, 0, 62),
  [482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 6, 0, 63),
  [484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 6, 0, 63),
  [486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_anon_struct_block, 7, 0, 0),
  [488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_anon_struct_block, 7, 0, 0),
  [490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 7, 0, 68),
  [492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 7, 0, 68),
  [494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 8, 0, 69),
  [496] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 8, 0, 69),
  [498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 8, 0, 70),
  [500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 8, 0, 70),
  [502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 8, 0, 71),
  [504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 8, 0, 71),
  [506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_image_call, 8, 0, 33),
  [508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_image_call, 8, 0, 33),
  [510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gradient_call, 8, 0, 72),
  [512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gradient_call, 8, 0, 72),
  [514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gradient_call, 8, 0, 73),
  [516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gradient_call, 8, 0, 73),
  [518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 9, 0, 74),
  [520] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 9, 0, 74),
  [522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_image_call, 9, 0, 33),
  [524] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_image_call, 9, 0, 33),
  [526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gradient_call, 9, 0, 75),
  [528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gradient_call, 9, 0, 75),
  [530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gradient_call, 9, 0, 76),
  [532] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gradient_call, 9, 0, 76),
  [534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gradient_call, 9, 0, 77),
  [536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gradient_call, 9, 0, 77),
  [538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gradient_call, 9, 0, 78),
  [540] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gradient_call, 9, 0, 78),
  [542] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 10, 0, 79),
  [544] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 10, 0, 79),
  [546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 10, 0, 81),
  [548] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 10, 0, 81),
  [550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gradient_call, 10, 0, 82),
  [552] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gradient_call, 10, 0, 82),
  [554] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gradient_call, 10, 0, 83),
  [556] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gradient_call, 10, 0, 83),
  [558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 11, 0, 84),
  [560] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 11, 0, 84),
  [562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 12, 0, 85),
  [564] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 12, 0, 85),
  [566] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 12, 0, 86),
  [568] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 12, 0, 86),
  [570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 14, 0, 88),
  [572] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 14, 0, 88),
  [574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_easing_kind_identifier, 1, 0, 0),
  [576] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_easing_kind_identifier, 1, 0, 0),
  [578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reference_identifier, 1, 0, 0),
  [580] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_reference_identifier, 1, 0, 0),
  [582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bool_value, 1, 0, 0),
  [584] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bool_value, 1, 0, 0),
  [586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value, 1, 0, 0),
  [588] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value, 1, 0, 0),
  [590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 1, 0, 8),
  [592] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 1, 0, 8),
  [594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_anon_struct_block, 2, 0, 0),
  [600] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_anon_struct_block, 2, 0, 0),
  [602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [604] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_list, 2, 0, 0),
  [606] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_list, 2, 0, 0),
  [608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_easing_kind_identifier, 2, 0, 0),
  [610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_easing_kind_identifier, 2, 0, 0),
  [612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_physical_length_value, 2, 0, 0),
  [614] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_physical_length_value, 2, 0, 0),
  [616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_length_value, 2, 0, 0),
  [618] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_length_value, 2, 0, 0),
  [620] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_duration_value, 2, 0, 0),
  [622] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_duration_value, 2, 0, 0),
  [624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_angle_value, 2, 0, 0),
  [626] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_angle_value, 2, 0, 0),
  [628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_percent_value, 2, 0, 0),
  [630] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_percent_value, 2, 0, 0),
  [632] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relative_font_size_value, 2, 0, 0),
  [634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_relative_font_size_value, 2, 0, 0),
  [636] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_anon_struct_block, 3, 0, 0),
  [638] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_anon_struct_block, 3, 0, 0),
  [640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_list, 3, 0, 0),
  [642] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_list, 3, 0, 0),
  [644] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parens_op, 3, 0, 18),
  [646] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parens_op, 3, 0, 18),
  [648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tr, 13, 0, 87),
  [650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tr, 13, 0, 87),
  [652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expr, 2, 0, 42),
  [654] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expr, 2, 0, 42),
  [656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_imperative_block, 2, 0, 0),
  [662] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_imperative_block, 2, 0, 0),
  [664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_in_out_transition, 3, 0, 0),
  [666] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_in_out_transition, 3, 0, 0),
  [668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 0),
  [670] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2, 0, 0),
  [672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expr, 3, 0, 24),
  [674] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_expr, 3, 0, 24),
  [676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(648),
  [678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_imperative_block, 3, 0, 0),
  [680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_imperative_block, 3, 0, 0),
  [682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__assignment_value_block, 2, 0, 55),
  [684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__assignment_value_block, 2, 0, 55),
  [686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 0),
  [688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 0),
  [690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_block, 3, 0, 41),
  [692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_block, 3, 0, 41),
  [694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expr, 5, 0, 24),
  [696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_expr, 5, 0, 24),
  [698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__assignment_value_block, 1, 0, 4),
  [700] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__assignment_value_block, 1, 0, 4), SHIFT(248),
  [703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__assignment_value_block, 1, 0, 4),
  [705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_block, 2, 0, 41),
  [707] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_assignment_block, 2, 0, 41), SHIFT(239),
  [710] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_block, 2, 0, 41),
  [712] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__assignment_value_block, 1, 0, 4), SHIFT(237),
  [715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binding, 1, 0, 35),
  [719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binding, 1, 0, 35),
  [723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binding, 2, 0, 50),
  [725] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binding, 2, 0, 50),
  [727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_states_definition_repeat1, 2, 0, 0),
  [729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binding, 3, 0, 56),
  [731] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binding, 3, 0, 56),
  [733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_callback_event, 3, 0, 14),
  [735] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_callback_event, 3, 0, 14),
  [737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_in_out_transition, 5, 0, 0),
  [739] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_in_out_transition, 5, 0, 0),
  [741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_in_out_transition, 4, 0, 0),
  [743] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_in_out_transition, 4, 0, 0),
  [745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_in_out_transition, 6, 0, 0),
  [747] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_in_out_transition, 6, 0, 0),
  [749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__imperative_block_statement, 3, 0, 0),
  [751] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__imperative_block_statement, 3, 0, 0),
  [753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__imperative_block_statement, 2, 0, 0),
  [755] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__imperative_block_statement, 2, 0, 0),
  [757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mult_prec_operator, 1, 0, 0),
  [759] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_mult_prec_operator, 1, 0, 0),
  [761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_prec_operator, 1, 0, 0),
  [763] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_prec_operator, 1, 0, 0),
  [765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comparison_operator, 1, 0, 0),
  [767] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comparison_operator, 1, 0, 0),
  [769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_prec_operator, 1, 0, 0),
  [771] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_prec_operator, 1, 0, 0),
  [773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__assignment_setup, 2, 0, 43),
  [775] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__assignment_setup, 2, 0, 43),
  [777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_add_prec_operator, 1, 0, 0),
  [779] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_add_prec_operator, 1, 0, 0),
  [781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(649),
  [787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(804),
  [789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(841),
  [791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(849),
  [793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(100),
  [795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(102),
  [797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(730),
  [799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(821),
  [801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(617),
  [803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(638),
  [805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(595),
  [807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(755),
  [809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(765),
  [811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(601),
  [813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [831] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(649),
  [834] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(804),
  [837] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(841),
  [840] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(849),
  [843] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(100),
  [846] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(102),
  [849] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(730),
  [852] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(821),
  [855] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(617),
  [858] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(638),
  [861] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(595),
  [864] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(755),
  [867] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(765),
  [870] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(601),
  [873] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(272),
  [876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(580),
  [908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(762),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(651),
  [922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(798),
  [924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(810),
  [926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [928] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_global_block_repeat1, 2, 0, 0),
  [930] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_block_repeat1, 2, 0, 0), SHIFT_REPEAT(651),
  [933] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_block_repeat1, 2, 0, 0), SHIFT_REPEAT(804),
  [936] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_block_repeat1, 2, 0, 0), SHIFT_REPEAT(798),
  [939] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_block_repeat1, 2, 0, 0), SHIFT_REPEAT(617),
  [942] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_block_repeat1, 2, 0, 0), SHIFT_REPEAT(638),
  [945] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_block_repeat1, 2, 0, 0), SHIFT_REPEAT(595),
  [948] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_block_repeat1, 2, 0, 0), SHIFT_REPEAT(810),
  [951] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_block_repeat1, 2, 0, 0), SHIFT_REPEAT(279),
  [954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(112),
  [956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument, 1, 0, 0),
  [958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [964] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument, 1, 0, 0),
  [966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [1000] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tr_repeat1, 2, 0, 0),
  [1002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [1004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [1006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [1008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [1010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [1014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [1018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [1020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [1022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [1024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_anon_struct_block_repeat1, 4, 0, 0),
  [1026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [1028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [1030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [1032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [1034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [1038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [1040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [1042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [1044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [1046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [1048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [1050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [1052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [1054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [1056] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_range, 1, 0, 0),
  [1058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [1060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [1062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [1064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [1066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [1068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [1070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [1076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [1078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [1080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [1084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_assignment, 3, 0, 15),
  [1086] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_assignment, 3, 0, 15),
  [1088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [1092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [1094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [1096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [1100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [1102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [1104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [1106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [1108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [1110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_callback, 5, 0, 40),
  [1112] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_callback, 5, 0, 40),
  [1114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binding_alias, 5, 0, 46),
  [1116] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binding_alias, 5, 0, 46),
  [1118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component, 4, 0, 28),
  [1120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_component, 4, 0, 28),
  [1122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_states_definition, 3, 0, 0),
  [1124] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_states_definition, 3, 0, 0),
  [1126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_animate_statement, 3, 0, 0),
  [1128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_animate_statement, 3, 0, 0),
  [1130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_assignment, 4, 0, 29),
  [1132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_assignment, 4, 0, 29),
  [1134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 4, 0, 22),
  [1136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 4, 0, 22),
  [1138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binding_alias, 4, 0, 30),
  [1140] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binding_alias, 4, 0, 30),
  [1142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_callback, 6, 0, 54),
  [1144] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_callback, 6, 0, 54),
  [1146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_transitions_definition, 4, 0, 0),
  [1148] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_transitions_definition, 4, 0, 0),
  [1150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_states_definition, 4, 0, 23),
  [1152] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_states_definition, 4, 0, 23),
  [1154] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_callback, 3, 0, 3),
  [1156] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_callback, 3, 0, 3),
  [1158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_animate_body, 2, 0, 0),
  [1160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_animate_body, 2, 0, 0),
  [1162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 24),
  [1164] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 24),
  [1166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 27),
  [1168] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 27),
  [1170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 54),
  [1172] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 54),
  [1174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_loop, 6, 0, 52),
  [1176] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_loop, 6, 0, 52),
  [1178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 3),
  [1180] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 3, 0, 3),
  [1182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_callback, 5, 0, 44),
  [1184] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_callback, 5, 0, 44),
  [1186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 44),
  [1188] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 44),
  [1190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 6, 0, 51),
  [1192] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 6, 0, 51),
  [1194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_transitions_definition, 3, 0, 0),
  [1196] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_transitions_definition, 3, 0, 0),
  [1198] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 5, 0, 36),
  [1200] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 5, 0, 36),
  [1202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_callback_alias, 6, 0, 58),
  [1204] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_callback_alias, 6, 0, 58),
  [1206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_callback, 6, 0, 59),
  [1208] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_callback, 6, 0, 59),
  [1210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binding_alias, 5, 0, 37),
  [1212] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binding_alias, 5, 0, 37),
  [1214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 6, 0, 60),
  [1216] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 6, 0, 60),
  [1218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binding_alias, 6, 0, 61),
  [1220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binding_alias, 6, 0, 61),
  [1222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_animate_body, 3, 0, 0),
  [1224] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_animate_body, 3, 0, 0),
  [1226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component, 2, 0, 11),
  [1228] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_component, 2, 0, 11),
  [1230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_callback_alias, 5, 0, 37),
  [1232] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_callback_alias, 5, 0, 37),
  [1234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_callback, 7, 0, 66),
  [1236] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_callback, 7, 0, 66),
  [1238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 7, 0, 67),
  [1240] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 7, 0, 67),
  [1242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 66),
  [1244] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 66),
  [1246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 5, 0, 45),
  [1248] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 5, 0, 45),
  [1250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 59),
  [1252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 59),
  [1254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 40),
  [1256] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 40),
  [1258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_sourcefile_repeat1, 2, 0, 0),
  [1260] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sourcefile_repeat1, 2, 0, 0), SHIFT_REPEAT(511),
  [1263] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sourcefile_repeat1, 2, 0, 0), SHIFT_REPEAT(627),
  [1266] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sourcefile_repeat1, 2, 0, 0), SHIFT_REPEAT(814),
  [1269] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sourcefile_repeat1, 2, 0, 0), SHIFT_REPEAT(768),
  [1272] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sourcefile_repeat1, 2, 0, 0), SHIFT_REPEAT(794),
  [1275] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sourcefile_repeat1, 2, 0, 0), SHIFT_REPEAT(799),
  [1278] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sourcefile_repeat1, 2, 0, 0), SHIFT_REPEAT(549),
  [1281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sourcefile, 1, 0, 0),
  [1283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 25),
  [1285] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 25),
  [1287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_changed_callback, 4, 0, 26),
  [1289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_changed_callback, 4, 0, 26),
  [1291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_callback, 4, 0, 27),
  [1293] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_callback, 4, 0, 27),
  [1295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_callback, 4, 0, 25),
  [1297] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_callback, 4, 0, 25),
  [1299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exported_type, 1, 0, 0),
  [1301] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__exported_type, 1, 0, 0),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_block, 2, 0, 0),
  [1307] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_block, 2, 0, 0),
  [1309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_block, 5, 0, 31),
  [1311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_block, 5, 0, 31),
  [1313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_block, 6, 0, 47),
  [1315] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_block, 6, 0, 47),
  [1317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_block, 7, 0, 47),
  [1319] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_block, 7, 0, 47),
  [1321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_block, 6, 0, 31),
  [1323] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_block, 6, 0, 31),
  [1325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_block, 3, 0, 0),
  [1327] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_block, 3, 0, 0),
  [1329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_type_identifier, 1, 0, 0),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [1337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [1339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [1341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_animate_body_repeat1, 2, 0, 0),
  [1343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_animate_body_repeat1, 2, 0, 0), SHIFT_REPEAT(915),
  [1346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 7, 0, 0),
  [1348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 7, 0, 0),
  [1350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_block, 3, 0, 0),
  [1352] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_block, 3, 0, 0),
  [1354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 6, 0, 0),
  [1356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 6, 0, 0),
  [1358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_block, 2, 0, 0),
  [1360] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_block, 2, 0, 0),
  [1362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_definition, 4, 0, 3),
  [1364] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_definition, 4, 0, 3),
  [1366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 3, 0, 0),
  [1368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 3, 0, 0),
  [1370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component_definition, 3, 0, 3),
  [1372] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_component_definition, 3, 0, 3),
  [1374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_definition, 4, 0, 3),
  [1376] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_definition, 4, 0, 3),
  [1378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_definition, 3, 0, 3),
  [1380] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_definition, 3, 0, 3),
  [1382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_block, 2, 0, 0),
  [1384] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_block, 2, 0, 0),
  [1386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_block, 4, 0, 16),
  [1388] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_block, 4, 0, 16),
  [1390] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 3, 0, 3),
  [1392] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_definition, 3, 0, 3),
  [1394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exported_type, 4, 0, 0),
  [1396] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__exported_type, 4, 0, 0),
  [1398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component_definition, 4, 0, 5),
  [1400] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_component_definition, 4, 0, 5),
  [1402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_block, 5, 0, 16),
  [1404] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_block, 5, 0, 16),
  [1406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 8, 0, 0),
  [1408] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_statement, 8, 0, 0),
  [1410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component_definition, 5, 0, 12),
  [1412] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_component_definition, 5, 0, 12),
  [1414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exported_type, 5, 0, 0),
  [1416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__exported_type, 5, 0, 0),
  [1418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_block, 3, 0, 0),
  [1420] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_block, 3, 0, 0),
  [1422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_block, 4, 0, 3),
  [1424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_block, 4, 0, 3),
  [1426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_block, 3, 0, 3),
  [1428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_block, 3, 0, 3),
  [1430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exported_type, 2, 0, 0),
  [1432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__exported_type, 2, 0, 0),
  [1434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exported_type, 3, 0, 0),
  [1436] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__exported_type, 3, 0, 0),
  [1438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_builtin_type_identifier, 1, 0, 0),
  [1440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_definition, 3, 0, 3),
  [1442] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_definition, 3, 0, 3),
  [1444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [1446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(129),
  [1448] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(617),
  [1451] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(638),
  [1454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [1456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [1458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [1460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [1462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [1464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [1466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [1468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(73),
  [1470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [1472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [1474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_list, 5, 0, 0),
  [1476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [1478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1, 0, 0),
  [1480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [1482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [1484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [1486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [1488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [1490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [1492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_animate_option, 4, 0, 64),
  [1494] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_visibility, 1, 0, 0),
  [1496] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_visibility, 1, 0, 4),
  [1498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_list, 3, 0, 0),
  [1500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gradient_color, 1, 0, 0),
  [1502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(905),
  [1504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [1506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_list, 4, 0, 0),
  [1508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_list, 2, 0, 0),
  [1510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(57),
  [1512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [1514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [1516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [1518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [1522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [1524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [1526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [1528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(611),
  [1530] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [1532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [1534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [1536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [1538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(283),
  [1540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(173),
  [1542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [1544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(287),
  [1546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [1548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_transitions_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(97),
  [1551] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_transitions_definition_repeat1, 2, 0, 0),
  [1553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [1555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [1557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [1559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [1561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [1563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [1565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [1567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [1569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [1571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 1, 0, 0),
  [1573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [1575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [1577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [1579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [1581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [1585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [1587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_purity, 1, 0, 4),
  [1589] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__string_repeat1, 2, 0, 0),
  [1591] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__string_repeat1, 2, 0, 0), SHIFT_REPEAT(618),
  [1594] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string_repeat1, 2, 0, 0), SHIFT_REPEAT(611),
  [1597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [1599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [1601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [1603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [1605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [1607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [1609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [1615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [1617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [1619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [1621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [1623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [1625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [1627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [1629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [1631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [1633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [1635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_in_out_transition_repeat1, 2, 0, 0),
  [1637] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_in_out_transition_repeat1, 2, 0, 0), SHIFT_REPEAT(129),
  [1640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [1642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [1644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [1648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [1650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [1656] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tr_repeat1, 2, 0, 0), SHIFT_REPEAT(82),
  [1659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [1661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_visibility, 1, 0, 4),
  [1663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [1665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [1667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [1669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [1671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [1673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [1675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [1677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [1679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [1681] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_list_repeat1, 2, 0, 0), SHIFT_REPEAT(376),
  [1684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_list_repeat1, 2, 0, 0),
  [1686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [1688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [1690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [1692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat2, 2, 0, 17),
  [1694] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat2, 2, 0, 17), SHIFT_REPEAT(279),
  [1697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [1699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [1701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [1703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [1705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [1707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [1709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [1711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [1713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [1715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [1717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [1719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [1721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [1723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [1725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [1727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [1729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [1731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [1737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [1741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [1743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [1745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [1747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [1749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [1751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [1753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [1755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [1757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [1759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [1761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [1763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [1765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [1767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [1769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(64),
  [1772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0),
  [1774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [1776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [1778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [1780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [1782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [1784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_anon_struct_block_repeat1, 2, 0, 0), SHIFT_REPEAT(767),
  [1787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_anon_struct_block_repeat1, 2, 0, 0),
  [1789] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_signature_repeat1, 2, 0, 0), SHIFT_REPEAT(737),
  [1792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_signature_repeat1, 2, 0, 0),
  [1794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [1796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [1798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [1800] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__exported_type_repeat1, 2, 0, 0), SHIFT_REPEAT(431),
  [1803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__exported_type_repeat1, 2, 0, 0),
  [1805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [1807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_type, 1, 0, 2),
  [1809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [1811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [1813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [1815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [1817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [1819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [1821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [1823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_import_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(695),
  [1826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_import_statement_repeat1, 2, 0, 0),
  [1828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [1830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [1832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [1834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [1836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [1838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [1840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [1842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [1844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [1846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [1848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [1850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [1852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [1854] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_type, 1, 0, 1),
  [1856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [1858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [1860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [1862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [1864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [1866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [1868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [1870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [1872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [1874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [1876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [1878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [1880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [1882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [1884] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_block_repeat1, 2, 0, 48), SHIFT_REPEAT(826),
  [1887] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_block_repeat1, 2, 0, 48),
  [1889] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_escape_sequence, 2, 0, 0),
  [1891] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_escape_sequence, 2, 0, 0),
  [1893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [1895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [1897] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_escape_sequence, 4, 0, 0),
  [1899] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_escape_sequence, 4, 0, 0),
  [1901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [1903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [1905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [1907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [1909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [1911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [1913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [1915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [1917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [1919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [1921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [1923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [1925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [1929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(643),
  [1931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [1933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [1935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [1937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [1941] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_block_repeat1, 2, 0, 17), SHIFT_REPEAT(806),
  [1944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_block_repeat1, 2, 0, 17),
  [1946] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_image_call_repeat1, 2, 0, 0),
  [1948] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_image_call_repeat1, 2, 0, 0), SHIFT_REPEAT(745),
  [1951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(653),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [1955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [1957] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gradient_call_repeat1, 2, 0, 0), SHIFT_REPEAT(31),
  [1960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gradient_call_repeat1, 2, 0, 0),
  [1962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [1964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat2, 6, 0, 9),
  [1966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__callback_signature, 5, 0, 65),
  [1968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [1970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [1972] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_signature, 5, 0, 65),
  [1974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_type, 3, 0, 7),
  [1976] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__callback_signature, 2, 0, 0),
  [1978] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_block_repeat1, 4, 0, 31),
  [1980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [1982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [1984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_signature, 3, 0, 39),
  [1986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [1988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [1990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [1992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [1994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [1996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_signature, 2, 0, 0),
  [1998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [2000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [2002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [2004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat2, 7, 0, 9),
  [2006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [2008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [2010] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_block_repeat1, 2, 0, 3),
  [2012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [2014] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_states_definition_repeat2, 8, 0, 9),
  [2016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__callback_signature, 4, 0, 53),
  [2018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [2020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [2022] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_signature, 4, 0, 53),
  [2024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_indexed_identifier, 1, 0, 9),
  [2026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [2028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_identifier, 3, 0, 57),
  [2030] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_type, 3, 0, 6),
  [2032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__callback_signature, 3, 0, 39),
  [2034] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gradient_color, 2, 0, 0),
  [2036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [2038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [2040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [2042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [2044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [2046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [2048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [2050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [2052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [2054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [2056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [2058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [2060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [2062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [2064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [2066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [2068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [2070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [2072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [2074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [2076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [2078] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [2082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [2084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [2086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [2088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [2090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [2092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [2094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [2096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [2098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [2100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [2102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_radial_gradient_kind, 1, 0, 0),
  [2104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [2106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [2108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [2110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [2112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__property_type, 3, 0, 21),
  [2114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [2116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [2118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [2120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [2122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [2124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [2126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [2128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [2130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [2132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [2134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_linear_gradient_identifier, 1, 0, 0),
  [2136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_indexed_identifier, 4, 0, 38),
  [2138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [2140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [2142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [2144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [2146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [2148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [2150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [2152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [2154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [2156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [2158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [2160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [2162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [2164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [2166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [2168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_radial_gradient_identifier, 1, 0, 0),
  [2170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [2172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [2174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [2176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_animate_option_identifier, 1, 0, 0),
  [2178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [2180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [2182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [2184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [2186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [2188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [2190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [2192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_slint(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
